@@ -9,11 +9,13 @@ for i in `cd /home/groups ; ls | grep -v lost+found | grep -v quota.group | grep
 		chmod 0774 /home/groups/$i/log
 	fi
 
-	if [ ! -d /home/groups/$i/cgi-bin ] ; then
-		mkdir /home/groups/$i/cgi-bin
-		chown dummy:$i /home/groups/$i/cgi-bin
-		chmod 0774 /home/groups/$i/cgi-bin
-	fi
+# disabled for CVE-2014-6275
+# Only enable it if you know what you are doing, by default all scripts run as Apache
+#	if [ ! -d /home/groups/$i/cgi-bin ] ; then
+#		mkdir /home/groups/$i/cgi-bin
+#		chown dummy:$i /home/groups/$i/cgi-bin
+#		chmod 0774 /home/groups/$i/cgi-bin
+#	fi
 
 	if [ ! -d /home/groups/$i/htdocs ] ; then
 		mkdir /home/groups/$i/htdocs
