@@ -6,6 +6,8 @@
  * Copyright 2002-2003, Tim Perdue/GForge, LLC
  * Copyright 2009, Roland Mas
  * Copyright 2010, Franck Villaume - Capgemini
+ * Copyright 2012-2013, Franck Villaume - TrivialDev
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -49,28 +51,27 @@ class DocumentGroupFactory extends Error {
 	/**
 	 * Constructor.
 	 *
-	 * @return	boolean	success.
+	 * @param	$Group
+	 * @return	\DocumentGroupFactory
 	 */
-	function DocumentGroupFactory(&$Group) {
+	function __construct(&$Group) {
 		$this->Error();
 
 		if (!$Group || !is_object($Group)) {
-			$this->setError(_('DocumentGroupFactory:: Invalid Project'));
-			return false;
+			$this->setError(_('No Valid Group Object'));
+			return;
 		}
 		if ($Group->isError()) {
 			$this->setError('DocumentGroupFactory::'.' '.$Group->getErrorMessage());
-			return false;
+			return;
 		}
 		$this->Group =& $Group;
-
-		return true;
 	}
 
 	/**
 	 * getNested - Return an array of DocumentGroup objects arranged for nested views.
 	 *
-	 * @param	int	The stateid of DocumentGroup.
+	 * @param	int	$stateid	The stateid of DocumentGroup : default is public (1).
 	 * @return	array	The array of DocumentGroup.
 	 */
 	function &getNested($stateid = 1) {
@@ -80,10 +81,9 @@ class DocumentGroupFactory extends Error {
 
 		$result = db_query_params('SELECT * FROM doc_groups WHERE group_id=$1 AND stateid=$2 ORDER BY groupname ASC',
 						array($this->Group->getID(), $stateid));
-		$rows = db_numrows($result);
 
 		if (!$result) {
-			$this->setError(_('No Document Directory Found').' '.db_error());
+			$this->setError(_('No Documents Folder Found').' '.db_error());
 			return false;
 		} else {
 			while ($arr = db_fetch_array($result)) {
@@ -96,14 +96,13 @@ class DocumentGroupFactory extends Error {
 		for ($i=0; $i < $count; $i++) {
 			$this->nested_groups["".$this->flat_groups[$i]->getParentID()][] =& $this->flat_groups[$i];
 		}
-
 		return $this->nested_groups;
 	}
 
 	/**
 	 * getDocumentGroups - Return an array of DocumentGroup objects.
 	 *
-	 * @param	int	The stateid of DocumentGroups
+	 * @param	int	$stateid	The stateid of DocumentGroups : default is public (1).
 	 * @return	array	The array of DocumentGroup.
 	 */
 	function &getDocumentGroups($stateid = 1) {
@@ -111,14 +110,14 @@ class DocumentGroupFactory extends Error {
 			return $this->flat_groups;
 		}
 
-		$this->flat_groups = array () ;
+		$this->flat_groups = array();
 
 		$result = db_query_params('SELECT * FROM doc_groups WHERE group_id=$1 AND stateid=$2 ORDER BY groupname ASC',
 						array($this->Group->getID(), $stateid));
 		$rows = db_numrows($result);
 
 		if (!$result || $rows < 1) {
-			$this->setError(_('No Document Directory Found').' '.db_error());
+			$this->setError(_('No Documents Folder Found').' '.db_error());
 		} else {
 			while ($arr = db_fetch_array($result)) {
 				$this->flat_groups[] = new DocumentGroup($this->Group, $arr);
@@ -133,5 +132,3 @@ class DocumentGroupFactory extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
