@@ -2,7 +2,7 @@
 /**
  * FusionForge Documentation Manager
  *
- * Copyright 2010, Franck Villaume - Capgemini
+ * Copyright 2010-2011, Franck Villaume - Capgemini
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -28,20 +28,21 @@ global $dirid; //id of doc_group
 global $group_id; // id of group
 
 if (!forge_check_perm('docman', $group_id, 'admin')) {
-	$return_msg = _('Docman Action Denied.');
+	$return_msg = _('Document Manager Action Denied.');
 	session_redirect('/docman/?group_id='.$group_id.'&view=listfile&dirid='.$dirid.'&warning_msg='.urlencode($return_msg));
-} else {
+}
 
-	$fileid = getIntFromRequest('fileid');
+$arr_fileid = explode(',',getStringFromRequest('fileid'));
+$return_msg = _('Document(s)').' ';
+foreach ($arr_fileid as $fileid) {
 	$d = new Document($g, $fileid);
-
+	$return_msg .= $d->getFilename().' ';
 	if ($d->isError())
 		session_redirect('/docman/?group_id='.$group_id.'&view=listfile&dirid='.$dirid.'&error_msg='.urlencode($d->getErrorMessage()));
 
 	if (!$d->setReservedBy('0'))
 		session_redirect('/docman/?group_id='.$group_id.'&view=listfile&dirid='.$dirid.'&error_msg='.urlencode($d->getErrorMessage()));
 
-	$return_msg = _('Document reservation enforced successfully.');
-	session_redirect('/docman/?group_id='.$group_id.'&view=listfile&dirid='.$dirid.'&feedback='.urlencode($return_msg));
 }
-?>
+$return_msg .= _('reservation enforced successfully.');
+session_redirect('/docman/?group_id='.$group_id.'&view=listfile&dirid='.$dirid.'&feedback='.urlencode($return_msg));
