@@ -2,7 +2,7 @@
 /**
  * FusionForge Documentation Manager
  *
- * Copyright 2010, Franck Villaume - Capgemini
+ * Copyright 2010-2011, Franck Villaume - Capgemini
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -26,18 +26,17 @@
 global $g; //group object
 global $group_id; // id of group
 
-if ( !forge_check_perm('docman', $group_id, 'approve')) {
-	$return_msg = _('Docman Action Denied');
+if ( !forge_check_perm('docman', $group_id, 'admin')) {
+	$return_msg = _('Document Manager Action Denied.');
 	session_redirect('/docman/?group_id='.$group_id.'&warning_msg='.urlencode($return_msg));
-} else {
-	if ($_POST['status']) {
-		$status = 1;
-		$return_msg = _('Search Engine Reindex Forced : search results will be available within 24h.');
-	}
-
-	if (!$g->setDocmanForceReindexSearch($status))
-		session_redirect('/docman/?group_id='.$group_id.'&view=admin&error_msg='.urlencode($g->getErrorMessage()));
-
-	session_redirect('/docman/?group_id='.$group_id.'&view=admin&feedback='.urlencode($return_msg));
 }
-?>
+
+if ($_POST['status']) {
+	$status = 1;
+	$return_msg = _('Search Engine Reindex Forced: search results will be available within 24 h.');
+}
+
+if (!$g->setDocmanForceReindexSearch($status))
+	session_redirect('/docman/?group_id='.$group_id.'&view=admin&error_msg='.urlencode($g->getErrorMessage()));
+
+session_redirect('/docman/?group_id='.$group_id.'&view=admin&feedback='.urlencode($return_msg));
