@@ -2,7 +2,9 @@
 /**
  * FusionForge Documentation Manager
  *
- * Copyright 2010, Franck Villaume - Capgemini
+ * Copyright 2010-2011, Franck Villaume - Capgemini
+ * Copyright 2013, Franck Villaume - TrivialDev
+ * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -28,20 +30,21 @@ global $group_id; // id of group
 global $LUSER; // User object
 
 if (!forge_check_perm('docman', $group_id, 'approve')) {
-	$return_msg = _('Docman Action Denied.');
+	$return_msg = _('Document Manager Action Denied.');
 	session_redirect('/docman/?group_id='.$group_id.'&view=listfile&dirid='.$dirid.'&warning_msg='.urlencode($return_msg));
-} else {
+}
 
-	$fileid = getIntFromRequest('fileid');
+$arr_fileid = explode(',', getStringFromRequest('fileid'));
+$return_msg = _('Document(s)').' ';
+foreach ($arr_fileid as $fileid) {
 	$d = new Document($g, $fileid);
-
+	$return_msg .= $d->getFilename().' ';
 	if ($d->isError())
 		session_redirect('/docman/?group_id='.$group_id.'&view=listfile&dirid='.$dirid.'&error_msg='.urlencode($d->getErrorMessage()));
 
 	if (!$d->setReservedBy('1', $LUSER->getID()))
 		session_redirect('/docman/?group_id='.$group_id.'&view=listfile&dirid='.$dirid.'&error_msg='.urlencode($d->getErrorMessage()));
 
-	$return_msg = _('Document reserved successfully.');
-	session_redirect('/docman/?group_id='.$group_id.'&view=listfile&dirid='.$dirid.'&feedback='.urlencode($return_msg));
 }
-?>
+$return_msg .= _('reserved successfully.');
+session_redirect('/docman/?group_id='.$group_id.'&view=listfile&dirid='.$dirid.'&feedback='.urlencode($return_msg));
