@@ -2,7 +2,7 @@
 /**
  * FusionForge Documentation Manager
  *
- * Copyright 2010, Franck Villaume - Capgemini
+ * Copyright 2010-2011, Franck Villaume - Capgemini
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -21,24 +21,22 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-/* please do not add require here : use www/docman/index.php to add require */
+/* please do not add require here: use www/docman/index.php to add require */
 
-if (!forge_check_perm('docman', $group_id, 'approve')) {
-	$return_msg= _('Docman Action Denied.');
+if (!forge_check_perm('docman', $group_id, 'admin')) {
+	$return_msg= _('Document Manager Action Denied.');
 	session_redirect('/docman/?group_id='.$group_id.'&warning_msg='.urlencode($return_msg));
-} else {
-
-	if ($_POST['status']) {
-		$status = 1;
-		$return_msg = _('Search Engine Status updated successfully : Active.');
-	} else {
-		$status = 0;
-		$return_msg = _('Search Engine Status updated successfully : Off.');
-	}
-
-	if (!$g->setDocmanSearchStatus($status))
-		session_redirect('/docman/?group_id='.$group_id.'&view=admin&warning_msg='.urlencode($g->getErrorMessage()));
-
-	session_redirect('/docman/?group_id='.$group_id.'&view=admin&feedback='.urlencode($return_msg));
 }
-?>
+
+if ($_POST['status']) {
+	$status = 1;
+	$return_msg = _('Search Engine Status updated successfully: Active.');
+} else {
+	$status = 0;
+	$return_msg = _('Search Engine Status updated successfully: Off.');
+}
+
+if (!$g->setDocmanSearchStatus($status))
+	session_redirect('/docman/?group_id='.$group_id.'&view=admin&warning_msg='.urlencode($g->getErrorMessage()));
+
+session_redirect('/docman/?group_id='.$group_id.'&view=admin&feedback='.urlencode($return_msg));
