@@ -5,6 +5,7 @@
  *
  * Copyright 2005, Fabio Bertagnin
  * Copyright 2009-2011, Franck Villaume - Capgemini
+ * Copyright 2012, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -28,20 +29,17 @@ require dirname(__FILE__).'/../../include/env.inc.php';
 require_once $gfcommon.'docman/engine/parser_text.inc.php';
 
 if ($argc != 2) {
-	echo "Usage : parser_text.php <filename>\n";
-	exit (1);
+	echo 'Usage : parser_text.php <filename>'."\n";
+	exit(1);
 }
 
 $fichin = $argv[1];
 if (!is_file($fichin))
-	exit (1);
+	exit(1);
 
 echo parser_text($fichin);
-unlink ($fichin);
 
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
