@@ -4,6 +4,8 @@
  *
  * Copyright 2002 GForge, LLC
  * Copyright 2010, Franck Villaume - Capgemini
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013-2014 Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -31,30 +33,34 @@ require_once $gfwww.'include/note.php';
 class DocumentGroupHTML extends Error {
 	var $Group;
 
-	function DocumentGroupHTML(&$Group) {
+	/**
+	 * Constructor.
+	 *
+	 * @param	$Group
+	 * @return	\DocumentGroupHTML
+	 */
+	function __construct(&$Group) {
 		$this->Error();
 
 		if (!$Group || !is_object($Group)) {
-			$this->setError(_('DocumentGroupHTML:: Invalid Project'));
-			return false;
+			$this->setError(_('No Valid Group Object'));
+			return;
 		}
 		if ($Group->isError()) {
-			$this->setError('DocumentGroupHTML:: '.$Group->getErrorMessage());
-			return false;
+			$this->setError(_('Error') . _(': ') . $Group->getErrorMessage());
+			return;
 		}
 		$this->Group =& $Group;
-
-		return true;
 	}
 
 	/**
 	 * showSelectNestedGroups - Display the tree of document groups inside a <select> tag
 	 *
-	 * @param	array	Array of groups.
-	 * @param	string	The name that will be assigned to the input
-	 * @param	bool	Allow selection of "None"
-	 * @param	int	The ID of the group that should be selected by default (if any)
-	 * @param	array	Array of IDs of groups that should not be displayed
+	 * @param	array	$group_arr	Array of groups.
+	 * @param	string	$select_name	The name that will be assigned to the input
+	 * @param	bool	$allow_none	Allow selection of "None"
+	 * @param	int	$selected_id	The ID of the group that should be selected by default (if any)
+	 * @param	array	$dont_display	Array of IDs of groups that should not be displayed
 	 * @return	string	html select box code
 	 */
 	function showSelectNestedGroups($group_arr, $select_name, $allow_none = true, $selected_id = 0, $dont_display = array()) {
@@ -65,24 +71,24 @@ class DocumentGroupHTML extends Error {
 		if ($allow_none) {
 			// First option to be displayed
 			$id_array[] = 0;
-			$text_array[] = "(None)";
+			$text_array[] = _('None');
 		}
 
 		// Recursively build the document group tree
 		$this->buildArrays($group_arr, $id_array, $text_array, $dont_display);
-		
+
 		echo html_build_select_box_from_arrays($id_array, $text_array, $select_name, $selected_id, false);
 	}
 
 	/**
 	 * buildArrays - Build the arrays to call html_build_select_box_from_arrays()
 	 *
-	 * @param	array	Array of groups.
-	 * @param	array	Reference to the array of ids that will be build
-	 * @param	array	Reference to the array of group names
-	 * @param	array	Array of IDs of groups that should not be displayed
-	 * @param	int	The ID of the parent whose childs are being showed (0 for root groups)
-	 * @param	int	The current level
+	 * @param	array	$group_arr	Array of groups.
+	 * @param	array	$id_array	Reference to the array of ids that will be build
+	 * @param	array	$text_array	Reference to the array of group names
+	 * @param	array	$dont_display	Array of IDs of groups that should not be displayed
+	 * @param	int	$parent		The ID of the parent whose childs are being showed (0 for root groups)
+	 * @param	int	$level		The current level
 	 */
 	function buildArrays($group_arr, &$id_array, &$text_array, &$dont_display, $parent = 0, $level = 0) {
 		if (!is_array($group_arr) || !array_key_exists("$parent", $group_arr)) return;
@@ -95,10 +101,10 @@ class DocumentGroupHTML extends Error {
 			if (in_array($doc_group->getID(), $dont_display)) continue;
 
 			$margin = str_repeat("--", $level);
-			
+
 			$id_array[] = $doc_group->getID();
 			$text_array[] = $margin.$doc_group->getName();
-			
+
 			// Show childs (if any)
 			$this->buildArrays($group_arr, $id_array, $text_array, $dont_display, $doc_group->getID(), $level+1);
 		}
@@ -109,5 +115,3 @@ class DocumentGroupHTML extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
