@@ -4,8 +4,9 @@
  *
  * Copyright 2000, Quentin Cregan/Sourceforge
  * Copyright 2002-2003, Tim Perdue/GForge, LLC
- * Copyright 2010, Franck Villaume - Capgemini
+ * Copyright 2010-2011, Franck Villaume - Capgemini
  * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -27,25 +28,38 @@
 /* please do not add require here : use www/docman/index.php to add require */
 /* global variables used */
 global $group_id; // id of the group
-global $dirid; //id of the doc_group
+global $dirid; // id of the doc_group
+
+if (!forge_check_perm('docman', $group_id, 'approve')) {
+	$return_msg= _('Document Manager Access Denied');
+	session_redirect('/docman/?group_id='.$group_id.'&warning_msg='.urlencode($return_msg));
+}
+
+// plugin projects-hierarchy
+$actionurl = '?group_id='.$group_id.'&amp;action=addsubdocgroup&amp;dirid='.$dirid;
+if (isset($childgroup_id) && $childgroup_id) {
+	$g = group_get_object($childgroup_id);
+	$actionurl .= '&amp;childgroup_id='.$childgroup_id;
+}
 
 ?>
-<script language="JavaScript" type="text/javascript">/* <![CDATA[ */
+<script type="text/javascript">//<![CDATA[
 function doItAddSubGroup() {
 	document.getElementById('addsubgroup').submit();
 	document.getElementById('submitaddsubgroup').disabled = true;
 }
-/* ]]> */</script>
+//]]></script>
 <?php
-echo '<div class="docmanDivIncluded" >';
-echo '<form id="addsubgroup" name="addsubgroup" method="post" action="?group_id='.$group_id.'&amp;action=addsubdocgroup&amp;dirid='.$dirid.'">';
+echo '<div class="docmanDivIncluded">';
+echo '<form id="addsubgroup" name="addsubgroup" method="post" action="'.$actionurl.'">';
 if ($dirid) {
-	echo _('Name of the document subfolder to create:'). ' ';
+	$folderMessage = _('Name of the document subfolder to create');
+	echo $folderMessage._(': ');
 } else {
-	echo _('Name of the document folder to create:'). ' ';
+	$folderMessage = _('Name of the document folder to create');
+	echo $folderMessage._(': ');
 }
-echo '<input type="text" name="groupname" size="40" maxlength="255" />';
+echo '<input required="required" type="text" name="groupname" size="40" maxlength="255" placeholder="'.$folderMessage.'" />';
 echo '<input id="submitaddsubgroup" type="button" value="'. _('Create') .'" onclick="javascript:doItAddSubGroup()" />';
 echo '</form>';
 echo '</div>';
-?>
