@@ -2,7 +2,8 @@
 /**
  * FusionForge Documentation Manager
  *
- * Copyright 2010, Franck Villaume - Capgemini
+ * Copyright 2010-2011, Franck Villaume - Capgemini
+ * Copyright 2012, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -20,16 +21,20 @@
  * with FusionForge; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
+if (!forge_check_perm('docman', $group_id, 'read')) {
+	$return_msg= _('Document Manager Access Denied');
+	session_redirect('/docman/?group_id='.$group_id.'&warning_msg='.urlencode($return_msg));
+}
 
-$view = getStringFromRequest('view');
+$view = getStringFromRequest('view', 'listfile');
 switch ($view) {
-	case 'addfile':
-	case 'addsubdocgroup':
+	case 'additem':
 	case 'admin':
 	case 'editdocgroup':
 	case 'editfile':
 	case 'listfile':
-	case 'trashdir':
+	case 'listtrashfile':
+	case 'reporting':
 	case 'search': {
 		include ($gfcommon.'docman/views/'.$view.'.php');
 		break;
@@ -38,4 +43,3 @@ switch ($view) {
 		include ($gfcommon.'docman/views/help.php');
 	}
 }
-?>
