@@ -6,7 +6,7 @@
  * Copyright 2002-2004 (c) GForge Team
  * Copyright 2005 (c) Daniel Perez
  * Copyright 2010 (c) Franck Villaume - Capgemini
- * Copyright (C) 2010 Alain Peyrat - Alcatel-Lucent
+ * Copyright (C) 2010-2012 Alain Peyrat - Alcatel-Lucent
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -28,30 +28,37 @@
 class ForumAdmin extends Error {
 	var $group_id;
 	var $p,$g;
-	
-	function ForumAdmin($group_id) {
-		$this->group_id = $group_id; 
+
+	function __construct($group_id) {
+		$this->Error();
+		$this->group_id = $group_id;
 		if ($group_id) {
 			$this->group_id = $group_id;
 			$this->g = group_get_object($group_id);
-			$this->p =& $this->g->getPermission ();
+			$this->p =& $this->g->getPermission();
+			if (!$this->g->usesForum()) {
+				$this->setError(sprintf(_('%s does not use the Forum tool.'),
+				    $this->g->getPublicName()));
+				return;
+			}
 		}
 	}
-	
+
 	/**
 	 *  PrintAdminMessageOptions - prints the different administrator options for a message
 	 *
-	 *	@param   integer	The Message ID
-	 *	@param   integer	The Project ID
-	 *	@param   integer	The Thread ID : to return to the message if the user cancels (forumhtml only, not message.php)
-	 *	@param   integer	The Forum ID : to return to the message if the user cancels (forumhtml only, not message.php)
-	 *	@return  The HTML output
+	 *	@param   int	$msg_id		The Message ID
+	 *	@param   int	$group_id	The Project ID
+	 *	@param   int	$thread_id	The Thread ID : to return to the message if the user cancels (forumhtml only, not message.php)
+	 *	@param   int	$forum_id	The Forum ID : to return to the message if the user cancels (forumhtml only, not message.php)
+	 *	@param	 int	$return_to_message
+	 *	@return  string	The HTML output
 	 */
-	
+
 	function PrintAdminMessageOptions($msg_id,$group_id,$thread_id=0,$forum_id=0,$return_to_message=0) {
-		
+
 		$return = '<a href="admin/index.php?movethread=' . $thread_id  . '&amp;msg_id=' . $msg_id . '&amp;group_id=' . $group_id . '&amp;forum_id=' . $forum_id .
-				  '&amp;return_to_message=' . $return_to_message . '">' . html_image('ic/forum_move.gif','37','15',array('alt'=>_('Move thread'))). "</a>";
+				  '&amp;return_to_message=' . $return_to_message . '">' . html_image('ic/forum_move.gif','37','15',array('alt'=>_('Move Thread'))). "</a>";
 
 		// Following code (if ...) is to keep old implementation but need to be cleaned
 		if ($return_to_message) {
@@ -63,34 +70,34 @@ class ForumAdmin extends Error {
 		//		$return .= "<br />";
 		return $return;
 	}
-	
+
 	/**
 	 *  PrintAdminOptions - prints the different administrator option for the forums (heading).
 	 *
 	 */
-	
+
 	function PrintAdminOptions() {
 		global $group_id,$forum_id;
-		
+
 		echo '
 			<p>
-			<a href="index.php?group_id='.$group_id.'&amp;add_forum=1">'._('Add forum').'</a>';
+			<a href="index.php?group_id='.$group_id.'&amp;add_forum=1">'._('Add Forum').'</a>';
 		echo '
 			| <a href="pending.php?action=view_pending&amp;group_id=' . $group_id . '">' . _('Manage Pending Messages').'</a><br /></p>';
 	}
-	
+
 	/**
 	 *  PrintAdminOptions - prints the administrator option for an individual forum, to link to the pending messages management
 	 *
-	 *	@param 	int		The Forum ID.
+	 *	@param 	int		$forum_id	The Forum ID.
 	 */
-	
+
 	function PrintAdminPendingOption($forum_id) {
 		echo '
 			<p>
 			<a href="pending.php?action=view_pending&amp;group_id=' . $this->group_id . '&amp;forum_id=' . $forum_id . '">' . _('Manage Pending Messages').'</a><br /></p>';
 	}
-	
+
 	/**
 	 *  GetPermission - Gets the permission for the user
 	 *
@@ -99,7 +106,7 @@ class ForumAdmin extends Error {
 	function &GetPermission() {
 		return $this->p;
 	}
-	
+
 	/**
 	 *  GetGroupObject - Gets the group object of the forum
 	 *
@@ -108,7 +115,7 @@ class ForumAdmin extends Error {
 	function &GetGroupObject() {
 		return $this->g;
 	}
-	
+
 	/**
 	 *  isGroupAdmin - checks whether the authorized user is a group admin for the forums. The user must be authenticated
 	 *
@@ -116,13 +123,14 @@ class ForumAdmin extends Error {
 	function isGroupAdmin() {
 		return forge_check_perm ('forum_admin', $this->group_id) ;
 	}
-	
+
 	/**
 	 *  Authorized - authorizes and returns true if the user is authorized for the group, or false.
 	 *
-	 *  @param  string	 The group id.
+	 *  @param  string	 $group_id	The group id.
+	 *	@return bool
 	 */
-	
+
 	function Authorized($group_id) {
 		if (!$group_id) {
 			$this->setGroupIdError();
@@ -138,30 +146,28 @@ class ForumAdmin extends Error {
 			$this->setGroupIdError();
 			return false;
 		}
-		$this->p =& $this->g->getPermission ();
+		$this->p =& $this->g->getPermission();
 		if (!$this->p || !is_object($this->p) || $this->p->isError()) {
 			$this->setPermissionDeniedError();
 			return false;
 		}
 		return true;
 	}
-	
+
 	/**
 	 *  ExecuteAction - Executes the action passed as parameter
 	 *
-	 *  @param  string	 action to execute.
+	 *  @param  string	 $action	action to execute.
+	 *	@return string
 	 */
 	function ExecuteAction ($action) {
-        global $HTML;
-		
+		global $HTML;
+
 		$feedback='';
 		if ($action == "change_status") { //change a forum
 			$forum_name = getStringFromRequest('forum_name');
 			$description = getStringFromRequest('description');
 			$send_all_posts_to = getStringFromRequest('send_all_posts_to');
-			$allow_anonymous = getIntFromRequest('allow_anonymous');
-			$is_public = getIntFromRequest('is_public');
-			$moderation_level = getIntFromRequest('moderation_level');
 			$group_forum_id = getIntFromRequest('group_forum_id');
 			/*
 				Change a forum
@@ -175,8 +181,8 @@ class ForumAdmin extends Error {
 
 			session_require_perm ('forum_admin', $f->Group->getID()) ;
 
-			if (!$f->update($forum_name,$description,$allow_anonymous,$is_public,$send_all_posts_to,$moderation_level)) {
-				exit_error($f->getErrorMessage(),'forums');
+			if (!$f->update($forum_name,$description,$send_all_posts_to)) {
+				$this->setError($f->getErrorMessage());
 			} else {
 				$feedback = _('Forum Info Updated Successfully');
 			}
@@ -185,10 +191,7 @@ class ForumAdmin extends Error {
 		if ($action == "add_forum") { //add forum
 			$forum_name = getStringFromRequest('forum_name');
 			$description = getStringFromRequest('description');
-			$is_public = getStringFromRequest('is_public');
 			$send_all_posts_to = getStringFromRequest('send_all_posts_to');
-			$allow_anonymous = getStringFromRequest('allow_anonymous');
-			$moderation_level = getIntFromRequest('moderation_level');
 			/*
 				Adding forums to this group
 			*/
@@ -204,9 +207,9 @@ class ForumAdmin extends Error {
 				form_release_key(getStringFromRequest("form_key"));
 				exit_error($f->getErrorMessage(),'forums');
 			}
-			if (!$f->create($forum_name,$description,$is_public,$send_all_posts_to,1,$allow_anonymous,$moderation_level)) {
+			if (!$f->create($forum_name,$description,$send_all_posts_to,1)) {
 				form_release_key(getStringFromRequest("form_key"));
-				exit_error($f->getErrorMessage(),'forums');
+				$this->setError($f->getErrorMessage());
 			} else {
 				$feedback = _('Forum added successfully');
 			}
@@ -234,7 +237,7 @@ class ForumAdmin extends Error {
 			if (!$count || $fm->isError()) {
 				exit_error($fm->getErrorMessage(),'forums');
 			} else {
-				$feedback = sprintf(ngettext('%1$s message deleted', '%1$s messages deleted', $count), $count);
+				$feedback = sprintf(ngettext('%s message deleted', '%s messages deleted', $count), $count);
 			}
 			return $feedback;
 		}
@@ -255,7 +258,7 @@ class ForumAdmin extends Error {
 			if (!$f->delete(getStringFromRequest('sure'),getStringFromRequest('really_sure'))) {
 				exit_error($f->getErrorMessage(),'forums');
 			} else {
-				$feedback = _('Successfully Deleted');
+				$feedback = _('Successfully Deleted.');
 			}
 			return $feedback;
 		}
@@ -270,15 +273,15 @@ class ForumAdmin extends Error {
 						array ($group_id));
 			if (!$res) {
 				echo db_error();
-				return;			
+				return;
 			}
-			
+
 			$moderated_forums = array();
 			for ($i=0;$i<db_numrows($res);$i++) {
 				$aux = db_fetch_array($res);
 				$moderated_forums[$aux[1]] = $aux[0];
 			}
-			
+
 			if (count($moderated_forums)==0) {
 				echo $HTML->feedback(_('No forums are moderated for this group'));
 				forum_footer(array());
@@ -289,10 +292,10 @@ class ForumAdmin extends Error {
 				$keys = array_keys($moderated_forums);
 				$forum_id = $keys[0];
 			}
-			
+
 			echo '
-			<script language="JavaScript" type="text/javascript">/* <![CDATA[ */
-		
+			<script type="text/javascript">/* <![CDATA[ */
+
 			function confirmDel() {
 				var agree=confirm("' . _('Proceed? Actions are permanent!') . '");
 				if (agree) {
@@ -309,21 +312,21 @@ class ForumAdmin extends Error {
 			<input type="hidden" name="forum_id" value="' . $forum_id . '" />
 
 			';
-			
+
 			echo html_build_select_box_from_assoc($moderated_forums,'forum_id',$forum_id);
 			echo '    <input name="Go" type="submit" value="Go" />';
-			
+
 			$title = array();
 			$title[] = _('Forum Name');
 			$title[] = _('Message');
 			$title[] = "Action";
-			
+
 			$res = db_query_params ('SELECT msg_id,subject,pm.group_forum_id,gl.forum_name FROM forum_pending_messages pm, forum_group_list gl WHERE pm.group_forum_id=$1 AND pm.group_forum_id=gl.group_forum_id AND gl.group_forum_id=$2',
 			array ($forum_id,
 				$forum_id));
 			if (!$res) {
 				echo db_error();
-				return;			
+				return;
 			}
 
 			//array with the supported actions
@@ -335,7 +338,7 @@ class ForumAdmin extends Error {
 			for($i=0;$i<db_numrows($res);$i++) {
 				$ids .= db_result($res,$i,'msg_id') . ",";
 			}
-			
+
 			$i = 2;
 			echo $HTML->listTableTop($title);
 			while ($onemsg = db_fetch_array($res)) {
@@ -344,17 +347,17 @@ class ForumAdmin extends Error {
 				//<a href=\"javascript:msgdetail('$url');\">$onemsg[subject]</a>
 				$url = "http://www.google.com";
 				echo "
-				<tr" . $HTML->boxGetAltRowStyle($i++). ">
-					<td>$onemsg[forum_name]</td>	
+				<tr " . $HTML->boxGetAltRowStyle($i++). ">
+					<td>$onemsg[forum_name]</td>
 					<td><a href=\"#\" onclick=\"window.open('pendingmsgdetail.php?msg_id=$onemsg[msg_id]&amp;forum_id=$onemsg[group_forum_id]&amp;group_id=$group_id','PendingMessageDetail','width=800,height=600,status=no,resizable=yes');\">$onemsg[subject]</a></td>
-					<td><div align=\"right\">" . html_build_select_box_from_assoc($options,"doaction[]",1) . "</div></td>
+					<td><div class=\"align-right\">" . html_build_select_box_from_assoc($options,"doaction[]",1) . "</div></td>
 				</tr>";
 			}
-			
+
 			echo $HTML->listTableBottom();
 			echo '
 			<input type="hidden" name="msgids" value="' . $ids . '" />
-			<p align="right"><input type="submit" onclick="return confirmDel();" name="update" value="' . _('Update') . '" /></p>
+			<p class="align-right"><input type="submit" onclick="return confirmDel();" name="update" value="' . _('Update') . '" /></p>
 			</form>
 			';
 		}
@@ -363,22 +366,22 @@ class ForumAdmin extends Error {
 			$forum_id = getIntFromRequest("forum_id");
 			$msgids = getStringFromRequest("msgids");//the message ids to update
 			$doaction = getArrayFromRequest("doaction"); //the actions for the messages
-			
+
 			$msgids = explode(",",$msgids);
 			array_pop($msgids);//this last one is empty
-			
+
 			/*if ($this->isGroupAdmin()) {
 				$this->PrintAdminOptions();
 			}*/
-			
+
 			$results = array(); //messages
 			for($i=0;$i<count($msgids);$i++) {
 				switch ($doaction[$i]) {
-					case 1 : { 
+					case 1 : {
 						//no action
 						break;
 					}
-					case 2 : { 
+					case 2 : {
 						//delete
 						db_begin();
 						if (!db_query_params ('DELETE FROM forum_pending_attachment WHERE msg_id=$1',
@@ -397,18 +400,18 @@ class ForumAdmin extends Error {
 						$feedback .= _('Forum deleted');
 						break;
 					}
-					case 3 : { 
+					case 3 : {
 						//release
 						$res1 = db_query_params ('SELECT * FROM forum_pending_messages WHERE msg_id=$1',
 			array ($msgids[$i]));
 						if (!$res1) {
-							$error_msg .= "DB Error: " . db_error();
+							$error_msg .= "DB Error " . db_error() . "<br />";
 							break;
 						}
 						$res2 = db_query_params ('SELECT * FROM forum_pending_attachment WHERE msg_id=$1',
 			array ($msgids[$i]));
 						if (!$res2) {
-							$error_msg .= "DB Error " . db_error();
+							$error_msg .= "DB Error " . db_error() . "<br />";
 							break;
 						}
 						$f = new Forum($this->g,$forum_id);
@@ -421,7 +424,7 @@ class ForumAdmin extends Error {
 						if (!$fm || !is_object($fm)) {
 							exit_error(_('Error getting new ForumMessage'),'forums');
 						} elseif ($fm->isError()) {
-							exit_error(_('Error getting new ForumMessage: ').$fm->getErrorMessage(),'forums');
+							exit_error(_('Error getting new ForumMessage')._(': ').$fm->getErrorMessage(),'forums');
 						}
 						$group_forum_id = db_result($res1,0,"group_forum_id");
 						$subject = db_result($res1,0,"subject");
@@ -433,7 +436,7 @@ class ForumAdmin extends Error {
 						$has_followups = db_result($res1,0,"has_followups");
 						$most_recent_date = db_result($res1,0,"most_recent_date");
 						if ($fm->insertreleasedmsg($group_forum_id,$subject, $body,$post_date, $thread_id, $is_followup_to,$posted_by,$has_followups,time())) {
-							$feedback .= "( $subject ) " . _('Pending message released') . "<br />";
+							$feedback .= "($subject) " . _('Pending message released') . "<br />";
 							if (db_numrows($res2)>0) {
 								//if there's an attachment
 								$am = NEW AttachManager();//object that will handle and insert the attachment into the db
@@ -455,16 +458,16 @@ class ForumAdmin extends Error {
 							$deleteok = true;
 						} else {
 							if ($fm->isError()) {
-							    if ( $fm->getErrorMessage() == (_('Couldn\'t Update Master Thread parent with current time')) ) {
+							    if ( $fm->getErrorMessage() == (_('Could not Update Master Thread parent with current time')) ) {
 							    	//the thread which the message was replying to doesn't exist any more
-							    	$feedback .= "( " . $subject . " ) " . _('The thread which the message was posted to doesn\'t exist anymore, please delete the message.');
+							    	$feedback .= "( " . $subject . " ) " . _('The thread which the message was posted to doesn\'t exist anymore, please delete the message.') . "<br />";
 							    } else {
-									$error_msg .= "$msg_id - " . $fm->getErrorMessage();
+									$error_msg .= "$msg_id - " . $fm->getErrorMessage() . "<br />";
 							    }
 								$deleteok = false;
 							}
 						}
-								
+
 						if ( isset($am) && (is_object($am)) ) {
 							//if there was an attach, check if it was uploaded ok
 							 if ((!$am->isError())) {
@@ -482,7 +485,7 @@ class ForumAdmin extends Error {
 								$deleteok = false;
 							 }
 						}
-						
+
 						if ($deleteok) {
 							//delete the message and attach
 							db_begin();
@@ -514,5 +517,3 @@ class ForumAdmin extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
