@@ -30,41 +30,44 @@ class ForumFactory extends Error {
 	/**
 	 * The Group object.
 	 *
-	 * @var	 object  $Group.
+	 * @var	object	$Group.
 	 */
 	var $Group;
 
 	/**
 	 * The forums array.
 	 *
-	 * @var	 array	forums.
+	 * @var	array	forums.
 	 */
 	var $forums;
 
 	/**
-	 *  Constructor.
+	 * Constructor.
 	 *
-	 *	@param	object	The Group object to which this forum is associated.
+	 * @param	object	$Group	The Group object to which this forum is associated.
 	 */
-	function ForumFactory(&$Group) {
+	function __construct(&$Group) {
 		$this->Error();
 		if (!$Group || !is_object($Group)) {
-			$this->setError(_('Forum:: No Valid Group Object'));
-			return false;
+			$this->setError(_('No Valid Group Object'));
+			return;
 		}
 		if ($Group->isError()) {
 			$this->setError(_('Forum').':: '.$Group->getErrorMessage());
-			return false;
+			return;
+		}
+		if (!$Group->usesForum()) {
+			$this->setError(sprintf(_('%s does not use the Forum tool.'),
+			    $Group->getPublicName()));
+			return;
 		}
 		$this->Group =& $Group;
-
-		return true;
 	}
 
 	/**
-	 *	getGroup - get the Group object this ForumFactory is associated with.
+	 * getGroup - get the Group object this ForumFactory is associated with.
 	 *
-	 *	@return object	The Group object.
+	 * @return	object	The Group object.
 	 */
 	function &getGroup() {
 		return $this->Group;
@@ -72,10 +75,13 @@ class ForumFactory extends Error {
 
 	function &getAllForumIds() {
 		$result = array () ;
-		$res = db_query_params ('SELECT * FROM forum_group_list_vw
-WHERE group_id=$1
+		$res = db_query_params('SELECT group_forum_id FROM forum_group_list
+WHERE group_forum_id NOT IN (
+	SELECT group_forum_id FROM forum_group_list WHERE group_forum_id IN (
+		SELECT forum_id FROM news_bytes))
+AND group_id=$1
 ORDER BY group_forum_id',
-					   array ($this->Group->getID())) ;
+			array ($this->Group->getID()));
 		if (!$res) {
 			return $result ;
 		}
@@ -83,7 +89,20 @@ ORDER BY group_forum_id',
 			$result[] = $arr['group_forum_id'] ;
 		}
 		return $result ;
-	}		
+	}
+
+	function &getAllForumIdsWithNews() {
+		$result = array () ;
+		$res = db_query_params('SELECT group_forum_id FROM forum_group_list WHERE group_id=$1 ORDER BY group_forum_id',
+			array ($this->Group->getID()));
+		if (!$res) {
+			return $result ;
+		}
+		while ($arr = db_fetch_array($res)) {
+			$result[] = $arr['group_forum_id'] ;
+		}
+		return $result ;
+	}
 
 	/**
 	 *	getForums - get an array of Forum objects for this Group.
@@ -97,7 +116,7 @@ ORDER BY group_forum_id',
 
 		$this->forums = array () ;
 		$ids = $this->getAllForumIds() ;
-		
+
 		if (!empty($ids) ) {
 			foreach ($ids as $id) {
 				if (forge_check_perm ('forum', $id, 'read')) {
@@ -107,7 +126,7 @@ ORDER BY group_forum_id',
 		}
 		return $this->forums;
 	}
-		
+
 	/**
 	 *	getForumsAdmin - get an array of all (public, private and suspended) Forum objects for this Group.
 	 *
@@ -118,7 +137,6 @@ ORDER BY group_forum_id',
 			return $this->forums;
 		}
 
-		
 		if (session_loggedin()) {
 			if (!forge_check_perm ('forum_admin', $this->Group->getID())) {
 				$this->setError(_("You don't have a permission to access this page"));
@@ -133,9 +151,9 @@ ORDER BY group_forum_id',
 			$this->setError(_("You don't have a permission to access this page"));
 			$this->forums = false;
 		}
-		
+
 		$rows = db_numrows($result);
-		
+
 		if (!$result) {
 			$this->setError(_('Forum not found').' : '.db_error());
 			$this->forums = false;
@@ -147,18 +165,21 @@ ORDER BY group_forum_id',
 		return $this->forums;
 	}
 
-	/**
-	 *	moveThread - move thread in another forum
-	 *	
-	 *	@param	string	The forum ID
-	 *	@param	int		The thread_id of the tread to change.
-	 *	@param	string	The old forum ID
-	 * 
-	 * 	Note:
-	 *   old forum ID is useless if forum_agg_msg_count table is no longer used
-	 *
-	 *	@return boolean success.
-	 */
+    /**
+     *    moveThread - move thread in another forum
+     *
+     * @param $group_forum_id
+     * @param $thread_id
+     * @param bool $old_forum_id
+     * @internal param \The $string forum ID
+     * @internal param \The $int thread_id of the tread to change.
+     * @internal param \The $string old forum ID
+     *
+     *    Note:
+     *   old forum ID is useless if forum_agg_msg_count table is no longer used
+     *
+     * @return boolean success.
+     */
 	function moveThread($group_forum_id,$thread_id,$old_forum_id = false) {
 		$res = db_query_params('UPDATE forum SET group_forum_id=$1 WHERE thread_id=$2',
 			array($group_forum_id, $thread_id));
@@ -168,7 +189,7 @@ ORDER BY group_forum_id',
 		} else {
 			$msg_count = db_affected_rows($res);
 			if ($msg_count < 1) {
-				$this->setError("Thread not found");
+				$this->setError(_("Thread not found"));
 				return false;
 			}
 		}
@@ -226,5 +247,3 @@ ORDER BY group_forum_id',
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
