@@ -5,6 +5,8 @@
  * Copyright 1999-2000, Tim Perdue/Sourceforge
  * Copyright 2002, Tim Perdue/GForge, LLC
  * Copyright 2009, Roland Mas
+ * Copyright 2013, Franck Villaume - TrivialDev
+ * Copyright 2013, French Ministry of National Education
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -42,20 +44,20 @@ class ForumMessage extends Error {
 	 * @var	 object  $Forum.
 	 */
 	var $Forum;
-	
-		/**
+
+	/**
 	 *  Constructor.
 	 *
-	 *	@param	object	The Forum object to which this ForumMessage is associated.
-	 *  @param  int	 The message_id.
-	 *  @param  array   The associative array of data.
-	 *	@param 	boolean	Whether the message is a pending one.
-	 *	@return	boolean	success.
+	 * @param	object		$Forum		The Forum object to which this ForumMessage is associated.
+	 * @param	bool|int	$msg_id		The message_id.
+	 * @param	array		$arr		The associative array of data.
+	 * @param	bool		$pending	Whether the message is a pending one.
+	 * @return	bool		success.
 	 */
-	function ForumMessage(&$Forum, $msg_id=false, $arr=false, $pending=false) {
+	function ForumMessage(&$Forum, $msg_id=false, $arr=array(), $pending=false) {
 		$this->Error();
 		if (!$Forum || !is_object($Forum)) {
-			$this->setError(_('ForumMessage:: No Valid Forum Object'));
+			$this->setError(_('Invalid Forum Object'));
 			return false;
 		}
 		if ($Forum->isError()) {
@@ -95,15 +97,15 @@ class ForumMessage extends Error {
 
 /**
 	*	insertmoderated - inserts the message into the table for moderation (forum_pending_messages)
-	 *	@param	string	The subject of the message.
-	 *	@param	string	The body of the message.
-	 *	@param	int	The thread_id of the message, if known.
-	 *	@param	int	The message_id of the parent message, if any.
-	 *	@param 	int	The id of the user that is posting the message
+	 *	@param	string	$subject			The subject of the message.
+	 *	@param	string	$body				The body of the message.
+	 *	@param	int		$thread_id			The thread_id of the message, if known.
+	 *	@param	int		$is_followup_to 	The message_id of the parent message, if any.
+	 *	@param 	int		$user_id		The id of the user that is posting the message
 	 *	@return	boolean success.
 	*/
-	
-	function insertmoderated($subject, $body, $thread_id='', $is_followup_to='',$user_id) {
+
+	function insertmoderated($subject, $body, $thread_id=0, $is_followup_to=0,$user_id) {
 		if (!$thread_id) {
 			$thread_id=$this->Forum->getNextThreadID();
 			$is_followup_to=0;
@@ -113,7 +115,7 @@ class ForumMessage extends Error {
 				return false;
 			}
 		}
-		
+
 		$result = db_query_params ('INSERT INTO forum_pending_messages (group_forum_id,posted_by,subject,
 		body,post_date,is_followup_to,thread_id,most_recent_date) VALUES ($1,$2,$3,$4,$5,$6,$7,$8)',
 					   array ($this->Forum->getID(),
@@ -125,7 +127,7 @@ class ForumMessage extends Error {
 						  $thread_id,
 						  time ())) ;
 		if (!$result || db_affected_rows($result) < 1) {
-			$this->setError(_('ForumMessage::create() Posting Failed').' '.db_error());
+			$this->setError(_('Posting Failed').' '.db_error());
 			db_rollback();
 			return false;
 		} else {
@@ -136,7 +138,7 @@ class ForumMessage extends Error {
 			}
 			if (!$msg_id) {
 				db_rollback();
-				$this->setError(_('ForumMessage::create() Unable to get new message id'));
+				$this->setError(_('Unable to get new message id'));
 				return false;
 			} else {
 				if (!$this->sendNewModeratedMsgNotice()) {
@@ -149,25 +151,25 @@ class ForumMessage extends Error {
 			}
 		}
 	}
-	
 
 	/**
 	*	insertreleasedmsg - inserts the released message into the main table (forum)
-	 *	@param 	string	The Forum id
-	 *	@param	string	The subject of the message.
-	 *	@param	string	The body of the message.
-	 *	@param	string	The post date
-	 *	@param	int	The thread_id of the message
-	 *	@param	int	The message_id of the parent message, if any.
-	 *	@param 	int	The id of the user that is posting the message
-	 *	@param 	int	has followups?
-	 *	@param 	int	most recent date
-	 *	@return	boolean success.
+	 *	@param 	string	$group_forum_id	The Forum id
+	 *	@param	string	$subject		The subject of the message.
+	 *	@param	string	$body			The body of the message.
+	 *	@param	string	$post_date		The post date
+	 *	@param	int		$thread_id		The thread_id of the message
+	 *	@param	int		$is_followup_to	The message_id of the parent message, if any.
+	 *	@param 	int		$posted_by		The id of the user that is posting the message
+	 *	@param 	int		$has_followups	has followups?
+	 *	@param 	int		$most_recent_date	most recent date
+	 *	@return	bool	success.
 	*/
-	
-	function insertreleasedmsg($group_forum_id,$subject, $body,$post_date, $thread_id, $is_followup_to,$posted_by,$has_followups,$most_recent_date) {
+
+	function insertreleasedmsg($group_forum_id, $subject, $body, $post_date, $thread_id,
+							   $is_followup_to, $posted_by, $has_followups, $most_recent_date) {
 		if ($is_followup_to != 0) {
-			
+
 			//was posted in reply to another thread
 			//we must check whether that thread still exists. if it does, post the message. else, set the error
 				//
@@ -178,7 +180,7 @@ class ForumMessage extends Error {
 						 array (time(),
 							$thread_id)) ;
 			if (!$res4 || db_affected_rows($res4) < 1) {
-				$this->setError(_('Couldn\'t Update Master Thread parent with current time'));
+				$this->setError(_('Could not Update Master Thread parent with current time'));
 				db_rollback();
 				return false;
 			} else {
@@ -196,8 +198,8 @@ class ForumMessage extends Error {
 			}
 			db_commit();
 		}
-			
-			
+
+
 		db_begin();
 		$result = db_query_params ('INSERT INTO forum (group_forum_id,posted_by,subject,body,post_date,is_followup_to,thread_id,most_recent_date) VALUES ($1,$2,$3,$4,$5,$6,$7,$8)',
 					   array ($group_forum_id,
@@ -210,18 +212,18 @@ class ForumMessage extends Error {
 						  $most_recent_date)) ;
 
 		if (!$result || db_affected_rows($result) < 1) {
-			$this->setError(_('ForumMessage::create() Posting Failed').' '.db_error());
+			$this->setError(_('Posting Failed').' '.db_error());
 			db_rollback();
 			return false;
 		} else {
 			$msg_id=db_insertid($result,'forum','msg_id');
 			if (!$this->fetchData($msg_id)) {
-				$this->setError(_('ForumMessage::create() Posting Failed').' '.db_error());
+				$this->setError(_('Posting Failed').' '.db_error());
 				db_rollback();
 				return false;
 			}
 			if (!$msg_id) {
-				$this->setError(_('ForumMessage::create() Unable to get new message id'));
+				$this->setError(_('Unable to get new message id'));
 				db_rollback();
 				return false;
 			} else {
@@ -235,22 +237,22 @@ class ForumMessage extends Error {
 			}
 		}
 	}
-	
-	
-	
+
+
+
 	/**
 	*	insertmsg - inserts the message into the main table (forum)
-	 *	@param	string	The subject of the message.
-	 *	@param	string	The body of the message.
-	 *	@param	int	The thread_id of the message, if known.
-	 *	@param	int	The message_id of the parent message, if any.
-	 *	@param 	int	The id of the user that is posting the message
-	 *	@param  boolean	Whether the message has an attach associated. Defaults to false
-	 *	@param	int	The timestamp of the message to insert, defaults to 0. 
+	 *	@param	string	$subject			The subject of the message.
+	 *	@param	string	$body				The body of the message.
+	 *	@param	int		$thread_id			The thread_id of the message, if known.
+	 *	@param	int		$is_followup_to		The message_id of the parent message, if any.
+	 *	@param 	int		$user_id			The id of the user that is posting the message
+	 *	@param  bool	$has_attach			Whether the message has an attach associated. Defaults to false
+	 *	@param	int		$timestamp			The timestamp of the message to insert, defaults to 0.
 	 *	@return	boolean success.
 	*/
-	
-	function insertmsg($subject, $body, $thread_id='', $is_followup_to='',$user_id,$has_attach=false, $timestamp = 0) {
+	function insertmsg($subject, $body, $thread_id=0, $is_followup_to=0,
+					   $user_id, $has_attach=false, $timestamp=0) {
 		if ($timestamp == 0){
 			$timestamp = time();
 		}
@@ -272,7 +274,7 @@ class ForumMessage extends Error {
 						 array ($timestamp,
 							$thread_id)) ;
 				if (!$res4 || db_affected_rows($res4) < 1) {
-					$this->setError(_('Couldn\'t Update Master Thread parent with current time'));
+					$this->setError(_('Could not Update Master Thread parent with current time'));
 					db_rollback();
 					return false;
 				} else {
@@ -300,7 +302,7 @@ class ForumMessage extends Error {
 				return false;
 			}
 		}
-		
+
 		$result = db_query_params ('INSERT INTO forum (group_forum_id,posted_by,subject,body,post_date,is_followup_to,thread_id,most_recent_date) VALUES ($1,$2,$3,$4,$5,$6,$7,$8)',
 					   array ($this->Forum->getID(),
 						  $user_id,
@@ -311,7 +313,7 @@ class ForumMessage extends Error {
 						  $thread_id,
 						  $timestamp)) ;
 		if (!$result || db_affected_rows($result) < 1) {
-			$this->setError(_('ForumMessage::create() Posting Failed').' '.db_error());
+			$this->setError(_('Posting Failed').' '.db_error());
 			db_rollback();
 			return false;
 		}
@@ -323,7 +325,7 @@ class ForumMessage extends Error {
 		}
 
 		if (!$msg_id) {
-			$this->setError(_('ForumMessage::create() Unable to get new message id'));
+			$this->setError(_('Unable to get new message id'));
 			db_rollback();
 			return false;
 		}
@@ -338,22 +340,21 @@ class ForumMessage extends Error {
 		$this->awaits_moderation = false;
 		return true;
 	}
-	
-	
+
 	/**
 	 *	create - use this function to create a new message in the database.
 	 *
-	 *	@param	string	The subject of the message.
-	 *	@param	string	The body of the message.
-	 *	@param	int	The thread_id of the message, if known.
-	 *	@param	int	The message_id of the parent message, if any.
-	 *	@param  boolean	Whether the message has an attach associated. Defaults to false
-	 *	@param	int	The timestamp of the message to create. Defaults to 0, meaning the timestamp used for this message will be "time()"
+	 *	@param	string	$subject		The subject of the message.
+	 *	@param	string	$body			The body of the message.
+	 *	@param	int		$thread_id		The thread_id of the message, if known.
+	 *	@param	int		$is_followup_to	The message_id of the parent message, if any.
+	 *	@param  bool	$has_attach		Whether the message has an attach associated. Defaults to false
+	 *	@param	int		$timestamp		The timestamp of the message to create. Defaults to 0, meaning the timestamp used for this message will be "time()"
 	 *	@return	boolean success.
 	 */
-	function create($subject, $body, $thread_id='', $is_followup_to='',$has_attach=false, $timestamp = 0) {
-		if (!$body || !$subject) {
-			$this->setError(_('Must Include A Message Body And Subject'));
+	function create($subject, $body, $thread_id=0, $is_followup_to=0, $has_attach=false, $timestamp = 0) {
+		if (!strlen(trim($body)) || !strlen(trim($subject))) {
+			$this->setError(_('Error: a forum message must include a message body and a subject.'));
 			return false;
 		}
 		if (!forge_check_perm ('forum', $this->Forum->getID(), 'post')) {
@@ -369,7 +370,7 @@ class ForumMessage extends Error {
 		if ($is_followup_to) {
 			$ParentMessage=new ForumMessage($this->Forum,$is_followup_to);
 			if (!$ParentMessage || !is_object($ParentMessage)) {
-				$this->setError("ForumMessage::create()"._('ForumMessage::create() No Valid ParentMessage Object'));
+				$this->setError(_('Invalid ParentMessage Object'));
 				return false;
 			}
 			if ($ParentMessage->isError()) {
@@ -377,12 +378,12 @@ class ForumMessage extends Error {
 				return false;
 			}
 		}
-		if (!$is_followup_to) { 
-			$is_followup_to=0; 
+		if (!$is_followup_to) {
+			$is_followup_to=0;
 		}
 
 		db_begin();
-		
+
 		//now we check the moderation status of the forum and act accordingly
 		if (forge_check_perm ('forum', $this->Forum->getID(), 'unmoderated_post')) {
 			//no moderation
@@ -400,17 +401,16 @@ class ForumMessage extends Error {
 	 */
 	function fetchData($msg_id) {
 		$res = db_query_params ('SELECT * FROM forum_user_vw WHERE msg_id=$1 AND group_forum_id=$2',
-					array ($msg_id,
-					       $this->Forum->getID())) ;
+					array($msg_id, $this->Forum->getID()));
 		if (!$res || db_numrows($res) < 1) {
-			$this->setError(_('ForumMessage::fetchData() Invalid MessageID').db_error());
+			$this->setError(_('Invalid Message Id'));
 			return false;
 		}
 		$this->data_array = db_fetch_array($res);
 		db_free_result($res);
 		return true;
 	}
-	
+
 	/**
 	 *  fetchModeratedData - re-fetch the data for this forum_message from the database, for pending messages
 	 *
@@ -419,10 +419,9 @@ class ForumMessage extends Error {
 	 */
 	function fetchModeratedData($msg_id) {
 		$res = db_query_params ('SELECT * FROM forum_pending_user_vw WHERE msg_id=$1 AND group_forum_id=$2',
-					array ($msg_id,
-					       $this->Forum->getID())) ;
+					array($msg_id, $this->Forum->getID()));
 		if (!$res || db_numrows($res) < 1) {
-			$this->setError(_('ForumMessage::fetchData() Invalid MessageID').db_error());
+			$this->setError(_('Invalid Message Id'));
 			return false;
 		}
 		$this->data_array = db_fetch_array($res);
@@ -510,7 +509,7 @@ class ForumMessage extends Error {
 	function getParentID() {
 		return $this->data_array['is_followup_to'];
 	}
-	
+
 	/**
 	 *	isPending - is the message pending, awaiting moderation?
 	 *
@@ -546,13 +545,13 @@ class ForumMessage extends Error {
 	function hasFollowups() {
 		return $this->data_array['has_followups'];
 	}
-	
+
 	/**
 	 *	hasAttach - whether this message has an attachment.
 	 *
 	 *	@return boolean has_attach.
 	 */
-	
+
 	function hasAttach() {
 		if ($this->isPending()) {
 			$res = db_query_params ('SELECT attachmentid FROM forum_pending_attachment WHERE msg_id=$1',
@@ -564,7 +563,7 @@ class ForumMessage extends Error {
 		if (db_numrows($res) > 0) {
 			return true;
 		}
-		return false;		
+		return false;
 	}
 
 	/**
@@ -575,16 +574,16 @@ class ForumMessage extends Error {
 	function delete() {
 		$msg_id=$this->getID();
 		if (!$msg_id) {
-			$this->setError(_('Invalid Message ID'));
+			$this->setError(_('Invalid Message Id'));
 			return false;
 		}
-		
+
 		if (!forge_check_perm ('forum_admin', $this->Forum->Group->getID())) {
 			$this->setPermissionDeniedError();
 			return false;
 		}
-		
-		$result = db_query_params ('SELECT msg_id FROM forum 
+
+		$result = db_query_params ('SELECT msg_id FROM forum
 			WHERE is_followup_to=$1
 			AND group_forum_id=$2',
 					   array ($msg_id,
@@ -596,7 +595,7 @@ class ForumMessage extends Error {
 			$msg = new ForumMessage($this->Forum,db_result($result,$i,'msg_id'));
 			$count += $msg->delete();
 		}
-		$toss = db_query_params ('DELETE FROM forum 
+		$toss = db_query_params ('DELETE FROM forum
 			WHERE msg_id=$1
 			AND group_forum_id=$2',
 					 array ($msg_id,
@@ -618,11 +617,11 @@ class ForumMessage extends Error {
 		$replaced =  preg_replace("/\[.+\](.+)\[\/.+\]/","$1",$text);
 		return $replaced;
 	}
-	
+
 	/**
 	 *	sendNotice - contains the logic to send out email followups when a message is posted.
 	 *
-	 *	@param  boolean	Whether the message has an attach associated. Defaults to false
+	 *	@param  boolean	$has_attach Whether the message has an attach associated. Defaults to false
 	 *
 	 *	@return boolean success.
 	 */
@@ -648,7 +647,7 @@ class ForumMessage extends Error {
 		}
 
 		foreach ($recipients as $recipient) {
-			if (is_a ($recipient, 'GFUser')) {
+			if ($recipient instanceof GFUser) {
 				setup_gettext_for_user ($recipient) ;
 				$dest_email = $recipient->getEmail ();
 			} else {
@@ -657,14 +656,14 @@ class ForumMessage extends Error {
 			}
 
 			$body = sprintf(_("\nRead and respond to this message at: \n%s"), util_make_url ('/forum/message.php?msg_id='.$this->getID()));
-			if (forge_get_config('use_mail')) {
+			if (forge_get_config('use_mail') && forge_get_config('use_forum_mail_replies')) {
 				$body .= stripcslashes(sprintf(_('
-Or reply to this e-mail entering your response between the following markers: 
+Or reply to this e-mail entering your response between the following markers:
 %1$s
 (enter your response here)
 %1$s'), FORUM_MAIL_MARKER));
 			}
-			$body .= sprintf(_("\n\n\nBy: %s\n"), $this->getPosterRealName());
+			$body .= "\n\n\n"._('By')._(': ').$this->getPosterRealName()."\n";
 
 			if ($has_attach) {
 				//if there's an attachment for the message, make it note.
@@ -676,7 +675,7 @@ Or reply to this e-mail entering your response between the following markers:
 			$sanitizer = new TextSanitizer();
 			$text = $this->getBody();
 			$text = $sanitizer->convertNeededTagsForEmail($text);
-			$text= strip_tags($this->removebbcode(util_line_wrap($text)));
+			$text = strip_tags($this->removebbcode(util_line_wrap($text)));
 			$text = $sanitizer->convertExtendedCharsForEmail($text);
 			$body .= sprintf(
 				"%s\n\n______________________________________________________________________\n".
@@ -685,13 +684,15 @@ Or reply to this e-mail entering your response between the following markers:
 				$text,
 				forge_get_config ('forge_name'),
 				util_make_url('/forum/monitor.php?forum_id='.$this->Forum->getID().
-					      '&group_id='.$this->Forum->Group->getID().'&stop=1')
+						'&group_id='.$this->Forum->Group->getID().'&stop=1')
 				);
 
 			$extra_headers = "Return-Path: <noreply@".forge_get_config('web_host').">\n";
 			$extra_headers .= "Errors-To: <noreply@".forge_get_config('web_host').">\n";
 			$extra_headers .= "Sender: <noreply@".forge_get_config('web_host').">\n";
-			$extra_headers .= "Reply-To: ".$this->Forum->getReturnEmailAddress()."\n";
+			if (forge_get_config('use_mail') && forge_get_config('use_forum_mail_replies')) {
+				$extra_headers .= "Reply-To: ".$this->Forum->getReturnEmailAddress()."\n";
+			}
 			$extra_headers .= "Precedence: Bulk\n"
 				."List-Id: ".$this->Forum->getName()." <forum".$this->Forum->getId()."@".forge_get_config('web_host').">\n"
 				."List-Help: ".util_make_url ('/forum/forum.php?id='.$this->Forum->getId())."\n"
@@ -701,7 +702,7 @@ Or reply to this e-mail entering your response between the following markers:
 				$extra_headers .= "\nIn-Reply-To: ".$this->Forum->getReturnEmailAddress()."\n"
 					."References: <forumpost".$this->getParentId()."@".forge_get_config('web_host').">";
 			}
-			
+
 			$subject="[" . $this->Forum->getUnixName() ."][".$this->getID()."] ".util_unconvert_htmlspecialchars($this->getSubject());
 
 			util_send_message($dest_email,$subject,$body,"noreply@".forge_get_config('web_host'),'','Forum',$extra_headers);
@@ -711,7 +712,7 @@ Or reply to this e-mail entering your response between the following markers:
 		setup_gettext_from_context();
 		return true;
 	}
-	
+
 	/**
 	 *	sendNewModeratedMsgNotice - contains the logic to send out email notifications to the forum admins when a new moderated message is posted
 	 *
@@ -725,14 +726,14 @@ Or reply to this e-mail entering your response between the following markers:
 		foreach ($moderators as $m) {
 			$ids[] = $m->getID () ;
 		}
-		
+
 		//
 		//	See if there is anyone to send messages to
 		//
 		if (!count($ids) > 0 && !$this->Forum->getSendAllPostsTo()) {
 			return true;
 		}
-		
+
 		$f =& $this->getForum();
 		$g =& $f->getGroup();
 
@@ -741,7 +742,7 @@ Or reply to this e-mail entering your response between the following markers:
 		"\nBy: " . $this->getPosterRealName() . "\n\n";
 
 		$text = $this->getBody();
-		$sanitizer = new TextSanitizer();	
+		$sanitizer = new TextSanitizer();
 		$text = $sanitizer->convertNeededTagsForEmail($text);
 		$text= strip_tags($this->removebbcode(util_line_wrap($text)));
 		$text = $sanitizer->convertExtendedCharsForEmail($text);
@@ -770,7 +771,7 @@ Or reply to this e-mail entering your response between the following markers:
 						   array ('A',
 							  db_int_array_to_any_clause ($ids))) ;
 		}
-		
+
 		$BCC = implode(util_result_column_to_array($bccres),',').','.$this->Forum->getSendAllPostsTo();
 		$User = user_get_object($this->getPosterID());
 		//util_send_message('',$subject,$body,$User->getEmail(),$BCC,$this->getPosterRealName(),$extra_headers);
@@ -781,53 +782,57 @@ Or reply to this e-mail entering your response between the following markers:
 
 	/**
 	 *	updatemsg - impacts in the DB the new content of the message
-	 *	
-	 *	@param	string	The forum ID
-	 *	@param 	int		The id of the user that is posting the message
-	 *	@param	string	The subject of the message.
-	 *	@param	string	The body of the message.
-	 *	@param	string	The post date
-	 *	@param	int		The message_id of the parent message, if any.
-	 *	@param	int		The thread_id of the message, if known.
-	 *	@param	int		has followups?
-	 *	@param	string	The most recent date.
+	 *
+	 *	@param	string	$group_forum_id		The forum ID
+	 *	@param 	int		$posted_by			The id of the user that is posting the message
+	 *	@param	string	$subject			The subject of the message.
+	 *	@param	string	$body				The body of the message.
+	 *	@param	string	$post_date			The post date
+	 *	@param	int		$is_followup_to		The message_id of the parent message, if any.
+	 *	@param	int		$thread_id			The thread_id of the message, if known.
+	 *	@param	int		$has_followups		has followups?
+	 *	@param	string	$most_recent_date	The most recent date.
 	 *
 	 *	@return boolean success.
 	 */
-	function updatemsg($group_forum_id,$posted_by,$subject,$body,$post_date,$is_followup_to,$thread_id,$has_followups,$most_recent_date) {
+	function updatemsg($group_forum_id, $posted_by, $subject, $body,
+					   $post_date, $is_followup_to, $thread_id, $has_followups, $most_recent_date) {
+		if (!strlen(trim($body)) || !strlen(trim($subject))) {
+			$this->setError(_('Error: a forum message must include a message body and a subject.'));
+			return false;
+		}
 		$subject = htmlspecialchars($subject);
-		$body = $body;
 		$msg_id = $this->getID();
-		$res = db_query_params ('UPDATE forum 
+		$res = db_query_params ('UPDATE forum
 			SET group_forum_id=$1, posted_by=$2, subject=$3,
 			body=$4, post_date=$5, is_followup_to=$6,
 			thread_id=$7, most_recent_date=$8
 			WHERE msg_id=$9',
 					array ($group_forum_id,
-					       $posted_by,
-					       $subject,
-					       $body,
-					       $post_date,
-					       $is_followup_to,
-					       $thread_id,
-					       $most_recent_date,
-					       $msg_id)) ;
+						$posted_by,
+						$subject,
+						$body,
+						$post_date,
+						$is_followup_to,
+						$thread_id,
+						$most_recent_date,
+						$msg_id)) ;
 		if (!$res) {
 			$this->setError(db_error());
 			return false;
 		} else {
 			if (db_affected_rows($res)<1) {
-				$this->setError("Message not found");
+				$this->setError(_("Message not found"));
 				return false;
 			}
 			return true;
 		}
 	}
-	
+
 	/**
 	 *	sendAttachNotice - contains the logic to send out email attachement followups when a message is posted.
 	 *
-	 *	@param int	attach_id	- The id of the file that has been attached
+	 *	@param int	$attach_id	- The id of the file that has been attached
 	 *
 	 *	@return boolean success.
 	 */
@@ -841,11 +846,11 @@ Or reply to this e-mail entering your response between the following markers:
 			if (!count($ids) > 0 && !$this->Forum->getSendAllPostsTo()) {
 				return true;
 			}
-			
+
 			$body = "\nRead and respond to this message at: ".
 				"\n".util_make_url('/forum/message.php?msg_id='.$this->getID()).
 			"\nBy: " . $this->getPosterRealName() . "\n\n";
-			
+
 			$body .= "A file has been uploaded to this message, you can download it at: ".
 				"\n".util_make_url('/forum/attachment.php?attachid='. $attach_id . "&group_id=" . $this->Forum->Group->getID() . "&forum_id=" . $this->Forum->getID()) . "\n\n";
 
@@ -854,7 +859,7 @@ Or reply to this e-mail entering your response between the following markers:
 			"\nYou are receiving this email because you elected to monitor this forum.".
 			"\nTo stop monitoring this forum, login to ".forge_get_config ('forge_name')." and visit: ".
 			"\n".util_make_url ('/forum/monitor.php?forum_id='.$this->Forum->getID() .'&group_id='.$this->Forum->Group->getID().'&stop=1');
-	
+
 			$extra_headers = "Return-Path: <noreply@".forge_get_config('web_host').">\n";
 			$extra_headers .= "Errors-To: <noreply@".forge_get_config('web_host').">\n";
 			$extra_headers .= "Sender: <noreply@".forge_get_config('web_host').">\n";
@@ -868,7 +873,7 @@ Or reply to this e-mail entering your response between the following markers:
 				$extra_headers .= "\nIn-Reply-To: ".$this->Forum->getReturnEmailAddress()."\n"
 					."References: <forumpost".$this->getParentId()."@".forge_get_config('web_host').">";
 			}
-	
+
 			$subject="[" . $this->Forum->getUnixName() ."][".$this->getID()."] ".util_unconvert_htmlspecialchars($this->getSubject());
 			if (count($ids) != 0) {
 				$bccres = db_query_params ('SELECT email FROM users WHERE status=$1 AND user_id = ANY ($2)',
@@ -880,7 +885,7 @@ Or reply to this e-mail entering your response between the following markers:
 			util_send_message('',$subject,$body,"noreply@".forge_get_config('web_host'),$BCC,'Forum',$extra_headers);
 			return true;
 		}
-		
+
 		return false;
 	}
 }
@@ -889,5 +894,3 @@ Or reply to this e-mail entering your response between the following markers:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
