@@ -49,17 +49,17 @@ class ForumMessageFactory extends Error {
 	/**
 	 *  Constructor.
 	 *
-	 *	@param	object	The Forum object to which this ForumMessageFactory is associated.
+	 *	@param	object	$Forum	The Forum object to which this ForumMessageFactory is associated.
 	 *	@return	boolean	success.
 	 */
 	function ForumMessageFactory(&$Forum) {
 		$this->Error();
 		if (!$Forum || !is_object($Forum)) {
-			$this->setError("ForumMessage:: Invalid group_form_id");
+			$this->setError(_("Invalid group_form_id"));
 			return false;
 		}
 		if ($Forum->isError()) {
-			$this->setError('ForumMessage:: '.$Forum->getErrorMessage());
+			$this->setError('ForumMessage: '.$Forum->getErrorMessage());
 			return false;
 		}
 		$this->Forum =& $Forum;
@@ -70,10 +70,10 @@ class ForumMessageFactory extends Error {
 	/**
 	 *	setup - call this function before getThreaded/nested/etc to set up the user preferences.
 	 *
-	 *	@param	int	The number of rows to skip.
-	 *	@param	string	The style of forum, whether it's nested, ultimate, etc.
-	 *	@param	int	The maximum number of rows to return.
-	 *	@param	int	Whether to set these prefs into the database - use "custom".
+	 *	@param	int    $offset   The number of rows to skip.
+	 *	@param	string $style    The style of forum, whether it's nested, ultimate, etc.
+	 *	@param	int	   $max_rows The maximum number of rows to return.
+	 *	@param	int	   $set      Whether to set these prefs into the database - use "custom".
 	 */
 	function setup($offset,$style,$max_rows,$set) {
 //echo "<br />offset: $offset| style: $style|max_rows: $max_rows|set: $set+";
@@ -136,31 +136,33 @@ class ForumMessageFactory extends Error {
 	}
 
 	/**
-	 *	nestArray - take an array of Forum Messages and building a multi-dimensional associative array for followups.
+	 * nestArray - take an array of Forum Messages and building a multi-dimensional associative array for followups.
 	 *
-	 *	@return	array	The nested multi-dimensional associative array.
+	 * @param	array	$row
+	 * @return	array	The nested multi-dimensional associative array.
 	 */
 	function &nestArray($row) {
 		$cnt=count($row);
 		for ($i=0; $i<$cnt; $i++) {
 			if ($row[$i]) {
 				$msg_arr["".$row[$i]->getParentID().""][] =& $row[$i];
-			}  
+			}
 	  	}
 		return $msg_arr;
 	}
 
 	/**
-	 *	getNested - Return an array of ForumMessage objects arranged for nested forum views.
+	 * getNested - Return an array of ForumMessage objects arranged for nested forum views.
 	 *
-	 *	@return	array	The array of ForumMessages.
+	 * @param	bool	$thread_id
+	 * @return	array   The array of ForumMessages.
 	 */
 	function &getNested($thread_id=false) {
 		if ($this->forum_messages) {
 			return $this->forum_messages;
 		}
 		if (isset ($thread_id) && is_numeric($thread_id)) {
-			$result = db_query_params ('SELECT * FROM forum_user_vw 
+			$result = db_query_params ('SELECT * FROM forum_user_vw
 		WHERE group_forum_id=$1
                   AND thread_id=$2
 		ORDER BY most_recent_date DESC',
@@ -169,7 +171,7 @@ class ForumMessageFactory extends Error {
 						   $this->max_rows+25,
 						   $this->offset);
 		} else {
-			$result = db_query_params ('SELECT * FROM forum_user_vw 
+			$result = db_query_params ('SELECT * FROM forum_user_vw
 		WHERE group_forum_id=$1
 		ORDER BY most_recent_date DESC',
 						   array ($this->Forum->getID()),
@@ -192,16 +194,17 @@ class ForumMessageFactory extends Error {
 	}
 
 	/**
-	 *	getThreaded - Return an array of ForumMessage objects arranged for threaded forum views.
+	 *    getThreaded - Return an array of ForumMessage objects arranged for threaded forum views.
 	 *
-	 *	@return	array	The array of ForumMessages.
+	 * @param	bool	$thread_id
+	 * @return	array	The array of ForumMessages.
 	 */
 	function &getThreaded($thread_id=false) {
 		if ($this->forum_messages) {
 			return $this->forum_messages;
 		}
 		if (isset ($thread_id) && is_numeric($thread_id)) {
-			$result = db_query_params ('SELECT * FROM forum_user_vw 
+			$result = db_query_params ('SELECT * FROM forum_user_vw
 		WHERE group_forum_id=$1
                   AND thread_id=$2
 		ORDER BY most_recent_date DESC',
@@ -210,7 +213,7 @@ class ForumMessageFactory extends Error {
 						   $this->max_rows+25,
 						   $this->offset);
 		} else {
-			$result = db_query_params ('SELECT * FROM forum_user_vw 
+			$result = db_query_params ('SELECT * FROM forum_user_vw
 		WHERE group_forum_id=$1
 		ORDER BY most_recent_date DESC',
 						   array ($this->Forum->getID()),
@@ -222,7 +225,7 @@ class ForumMessageFactory extends Error {
 		if (!$result) {
 			$this->setError('Error when fetching messages '.db_error());
 			return false;
-		} else if ($rows < 1) {
+		} elseif ($rows < 1) {
 			$this->forum_messages = array();
 		} else {
 			while ($arr = db_fetch_array($result)) {
@@ -235,14 +238,15 @@ class ForumMessageFactory extends Error {
 	/**
 	 *	getFlat - Return an array of ForumMessage objects arranged for flat forum views.
 	 *
-	 *	@return	array	The array of ForumMessages.
+	 *	@param	int|bool	$thread_id
+	 *	@return	array		The array of ForumMessages.
 	 */
 	function &getFlat($thread_id=false) {
 		if ($this->forum_messages) {
 			return $this->forum_messages;
 		}
 		if (isset ($thread_id) && is_numeric($thread_id)) {
-			$result = db_query_params ('SELECT * FROM forum_user_vw 
+			$result = db_query_params ('SELECT * FROM forum_user_vw
 		WHERE group_forum_id=$1
                   AND thread_id=$2
 		ORDER BY msg_id DESC',
@@ -251,7 +255,7 @@ class ForumMessageFactory extends Error {
 						   $this->max_rows+25,
 						   $this->offset);
 		} else {
-			$result = db_query_params ('SELECT * FROM forum_user_vw 
+			$result = db_query_params ('SELECT * FROM forum_user_vw
 		WHERE group_forum_id=$1
 		ORDER BY msg_id DESC',
 						   array ($this->Forum->getID()),
@@ -277,5 +281,3 @@ class ForumMessageFactory extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
