@@ -4,6 +4,8 @@
  *
  * Copyright 2002, Tim Perdue/GForge, LLC
  * Copyright 2009, Roland Mas
+ * Copyright 2012-2013, Franck Villaume - TrivialDev
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -23,84 +25,112 @@
 
 require_once $gfcommon.'include/Error.class.php';
 
+/**
+ * Factory method which creates a FRSFile from an file id
+ *
+ * @param	int		$file_id	The file id
+ * @param	array|bool	$data		The result array, if it's passed in
+ * @return	object		FRSFile object
+ */
+function &frsfile_get_object($file_id, $data=false) {
+	global $FRSFILE_OBJ;
+	if (!isset($FRSFILE_OBJ['_'.$file_id.'_'])) {
+		if ($data) {
+					//the db result handle was passed in
+		} else {
+			$res = db_query_params ('SELECT * FROM frs_file WHERE file_id=$1',
+						array ($file_id)) ;
+			if (db_numrows($res)<1 ) {
+				$FRSFILE_OBJ['_'.$file_id.'_']=false;
+				return false;
+			}
+			$data = db_fetch_array($res);
+		}
+		$FRSRelease = frsrelease_get_object($data['release_id']);
+		$FRSFILE_OBJ['_'.$file_id.'_']= new FRSFile($FRSRelease,$data['file_id'],$data);
+	}
+	return $FRSFILE_OBJ['_'.$file_id.'_'];
+}
+
 class FRSFile extends Error {
 
 	/**
 	 * Associative array of data from db.
 	 *
-	 * @var  array   $data_array.
+	 * @var	array	$data_array.
 	 */
 	var $data_array;
 
 	/**
 	 * The FRSRelease.
 	 *
-	 * @var  object  FRSRelease.
+	 * @var	object	FRSRelease.
 	 */
 	var $FRSRelease;
 
 	/**
-	 *  Constructor.
-	 *
-	 *  @param  object  The FRSRelease object to which this file is associated.
-	 *  @param  int  The file_id.
-	 *  @param  array   The associative array of data.
-	 *	@return	boolean	success.
-	 */
-	function FRSFile(&$FRSRelease, $file_id=false, $arr=false) {
+	* Constructor.
+	*
+	* @param	object		$FRSRelease	The FRSRelease object to which this file is associated.
+	* @param	int|bool	$file_id	The file_id.
+	* @param	array|bool	$arr		The associative array of data.
+	* @return	\FRSFile
+	*/
+	function __construct(&$FRSRelease, $file_id=false, $arr=false) {
 		$this->Error();
 		if (!$FRSRelease || !is_object($FRSRelease)) {
-			$this->setError('FRSFile:: No Valid FRSRelease Object');
-			return false;
+			$this->setError(_('Invalid FRS Release Object'));
+			return;
 		}
 		if ($FRSRelease->isError()) {
-			$this->setError('FRSFile:: '.$FRSRelease->getErrorMessage());
-			return false;
+			$this->setError('FRSFile: '.$FRSRelease->getErrorMessage());
+			return;
 		}
 		$this->FRSRelease =& $FRSRelease;
 
 		if ($file_id) {
 			if (!$arr || !is_array($arr)) {
 				if (!$this->fetchData($file_id)) {
-					return false;
+					return;
 				}
 			} else {
 				$this->data_array =& $arr;
 				if ($this->data_array['release_id'] != $this->FRSRelease->getID()) {
 					$this->setError('FRSRelease_id in db result does not match FRSRelease Object');
 					$this->data_array=null;
-					return false;
+					return;
 				}
 			}
 		}
-		return true;
 	}
 
 	/**
-	 *	create - create a new file in this FRSFileRelease/FRSPackage.
+	 * create - create a new file in this FRSFileRelease/FRSPackage.
 	 *
-	 *	@param	string	The name of this file.
-	 *	@param	string	The location of this file in the local file system.
-	 *	@param	int	The type_id of this file from the frs-file-types table.
-	 *	@param	int	The processor_id of this file from the frs-processor-types table.
-	 *	@param	int	The release_date of this file in unix time (seconds).
-	 *	@return	boolean success.
+	 * @param	string		$name		The name of this file.
+	 * @param	string		$file_location	The location of this file in the local file system.
+	 * @param	int		$type_id	The type_id of this file from the frs-file-types table.
+	 * @param	int		$processor_id	The processor_id of this file from the frs-processor-types table.
+	 * @param	int|bool	$release_time	The release_date of this file in unix time (seconds).
+	 * @param	string		$mime_type	The mime type of the file (default: application/octet-stream)
+	 * @param	bool		$is_remote	True if file is an URL and not an uploaded file (default: false)
+	 * @return	bool		success.
 	 */
 	function create($name,$file_location,$type_id,$processor_id,$release_time=false) {
 		if (strlen($name) < 3) {
-			$this->setError(_('FRSFile Name Must Be At Least 3 Characters'));
+			$this->setError(_('Name is too short. It must be at least 3 characters.'));
 			return false;
 		}
 		if (!util_is_valid_filename($name)) {
-			$this->setError(_('Filename can only be alphanumeric and "-" "_" "+" "." "~" characters.'));
+			$this->setError(_('Filename can only be alphanumeric and “-”, “_”, “+”, “.”, “~” characters.'));
 			return false;
 		}
-//
-//	Can't really use is_uploaded_file() or move_uploaded_file()
-//	since we want this to be generalized code
-//	This is potentially exploitable if you do not validate 
-//	before calling this function
-//
+		//
+		//	Can't really use is_uploaded_file() or move_uploaded_file()
+		//	since we want this to be generalized code
+		//	This is potentially exploitable if you do not validate
+		//	before calling this function
+		//
 		if (!is_file($file_location) || !file_exists($file_location)) {
 			$this->setError(_('FRSFile Appears to be invalid'));
 			return false;
@@ -122,29 +152,28 @@ class FRSFile extends Error {
 			return false;
 		}
 
-
-		$path_name=forge_get_config('upload_dir').'/'.$this->FRSRelease->FRSPackage->Group->getUnixName();
+		$path_name = forge_get_config('upload_dir').'/'.$this->FRSRelease->FRSPackage->Group->getUnixName();
 		if (!is_dir($path_name)) {
-			mkdir($path_name,0755);
+			mkdir($path_name, 0755, true);
 		} else {
 			if ( fileperms($path_name) != 0x4755 ) {
-				chmod($path_name,0755);
+				chmod($path_name, 0755);
 			}
 		}
-		$path_name=$path_name.'/'.$this->FRSRelease->FRSPackage->getFileName();
+		$path_name = $path_name.'/'.$this->FRSRelease->FRSPackage->getFileName();
 		if (!is_dir($path_name)) {
-			mkdir($path_name,0755);
+			mkdir($path_name, 0755);
 		} else {
 			if ( fileperms($path_name) != 0x4755 ) {
-				chmod($path_name,0755);
+				chmod($path_name, 0755);
 			}
 		}
-		$path_name=$path_name.'/'.$this->FRSRelease->getFileName();
+		$path_name = $path_name.'/'.$this->FRSRelease->getFileName();
 		if (!is_dir($path_name)) {
-			mkdir($path_name,0755);
+			mkdir($path_name, 0755);
 		} else {
 			if ( fileperms($path_name) != 0x4755 ) {
-				chmod($path_name,0755);
+				chmod($path_name, 0755);
 			}
 		}
 
@@ -155,7 +184,7 @@ class FRSFile extends Error {
 
 		$ret = rename($file_location, $newfilelocation.$name);
 		if (!$ret) {
-			$this->setError(_('File cannot be moved to the permanent location').': '.$newfilelocation.$name);
+			$this->setError(_('File cannot be moved to the permanent location')._(': ').$newfilelocation.$name);
 			return false;
 		}
 
@@ -163,22 +192,18 @@ class FRSFile extends Error {
 			$release_time=time();
 		}
 		$file_size=filesize("$newfilelocation$name");
-		$sql="INSERT INTO frs_file(release_id,filename,release_time,
-				type_id,processor_id,file_size,post_date)
-			VALUES ('".$this->FRSRelease->getId()."','$name','$release_time',
-				'$type_id','$processor_id','$file_size','".time()."')";
 
 		db_begin();
-		$result = db_query_params ('INSERT INTO frs_file(release_id,filename,release_time,type_id,processor_id,file_size,post_date) VALUES ($1,$2,$3,$4,$5,$6,$7)',
+		$result = db_query_params('INSERT INTO frs_file(release_id,filename,release_time,type_id,processor_id,file_size,post_date) VALUES ($1,$2,$3,$4,$5,$6,$7)',
 					   array ($this->FRSRelease->getId(),
 						  $name,
 						  $release_time,
 						  $type_id,
 						  $processor_id,
 						  $file_size,
-						  time ())) ;
+						  time()));
 		if (!$result) {
-			$this->setError('FRSFile::create() Error Adding Release: '.db_error());
+			$this->setError(_('Error Adding Release: ').db_error());
 			db_rollback();
 			return false;
 		}
@@ -188,22 +213,23 @@ class FRSFile extends Error {
 			return false;
 		} else {
 			db_commit();
+			$this->FRSRelease->FRSPackage->createNewestReleaseFilesAsZip();
 			return true;
 		}
 	}
 
 	/**
-	 *  fetchData - re-fetch the data for this FRSFile from the database.
+	 * fetchData - re-fetch the data for this FRSFile from the database.
 	 *
-	 *  @param  int  The file_id.
-	 *  @return boolean	success.
+	 * @param	int	$file_id	The file_id.
+	 * @return	boolean	success.
 	 */
 	function fetchData($file_id) {
 		$res = db_query_params ('SELECT * FROM frs_file_vw WHERE file_id=$1 AND release_id=$2',
 					array ($file_id,
 					       $this->FRSRelease->getID())) ;
 		if (!$res || db_numrows($res) < 1) {
-			$this->setError('FRSFile::fetchData()  Invalid file_id');
+			$this->setError(_('Invalid file_id'));
 			return false;
 		}
 		$this->data_array = db_fetch_array($res);
@@ -212,108 +238,109 @@ class FRSFile extends Error {
 	}
 
 	/**
-	 *  getFRSRelease - get the FRSRelease object this file is associated with.
+	 * getFRSRelease - get the FRSRelease object this file is associated with.
 	 *
-	 *  @return	object	The FRSRelease object.
+	 * @return	object	The FRSRelease object.
 	 */
 	function &getFRSRelease() {
 		return $this->FRSRelease;
 	}
 
 	/**
-	 *  getID - get this file_id.
+	 * getID - get this file_id.
 	 *
-	 *  @return	int	The id of this file.
+	 * @return	int	The id of this file.
 	 */
 	function getID() {
 		return $this->data_array['file_id'];
 	}
 
 	/**
-	 *  getName - get the name of this file.
+	 * getName - get the name of this file.
 	 *
-	 *  @return string  The name of this file.
+	 * @return	string	The name of this file.
 	 */
 	function getName() {
 		return $this->data_array['filename'];
 	}
 
 	/**
-	 *  getSize - get the size of this file.
+	 * getSize - get the size of this file.
 	 *
-	 *  @return int	The size.
+	 * @return	int	The size.
 	 */
 	function getSize() {
 		return $this->data_array['file_size'];
 	}
 
 	/**
-	 *  getTypeID - the filetype id.
+	 * getTypeID - the filetype id.
 	 *
-	 *  @return int the filetype id.
+	 * @return	int	the filetype id.
 	 */
 	function getTypeID() {
 		return $this->data_array['type_id'];
 	}
 
 	/**
-	 *  getTypeName - the filetype name.
+	 * getTypeName - the filetype name.
 	 *
-	 *  @return string	The filetype name.
+	 * @return	string	The filetype name.
 	 */
+	// FIXME : Undefined index: filetype in .../common/frs/FRSFile.class.php on line 293
 	function getFileType() {
 		return $this->data_array['filetype'];
 	}
 
 	/**
-	 *  getProcessorID - the processor id.
+	 * getProcessorID - the processor id.
 	 *
-	 *  @return int the processor id.
+	 * @return	int	the processor id.
 	 */
 	function getProcessorID() {
 		return $this->data_array['processor_id'];
 	}
 
 	/**
-	 *  getProcessor - the processor name.
+	 * getProcessor - the processor name.
 	 *
-	 *  @return string	The processor name.
+	 * @return	string	The processor name.
 	 */
 	function getProcessor() {
 		return $this->data_array['processor'];
 	}
 
 	/**
-	 *  getDownloads - the number of downloads.
+	 * getDownloads - the number of downloads.
 	 *
-	 *  @return int  The number of downloads.
+	 * @return	int	The number of downloads.
 	 */
 	function getDownloads() {
 		return $this->data_array['downloads'];
 	}
 
 	/**
-	 *  getReleaseTime - get the releasetime of this file.
+	 * getReleaseTime - get the releasetime of this file.
 	 *
-	 *  @return int	The release time in unix time.
+	 * @return	int	The release time in unix time.
 	 */
 	function getReleaseTime() {
 		return $this->data_array['release_time'];
 	}
 
 	/**
-	 *  getPostDate - get the post date of this file.
+	 * getPostDate - get the post date of this file.
 	 *
-	 *  @return int	The post date in unix time.
+	 * @return	int	The post date in unix time.
 	 */
 	function getPostDate() {
 		return $this->data_array['post_date'];
 	}
 
 	/**
-	 *  delete - Delete this file from the database and file system.
+	 * delete - Delete this file from the database and file system.
 	 *
-	 *  @return	boolean	success.
+	 * @return	boolean	success.
 	 */
 	function delete() {
 		if (!forge_check_perm ('frs', $this->FRSRelease->FRSPackage->Group->getID(), 'write')) {
@@ -321,8 +348,8 @@ class FRSFile extends Error {
 			return false;
 		}
 
-		$file=forge_get_config('upload_dir').'/'. 
-			$this->FRSRelease->FRSPackage->Group->getUnixName() . '/' . 
+		$file=forge_get_config('upload_dir').'/'.
+			$this->FRSRelease->FRSPackage->Group->getUnixName() . '/' .
 			$this->FRSRelease->FRSPackage->getFileName().'/'.
 			$this->FRSRelease->getFileName().'/'.
 			$this->getName();
@@ -334,22 +361,23 @@ class FRSFile extends Error {
 			$this->setError("frsDeleteFile()::2 ".db_error());
 			return false;
 		} else {
-			$res = db_query_params ('DELETE FROM frs_dlstats_file WHERE file_id=$1',
+			db_query_params ('DELETE FROM frs_dlstats_file WHERE file_id=$1',
 						array ($this->getID())) ;
-			$res = db_query_params ('DELETE FROM frs_dlstats_filetotal_agg WHERE file_id=$1',
+			db_query_params ('DELETE FROM frs_dlstats_filetotal_agg WHERE file_id=$1',
 						array ($this->getID())) ;
+			$this->FRSRelease->FRSPackage->createNewestReleaseFilesAsZip();
 			return true;
 		}
 	}
 
 	/**
-	 *	update - update an existing file in this FRSFileRelease/FRSPackage.
+	 * update - update an existing file in this FRSFileRelease/FRSPackage.
 	 *
-	 *	@param	int	The type_id of this file from the frs-file-types table.
-	 *	@param	int	The processor_id of this file from the frs-processor-types table.
-	 *	@param	int	The release_date of this file in unix time (seconds).
-	 *	@param	int	The release_id of the release this file belongs to (if not set, defaults to the release id of this file).
-	 *	@return	boolean success.
+	 * @param	int		$type_id	The type_id of this file from the frs-file-types table.
+	 * @param	int		$processor_id	The processor_id of this file from the frs-processor-types table.
+	 * @param	int		$release_time	The release_date of this file in unix time (seconds).
+	 * @param	int|bool	$release_id	The release_id of the release this file belongs to (if not set, defaults to the release id of this file).
+	 * @return	boolean		success.
 	 */
 	function update($type_id,$processor_id,$release_time,$release_id=false) {
 		if (!forge_check_perm ('frs', $this->FRSRelease->FRSPackage->Group->getID(), 'write')) {
@@ -363,11 +391,11 @@ class FRSFile extends Error {
 			if ($FRSRelease=frsrelease_get_object($release_id)) {
 				// Check that the new FRSRelease id belongs to the group of this FRSFile
 				if ($FRSRelease->FRSPackage->Group->getID()!=$this->FRSRelease->FRSPackage->Group->getID()) {
-					$this->setError('FRSFile:: No Valid Group Object');
+					$this->setError(_('No Valid Group Object'));
 					return false;
 				}
 			} else {
-				$this->setError('FRSFile:: No Valid FRSRelease Object');
+				$this->setError(_('Invalid FRS Release Object'));
 				return false;
 			}
 		} else {
@@ -385,7 +413,7 @@ class FRSFile extends Error {
 					       $this->getID())) ;
 
 		if (!$res || db_affected_rows($res) < 1) {
-			$this->setError('FRSFile::update() Error On Update: '.db_error());
+			$this->setError(sprintf(_('Error On Update: %s'), db_error()));
 			db_rollback();
 			return false;
 		}
@@ -409,12 +437,13 @@ class FRSFile extends Error {
 			}
 			$ret = rename($old_file_location, $new_file_location);
 			if (!$ret) {
-				$this->setError(_('File cannot be moved to the permanent location').': '.$new_file_location);
+				$this->setError(_('File cannot be moved to the permanent location')._(': ').$new_file_location);
 				db_rollback();
 				return false;
 			}
 		}
 		db_commit();
+		$this->FRSRelease->FRSPackage->createNewestReleaseFilesAsZip();
 		return true;
 	}
 }
@@ -423,5 +452,3 @@ class FRSFile extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
