@@ -4,6 +4,7 @@
  *
  * Copyright 2002, Tim Perdue/GForge, LLC
  * Copyright 2009, Roland Mas
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -25,17 +26,17 @@ require_once $gfcommon.'include/Error.class.php';
 require_once $gfcommon.'frs/FRSFile.class.php';
 
 /**
- *	  Factory method which creates a FRSRelease from an release id
+ * Factory method which creates a FRSRelease from an release id
  *
- *	  @param int	  The release id
- *	  @param array	The result array, if it's passed in
- *	  @return object  FRSRelease object
+ * @param	int	$release_id	The release id
+ * @param	array	$data		The result array, if it's passed in
+ * @return	object	FRSRelease object
  */
-function &frsrelease_get_object($release_id, $data=false) {
+function frsrelease_get_object($release_id, $data = array()) {
 	global $FRSRELEASE_OBJ;
 	if (!isset($FRSRELEASE_OBJ['_'.$release_id.'_'])) {
 		if ($data) {
-					//the db result handle was passed in
+			//the db result handle was passed in
 		} else {
 			$res = db_query_params ('SELECT * FROM frs_release WHERE release_id=$1',
 						array ($release_id)) ;
@@ -45,7 +46,7 @@ function &frsrelease_get_object($release_id, $data=false) {
 			}
 			$data = db_fetch_array($res);
 		}
-		$FRSPackage =& frspackage_get_object($data['package_id']);
+		$FRSPackage = frspackage_get_object($data['package_id']);
 		$FRSRELEASE_OBJ['_'.$release_id.'_']= new FRSRelease($FRSPackage,$data['release_id'],$data);
 	}
 	return $FRSRELEASE_OBJ['_'.$release_id.'_'];
@@ -63,27 +64,27 @@ class FRSRelease extends Error {
 	/**
 	 * The FRSPackage.
 	 *
-	 * @var  object  FRSPacakge.
+	 * @var  object  FRSPackage.
 	 */
 	var $FRSPackage;
 	var $release_files;
 
 	/**
-	 *  Constructor.
+	 * Constructor.
 	 *
-	 *  @param  object  The FRSPackage object to which this release is associated.
-	 *  @param  int  The release_id.
-	 *  @param  array   The associative array of data.
-	 *	@return	boolean	success.
+	 * @param	object  	$FRSPackage	The FRSPackage object to which this release is associated.
+	 * @param	int|bool	$release_id	The release_id.
+	 * @param	array|bool	$arr		The associative array of data.
+	 * @return	bool	success.
 	 */
-	function FRSRelease(&$FRSPackage, $release_id=false, $arr=false) {
+	function FRSRelease(&$FRSPackage, $release_id = false, $arr = false) {
 		$this->Error();
 		if (!$FRSPackage || !is_object($FRSPackage)) {
-			$this->setError('FRSRelease:: No Valid FRSPackage Object');
+			$this->setError(_('Invalid FRS Package Object'));
 			return false;
 		}
 		if ($FRSPackage->isError()) {
-			$this->setError('FRSRelease:: '.$FRSPackage->getErrorMessage());
+			$this->setError('FRSRelease: '.$FRSPackage->getErrorMessage());
 			return false;
 		}
 		$this->FRSPackage =& $FRSPackage;
@@ -106,14 +107,14 @@ class FRSRelease extends Error {
 	}
 
 	/**
-	 *	create - create a new release in the database.
+	 * create - create a new release in the database.
 	 *
-	 *	@param	string	The name of the release.
-	 *	@param	string	The release notes for the release.
-	 *	@param	string	The change log for the release.
-	 *	@param	int	Whether the notes/log are preformatted with \n chars (1) true (0) false.
-	 *	@param	int	The unix date of the release.
-	 *	@return	boolean success.
+	 * @param	string	$name		The name of the release.
+	 * @param	string	$notes		The release notes for the release.
+	 * @param	string	$changes	The change log for the release.
+	 * @param	int	$preformatted	Whether the notes/log are preformatted with \n chars (1) true (0) false.
+	 * @param	int	$release_date	The unix date of the release.
+	 * @return	boolean	success.
 	 */
 	function create($name,$notes,$changes,$preformatted,$release_date=false) {
 		if (strlen($name) < 3) {
@@ -137,9 +138,9 @@ class FRSRelease extends Error {
 		}
 		$res = db_query_params ('SELECT * FROM frs_release WHERE package_id=$1 AND name=$2',
 					array ($this->FRSPackage->getID(),
-					       htmlspecialchars($name))) ;
+						   htmlspecialchars($name))) ;
 		if (db_numrows($res)) {
-			$this->setError('FRSRelease::create() Error Adding Release: Name Already Exists');
+			$this->setError(_('Error Adding Release: Name Already Exists'));
 			return false;
 		}
 
@@ -154,7 +155,7 @@ class FRSRelease extends Error {
 						user_getid(),
 						1)) ;
 		if (!$result) {
-			$this->setError('FRSRelease::create() Error Adding Release: '.db_error());
+			$this->setError(_('Error Adding Release: ').db_error());
 			db_rollback();
 			return false;
 		}
@@ -173,17 +174,17 @@ class FRSRelease extends Error {
 	}
 
 	/**
-	 *  fetchData - re-fetch the data for this Release from the database.
+	 * fetchData - re-fetch the data for this Release from the database.
 	 *
-	 *  @param  int  The release_id.
-	 *  @return	boolean	success.
+	 * @param	int	$release_id	The release_id.
+	 * @return	bool	success.
 	 */
 	function fetchData($release_id) {
 		$res = db_query_params ('SELECT * FROM frs_release WHERE release_id=$1 AND package_id=$2',
 					array ($release_id,
-					       $this->FRSPackage->getID())) ;
+						   $this->FRSPackage->getID())) ;
 		if (!$res || db_numrows($res) < 1) {
-			$this->setError('FRSRelease::fetchData()  Invalid release_id');
+			$this->setError(_('Invalid release_id'));
 			return false;
 		}
 		$this->data_array = db_fetch_array($res);
@@ -192,90 +193,90 @@ class FRSRelease extends Error {
 	}
 
 	/**
-	 *  getFRSPackage - get the FRSPackage object this release is associated with.
+	 * getFRSPackage - get the FRSPackage object this release is associated with.
 	 *
-	 *  @return	object	The FRSPackage object.
+	 * @return	object	The FRSPackage object.
 	 */
 	function &getFRSPackage() {
 		return $this->FRSPackage;
 	}
 
 	/**
-	 *  getID - get this release_id.
+	 * getID - get this release_id.
 	 *
-	 *  @return	int	The id of this release.
+	 * @return	int	The id of this release.
 	 */
 	function getID() {
 		return $this->data_array['release_id'];
 	}
 
 	/**
-	 *  getName - get the name of this release.
+	 * getName - get the name of this release.
 	 *
-	 *  @return string  The name of this release.
+	 * @return	string	The name of this release.
 	 */
 	function getName() {
 		return $this->data_array['name'];
 	}
 
 	/**
-	 *  getFileName - get the filename of this release.
+	 * getFileName - get the filename of this release.
 	 *
-	 *  @return string  The filename of this release.
+	 * @return	string	The filename of this release.
 	 */
 	function getFileName() {
 		return util_secure_filename($this->data_array['name']);
 	}
 
 	/**
-	 *  getStatus - get the status of this release.
+	 * getStatus - get the status of this release.
 	 *
-	 *  @return int	The status.
+	 * @return	int	The status.
 	 */
 	function getStatus() {
 		return $this->data_array['status_id'];
 	}
 
 	/**
-	 *  getNotes - get the release notes of this release.
+	 * getNotes - get the release notes of this release.
 	 *
-	 *  @return string	The release notes.
+	 * @return	string	The release notes.
 	 */
 	function getNotes() {
 		return $this->data_array['notes'];
 	}
 
 	/**
-	 *  getChanges - get the changelog of this release.
+	 * getChanges - get the changelog of this release.
 	 *
-	 *  @return string	The changelog.
+	 * @return	string	The changelog.
 	 */
 	function getChanges() {
 		return $this->data_array['changes'];
 	}
 
 	/**
-	 *  getPreformatted - get the preformatted option of this release.
+	 * getPreformatted - get the preformatted option of this release.
 	 *
-	 *  @return	boolean	preserve_formatting.
+	 * @return	boolean	preserve_formatting.
 	 */
 	function getPreformatted() {
 		return $this->data_array['preformatted'];
 	}
 
 	/**
-	 *  getReleaseDate - get the releasedate of this release.
+	 * getReleaseDate - get the releasedate of this release.
 	 *
-	 *  @return int	The release date in unix time.
+	 * @return	int	The release date in unix time.
 	 */
 	function getReleaseDate() {
 		return $this->data_array['release_date'];
 	}
 
 	/**
-	 *  sendNotice - the logic to send an email/jabber notice for a release.
+	 * sendNotice - the logic to send an email notice for a release.
 	 *
-	 *  @return	boolean	success.
+	 * @return	boolean	success.
 	 */
 	function sendNotice() {
 		$arr =& $this->FRSPackage->getMonitorIDs();
@@ -283,54 +284,51 @@ class FRSRelease extends Error {
 		$date = date('Y-m-d H:i',time());
 
 		$subject = sprintf (_('[%1$s Release] %2$s'),
-				    $this->FRSPackage->Group->getUnixName(),
-				    $this->FRSPackage->getName());
-		$text = stripcslashes(sprintf(_('Project %1$s (%2$s) has released a new version of package "%3$s".
-
-Release note: 
-		
-%4$s
-								
-Change note:
-
-%5$s
-
-
-You can download it by following this link:
-
-%6$s
-
-You receive this email because you requested to be notified when new
-versions of this package were released. If you don\'t wish to be
-notified in the future, please login to %7$s and click this link:
-
-%8$s
-		
-
-		
-	
-
-'
-),
-					      $this->FRSPackage->Group->getPublicName(),
-					      $this->FRSPackage->Group->getUnixName(),
-					      $this->FRSPackage->getName(), 
-					      $this->getNotes(),
-					      $this->getChanges(),
-					      util_make_url ("/frs/?group_id=". $this->FRSPackage->Group->getID() ."&release_id=". $this->getID()),
-					      forge_get_config ('forge_name'),
-					      util_make_url ("/frs/monitor.php?filemodule_id=".$this->FRSPackage->getID()."&group_id=".$this->FRSPackage->Group->getID()."&stop=1")));
+					$this->FRSPackage->Group->getUnixName(),
+					$this->FRSPackage->getName());
+		$text = sprintf(_('Project %1$s (%2$s) has released a new version of package “%3$s”.'),
+										$this->FRSPackage->Group->getPublicName(),
+										$this->FRSPackage->Group->getUnixName(),
+										$this->FRSPackage->getName())
+							. "\n\n"
+							. _('Release Notes')._(':')
+							. "\n\n"
+							. $this->getNotes()
+							. _('Change Log')._(':')
+							. "\n\n"
+							. $this->getChanges()
+							. "\n\n"
+							. _('You can download it by following this link')._(':')
+							. "\n\n"
+							. util_make_url ("/frs/?group_id=". $this->FRSPackage->Group->getID() ."&release_id=". $this->getID())
+							. "\n\n"
+							. sprintf(_('You receive this email because you requested to be notified when new '
+										. 'versions of this package were released. If you don\'t wish to be '
+										. 'notified in the future, please login to %s and click this link:'),
+										forge_get_config('forge_name'))
+							. "\n\n"
+							. util_make_url ("/frs/monitor.php?filemodule_id=".$this->FRSPackage->getID()."&group_id=".$this->FRSPackage->Group->getID()."&stop=1");
 //		$text = util_line_wrap($text);
 		if (count($arr)) {
 			util_handle_message(array_unique($arr),$subject,$text);
 		}
-		
 	}
 
 	/**
-	 *	getFiles - gets all the file objects for files in this release.
+	 * newFRSFile - generates a FRSFile (allows overloading by subclasses)
 	 *
-	 *	return	array	Array of FRSFile Objects.
+	 * @param	string	FRS file identifier
+	 * @param	array	fetched data from the DB
+	 * @return	FRSFile	new FRSFile object.
+	 */
+	protected function newFRSFile($file_id, $data) {
+		return new FRSFile($this,$file_id, $data);
+	}
+
+	/**
+	 * getFiles - gets all the file objects for files in this release.
+	 *
+	 * @return	array	Array of FRSFile Objects.
 	 */
 	function &getFiles() {
 		if (!is_array($this->release_files) || count($this->release_files) < 1) {
@@ -338,18 +336,18 @@ notified in the future, please login to %7$s and click this link:
 			$res = db_query_params ('SELECT * FROM frs_file_vw WHERE release_id=$1',
 						array ($this->getID())) ;
 			while ($arr = db_fetch_array($res)) {
-				$this->release_files[]=new FRSFile($this,$arr['file_id'],$arr);
+				$this->release_files[]=$this->newFRSFile($arr['file_id'],$arr);
 			}
 		}
 		return $this->release_files;
 	}
 
 	/**
-	 *  delete - delete this release and all its related data.
+	 * delete - delete this release and all its related data.
 	 *
-	 *  @param  bool	I'm Sure.
-	 *  @param  bool	I'm REALLY sure.
-	 *  @return   bool true/false;
+	 * @param	bool	$sure		I'm Sure.
+	 * @param	bool	$really_sure	I'm REALLY sure.
+	 * @return	bool	true/false;
 	 */
 	function delete($sure, $really_sure) {
 		if (!$sure || !$really_sure) {
@@ -371,14 +369,14 @@ notified in the future, please login to %7$s and click this link:
 			$this->FRSPackage->Group->getUnixName() . '/' .
 			$this->FRSPackage->getFileName().'/'.
 			$this->getFileName().'/';
-		
+
 		// double-check we're not trying to remove root dir
 		if (util_is_root_dir($dir)) {
-			$this->setError('Release::delete error: trying to delete root dir');
+			$this->setError(_('Release delete error: trying to delete root dir'));
 			return false;
 		}
 		rmdir($dir);
-		
+
 		db_query_params ('DELETE FROM frs_release WHERE release_id=$1 AND package_id=$2',
 				 array ($this->getID(),
 					$this->FRSPackage->getID())) ;
@@ -386,23 +384,23 @@ notified in the future, please login to %7$s and click this link:
 	}
 
 	/**
-	 *	update - update a new release in the database.
+	 * update - update a new release in the database.
 	 *
-	 *	@param	int	The status of this release from the frs_status table.
-	 *	@param	string	The name of the release.
-	 *	@param	string	The release notes for the release.
-	 *	@param	string	The change log for the release.
-	 *	@param	int	Whether the notes/log are preformatted with \n chars (1) true (0) false.
-	 *	@param	int	The unix date of the release.
-	 *	@return	boolean success.
+	 * @param	int	The status of this release from the frs_status table.
+	 * @param	string	The name of the release.
+	 * @param	string	The release notes for the release.
+	 * @param	string	The change log for the release.
+	 * @param	int	Whether the notes/log are preformatted with \n chars (1) true (0) false.
+	 * @param	int	The unix date of the release.
+	 * @return	boolean success.
 	 */
-	function update($status,$name,$notes,$changes,$preformatted,$release_date) {
+	function update($status, $name, $notes, $changes, $preformatted, $release_date) {
 		if (strlen($name) < 3) {
 			$this->setError(_('FRSPackage Name Must Be At Least 3 Characters'));
 			return false;
 		}
-		
-		if (!forge_check_perm ('frs', $this->FRSPackage->Group->getID(), 'write')) {
+
+		if (!forge_check_perm('frs', $this->FRSPackage->Group->getID(), 'write')) {
 			$this->setPermissionDeniedError();
 			return false;
 		}
@@ -412,60 +410,61 @@ notified in the future, please login to %7$s and click this link:
 		} else {
 			$preformatted = 0;
 		}
-		
-		if($this->getName()!=htmlspecialchars($name)) {
+
+		if($this->getName() != htmlspecialchars($name)) {
 			$res = db_query_params ('SELECT * FROM frs_release WHERE package_id=$1 AND name=$2',
 						array ($this->FRSPackage->getID(),
-						       htmlspecialchars($name))) ;
+							   htmlspecialchars($name))) ;
 			if (db_numrows($res)) {
-				$this->setError('FRSRelease::update() Error On Update: Name Already Exists');
+				$this->setError(_('Error On Update: Name Already Exists'));
 				return false;
 			}
-		}		
+		}
 		db_begin();
 		$res = db_query_params ('UPDATE frs_release SET	name=$1,status_id=$2,notes=$3,
 			changes=$4,preformatted=$5,release_date=$6,released_by=$7
 			WHERE package_id=$8 AND release_id=$9',
 					array (htmlspecialchars($name),
-					       $status,
-					       htmlspecialchars($notes),
-					       htmlspecialchars($changes),
-					       $preformatted,
-					       $release_date,
-					       user_getid(),
-					       $this->FRSPackage->getID(),
-					       $this->getID())) ;
+						   $status,
+						   htmlspecialchars($notes),
+						   htmlspecialchars($changes),
+						   $preformatted,
+						   $release_date,
+						   user_getid(),
+						   $this->FRSPackage->getID(),
+						   $this->getID())) ;
 
 		if (!$res || db_affected_rows($res) < 1) {
-			$this->setError('FRSRelease::update() Error On Update: '.db_error());
+			$this->setError(sprintf(_('Error On Update: %s'), db_error()));
 			db_rollback();
 			return false;
 		}
 
 		$oldfilename = $this->getFileName();
 		if(!$this->fetchData($this->getID())){
-			$this->setError("FRSRelease::update() Error Updating Release: Couldn't fetch data");
+			$this->setError(_("Error Updating Release: Couldn't fetch data"));
 			db_rollback();
 			return false;
 		}
 		$newfilename = $this->getFileName();
 		$olddirlocation = forge_get_config('upload_dir').'/'.$this->FRSPackage->Group->getUnixName().'/'.$this->FRSPackage->getFileName().'/'.$oldfilename;
 		$newdirlocation = forge_get_config('upload_dir').'/'.$this->FRSPackage->Group->getUnixName().'/'.$this->FRSPackage->getFileName().'/'.$newfilename;
-	
+
 		if (($oldfilename!=$newfilename) && is_dir($olddirlocation)) {
 			if (is_dir($newdirlocation)) {
-				$this->setError('FRSRelease::update() Error Updating Release: Directory Already Exists');
+				$this->setError(_('Error Updating Release: Directory Already Exists'));
 				db_rollback();
-				return false;	
+				return false;
 			} else {
-				if(!rename($olddirlocation,$newdirlocation)) {
-					$this->setError("FRSRelease::update() Error Updating Release: Couldn't rename dir");
+				if(!rename($olddirlocation, $newdirlocation)) {
+					$this->setError(_("Error Updating Release: Couldn't rename dir"));
 					db_rollback();
 					return false;
 				}
 			}
-		}	
+		}
 		db_commit();
+		$this->FRSPackage->createNewestReleaseFilesAsZip();
 		return true;
 	}
 
@@ -475,5 +474,3 @@ notified in the future, please login to %7$s and click this link:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
