@@ -1,4 +1,4 @@
-<?php   
+<?php
 /**
  * FusionForge top-level information
  *
@@ -35,8 +35,10 @@ class FusionForge extends Error {
 	function FusionForge() {
 		$this->Error();
 
-		// Some variables are overridden if installed from a package
-		@include_once $gfcommon.'pkginfo.inc.php';
+		$pkg = dirname(dirname(__FILE__)).'/pkginfo.inc.php';
+		if (file_exists($pkg)) {
+			include $pkg;
+		}
 
 		if (isset($forge_pkg_name)) {
 			$this->software_name = $forge_pkg_name;
@@ -47,7 +49,7 @@ class FusionForge extends Error {
 		if (isset($forge_pkg_version)) {
 			$this->software_version = $forge_pkg_version;
 		} else {
-			$this->software_version = '5.1.1' ;
+			$this->software_version = '5.3.2' ;
 		}
 
 		if (isset($forge_pkg_type)) {
@@ -61,7 +63,7 @@ class FusionForge extends Error {
 
 	function getNumberOfPublicHostedProjects() {
 		$res = db_query_params ('SELECT group_id FROM groups WHERE status=$1',
-				      array ('A'));	
+				      array ('A'));
 		if (!$res) {
 			$this->setError('Unable to get hosted project count: '.db_error());
 			return false;
@@ -78,7 +80,7 @@ class FusionForge extends Error {
 
 	function getNumberOfHostedProjects() {
 		$res = db_query_params ('SELECT group_id FROM groups WHERE status=$1',
-					array ('A'));	
+					array ('A'));
 		if (!$res) {
 			$this->setError('Unable to get hosted project count: '.db_error());
 			return false;
@@ -103,7 +105,6 @@ class FusionForge extends Error {
 		return $this->parseCount($res);
 	}
 
-
 	function getPublicProjectNames() {
 		$res = db_query_params ('SELECT unix_group_name, group_id FROM groups WHERE status=$1 ORDER BY unix_group_name',
 					array ('A'));
@@ -120,7 +121,7 @@ class FusionForge extends Error {
 		}
 		return $result;
 	}
-	
+
 	function parseCount($res) {
 		$row_count = db_fetch_array($res);
 		return $row_count['count'];
@@ -131,5 +132,3 @@ class FusionForge extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
