@@ -32,8 +32,7 @@ class MailParser extends Error {
 		$this->Error();
 		$size = filesize($input_file);
 		if ($size > $this->max_file_size) {
-			$this->setError("Error - file too large");
-			return false;
+			return $this->setError(_("Error: file too large"));
 		}
 		$fo = fopen($input_file, 'r');
 		$input_data = fread($fo, $size);
@@ -74,7 +73,6 @@ class MailParser extends Error {
 				$body .= $lines[$i]."\r\n";
 			}
 
-
 		}
 		$this->body =& $body;
 		$this->headers =& $header;
@@ -82,16 +80,14 @@ class MailParser extends Error {
 		if ($header['Content-Type']) {
 			$hdr = strtolower($header['Content-Type']);
 			if (strpos($hdr,'text/plain') !== false) {
-				
+
 			} else {
-				$this->setError('Error - only text/plain supported at this time');
+				$this->setError(_('Error - only text/plain supported at this time'));
 				return false;
 			}
 		}
 //echo "\n\n**".$header['Content-Type']."**\n\n";
 
-
-
 		unset ($lines);
 //system("echo \"mp: headers".implode("***\n",$header)."\n\" >> /tmp/forum.log");
 //system("echo \"mp: body".$body."\n\" >> /tmp/forum.log");
@@ -219,7 +215,7 @@ class MailParser extends Error {
 		if (!strcasecmp($string_arr[2], "B") && $string_arr[3]) {
 			$string = base64_decode($string_arr[3]);
 			$charset = $string_arr[1];
-		} else if (!strcasecmp($string_arr[2], "Q") && $string_arr[3]) {
+		} elseif (!strcasecmp($string_arr[2], "Q") && $string_arr[3]) {
 			$string = quoted_printable_decode($string_arr[3]);
 			$charset = $string_arr[1];
 		}
@@ -235,5 +231,3 @@ class MailParser extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
