@@ -5,6 +5,7 @@
  * Copyright 1999-2001, VA Linux Systems, Inc.
  * Copyright 2002-2004, GForge, LLC
  * Copyright 2009, Roland Mas
+ * Copyright 2011, Franck Villaume - Capgemini
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -30,17 +31,16 @@ $PERMISSION_OBJ=array();
  * permission_get_object() - Get permission objects
  *
  * permission_get_object is useful so you can pool Permission objects/save database queries
- * You should always use this instead of instantiating the object directly 
+ * You should always use this instead of instantiating the object directly
  *
- * @param		object	The Group in question
- * @param		object	The User needing Permission
- * @return a Permission or false on failure
+ * @param		$_Group object	The Group in question
+ * @return      object	a Permission or false on failure
  *
  */
 function &permission_get_object(&$_Group, &$_User = NULL) {
 	//create a common set of Permission objects
 	//saves a little wear on the database
-	
+
 	global $PERMISSION_OBJ;
 
 	if (is_object($_Group)) {
@@ -95,20 +95,19 @@ class Permission extends Error {
 	 *	Constructor for this object.
 	 *
 	 *	@param	object	Group Object required.
-	 *	@param	object	User Object required.
-	 *	
+	 *
 	 */
-	function Permission (&$_Group) {
+	function __construct (&$_Group) {
 		if (!$_Group || !is_object($_Group)) {
-			$this->setError('No Valid Group Object');
-			return false;
+			$this->setError(_('No Valid Group Object'));
+			return;
 		}
 		if ($_Group->isError()) {
 			$this->setError('Permission: '.$_Group->getErrorMessage());
-			return false;
+			return;
 		}
 		$this->Group =& $_Group;
-		$this->group_id = $this->Group->getID() ;
+		$this->group_id = $this->Group->getID();
 	}
 
 	/**
@@ -117,7 +116,7 @@ class Permission extends Error {
 	 *  @return	boolean	is_super_user.
 	 */
 	function isSuperUser() {
-		return forge_check_global_perm ('forge_admin') ;
+		return forge_check_global_perm ('forge_admin');
 	}
 
 	/**
@@ -126,7 +125,7 @@ class Permission extends Error {
 	 *  @return	boolean	is_forum_admin.
 	 */
 	function isForumAdmin() {
-		return forge_check_perm ('forum_admin', $this->group_id) ;
+		return forge_check_perm ('forum_admin', $this->group_id);
 	}
 
 	/**
@@ -135,7 +134,16 @@ class Permission extends Error {
 	 *  @return	boolean	is_doc_editor.
 	 */
 	function isDocEditor() {
-		return forge_check_perm ('docman', $this->group_id, 'admin') ;
+		return forge_check_perm('docman', $this->group_id, 'approve');
+	}
+
+	/**
+	 *  isDocAdmin - whether the current user has form doc admin perms.
+	 *
+	 *  @return	boolean	is_doc_admin.
+	 */
+	function isDocAdmin() {
+		return forge_check_perm('docman', $this->group_id, 'admin');
 	}
 
 	/**
@@ -144,7 +152,7 @@ class Permission extends Error {
 	 *  @return	boolean	is_release_technician.
 	 */
 	function isReleaseTechnician() {
-		return forge_check_perm ('frs', $this->group_id, 'write') ;
+		return forge_check_perm ('frs', $this->group_id, 'write');
 	}
 
 	/**
@@ -153,7 +161,7 @@ class Permission extends Error {
 	 *  @return	boolean	is_artifact_admin.
 	 */
 	function isArtifactAdmin() {
-		return forge_check_perm ('tracker_admin', $this->group_id) ;
+		return forge_check_perm ('tracker_admin', $this->group_id);
 	}
 
 	/**
@@ -162,7 +170,7 @@ class Permission extends Error {
 	 *  @return	boolean	is_projman_admin.
 	 */
 	function isPMAdmin() {
-		return forge_check_perm ('pm_admin', $this->group_id) ;
+		return forge_check_perm ('pm_admin', $this->group_id);
 	}
 
 	/**
@@ -171,7 +179,7 @@ class Permission extends Error {
 	 *  @return	boolean	is_admin.
 	 */
 	function isAdmin() {
-		return forge_check_perm ('project_admin', $this->group_id) ;
+		return forge_check_perm ('project_admin', $this->group_id);
 	}
 
 	/**
@@ -180,16 +188,16 @@ class Permission extends Error {
 	 *	@return	boolean	cvs_flags
 	 */
 	function isCVSReader() {
-		return forge_check_perm ('scm', $this->group_id, 'read') ;
+		return forge_check_perm ('scm', $this->group_id, 'read');
 	}
-	
+
 	/**
 	 *      isCVSWriter - checks if the user has CVS write access.
 	 *
 	 *      @return boolean cvs_flags
 	 */
 	function isCVSWriter() {
-		return forge_check_perm ('scm', $this->group_id, 'write') ;
+		return forge_check_perm ('scm', $this->group_id, 'write');
 	}
 
 	/**
@@ -200,21 +208,21 @@ class Permission extends Error {
 	function isMember() {
 		if ($this->isAdmin()) {
 			//admins are tested first so that super-users can return true
-			//and admins of a project should always have full privileges 
+			//and admins of a project should always have full privileges
 			//on their project
 			return true;
-		} else {
-			$engine = RBACEngine::getInstance() ;
+		}
+		$engine = RBACEngine::getInstance();
 
-			$roles = $engine->getAvailableRoles () ;
-			foreach ($roles as $role) {
-				$hp = $role->getHomeProject () ;
-				if ($hp != NULL
-				    && $hp->getID() == $this->group_id) {
-					return true ;
-				}
+		$roles = $engine->getAvailableRoles();
+		foreach ($roles as $role) {
+			$hp = $role->getHomeProject();
+			if ($hp != NULL
+			    && $hp->getID() == $this->group_id) {
+				return true;
 			}
 		}
+		return false;
 	}
 }
 
@@ -222,5 +230,3 @@ class Permission extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
