@@ -3,6 +3,7 @@
  * FusionForge configuration functions
  *
  * Copyright 2009, Roland Mas
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -20,18 +21,31 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+// See docs in http://fusionforge.org/plugins/mediawiki/wiki/fusionforge/index.php/Configuration
+
+/**
+ *
+ * Singleton FusionForge configuration database manager TODO : Enter better description here ...
+ *
+ */
 class FusionForgeConfig {
 	static protected $instance = NULL ;
 	private $settings ;
 	private $bools = array () ;
-    
+
+	/**
+	 * Singleton accessor to the configuration database
+	 * @return FusionForgeConfig instance
+	 */
 	static public function get_instance () {
 		if (self::$instance == NULL) {
 			self::$instance = new FusionForgeConfig () ;
 		}
 		return self::$instance ;
 	}
-  
+
+	// TODO: add a constructor that initializes self::$instance to self ?
+
 	public function get_sections () {
 		return array_keys ($this->settings) ;
 	}
@@ -54,7 +68,7 @@ class FusionForgeConfig {
 
 		foreach ($matches[0] as $m) {
 			$c = explode ('/', substr($m,1)) ;
-			
+
 			if (isset ($this->settings[$c[0]][$c[1]])) {
 				$tmp = str_replace ($m, $this->get_value($c[0],$c[1]), $tmp) ;
 			}
@@ -91,22 +105,14 @@ class FusionForgeConfig {
 		$this->settings[$section][$var] = $value ;
 	}
 
-	function read_config_file ($file) {
-		if (getenv ('FUSIONFORGE_USE_PRE_51_CONFIG') == 'true') {
-			$fallback_only = true;
-		} else {
-			$fallback_only = false;
-		}
-
-		if (file_exists($file) && is_readable($file)) {
-			$sections = parse_ini_file ($file, true) ;
+	function read_config_file($filename) {
+		if (file_exists($filename) && is_readable($filename)) {
+			$sections = parse_ini_file($filename, true);
 			if (is_array($sections)) {
 				foreach ($sections as $section => $options) {
-					foreach ($options as $var => $value) {
-						if ($fallback_only) {
-							$this->set_value($section,$var,$value);
-						} else {
-							$this->reset_value($section,$var,$value);
+					if (is_array($options)) {
+						foreach ($options as $var => $value) {
+							$this->reset_value($section, $var, $value);
 						}
 					}
 				}
@@ -139,16 +145,22 @@ class FusionForgeConfig {
 		case '1':
 			return true ;
 		}
-		
+
 		return false ;
 	}
 
-  }
-
-if (!isset ($fusionforge_config)) {
-	$fusionforge_config = new FusionForgeConfig () ;
 }
 
+if (!isset ($fusionforge_config)) {
+	$fusionforge_config = new FusionForgeConfig();
+}
+
+/**
+ * Get value of variable "name" in section "section"
+ * @param string $var
+ * @param string $section defaults to "core" if missing
+ * @return mixed <NULL, boolean>
+ */
 function forge_get_config ($var, $section = 'core') {
 	$c = FusionForgeConfig::get_instance () ;
 	return $c->get_value ($section, $var) ;
@@ -198,34 +210,60 @@ function forge_set_vars_from_config () {
 	}
 }
 
-
+/**
+ * Define a new configuration item with given name/section and default value
+ * @param string $var name
+ * @param string $section
+ * @param any $default
+ */
 function forge_define_config_item ($var, $section, $default) {
 	$c = FusionForgeConfig::get_instance () ;
-
-	return $c->set_value ($section, $var, $default) ;
+	$c->set_value ($section, $var, $default) ;
 }
 
+/**
+ * Tag the variable as boolean, which allows human-readable values in the configuration files (such as yes, true, on and 1; anything else is mapped to false)
+ * @param string $var name
+ * @param string $section
+ */
 function forge_set_config_item_bool ($var, $section) {
 	$c = FusionForgeConfig::get_instance () ;
-
-	return $c->mark_as_bool ($section, $var) ;
+	$c->mark_as_bool ($section, $var) ;
 }
 
-function forge_read_config_file ($file) {
+/**
+ * Define a new boolean configuration item with given name/section and default value
+ * @param string $var name
+ * @param string $section
+ * @param any $default
+ */
+function forge_define_config_item_bool ($var, $section, $default) {
+	forge_define_config_item ($var, $section, $default);
+	forge_set_config_item_bool ($var, $section);
+}
+
+/**
+ * Read a *.ini file and inject its contents into the configuration database
+ * @param string $filename
+ */
+function forge_read_config_file ($filename) {
 	$c = FusionForgeConfig::get_instance () ;
-
-	return $c->read_config_file ($file) ;
+	$c->read_config_file ($filename) ;
 }
 
+/**
+ * Read all configuration files in a directory
+ * @param string $path
+ */
 function forge_read_config_dir ($path) {
 	$c = FusionForgeConfig::get_instance () ;
-	
+
 	$files = array () ;
-	
+
 	if (is_dir($path)){
 		if ($handle = opendir($path)) {
 			while (false !== ($file = readdir($handle))) {
-				if ($file != "." 
+				if ($file != "."
 			    	&& $file != ".."
 			    	// Avoid .bak, .old, .dpkg-old and so on, but keep .ini
 			    	&& preg_match ('/^[0-9a-zA-Z_-]+(.ini)?$/', $file)) {
@@ -244,13 +282,10 @@ function forge_read_config_dir ($path) {
 
 function forge_reset_config_item ($var, $section, $default) {
 	$c = FusionForgeConfig::get_instance () ;
-
-	return $c->reset_value ($section, $var, $default) ;
+	$c->reset_value ($section, $var, $default) ;
 }
 
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
