@@ -37,7 +37,7 @@ class LDAP extends UNIX {
 	/*
  	* Auxilary functions
  	*/
-	
+
 	/**
  	*	asciize() - Replace non-ascii characters with question marks
  	*
@@ -45,15 +45,15 @@ class LDAP extends UNIX {
  	*	know which encoding 8-bit characters in database use, we
  	*	just replace them with question marks.
  	*
- 	*  @param		string	UTF-8 encoded character string.
- 	*	@return string which contains only ascii characters
+ 	*	@param		string	$str	UTF-8 encoded character string.
+ 	*	@return		string	which contains only ascii characters
  	*/
 	function asciize($str) {
 		if (!$str) {
 			// LDAP don't allow empty strings for some attributes
 			return '?';
 		}
-	
+
 		return preg_replace("/[\x80-\xff]/","?",$str);
 	}
 
@@ -64,7 +64,7 @@ class LDAP extends UNIX {
 	/**
 	 * gfLdapConnect() - Connect to the LDAP server
 	 *
-	 * @returns true on success/false on error
+	 * @returns bool	true on success/false on error
 	 *
 	 */
 	function gfLdapConnect() {
@@ -75,7 +75,7 @@ class LDAP extends UNIX {
 			$this->clearError();
 			$ldap_conn = @ldap_connect(forge_get_config('ldap_host'),forge_get_config('ldap_port'));
 			if (!$ldap_conn) {
-				$this->setError('ERROR: Cannot connect to LDAP server<br />');
+				$this->setError('Error: Cannot connect to LDAP server<br />');
 				return false;
 			}
 			if (forge_get_config('ldap_version')) {
@@ -88,10 +88,11 @@ class LDAP extends UNIX {
 
 	/**
 	 * gfLdapAdd() - Wrapper for ldap_add()
-	 * 
-	 * @param		string	dn
-	 * @param		string	entry
 	 *
+	 * @param		string	$dn		dn
+	 * @param		string	$entry	entry
+	 *
+	 * @return bool
 	 */
 	function gfLdapAdd($dn, $entry) {
 		global $ldap_conn;
@@ -101,8 +102,9 @@ class LDAP extends UNIX {
 	/**
 	 * gfLdapDelete() - Wrapper for ldap_delete()
 	 *
-	 * @param		string	dn
+	 * @param		string	$dn		dn
 	 *
+	 * @return bool
 	 */
 	function gfLdapDelete($dn) {
 		global $ldap_conn;
@@ -112,74 +114,79 @@ class LDAP extends UNIX {
 	/**
 	 * gfLdapModify() - Wrapper for ldap_modify()
 	 *
-	 * @param		string	dn
-	 * @param		string	entry
+	 * @param		string	$dn		dn
+	 * @param		string	$entry	entry
 	 *
+	 * @return bool
 	 */
 	function gfLdapModify($dn,$entry) {
 		global $ldap_conn;
 		return @ldap_modify($ldap_conn,$dn,$entry);
 	}
-	
+
 	/**
 	 * gfLdapModifyIfExists() - Wrapper for ldap_modify()
 	 * works like gfLdapModify, but returns true if the LDAP entry does not exist
 	 *
-	 * @param		string	dn
-	 * @param		string	entry
+	 * @param		string	$dn		dn
+	 * @param		string	$entry	entry
 	 *
+	 * @return bool
 	 */
 	function gfLdapModifyIfExists($dn,$entry) {
-        	$res = $this->gfLdapModify($dn,$entry);
-        	if ($res) {
-                	return true ;
-        	} else {
-                	$err = ldap_errno ($ldap_conn) ;
-                	if ($err == 32) {
-                        	return true ;
-                	} else {
-                        	return false ;
-                	}
-        	};
+			$res = $this->gfLdapModify($dn,$entry);
+			if ($res) {
+					return true ;
+			} else {
+					$err = ldap_errno ($ldap_conn) ;
+					if ($err == 32) {
+							return true ;
+					} else {
+							return false ;
+					}
+			}
 	}
 
 	/**
 	 * gfLdapModAdd() - Wrapper for ldap_mod_add()
 	 *
-	 * @param		string	dn
-	 * @param		string	entry
+	 * @param		string	$dn		dn
+	 * @param		string	$entry	entry
 	 *
+	 * @return bool
 	 */
 	function gfLdapModAdd($dn,$entry) {
 		global $ldap_conn;
 		return @ldap_mod_add($ldap_conn,$dn,$entry);
 	}
-	
+
 	/**
 	 * gfLdapModDel() - Wrapper for ldap_mod_del()
 	 *
-	 * @param		string	dn
-	 * @param		string	entry
+	 * @param		string	$dn		dn
+	 * @param		string	$entry	entry
 	 *
+	 * @return bool
 	 */
 	function gfLdapModDel($dn,$entry) {
 		global $ldap_conn;
 		return @ldap_mod_del($ldap_conn,$dn,$entry);
 	}
-	
+
 	/**
 	 * gfLdapRead() - Wrapper for ldap_read()
 	 *
-	 * @param		string	dn
-	 * @param		string	filter
-	 * @param		int		attrs
+	 * @param		string	$dn		dn
+	 * @param		string	$filter	filter
+	 * @param		int		$attrs	attrs
 	 *
+	 * @return resource
 	 */
 	function gfLdapRead($dn,$filter,$attrs=0) {
 		global $ldap_conn;
 		return @ldap_read($ldap_conn,$dn,$filter,$attrs);
 	}
-	
+
 	/**
 	 * gfLdapError() - Wrapper for ldap_error()
 	 *
@@ -190,7 +197,7 @@ class LDAP extends UNIX {
 		global $ldap_conn;
 		return ldap_error($ldap_conn);
 	}
-	
+
 	/**
 	 * gfLdapErrno() - Wrapper for ldap_errno()
 	 *
@@ -201,7 +208,7 @@ class LDAP extends UNIX {
 		global $ldap_conn;
 		return ldap_errno($ldap_conn);
 	}
-	
+
 	/**
 	 * gfLdapAlreadyExists()
 	 */
@@ -209,7 +216,7 @@ class LDAP extends UNIX {
 		global $ldap_conn;
 		return ldap_errno($ldap_conn)==20;
 	}
-	
+
 	/**
 	 * gfLdapDoesNotExist()
 	 */
@@ -217,88 +224,88 @@ class LDAP extends UNIX {
 		global $ldap_conn;
 		return ldap_errno($ldap_conn)==16;
 	}
-	
+
 	/*
 	 * User management functions
 	 */
-	
+
 	/**
 	 * sysCheckUser() - Check for the existence of a user
-	 * 
-	 * @param		int		The user ID of the user to check
-	 * @returns true on success/false on error
+	 *
+	 * @param		int	$user_id	The user ID of the user to check
+	 * @return bool	true on success/false on error
 	 *
 	 */
 	function sysCheckUser($user_id) {
-		$user =& user_get_object($user_id);
+		$user = user_get_object($user_id);
 		if (!$user) {
 			return false;
 		}
 		return $this->gfLdapcheck_user_by_name($user->getUnixName());
 	}
-	
+
 	/**
 	 * gfLdapcheck_user_by_name() - Check for a user by the username
 	 *
-	 * @param		string	The username 
-	 * @returns true on success/false on error
+	 * @param		string	$user_name	The username
+	 * @return bool	true on success/false on error
 	 *
 	 */
 	function gfLdapcheck_user_by_name($user_name) {
 		global $ldap_conn;
 
-	
+
 		if (!$this->gfLdapConnect()) {
 			return false;
 		}
-	
+
 		$dn = 'uid='.$user_name.',ou=People,'.forge_get_config('ldap_base_dn');
 		$res = $this->gfLdapRead($dn,"objectClass=*",array("uid"));
 		if ($res) {
 			ldap_free_result($res);
 			return true;
 		}
-	
+
 		return false;
 	}
-	
+
 	/**
 	 * sysCreateUser() - Create a user
 	 *
 	 * @param		int	The user ID of the user to create
-	 * @returns The return status of gfLdapcreate_user_from_object()
+	 * @return	bool	 The return status of gfLdapcreate_user_from_object()
 	 *
 	 */
 	function sysCreateUser($user_id) {
 		// Check even if the user shouldn't exist
 		// It can be created by a cron
 		if (!$this->sysCheckUser($user_id)){
-			$user = &user_get_object($user_id);
+			$user = user_get_object($user_id);
 			return $this->gfLdapcreate_user_from_object($user);
 		}
 		return true;
 	}
-	
+
 	/**
 	 * sysCheckCreateUser() - Check that a user has been created
 	 *
 	 * @param		int		The ID of the user to check
-	 * @returns true on success/false on error
+	 * @return bool	true on success/false on error
 	 *
 	 */
 	function sysCheckCreateUser($user_id) {
 		if (!$this->sysCheckUser($user_id)){
-			$user = &user_get_object($user_id);
+			$user = user_get_object($user_id);
 			return $this->gfLdapcreate_user_from_object($user);
 		}
 		return true;
 	}
-	
+
 	/**
 	 * gfLdapcreate_user_from_object() - Create a user from information contained within an object
 	 *
 	 * @param		object	The user object
-	 * @returns true on success/false on error
+	 * @return bool	true on success/false on error
 	 *
 	 */
 	function gfLdapcreate_user_from_object(&$user) {
@@ -325,22 +332,27 @@ class LDAP extends UNIX {
 		$entry['shadowLastChange']=1; // We don't have expiration, so any non-0
 		$entry['shadowMax']=99999;
 		$entry['shadowWarning']=7;
-	
+
 		if (!$this->gfLdapAdd($dn,$entry)) {
-			$this->setError("ERROR: cannot add LDAP user entry '".
+			$this->setError("Error: cannot add LDAP user entry '".
 				 $user->getUnixName()."': ".$this->gfLdapError()."<br />");
 			return false;
 		}
 		return true;
 	}
-	
+
 	/**
 	 * gfLdapCreateUserFromProps() - Creates an LDAP user from
 	 *
-	 * @param		string	The username 
-	 * @param		string	????
-	 * @param		string	The encrypted password
-	 * @returns true on success/false on error
+	 * @param		string	$username	The username
+	 * @param		string	$cn
+	 * @param		string	$crypt_pw	The encrypted password
+	 * @param		string	$shell
+	 * @param		string	$cvsshell
+	 * @param		int		$uid
+	 * @param		int		$gid
+	 * @param		string	$email
+	 * @return bool	true on success/false on error
 	 *
 	 */
 	function gfLdapCreateUserFromProps($username, $cn, $crypt_pw,
@@ -361,91 +373,90 @@ class LDAP extends UNIX {
 		$entry['userPassword']='{crypt}'.$crypt_pw;
 		$entry['homeDirectory'] = account_user_homedir($username);
 		$entry['loginShell']=$shell;
-		$entry['debGforgeCvsShell']=$cvsshell; 
+		$entry['debGforgeCvsShell']=$cvsshell;
 		$entry['debGforgeForwardEmail']=$email;
 		$entry['uidNumber']=$uid;
 		$entry['gidNumber']=$gid;
 		$entry['shadowLastChange']=1;
 		$entry['shadowMax']=99999;
 		$entry['shadowWarning']=7;
-	
+
 		if (!$this->gfLdapAdd($dn,$entry)) {
-			$this->setError("ERROR: cannot add LDAP user entry '".
+			$this->setError("Error: cannot add LDAP user entry '".
 				 $username."': ".$this->gfLdapError()."<br />");
 			return false;
 		}
 		return true;
 	}
-	
+
 	/**
 	 * sysRemoveUser() - Remove an LDAP user
 	 *
 	 * @param		int		The user ID of the user to remove
-	 * @returns true on success/false on failure
+	 * @return bool	true on success/false on error
 	 *
 	 */
 	function sysRemoveUser($user_id) {
 
-	
-		$user = &user_get_object($user_id);
+
+		$user = user_get_object($user_id);
 		if (!$this->gfLdapConnect()) {
 			return false;
 		}
 		$dn = 'uid='.$user->getUnixName().',ou=People,'.forge_get_config('ldap_base_dn');
-	
+
 		if (!$this->gfLdapDelete($dn)) {
-		    $this->setError("ERROR: cannot delete LDAP user entry '".
+			$this->setError("Error: cannot delete LDAP user entry '".
 				 $user->getUnixName()."': ".$this->gfLdapError()."<br />");
-		    return false;
+			return false;
 		}
 		return true;
 	}
-	
+
 	/**
 	 * sysUserSetAttribute() - Set an attribute for a user
 	 *
-	 * @param		int		The user ID 
+	 * @param		int		The user ID
 	 * @param		string	The attribute to set
 	 * @param		string	The new value of the attribute
-	 * @returns true on success/false on error
+	 * @return bool	true on success/false on error
 	 *
 	 */
 	function sysUserSetAttribute($user_id,$attr,$value) {
 
-	
-		$user = &user_get_object($user_id);
+
+		$user = user_get_object($user_id);
 		if (!$this->gfLdapConnect()) {
 			return false;
 		}
 		$dn = 'uid='.$user->getUnixName().',ou=People,'.forge_get_config('ldap_base_dn');
 		$entry[$attr]=$value;
-	
+
 		if (!$this->gfLdapModifyIfExists($dn, $entry)) {
-		    $this->setError("ERROR: cannot change LDAP attribute '$attr' for user '".
+			$this->setError("Error: cannot change LDAP attribute '$attr' for user '".
 				 $user->getUnixName()."': ".$this->gfLdapError()."<br />");
-		    return false;
+			return false;
 		}
 		return true;
 	}
-	
+
 	/*
 	 * Group management functions
 	 */
-	
+
 	/**
 	 * sysCheckGroup() - Check for the existence of a group
-	 * 
+	 *
 	 * @param		int		The ID of the group to check
-	 * @returns true on success/false on error
+	 * @return bool	true on success/false on error
 	 *
 	 */
 	function sysCheckGroup($group_id) {
 		global $ldap_conn;
 
-	
-		$group = &group_get_object($group_id);
+		$group = group_get_object($group_id);
 		if (!$group) {
-			$this->setError("ERROR: Cannot find group [$group_id]<br />");
+			$this->setError("Error: Cannot find group [$group_id]<br />");
 			return false;
 		}
 		if (!$this->gfLdapConnect()) {
@@ -459,18 +470,17 @@ class LDAP extends UNIX {
 		}
 		return false;
 	}
-	
+
 	/**
 	 * sysCreateGroup() - Create a group
-	 * 
+	 *
 	 * @param		int		The ID of the group to create
-	 * @returns true on success/false on error
+	 * @return bool	true on success/false on error
 	 *
 	 */
 	function sysCreateGroup($group_id) {
 
-	
-		$group = &group_get_object($group_id);
+		$group = group_get_object($group_id);
 		if (!$this->gfLdapConnect()) {
 			return false;
 		}
@@ -480,118 +490,117 @@ class LDAP extends UNIX {
 		$entry['cn']=$group->getUnixName();
 		$entry['userPassword']='{crypt}x';
 		$entry['gidNumber']=$this->getUnixGID();
-	
+
 		$i=0; $i_cvs=0;
-	
+
 		$ret_val=true;
-		
+
 		if (!$this->gfLdapAdd($dn,$entry)) {
-		    $this->setError("ERROR: cannot add LDAP group entry '".
+			$this->setError("Error: cannot add LDAP group entry '".
 				 $group->getUnixName()."': ".$this->gfLdapError()."<br />");
-		    // If there's error, that's bad. But don't stop.
-		    $ret_val=false;
+			// If there's error, that's bad. But don't stop.
+			$ret_val=false;
 		}
-	
+
 		//
 		//	Now create CVS group
 		//
-	
+
 		// Add virtual anoncvs user to CVS group
 		$cvs_member_list[$i_cvs++] = 'anoncvs_'.$group->getUnixName();
-	
+
 		$dn = 'cn='.$group->getUnixName().',ou=cvsGroup,'.forge_get_config('ldap_base_dn');
-	
+
 		if ($cvs_member_list) {
 			$entry['memberUid']=$cvs_member_list;
 		} else {
 			unset($entry['memberUid']);
 		}
-	
+
 		if (!$this->gfLdapAdd($dn,$entry)) {
-			$this->setError("ERROR: cannot add LDAP CVS group entry '"
+			$this->setError("Error: cannot add LDAP CVS group entry '"
 				 .$group->getUnixName()."': ".$this->gfLdapError()."<br />");
 			$ret_val=false;
 		}
-	
+
 		//
 		// Finally, setup AnonCVS virtual user
 		//
-	
-	        if (!$this->gfLdapcheck_user_by_name('anoncvs_'.$group->getUnixName())
-		    && !$this->gfLdapCreateUserFromProps('scm_'.$group->getUnixName(),
+
+			if (!$this->gfLdapcheck_user_by_name('anoncvs_'.$group->getUnixName())
+			&& !$this->gfLdapCreateUserFromProps('scm_'.$group->getUnixName(),
 							'anoncvs', 'x',
 							'/bin/false', '/bin/false',
 							$this->getSCMGID(),
 							$this->getUnixGID(), "/dev/null")) {
-			$this->setError("ERROR: cannot add LDAP AnonCVS user entry '"
+			$this->setError("Error: cannot add LDAP AnonCVS user entry '"
 				 .$group->getUnixName()."': ".$this->gfLdapError()."<br />");
 			$ret_val=false;
 		}
-	
+
 		return $ret_val;
 	}
-	
+
 	/**
 	 * sysRemoveGroup() - Remove a group
-	 * 
+	 *
 	 * @param		int		The ID of the group to remove
-	 * @returns true on success/false on error
+	 * @return bool	true on success/false on error
 	 *
 	 */
 	function sysRemoveGroup($group_id) {
 
-	
-		$group = &group_get_object($group_id);
+		$group = group_get_object($group_id);
 		if (!$this->gfLdapConnect()) {
 			return false;
 		}
-	
+
 		//
 		//	Remove shell LDAP group
 		//
 		$ret_val=true;
-		
+
 		$dn = 'cn='.$group->getUnixName().',ou=Group,'.forge_get_config('ldap_base_dn');
-	
+
 		if (!$this->gfLdapDelete($dn)) {
-		    $this->setError("ERROR: cannot delete LDAP group entry '".
+			$this->setError("Error: cannot delete LDAP group entry '".
 				 $group->getUnixName()."': ".$this->gfLdapError()."<br />");
-		    $ret_val = false;
+			$ret_val = false;
 		}
-	
+
 		//
 		//	Remove CVS LDAP group
 		//
-	
+
 		$dn = 'cn='.$group->getUnixName().',ou=cvsGroup,'.forge_get_config('ldap_base_dn');
-	
+
 		if (!$this->gfLdapDelete($dn)) {
-		    $this->setError("ERROR: cannot delete LDAP CVS group entry '".
+			$this->setError("Error: cannot delete LDAP CVS group entry '".
 				 $group->getUnixName()."': ".$this->gfLdapError()."<br />");
-		    $ret_val = false;
+			$ret_val = false;
 		}
-	
+
 		//
 		//	Remove AnonCVS virtual user
 		//
-	
+
 		$dn = 'uid=anoncvs_'.$group->getUnixName().',ou=People,'.forge_get_config('ldap_base_dn');
 		if (!$this->gfLdapDelete($dn)) {
-		    $this->setError("ERROR: cannot delete LDAP AnonCVS user entry '".
+			$this->setError("Error: cannot delete LDAP AnonCVS user entry '".
 				 $group->getUnixName()."': ".$this->gfLdapError()."<br />");
-		    $ret_val = false;
+			$ret_val = false;
 		}
-	
+
 		return $ret_val;
 	}
-	
+
 	function sysGroupCheckUser($group_id,$user_id) {
 		db_begin () ;
 		if (! $this->sysGroupRemoveUser($group_id,$user_id)) {
 			db_rollback () ;
 			return false;
 		}
-		
+
 		$u = user_get_object($user_id) ;
 		$p = group_get_object($group_id) ;
 		if (forge_check_perm_for_user($u,'scm',$group_id,'write')) {
@@ -614,29 +623,28 @@ class LDAP extends UNIX {
 	/**
 	 * sysGroupAddUser() - Add a user to an LDAP group
 	 *
-	 * @param		int		The ID of the group two which the user will be added
-	 * @param		int		The ID of the user to add
-	 * @param		bool	Only add this user to CVS
-	 * @returns true on success/false on error
+	 * @param		int		$group_id	The ID of the group two which the user will be added
+	 * @param		int		$user_id	The ID of the user to add
+	 * @param		bool	$cvs_only	Only add this user to CVS
+	 * @return bool	true on success/false on error
 	 *
 	 */
-	function sysGroupAddUser($group_id,$user_id,$cvs_only=0) {
+	function sysGroupAddUser($group_id, $user_id, $cvs_only=false) {
 		global $ldap_conn;
 
-	
-		$group = &group_get_object($group_id);
-		$user  = &user_get_object($user_id);
+		$group = group_get_object($group_id);
+		$user  = user_get_object($user_id);
 		if (!$this->gfLdapConnect()) {
 			return false;
 		}
 		$dn = 'cn='.$group->getUnixName().',ou=Group,'.forge_get_config('ldap_base_dn');
 		$cvs_dn = 'cn='.$group->getUnixName().',ou=cvsGroup,'.forge_get_config('ldap_base_dn');
 		$entry['memberUid'] = $user->getUnixName();
-		
+
 		//
 		//	Check if user already a member of CVS group
 		//
-	
+
 		$res=$this->gfLdapRead($cvs_dn,"memberUid=".$user->getUnixName(),array("cn"));
 		if ($res && ldap_count_entries($ldap_conn,$res)>0) {
 			//echo "already a member of CVS<br />";
@@ -644,84 +652,83 @@ class LDAP extends UNIX {
 			//
 			//	No, add one
 			//
-	
+
 			if (!$this->gfLdapModAdd($cvs_dn,$entry)) {
-				$this->setError("ERROR: cannot add member to LDAP CVS group entry '".
+				$this->setError("Error: cannot add member to LDAP CVS group entry '".
 				 $group->getUnixName()."': ".$this->gfLdapError()."<br />");
 				return false;
 			}
 		}
-	
+
 		ldap_free_result($res);
-		
+
 		if ($cvs_only) {
 			return true;
 		}
-		
+
 		//
 		//	Check if user already a member of shell group
 		//
 		$res = $this->gfLdapRead($dn, "memberUid=".$user->getUnixName(), array("cn"));
-	
+
 		if ($res && ldap_count_entries($ldap_conn,$res)>0) {
 			//echo "already a member<br />";
 		} else {
 			//
 			//	No, add one
 			//
-	
+
 			if (!$this->gfLdapModAdd($dn,$entry)) {
-				$this->setError("ERROR: cannot add member to LDAP group entry '".
+				$this->setError("Error: cannot add member to LDAP group entry '".
 				 $group->getUnixName()."': ".$this->gfLdapError()."<br />");
 				return false;
 			}
 		}
-	
+
 		ldap_free_result($res);
-	
+
 		return true;
 	}
-	
+
 	/**
 	 * sysGroupRemoveUser() - Remove a user from an LDAP group
 	 *
-	 * @param		int		The ID of the group from which to remove the user
-	 * @param		int		The ID of the user to remove
-	 * @param		bool	Only remove user from CVS group
-	 * @returns true on success/false on error
+	 * @param		int		$group_id	The ID of the group from which to remove the user
+	 * @param		int		$user_id	The ID of the user to remove
+	 * @param		bool	$cvs_only	Only remove user from CVS group
+	 * @return bool	true on success/false on error
 	 *
 	 */
-	function sysGroupRemoveUser($group_id,$user_id,$cvs_only=0) {
+	function sysGroupRemoveUser($group_id, $user_id, $cvs_only=false) {
 
-	
-		$group = &group_get_object($group_id);
-		$user  = &user_get_object($user_id);
+		$group = group_get_object($group_id);
+		$user  = user_get_object($user_id);
 		if (!$this->gfLdapConnect()) {
 			return false;
 		}
-	
+
 		$dn = 'cn='.$group->getUnixName().',ou=Group,'.forge_get_config('ldap_base_dn');
 		$cvs_dn = 'cn='.$group->getUnixName().',ou=cvsGroup,'.forge_get_config('ldap_base_dn');
 		$entry['memberUid'] = $user->getUnixName();
-	
+
 		$ret_val=true;
-	
+
 		if (!$this->gfLdapModDel($cvs_dn,$entry) && !$this->gfLdapDoesNotExist()) {
-			$this->setError("ERROR: cannot remove member from LDAP CVS group entry '".
+			$this->setError("Error: cannot remove member from LDAP CVS group entry '".
 				 $group->getUnixName()."': ".$this->gfLdapError()."(".$this->gfLdapErrno().")"."<br />");
 			$ret_val=false;
 		}
-		
+
 		if ($cvs_only) {
 			return $ret_val;
 		}
-	
+
 		if (!$this->gfLdapModDel($dn,$entry) && !$this->gfLdapDoesNotExist()) {
-			$this->setError("ERROR: cannot remove member from LDAP group entry '".
+			$this->setError("Error: cannot remove member from LDAP group entry '".
 				 $group->getUnixName()."': ".$this->gfLdapError()."(".$this->gfLdapErrno().")"."<br />");
 			$ret_val=false;
 		}
-		
+
 		return $ret_val;
 	}
 }
@@ -730,5 +737,3 @@ class LDAP extends UNIX {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
