@@ -5,6 +5,7 @@
  * Copyright 2002, Tim Perdue/GForge, LLC
  * Copyright 2003, Guillaume Smet
  * Copyright 2009, Roland Mas
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -30,7 +31,7 @@ class MailingListFactory extends Error {
 	/**
 	 * The Group object.
 	 *
-	 * @var	 object  $Group.
+	 * @var	 object	$Group.
 	 */
 	var $Group;
 
@@ -41,53 +42,56 @@ class MailingListFactory extends Error {
 	 */
 	var $mailingLists;
 
-
 	/**
-	 *  Constructor.
+	 * Constructor.
 	 *
-	 *	@param	object	The Group object to which these mailing lists are associated.
+	 * @param	Group	$Group The Group object to which these mailing lists are associated.
 	 */
-	function MailingListFactory(& $Group) {
+	function __construct(& $Group) {
 		$this->Error();
-		
+
 		if (!$Group || !is_object($Group)) {
-			$this->setError(sprintf(_('%1$s:: No Valid Group Object'), 'MailingListFactory'));
-			return false;
+			$this->setError(_('No Valid Group Object'));
+			return;
 		}
 		if ($Group->isError()) {
 			$this->setError('MailingListFactory:: '.$Group->getErrorMessage());
-			return false;
+			return;
+		}
+		if (!$Group->usesMail()) {
+			$this->setError(sprintf(_('%s does not use the Mailing-list tool'),
+			    $Group->getPublicName()));
+			return;
 		}
 		$this->Group =& $Group;
-
-		return true;
 	}
 
 	/**
-	 *	getGroup - get the Group object this MailingListFactory is associated with.
+	 * getGroup - get the Group object this MailingListFactory is associated with.
 	 *
-	 *	@return object	The Group object.
+	 * @return	object	The Group object.
 	 */
 	function &getGroup() {
 		return $this->Group;
 	}
 
 	/**
-	 *	getMailingLists - get an array of MailingList objects for this Group.
+	 * getMailingLists - get an array of MailingList objects for this Group.
 	 *
-	 * @param boolean $admin if we are in admin mode (we want to see deleted lists)
-	 *	@return	array	The array of MailingList objects.
+	 * @return	array	The array of MailingList objects.
 	 */
 	function getMailingLists() {
 		if (isset($this->mailingLists) && is_array($this->mailingLists)) {
 			return $this->mailingLists;
 		}
-		
+
 		$public_flag = MAIL__MAILING_LIST_IS_PUBLIC;
-		
-		$perm = & $this->Group->getPermission ();
-		if ($perm && is_object($perm) && $perm->isMember()) {
-			$public_flag = MAIL__MAILING_LIST_IS_PRIVATE.', '.MAIL__MAILING_LIST_IS_PUBLIC;
+
+		if (session_loggedin()) {
+			$perm = $this->Group->getPermission();
+			if ($perm && is_object($perm) && $perm->isMember()) {
+				$public_flag = MAIL__MAILING_LIST_IS_PRIVATE.', '.MAIL__MAILING_LIST_IS_PUBLIC;
+			}
 		}
 
 		$result = db_query_params ('SELECT * FROM mail_group_list WHERE group_id=$1 AND is_public = ANY ($2) ORDER BY list_name',
@@ -96,7 +100,7 @@ class MailingListFactory extends Error {
 										     MAIL__MAILING_LIST_IS_PUBLIC)))) ;
 
 		if (!$result) {
-			$this->setError(sprintf(_('Error Getting %1$s'), _('Error Getting %1$s')).db_error());
+			$this->setError(_('Error Getting mailing list')._(': ').db_error());
 			return false;
 		} else {
 			$this->mailingLists = array();
@@ -112,5 +116,3 @@ class MailingListFactory extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
