@@ -5,6 +5,7 @@
  * Copyright 1999-2000, Tim Perdue/Sourceforge
  * Copyright 2002, Tim Perdue/GForge, LLC
  * Copyright 2009, Roland Mas
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -42,63 +43,66 @@ class ProjectGroupFactory extends Error {
 	var $projectGroups;
 
 	/**
-	 *  Constructor.
+	 * Constructor.
 	 *
-	 *	@param	object	The Group object to which this ProjectGroupFactory is associated.
-	 *	@return	boolean	success.
-	 */
-	function ProjectGroupFactory(&$Group) {
+	 * @param	Group	$Group	The Group object to which this ProjectGroupFactory is associated.
+	 * @return	\ProjectGroupFactory
+	*/
+	function __construct(&$Group) {
 		$this->Error();
 		if (!$Group || !is_object($Group)) {
-			$this->setError('ProjectGroup:: No Valid Group Object');
-			return false;
+			$this->setError(_('No Valid Group Object'));
+			return;
 		}
 		if ($Group->isError()) {
 			$this->setError('ProjectGroup:: '.$Group->getErrorMessage());
-			return false;
+			return;
+		}
+		if (!$Group->usesPM()) {
+			$this->setError(sprintf(_('%s does not use the Project Management tool'),
+			    $Group->getPublicName()));
+			return;
 		}
 		$this->Group =& $Group;
-
-		return true;
 	}
 
 	/**
-	 *	getGroup - get the Group object this ProjectGroupFactory is associated with.
+	 * getGroup - get the Group object this ProjectGroupFactory is associated with.
 	 *
-	 *	@return	object	The Group object.
+	 * @return	Group	The Group object.
 	 */
 	function &getGroup() {
 		return $this->Group;
 	}
 
 	function &getAllProjectGroupIds() {
-		$result = array () ;
-		$res = db_query_params ('SELECT * FROM project_group_list_vw WHERE group_id=$1 ORDER BY group_project_id',
-					array ($this->Group->getID())) ;
+		$result = array();
+		$res = db_query_params('SELECT group_project_id FROM project_group_list_vw WHERE group_id=$1 ORDER BY group_project_id',
+					array($this->Group->getID()));
 		if (!$res) {
-			return $result ;
+			return $result;
 		}
 		while ($arr = db_fetch_array($res)) {
-			$result[] = $arr['group_project_id'] ;
+			$result[] = $arr['group_project_id'];
 		}
-		return $result ;
+		return $result;
 	}
 
 	/**
-	 *	getProjectGroups - get an array of ProjectGroup objects.
+	 * getProjectGroups - get an array of ProjectGroup objects.
 	 *
-	 *	@return	array	The array of ProjectGroups.
+	 * @return	array	ProjectGroups[]	The array of ProjectGroups.
 	 */
-	function &getProjectGroups() {
+	function getProjectGroups() {
 		if ($this->projectGroups) {
 			return $this->projectGroups;
 		}
 
-		$this->projectGroups = array () ;
-		$ids = $this->getAllProjectGroupIds() ;
+		$this->projectGroups = array();
+		$ids = $this->getAllProjectGroupIds();
 
 		foreach ($ids as $id) {
-			if (forge_check_perm ('pm', $id, 'read')) {
+			if (forge_check_perm('pm', $id, 'read')) {
 				$this->projectGroups[] = new ProjectGroup($this->Group, $id);
 			}
 		}
@@ -111,5 +115,3 @@ class ProjectGroupFactory extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
