@@ -23,34 +23,10 @@
 
 require_once $gfcommon.'pm/ProjectTaskFactory.class.php';
 
-function printr($var, $name='$var', $echo=true) {
-/*
-//	return;
-	//$str = highlight_string("<?php\n$name = ".var_export($var, 1).";\n? >\n", 1);
-//	$str=var_export($var, 1);
-	if ($echo) {
-		if (is_array($var)) {
-			$var =var_export($var, 1);
-		}
-//		echo $str;
-//	} else {
-		$fp=fopen('/tmp/msp.log','a');
-		fwrite($fp,"\n-------".date('Y-m-d H:i:s')."-----".$name."-----\n".$var);
-		fclose($fp);
-	}
-*/
-}
-
-function printrcomplete() {
-//	exec("/bin/cat /tmp/msp.log | mail -s\"printr\" tim@gforgegroup.com");
-//	exec("/bin/rm -f /tmp/msp.log");
-}
-
 function &pm_import_tasks($group_project_id,&$tasks) {
-	printr($tasks,'MSPCheckin::in-array');
-	printr(getenv('TZ'),'MSPCheckin::entry TZ');
+	$was_error = false;
 
-	$pg =& projectgroup_get_object($group_project_id);
+	$pg = projectgroup_get_object($group_project_id);
 	if (!$pg || !is_object($pg)) {
 		$array['success']=false;
 		$array['errormessage']='Could Not Get ProjectGroup';
@@ -59,7 +35,6 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 		$array['errormessage']='Could Not Get ProjectGroup: '.$pg->getErrorMessage();
 	} else {
 		$count=count($tasks);
-//printr($count,'count - count of tasks');
 		//
 		//  Build hash list of technicians so we can get their ID for assigning tasks
 		//
@@ -79,7 +54,7 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 			$resrc = $tasks[$i]['resources'];
 			for ($j=0; $j<count($resrc); $j++) {
 				//validate user - see if they really exist as techs in this subproject
-				if (!$tarr[strtolower($resrc[$j]['user_name'])]) {
+				if (!util_ifsetor($tarr[strtolower($resrc[$j]['user_name'])])) {
 					//create list of bogus names to send back
 					if (array_search(strtolower($resrc[$j]['user_name']),$invalid_names) === false) {
 						$invalid_names[]=$resrc[$j]['user_name'];
@@ -93,7 +68,10 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 		//
 		if (count($invalid_names)) {
 			$array['success']=false;
-			$array['errormessage']='Invalid Resource Name';
+			$array['errormessage']='Invalid Resource Name:';
+			foreach ($invalid_names as $i) {
+				$array['errormessage'] .= ' ' . $i;
+			}
 			$array['resourcename']=$invalid_names;
 			for ($i=0; $i<$tcount; $i++) {
 				$array['usernames'][$techs[$i]->getID()]=$techs[$i]->getUnixName();
@@ -126,7 +104,6 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 						//remap priority names=>numbers
 						$priority=$tasks[$i]['priority'];
 						if (!$priority || $priority < 1 || $priority > 5) {
-			//				printr($priority,'Invalid Priority On New Task');
 							$priority=3;
 						}
 						//map users
@@ -168,8 +145,8 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 						}
 
 						if (!$pt->create(
-							addslashes($tasks[$i]['name']),
-							addslashes($tasks[$i]['notes']),
+							$tasks[$i]['name'],
+							$tasks[$i]['notes'],
 							$priority,
 							$hours,
 							strtotime($tasks[$i]['start_date']),
@@ -197,14 +174,9 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 				} else {
 					//update existing task
 					//create the task
-					$pt = &projecttask_get_object($tasks[$i]['id']);
+					$pt = projecttask_get_object($tasks[$i]['id']);
 					if (!$pt || !is_object($pt)) {
-						printr($tasks[$i]['id'],'Could not get task');
-					//	$array['success']=false;
-					//	$was_error=true;
-					//	$array['errormessage']='Could Not Get ProjectTask';
 					} elseif ($pt->isError()) {
-						printr($tasks[$i]['id'],'Could not get task - error in task');
 						$array['success']=false;
 						$was_error=true;
 						$array['errormessage']='Could Not Get ProjectTask: '.$pt->getErrorMessage();
@@ -212,9 +184,9 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 						//remap priority names=>numbers
 						$priority=$tasks[$i]['priority'];
 						if (!$priority || $priority < 1 || $priority > 5) {
-							printr($priority,'Invalid Priority On Existing Task');
 							$priority=3;
 						}
+
 						//map users
 						$assignees=array();
 						$resrc = $tasks[$i]['resources'];
@@ -222,6 +194,7 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 							//get their user_id from the $tarr we created earlier
 							$assignees[]=$tarr[strtolower($resrc[$ucount]['user_name'])];
 						}
+
 						//don't do anything with dependencies yet - we may only have the
 						//MSprojid from dependent items
 						$hours = $tasks[$i]['work'];
@@ -254,8 +227,8 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 						}
 
 						if (!$pt->update(
-							addslashes($tasks[$i]['name']),
-							addslashes($tasks[$i]['notes']),
+							$tasks[$i]['name'],
+							$tasks[$i]['notes'],
 							$priority,
 							$hours,
 							strtotime($tasks[$i]['start_date']),
@@ -289,17 +262,15 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 				$completed[$tasks[$i]['id']]=true;
 			} //for i
 
-
 			//
 			//  Do task dependencies
 			//
 
-			printr($was_error,'Right before deps');
 			if (!$was_error) {
 				//iterate the tasks
 				for ($i=0; $i<$count; $i++) {
 					$darr=$tasks[$i]['dependenton'];
-				
+
 					$deps=array();
 					//iterate each dependency in a task
 					for ($dcount=0; $dcount<count($darr); $dcount++) {
@@ -315,21 +286,15 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 						}
 						$deps[$id]=$darr[$dcount]['link_type'];
 					}
-					printr($deps,'Deps for task id: '.$tasks[$i]['id']);
-					if (is_object($tasks[$i]['obj'])) {
-						printr($deps,'11 Done Setting deps for task id: '.$tasks[$i]['id']);
+					if (isset($tasks[$i]['obj']) && is_object($tasks[$i]['obj'])) {
 						if (!$tasks[$i]['obj']->setDependentOn($deps)) {
 							$was_error=true;
 							$array['success']=false;
-							printr($tasks[$i]['obj'],'FAILED TO SET DEPENDENCIES: '.$tasks[$i]['obj']->getErrorMessage());
 						}
-						printr($deps,'22 Done Setting deps for task id: '.$tasks[$i]['id']);
 					} else {
 		//				$was_error=true;
 		//				$array['success']=false;
-						printr($foo,'PROJECT TASK OBJECT DOES NOT EXIST IN OBJ ARRAY');
 					}
-					printr($deps,'Done Setting deps for task id: '.$tasks[$i]['id']);
 					unset($deps);
 				} //iterates tasks to do dependencies
 			}
@@ -338,18 +303,14 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 			//
 			//	Delete unreferenced tasks
 			//
-			printr($was_error,'Right before deleting unreferenced tasks');
 			if (!$was_error) {
-				$ptf =& new ProjectTaskFactory($pg);
+				$ptf = new ProjectTaskFactory($pg);
 				$pt_arr=& $ptf->getTasks();
 				for ($i=0; $i<count($pt_arr); $i++) {
 					if (is_object($pt_arr[$i])) {
-						if (!$completed[$pt_arr[$i]->getID()]) {
-							printr($pt_arr[$i]->getID(),'Deleting task');
+						if (!util_ifsetor($completed[$pt_arr[$i]->getID()])) {
 							if (!$pt_arr[$i]->delete(true)) {
 								echo $pt_arr[$i]->getErrorMessage();
-							} else {
-								printr($foo,'Deleting Unreferenced Tasks');
 							}
 						}
 					}
@@ -362,8 +323,6 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 		$array['success']=true;
 	}
 
-//	printr($array,'MSPCheckin::return-array');
-	printr(getenv('TZ'),'MSPCheckin::exit TZ');
 	return $array;
 }
 
@@ -371,5 +330,3 @@ function &pm_import_tasks($group_project_id,&$tasks) {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
