@@ -4,6 +4,7 @@
  *
  * Copyright 2003-2004, Tim Perdue/GForge, LLC
  * Copyright 2009, Roland Mas
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -58,48 +59,37 @@ function ReportTrackerAct($span,$group_id,$atid,$start=0,$end=0) {
 		$this->setError('No group_id');
 		return false;
 	}
-	if (!$span || $span == REPORT_TYPE_MONTHLY) {
 
-		$arr =& $this->getMonthStartArr();
-
-		for ($i=0; $i<count($arr); $i++) {
-			if ($arr[$i]<$start || $arr[$i]>$end) {
-				//skip this month as it's not in the range
-			} else {
-
-				$this->labels[]=date('M d',$arr[$i]).' <-> '.date('M d',($arr[$i-1]-1));
-				$this->avgtime[]=$this->getAverageTime($atid,$arr[$i],($arr[$i-1]-1));
-				$this->opencount[]=$this->getOpenCount($atid,$arr[$i],($arr[$i-1]-1));
-				$this->stillopencount[]=$this->getStillOpenCount($atid,$arr[$i],($arr[$i-1]-1));
-
-			}
+	switch ($span) {
+		case REPORT_TYPE_WEEKLY: {
+			$arr = $this->getWeekStartArr();
+			break;
 		}
-
-	} elseif ($span == REPORT_TYPE_WEEKLY) {
-
-		$arr =& $this->getWeekStartArr();
-
-		for ($i=0; $i<count($arr); $i++) {
-			if ($arr[$i]<$start || $arr[$i]>$end) {
-				//skip this month as it's not in the range
-			} else {
-
-				$this->labels[]=date('M d',$arr[$i]).' <-> '.date('M d',($arr[$i-1]-1));
-				$this->avgtime[]=$this->getAverageTime($atid,$arr[$i],($arr[$i-1]-1));
-				$this->opencount[]=$this->getOpenCount($atid,$arr[$i],($arr[$i-1]-1));
-				$this->stillopencount[]=$this->getStillOpenCount($atid,$arr[$i],($arr[$i-1]-1));
-
-			}
+		default: {
+			$arr = $this->getMonthStartArr();
+			break;
 		}
+	}
 
+	for ($i=0; $i<count($arr); $i++) {
+		if ($arr[$i]<$start || $arr[$i]>$end) {
+			//skip this month as it's not in the range
+			unset($arr[$i]);
+		} else {
+			$this->labels[]=date('M d',($arr[$i-1]-1)).' <-> '.date('M d',$arr[$i]);
+			$this->avgtime[]=$this->getAverageTime($atid,($arr[$i-1]-1),$arr[$i]);
+			$this->opencount[]=$this->getOpenCount($atid,($arr[$i-1]-1),$arr[$i]);
+			$this->stillopencount[]=$this->getStillOpenCount($atid,$arr[$i]);
+		}
 	}
 
 	$this->start_date=$start;
 	$this->end_date=$end;
 
 	$this->setSpan($span);
-	$this->setDates($res,1);
-	$this->res=$res;
+	$arr = array_values($arr);
+	$this->setDates($arr, 1);
+	$this->res = $arr;
 	return true;
 }
 
@@ -118,7 +108,7 @@ function getAverageTime($atid,$start,$end) {
 function getOpenCount($atid,$start,$end) {
 	$res = db_query_params ('SELECT count(*)
 		FROM artifact
-		WHERE 
+		WHERE
 		group_artifact_id=$1
 		AND open_date BETWEEN $2 AND $3',
 				array ($atid,
@@ -127,10 +117,10 @@ function getOpenCount($atid,$start,$end) {
 	return db_result($res,0,0);
 }
 
-function getStillOpenCount($atid,$start,$end) {
+function getStillOpenCount($atid,$end) {
 	$res = db_query_params ('SELECT count(*)
 		FROM artifact
-		WHERE 
+		WHERE
 		group_artifact_id=$1
 		AND open_date <= $2
 		AND (close_date >= $3 OR close_date < 1 OR close_date is null)',
@@ -140,6 +130,19 @@ function getStillOpenCount($atid,$start,$end) {
 	return db_result($res,0,0);
 }
 
+function getPerAssignee($atid, $start, $end) {
+	$res = db_query_params('SELECT u.realname,count(*)
+		FROM artifact a, users u
+		WHERE a.group_artifact_id=$1
+		AND a.assigned_to=u.user_id
+		AND a.open_date BETWEEN $2 AND $3
+		GROUP BY realname',
+				array($atid,
+				      $start,
+				      $end));
+	return $res;
+}
+
 function &getAverageTimeData() {
 	return $this->avgtime;
 }
@@ -158,5 +161,3 @@ function &getStillOpenCountData() {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
