@@ -48,7 +48,7 @@ class TimeEntry extends Error {
      * @access public
      *
      */
-    function TimeEntry() 
+    function TimeEntry()
     {
     }
 
@@ -62,22 +62,24 @@ class TimeEntry extends Error {
      *
      * @author Tony Bibbs <tony@geeklog.net>
      * @access public
-     * @param int $projectTaskId The project task the user is reporting time to
-     * @param int $week The week the time being reported was done
-     * @param int $daysAdjust Represents the offset to add to the given week to specify the day
-     * @param int $timeCode The type of work that was done (general categorization)
-     * @param float $hours The actual time spent
-     * @return int This will be the Artificat ID otherwise it will be false if an error occurred
+     * @param  int   $projectTaskId The project task the user is reporting time to
+     * @param  int   $week          The week the time being reported was done
+     * @param  int   $days_adjust    Represents the offset to add to the given week to specify the day
+     * @param  int   $timeCode      The type of work that was done (general categorization)
+     * @param  float $hours         The actual time spent
+     * @return int   This will be the Artificat ID otherwise it will be false if an error occurred
      * @todo I'm quite concerned that none of the form data is being sanitized for things like
      * unwanted HTML, JavaSript and SQL Injection.  Might be worth adding that sort of filtering
      * as provided by the KSES Filter (search Google).
-     * @todo The check that looks to see if this method works is not language independent.  
+     * @todo The check that looks to see if this method works is not language independent.
      * someone that better understands how that all works will want to remove the hardcoded
      * 'successfully added'.
      *
      */
-    function create($projectTaskId, $week, $daysAdjust, $timeCode, $hours)
+    function create($projectTaskId, $week, $days_adjust, $timeCode, $hours)
     {
+		global $feedback;
+
         $report_date=($week + ($days_adjust*REPORT_DAY_SPAN))+(12*60*60);
         $res = db_query_params ('INSERT INTO rep_time_tracking (user_id,week,report_date,project_task_id,time_code,hours) VALUES ($1,$2,$3,$4,$5,$6)',
 				array (user_getid(),
@@ -92,12 +94,12 @@ class TimeEntry extends Error {
             $feedback.=_('Successfully Added');
         }
 	return db_affected_rows($res);
-    }  
+    }
 
     /**
      * Updates a timeEntry record.
      *
-     * This isn't supported by the current timeadd.php code so I'm assuming that all 
+     * This isn't supported by the current timeadd.php code so I'm assuming that all
      * that is expected is that instead of changing something you'd simply delete it
      * and readd it.  Messy, IMHO, but I am still including this method here to let
      * know I purposely left this unimplemented.
@@ -111,16 +113,16 @@ class TimeEntry extends Error {
     {
         // Not supported in timeadd.php
         return false;
-    } 
+    }
 
     /**
      * Deletes an existing timeEntry record
      *
      * @author Tony Bibbs <tony@geeklog.net>
      * @access public
-     * @param int $projectTaskId ID for the task which the time entry record belongs to.
-     * @param int $reportDate
-     * @param int $oldTimeCode ID of time code that was associated with time entry record.
+     * @param  int     $projectTaskId ID for the task which the time entry record belongs to.
+     * @param  int     $reportDate
+     * @param  int     $oldTimeCode   ID of time code that was associated with time entry record.
      * @return boolean True if delete works, otherwise false)
      *
      */
@@ -147,8 +149,8 @@ class TimeEntry extends Error {
         $tmpOutput = ob_get_contents();
 
         // Now discard any output.
-        ob_clean();        
-        
+        ob_clean();
+
         if (!stristr($tmpOutput, 'successfully deleted')) return false;
         return true;
     }
@@ -162,5 +164,3 @@ class TimeEntry extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
