@@ -4,6 +4,7 @@
  *
  * Copyright 1999-2001, VA Linux Systems, Inc
  * Copyright 2004, Guillaume Smet/Open Wide
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -32,8 +33,8 @@ class ExportProjectSearchQuery extends SearchQuery {
 	 * @param int $offset offset
 	 * @param boolean $isExact if we want to search for all the words or if only one matching the query is sufficient
 	 */
-	function ExportProjectSearchQuery($words, $offset, $isExact) {	
-		$this->SearchQuery($words, $offset, $isExact, 200);
+	function __construct($words, $offset, $isExact) {
+		parent::__construct($words, $offset, $isExact, 200);
 	}
 
 	/**
@@ -45,59 +46,35 @@ class ExportProjectSearchQuery extends SearchQuery {
 
 		$qpa = db_construct_qpa () ;
 		if (forge_get_config('use_fti')) {
-			$words = $this->getFormattedWords();
-			if(count($this->words)) {
+			$words = $this->getFTIwords();
+
+			$qpa = db_construct_qpa ($qpa,
+						 'SELECT ts_headline(unix_group_name, q) as unix_group_name, ts_headline(short_description, q) as short_description, type_id, groups.group_id, license, register_time FROM groups, groups_idx, to_tsquery($1) q ',
+						 array (implode (' ', $words))) ;
+			$qpa = db_construct_qpa ($qpa,
+						 'WHERE status IN ($1, $2) AND short_description <> $3 AND groups.group_id = groups_idx.group_id',
+						 array ('A',
+							'H',
+							'')) ;
+			$qpa = db_construct_qpa ($qpa,
+						 ' AND (vectors @@ q' ) ;
+			if (count($this->phrases)) {
 				$qpa = db_construct_qpa ($qpa,
-							 'SELECT ts_headline(unix_group_name, q) as unix_group_name, ts_headline(short_description, q) as short_description, type_id, groups.group_id, license, register_time FROM groups, groups_idx, to_tsquery($1) q ',
-							 array (implode (' ', $words))) ;
+							 $this->getOperator()) ;
 				$qpa = db_construct_qpa ($qpa,
-							 'WHERE status IN ($1, $2) AND short_description <> $3 AND groups.group_id = groups_idx.group_id',
-							 array ('A',
-								'H',
-								'')) ;
+							 '(') ;
+				$qpa = $this->addMatchCondition($qpa, 'group_name');
 				$qpa = db_construct_qpa ($qpa,
-							 ' AND (vectors @@ q' ) ;
-				if (count($this->phrases)) {
-					$qpa = db_construct_qpa ($qpa,
-								 $this->getOperator()) ;
-					$qpa = db_construct_qpa ($qpa,
-								 '(') ;
-					$qpa = $this->addMatchCondition($qpa, 'group_name');
-					$qpa = db_construct_qpa ($qpa,
-								 ') OR (') ;
-					$qpa = $this->addMatchCondition($qpa, 'unix_group_name');
-					$qpa = db_construct_qpa ($qpa,
-								 ') OR (') ;
-					$qpa = $this->addMatchCondition($qpa, 'short_description');
-					$qpa = db_construct_qpa ($qpa,
-								 ')') ;
-				}
+							 ') OR (') ;
+				$qpa = $this->addMatchCondition($qpa, 'unix_group_name');
 				$qpa = db_construct_qpa ($qpa,
-							 ') ORDER BY ts_rank(vectors, q) DESC, group_name ASC') ;
-			} else {
+							 ') OR (') ;
+				$qpa = $this->addMatchCondition($qpa, 'short_description');
 				$qpa = db_construct_qpa ($qpa,
-							 'SELECT unix_group_name, short_description, type_id, groups.group_id, license, register_time FROM groups ') ;
-				$qpa = db_construct_qpa ($qpa,
-							 'WHERE status IN ($1, $2) AND short_description <> $3',
-							 array ('A',
-								'H',
-								'')) ;
-				if (count($this->phrases)) {
-					$qpa = db_construct_qpa ($qpa,
-								 ' AND ((' ) ;
-					$qpa = $this->addMatchCondition($qpa, 'group_name');
-					$qpa = db_construct_qpa ($qpa,
-								 ') OR (') ;
-					$qpa = $this->addMatchCondition($qpa, 'unix_group_name');
-					$qpa = db_construct_qpa ($qpa,
-								 ') OR (') ;
-					$qpa = $this->addMatchCondition($qpa, 'short_description');
-					$qpa = db_construct_qpa ($qpa,
-								 '))') ;
-				}
-				$qpa = db_construct_qpa ($qpa,
-							 ') ORDER BY group_name' ) ;
+							 ')') ;
 			}
+			$qpa = db_construct_qpa ($qpa,
+						 ') ORDER BY ts_rank(vectors, q) DESC, group_name ASC') ;
 		} else {
 			$qpa = db_construct_qpa ($qpa,
 						 'SELECT group_name,unix_group_name,type_id,groups.group_id, short_description,license,register_time FROM groups WHERE status IN ($1, $2) AND short_description <> $3 AND groups.group_id = groups_idx.group_id',
@@ -124,5 +101,3 @@ class ExportProjectSearchQuery extends SearchQuery {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
