@@ -4,6 +4,7 @@
  *
  * Copyright 1999-2001, VA Linux Systems, Inc
  * Copyright 2004, Guillaume Smet/Open Wide
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -24,21 +25,21 @@
 require_once $gfcommon.'search/SearchQuery.class.php';
 
 class ForumSearchQuery extends SearchQuery {
-	
+
 	/**
 	 * group id
 	 *
 	 * @var int $groupId
 	 */
 	var $groupId;
-	
+
 	/**
 	 * forum id
 	 *
 	 * @var int $groupId
 	 */
 	var $forumId;
-	
+
 	/**
 	 * Constructor
 	 *
@@ -48,11 +49,11 @@ class ForumSearchQuery extends SearchQuery {
 	 * @param int $groupId group id
 	 * @param int $forumId forum id
 	 */
-	function ForumSearchQuery($words, $offset, $isExact, $groupId, $forumId) {
+	function __construct($words, $offset, $isExact, $groupId, $forumId) {
 		$this->groupId = $groupId;
 		$this->forumId = $forumId;
-		
-		$this->SearchQuery($words, $offset, $isExact);
+
+		parent::__construct($words, $offset, $isExact);
 	}
 
 	/**
@@ -62,75 +63,41 @@ class ForumSearchQuery extends SearchQuery {
 	 */
 	function getQuery() {
 
-
 		$qpa = db_construct_qpa () ;
 
 		if (forge_get_config('use_fti')) {
-			$words = $this->getFormattedWords();
-			
-
-			if(count($this->words)) {
-				$qpa = db_construct_qpa ($qpa,
-							 'SELECT forum.msg_id, ts_headline(forum.subject, q) AS subject, forum.post_date, users.realname FROM forum, users, to_tsquery($1) AS q, forum_idx as fi WHERE forum.group_forum_id = $2 AND forum.posted_by = users.user_id AND fi.msg_id = forum.msg_id AND vectors @@ q ',
-							 array ($words,
-								$this->forumId)) ;
-				$phraseOp = $this->getOperator();
-			} else {
-				$qpa = db_construct_qpa ($qpa,
-							 'SELECT forum.msg_id, subject, forum.post_date, users.realname FROM forum, users WHERE forum.group_forum_id = $1 AND forum.posted_by = users.user_id ',
-							 array ($this->forumId)) ;
-			}
+			$words = $this->getFTIwords();
+			$qpa = db_construct_qpa ($qpa,
+						 'SELECT x.* FROM (SELECT forum.group_forum_id, forum.msg_id, ts_headline(forum.subject, $1::tsquery) AS subject, forum.post_date, users.realname, forum.subject||$2||forum.body as full_string_agg, forum_idx.vectors FROM forum, users, to_tsquery($1) AS q, forum_idx WHERE forum.group_forum_id = $3 AND forum.posted_by = users.user_id AND forum_idx.msg_id = forum.msg_id GROUP BY forum.group_forum_id, forum.msg_id, subject, body, post_date, realname, forum_idx.vectors) AS x WHERE vectors @@ $1::tsquery ',
+						 array ($words,
+							$this->field_separator,
+							$this->forumId)) ;
+			$phraseOp = $this->getOperator();
 
 			if(count($this->phrases)) {
 				$qpa = db_construct_qpa ($qpa,
-							 'AND ((') ;
-				$qpa = $this->addMatchCondition($qpa, 'forum.body');
+							 'AND (') ;
+				$qpa = $this->addMatchCondition($qpa, 'full_string_agg');
 				$qpa = db_construct_qpa ($qpa,
-							 ') OR (') ;
-				$qpa = $this->addMatchCondition($qpa, 'forum.subject');
-				$qpa = db_construct_qpa ($qpa,
-							 ')) ') ;
-			}
-			if(count($this->words)) {
-				$qpa = db_construct_qpa ($qpa,
-							 'ORDER BY ts_rank(vectors, q) DESC') ;
-			} else {
-				$qpa = db_construct_qpa ($qpa,
-							 'ORDER BY post_date DESC') ;
+							 ') ') ;
 			}
+			$qpa = db_construct_qpa ($qpa,
+						 'ORDER BY ts_rank(vectors, $1) DESC',
+						 array($words)) ;
 		} else {
 			$qpa = db_construct_qpa ($qpa,
-						 'SELECT forum.msg_id, forum.subject, forum.post_date, users.realname FROM forum,users WHERE users.user_id=forum.posted_by AND ((') ;
-			$qpa = $this->addIlikeCondition ($qpa, 'forum.body') ;
+						 'SELECT x.* FROM (SELECT forum.group_forum_id, forum.msg_id, forum.subject, forum.post_date, users.realname, forum.subject||$1||forum.body as full_string_agg FROM forum,users WHERE users.user_id=forum.posted_by AND forum.group_forum_id=$2 GROUP BY forum.group_forum_id, msg_id, subject, post_date, realname, body) AS x WHERE ',
+						 array ($this->field_separator,
+							$this->forumId)) ;
+			$qpa = $this->addIlikeCondition ($qpa, 'full_string_agg') ;
 			$qpa = db_construct_qpa ($qpa,
-						 ') OR (') ;
-			$qpa = $this->addIlikeCondition ($qpa, 'forum.subject') ;
-			$qpa = db_construct_qpa ($qpa,
-						 ')) AND forum.group_forum_id=$1 GROUP BY msg_id, subject, post_date, realname',
-						 array ($this->forumId)) ;
+						 ' ');
 		}
 		return $qpa ;
 	}
-	
-	/**
-	 * getSearchByIdQuery - get the sql query built to get the search results when we are looking for an int
-	 *
-	 * @return array query+params array
-	 */	
-	function getSearchByIdQuery() {
-		$qpa = db_construct_qpa () ;
-		$qpa = db_construct_qpa ($qpa,
-					 'SELECT msg_id FROM forum WHERE msg_id=$1 AND group_forum_id=$2',
-					 array ($this->searchId,
-						$this->forumId)) ;
-
-		return $qpa ;
-	}
 }
 
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
