@@ -4,6 +4,8 @@
  *
  * Copyright 2004, Dominik Haas
  * Copyright 2009, Roland Mas
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013, French Ministry of National Education
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -21,41 +23,41 @@
  * with FusionForge; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
- 
+
 require_once $gfcommon.'search/SearchQuery.class.php';
 
 class ForumsSearchQuery extends SearchQuery {
-	
+
 	/**
 	* group id
 	*
 	* @var int $groupId
 	*/
 	var $groupId;
-	
+
 	/**
 	* flag if non public items are returned
 	*
 	* @var boolean $showNonPublic
-	*/	
+	*/
 	var $showNonPublic;
-	
+
 	/**
 	 * Constructor
 	 *
-	 * @param string $words words we are searching for
-	 * @param int $offset offset
-	 * @param boolean $isExact if we want to search for all the words or if only one matching the query is sufficient
-	 * @param int $groupId group id
-	 * @param array $sections sections to search in
-	 * @param boolean $showNonPublic flag if private sections are searched too
+	 * @param string	$words words we are searching for
+	 * @param int		$offset offset
+	 * @param bool		$isExact if we want to search for all the words or if only one matching the query is sufficient
+	 * @param int		$groupId group id
+	 * @param string	$sections sections to search in
+	 * @param bool		$showNonPublic flag if private sections are searched too
 	 */
-	function ForumsSearchQuery($words, $offset, $isExact, $groupId, $sections=SEARCH__ALL_SECTIONS, $showNonPublic=false) {
+	function __construct($words, $offset, $isExact, $groupId, $sections=SEARCH__ALL_SECTIONS, $showNonPublic=false) {
 		$this->groupId = $groupId;
 		$this->showNonPublic = $showNonPublic;
-		
-		$this->SearchQuery($words, $offset, $isExact);
-		
+
+		parent::__construct($words, $offset, $isExact);
+
 		$this->setSections($sections);
 	}
 
@@ -66,7 +68,6 @@ class ForumsSearchQuery extends SearchQuery {
 	 */
 	function getQuery() {
 
-
 		$qpa = db_construct_qpa () ;
 
 		if (forge_get_config('use_fti')) {
@@ -80,84 +81,65 @@ class ForumsSearchQuery extends SearchQuery {
 			}
 
 			$qpa = db_construct_qpa ($qpa,
-						 'SELECT forum.msg_id, ts_headline(forum.subject, q) AS subject, forum.post_date, users.realname, forum_group_list.forum_name FROM forum, users, forum_group_list, forum_idx, to_tsquery($1) as q ',
-						 array ($this->getFormattedWords())) ;
+						 'SELECT forum.group_forum_id, forum.msg_id, ts_headline(forum.subject, q) AS subject, forum.post_date, users.realname, forum_group_list.forum_name, forum.subject||$2||forum.body as full_string_agg FROM forum, users, forum_group_list, forum_idx, to_tsquery($1) as q ',
+						 array ($this->getFTIwords(),
+							$this->field_separator)) ;
 			$qpa = db_construct_qpa ($qpa,
-						 'WHERE users.user_id = forum.posted_by AND vectors @@ q AND forum.msg_id = forum_idx.msg_id AND forum_group_list.group_forum_id = forum.group_forum_id AND forum_group_list.is_public <> 9 AND forum.group_forum_id IN (SELECT group_forum_id FROM forum_group_list WHERE group_id = $1) ',
+						 'WHERE users.user_id = forum.posted_by AND vectors @@ q AND forum.msg_id = forum_idx.msg_id AND forum_group_list.group_forum_id = forum.group_forum_id AND forum.group_forum_id IN (SELECT group_forum_id FROM forum_group_list WHERE group_id = $1) ',
 						 array ($this->groupId));
 			if ($this->sections != SEARCH__ALL_SECTIONS) {
 				$qpa = db_construct_qpa ($qpa,
 							 'AND forum_group_list.group_forum_id = ANY ($1) ',
 							 array (db_int_array_to_any_clause ($this->sections))) ;
 			}
-			if (!$this->showNonPublic) {
+
+			if(count($this->phrases)) {
 				$qpa = db_construct_qpa ($qpa,
-							 'AND forum_group_list.is_public = 1 ') ;
+							 'AND (') ;
+				$qpa = $this->addMatchCondition($qpa, 'full_string_agg');
+				$qpa = db_construct_qpa ($qpa,
+							 ') ') ;
 			}
+
 			$qpa = db_construct_qpa ($qpa,
 						 'ORDER BY forum_group_list.forum_name ASC, forum.msg_id ASC, ts_rank(vectors, q) DESC') ;
 		} else {
 			$qpa = db_construct_qpa ($qpa,
-						 'SELECT forum.msg_id, forum.subject, forum.post_date, users.realname, forum_group_list.forum_name FROM forum, users, forum_group_list WHERE users.user_id = forum.posted_by AND forum_group_list.group_forum_id = forum.group_forum_id AND forum_group_list.is_public <> 9 AND forum.group_forum_id IN (SELECT group_forum_id FROM forum_group_list WHERE group_id = $1) ',
-						 array ($this->groupId)) ;
+						 'SELECT x.* FROM (SELECT forum.group_forum_id, forum.msg_id, forum.subject, forum.post_date, users.realname, forum_group_list.forum_name, forum.subject||$1||forum.body as full_string_agg FROM forum, users, forum_group_list WHERE users.user_id = forum.posted_by AND forum_group_list.group_forum_id = forum.group_forum_id AND forum.group_forum_id IN (SELECT group_forum_id FROM forum_group_list WHERE group_id = $2) ',
+						 array ($this->field_separator,
+							$this->groupId)) ;
 			if ($this->sections != SEARCH__ALL_SECTIONS) {
 				$qpa = db_construct_qpa ($qpa,
 							 'AND forum_group_list.group_forum_id = ANY ($1) ',
 							 array (db_int_array_to_any_clause ($this->sections))) ;
 			}
-			if (!$this->showNonPublic) {
-				$qpa = db_construct_qpa ($qpa,
-							 'AND forum_group_list.is_public = 1 ') ;
-			}
 			$qpa = db_construct_qpa ($qpa,
-						 'AND ((') ;
-			$qpa = $this->addIlikeCondition ($qpa, 'forum.body') ;
+						 ') AS x WHERE ') ;
+			$qpa = $this->addIlikeCondition ($qpa, 'full_string_agg') ;
 			$qpa = db_construct_qpa ($qpa,
-						 ') OR (') ;
-			$qpa = $this->addIlikeCondition ($qpa,'forum.subject') ;
-			$qpa = db_construct_qpa ($qpa,
-						 ')) ORDER BY forum_group_list.forum_name, forum.msg_id') ;
+						 ' ORDER BY x.forum_name, x.msg_id') ;
 		}
 		return $qpa ;
 	}
 
-	/**
-	 * getSearchByIdQuery - get the sql query built to get the search results when we are looking for an int
-	 *
-	 * @return array query+params array
-	 */	
-	function getSearchByIdQuery() {
-		$qpa = db_construct_qpa () ;
-		$qpa = db_construct_qpa ($qpa,
-					 'SELECT msg_id FROM forum, forum_group_list WHERE msg_id=$1 AND forum_group_list.group_forum_id=forum.group_forum_id AND group_forum_id=$2',
-					 array ($this->searchId,
-						$this->forumId)) ;
-		if (!$this->showNonPublic) {
-			$qpa = db_construct_qpa ($qpa,
-						 ' AND forum_group_list.is_public=1') ;
-		}
-
-		return $qpa;
-	}
-	
 	/**
 	 * getSections - returns the list of available forums
 	 *
 	 * @param $groupId int group id
 	 * @param $showNonPublic boolean if we should consider non public sections
+	 * @return array
 	 */
 	static function getSections($groupId, $showNonPublic=false) {
-		$sql = 'SELECT group_forum_id, forum_name FROM forum_group_list WHERE group_id = $1 AND is_public <> 9';
-		if (!$showNonPublic) {
-			$sql .= ' AND is_public = 1';
-		}
-		$sql .= ' ORDER BY forum_name';
-		
+		$sql = 'SELECT group_forum_id, forum_name FROM forum_group_list WHERE group_id = $1 AND ';
+		$sql .= 'group_forum_id NOT IN (SELECT forum_id FROM news_bytes)  ORDER BY forum_name';
+
 		$sections = array();
 		$res = db_query_params ($sql,
 					array ($groupId));
 		while($data = db_fetch_array($res)) {
-			$sections[$data['group_forum_id']] = $data['forum_name'];
+			if (forge_check_perm('forum',$data['group_forum_id'],'read')) {
+				$sections[$data['group_forum_id']] = $data['forum_name'];
+			}
 		}
 		return $sections;
 	}
@@ -167,5 +149,3 @@ class ForumsSearchQuery extends SearchQuery {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
