@@ -4,6 +4,7 @@
  *
  * Copyright 2004, Dominik Haas
  * Copyright 2009, Roland Mas
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -25,39 +26,40 @@
 require_once $gfcommon.'search/SearchQuery.class.php';
 
 class FrsSearchQuery extends SearchQuery {
-	
+
 	/**
 	* group id
 	*
 	* @var int $groupId
 	*/
 	var $groupId;
-	
+
 	/**
 	* flag if non public items are returned
 	*
 	* @var boolean $showNonPublic
-	*/	
+	*/
 	var $showNonPublic;
-	
+
 	/**
 	 * Constructor
 	 *
-	 * @param string $words words we are searching for
-	 * @param int $offset offset
-	 * @param boolean $isExact if we want to search for all the words or if only one matching the query is sufficient
-	 * @param int $groupId group id
-	 * @param array $sections sections to search in
+	 * @param string	$words words we are searching for
+	 * @param int		$offset offset
+	 * @param bool		$isExact if we want to search for all the words or if only one matching the query is sufficient
+	 * @param int		$groupId group id
+	 * @param string	$sections sections to search in
+	 * @param bool		$showNonPublic
 	 */
-	function FrsSearchQuery($words, $offset, $isExact, $groupId, $sections=SEARCH__ALL_SECTIONS, $showNonPublic=false) {	
+	function __construct($words, $offset, $isExact, $groupId, $sections=SEARCH__ALL_SECTIONS, $showNonPublic=false) {
 		$this->groupId = $groupId;
 		$this->showNonPublic = $showNonPublic;
-		
-		$this->SearchQuery($words, $offset, $isExact);
-		
+
+		parent::__construct($words, $offset, $isExact);
+
 		$this->setSections($sections);
 	}
-	
+
 	/**
 	 * getQuery - get the query built to get the search results
 	 *
@@ -65,21 +67,14 @@ class FrsSearchQuery extends SearchQuery {
 	 */
 	function getQuery() {
 
-
 		$qpa = db_construct_qpa () ;
 
 		if (forge_get_config('use_fti')) {
-			if(count($this->words)) {
-				$qpa = db_construct_qpa () ;
-				$qpa = db_construct_qpa ($qpa,
-							 'SELECT ts_headline(frs_package.name, q) AS package_name, ts_headline(frs_release.name, q) as release_name, frs_release.release_date, frs_release.release_id, users.realname FROM frs_file, frs_release, users, frs_package, to_tsquery($1) AS q, frs_release_idx r, frs_file_idx f WHERE frs_release.released_by = users.user_id AND r.release_id = frs_release.release_id AND f.file_id = frs_file.file_id AND frs_package.package_id = frs_release.package_id AND frs_file.release_id=frs_release.release_id AND frs_package.group_id=$2 ',
-							 array ($this->getFormattedWords(),
-								 $this->groupId)) ;
-			} else {
-				$qpa = db_construct_qpa ($qpa,
-							 'SELECT frs_package.name as package_name, frs_release.name as release_name, frs_release.release_date, frs_release.release_id, users.realname FROM frs_file, frs_release, users, frs_package WHERE frs_release.released_by = users.user_id AND frs_package.package_id = frs_release.package_id AND frs_file.release_id=frs_release.release_id AND frs_package.group_id=$1 ',
-							 array ($this->groupId)) ;
-			}
+			$qpa = db_construct_qpa () ;
+			$qpa = db_construct_qpa ($qpa,
+						 'SELECT ts_headline(frs_package.name, q) AS package_name, ts_headline(frs_release.name, q) as release_name, frs_release.release_date, frs_release.release_id, users.realname FROM frs_file, frs_release, users, frs_package, to_tsquery($1) AS q, frs_release_idx r, frs_file_idx f WHERE frs_release.released_by = users.user_id AND r.release_id = frs_release.release_id AND f.file_id = frs_file.file_id AND frs_package.package_id = frs_release.package_id AND frs_file.release_id=frs_release.release_id AND frs_package.group_id=$2 ',
+						 array ($this->getFTIwords(),
+							$this->groupId)) ;
 			if ($this->sections != SEARCH__ALL_SECTIONS) {
 				$qpa = db_construct_qpa ($qpa,
 							 'AND frs_package.package_id = ANY ($1) ',
@@ -89,10 +84,8 @@ class FrsSearchQuery extends SearchQuery {
 				$qpa = db_construct_qpa ($qpa,
 							 'AND is_public = 1 ') ;
 			}
-			if (count ($this->words)) {
-				$qpa = db_construct_qpa ($qpa,
-							 'AND (f.vectors @@ q OR r.vectors @@ q) ') ;
-			}
+			$qpa = db_construct_qpa ($qpa,
+						 'AND (f.vectors @@ q OR r.vectors @@ q) ') ;
 			if(count($this->phrases)) {
 				$qpa = db_construct_qpa ($qpa,
 							 'AND ((') ;
@@ -109,7 +102,7 @@ class FrsSearchQuery extends SearchQuery {
 				$qpa = db_construct_qpa ($qpa,
 							 ')) ') ;
 			}
-			
+
 			$qpa = db_construct_qpa ($qpa,
 						 ' ORDER BY frs_package.name, frs_release.name') ;
 
@@ -143,12 +136,13 @@ class FrsSearchQuery extends SearchQuery {
 		}
 		return $qpa ;
 	}
-	
+
 	/**
 	 * getSections - returns the list of available forums
 	 *
 	 * @param $groupId int group id
 	 * @param $showNonPublic boolean if we should consider non public sections
+	 * @return array
 	 */
 	static function getSections($groupId, $showNonPublic) {
 		$sql = 'SELECT package_id, name FROM frs_package WHERE group_id=$1';
@@ -156,7 +150,7 @@ class FrsSearchQuery extends SearchQuery {
 			$sql .= ' AND is_public=1';
 		}
 		$sql .= ' ORDER BY name';
-		
+
 		$sections = array();
 		$res = db_query_params ($sql,
 					array ($groupId));
@@ -171,5 +165,3 @@ class FrsSearchQuery extends SearchQuery {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
