@@ -4,6 +4,7 @@
  *
  * Copyright 1999-2001, VA Linux Systems, Inc
  * Copyright 2004, Guillaume Smet/Open Wide
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -26,44 +27,23 @@ require_once $gfcommon.'search/SearchQuery.class.php';
 
 class PeopleSearchQuery extends SearchQuery {
 
-	/**
-	 * Constructor
-	 *
-	 * @param string $words words we are searching for
-	 * @param int $offset offset
-	 * @param boolean $isExact if we want to search for all the words or if only one matching the query is sufficient
-	 */
-	function PeopleSearchQuery($words, $offset, $isExact) {	
-		$this->SearchQuery($words, $offset, $isExact);
-	}
-
 	/**
 	 * getQuery - get the query built to get the search results
 	 *
 	 * @return array query+params array
 	 */
 	function getQuery() {
-
-		
 		$qpa = db_construct_qpa () ;
 
 		if (forge_get_config('use_fti')) {
-			if (count ($this->words)) {
-				$words = $this->getFormattedWords();
-				$qpa = db_construct_qpa ($qpa,
-							 'SELECT users.user_id, user_name, ts_headline(realname, q) as realname FROM users, to_tsquery($1) AS q, users_idx WHERE status=$2 AND users_idx.user_id = users.user_id AND (vectors @@ q ',
-							 array ($words,
-								'A'));
-			} else {
-				$qpa = db_construct_qpa ($qpa,
-							 'SELECT users.user_id, user_name, realname FROM users WHERE status=$1 AND users_idx.user_id = users.user_id AND (',
-							 array ('A'));
-			}
+			$words = $this->getFTIwords();
+			$qpa = db_construct_qpa ($qpa,
+						 'SELECT users.user_id, user_name, ts_headline(realname, q) as realname FROM users, to_tsquery($1) AS q, users_idx WHERE status=$2 AND users_idx.user_id = users.user_id AND (vectors @@ q ',
+						 array ($words,
+							'A'));
 			if (count ($this->phrases)) {
-				if (count ($this->words)) {
-					$qpa = db_construct_qpa ($qpa,
-								 $this->getOperator()) ;
-				}
+				$qpa = db_construct_qpa ($qpa,
+							 $this->getOperator()) ;
 				$qpa = db_construct_qpa ($qpa,
 							 '(') ;
 				$qpa = $this->addMatchCondition($qpa, 'user_name');
@@ -73,13 +53,8 @@ class PeopleSearchQuery extends SearchQuery {
 				$qpa = db_construct_qpa ($qpa,
 							 ')') ;
 			}
-			if (count ($this->words)) {
-				$qpa = db_construct_qpa ($qpa,
-							 ') ORDER BY ts_rank(vectors, q) DESC, user_name') ;
-			} else {
-				$qpa = db_construct_qpa ($qpa,
-							 ') ORDER BY user_name') ;
-			}
+			$qpa = db_construct_qpa ($qpa,
+						 ') ORDER BY ts_rank(vectors, q) DESC, user_name') ;
 		} else {
 			$qpa = db_construct_qpa ($qpa,
 						 'SELECT user_name,user_id,realname FROM users WHERE ((') ;
@@ -99,5 +74,3 @@ class PeopleSearchQuery extends SearchQuery {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
