@@ -5,7 +5,8 @@
  * Copyright 1999-2001, VA Linux Systems, Inc
  * Copyright 2004, Guillaume Smet/Open Wide
  * Copyright 2009, Roland Mas
- * Copyright 2010 (c) Capgemini - Franck Villaume
+ * Copyright 2010-2011, Franck Villaume - Capgemini
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -29,7 +30,7 @@ class SearchQuery extends Error {
 	 *
 	 * @var string $operator
 	 */
-	var $operator;	
+	var $operator;
 	/**
 	 * Number of rows per page
 	 *
@@ -60,12 +61,6 @@ class SearchQuery extends Error {
 	 * @var resource $result
 	 */
 	var $result;
-	/**
-	 * When search by id is enabled, the id to search for
-	 *
-	 * @var int $searchId
-	 */
-	var $searchId = false;
 	/**
 	 * if we want to search for all the words or if only one is sufficient
 	 *
@@ -76,22 +71,25 @@ class SearchQuery extends Error {
 	 * sections to search in
 	 *
 	 * @var array $sections
-	 */	
+	 */
 	var $sections = SEARCH__ALL_SECTIONS;
 
 	var $words = array();
 
 	var $phrases = array();
 
+	// Something that's hopefully not going to end up in real data
+	var $field_separator = ' ioM0Thu6_fieldseparator_kaeph9Ee ';
+
 	/**
 	 * Constructor
 	 *
-	 * @param string $words words we are searching for
-	 * @param int $offset offset
-	 * @param boolean $isExact if we want to search for all the words or if only one is sufficient
-	 * @param int $rowsPerPage number of rows per page
+	 * @param	string	$words words we are searching for
+	 * @param	int	$offset offset
+	 * @param	boolean	$isExact if we want to search for all the words or if only one is sufficient
+	 * @param	int	$rowsPerPage number of rows per page
 	 */
-	function SearchQuery($words, $offset, $isExact, $rowsPerPage = SEARCH__DEFAULT_ROWS_PER_PAGE) {
+	function __construct($words, $offset, $isExact, $rowsPerPage = SEARCH__DEFAULT_ROWS_PER_PAGE) {
 		$this->cleanSearchWords($words);
 		//We manual escap because every Query in Search escap parameters
 		$words = addslashes($words);
@@ -102,7 +100,7 @@ class SearchQuery extends Error {
 		}
 		if (is_array ($this->phrases)){
 			$this->phrases = array_map ('addslashes',$this->phrases);
-		} else{
+		} else {
 			$this->phrases = array();
 		}
 		$this->rowsPerPage = $rowsPerPage;
@@ -110,88 +108,72 @@ class SearchQuery extends Error {
 		$this->isExact = $isExact;
 		$this->operator = $this->getOperator();
 	}
-	
+
 	/**
 	 * cleanSearchWords - clean the words we are searching for
 	 *
-	 * @param string $words words we are searching for
+	 * @param	string	$words words we are searching for
 	 */
 	function cleanSearchWords($words) {
 		$words = trim($words);
 		if(!$words) {
-			$this->setError(_('Error: criteria not specified'));
+			$this->setError(_('Error') . _(': ') . _('Please enter a term to search for'));
 			return;
 		}
-		if(is_numeric($words) && $this->implementsSearchById()) {
-			$this->searchId = (int) $words;
-		} else {
-			$words = preg_replace("/[ \t]+/", ' ', $words);
-			if(strlen($words) < 3) {
-				$this->setError(_('Error: search query too short'));
-				return;
-			}
-			$words = htmlspecialchars($words);
-			$words = strtr($words, array('%' => '\%', '_' => '\_'));
-			$phrase = '';
-			$inQuote = false;
-			foreach(explode(' ', quotemeta($words)) as $word) {
-				if($inQuote) {
-					if(substr($word, -3) == "\\\\'") {
-						$word = substr($word, 0, -3);
+
+		$words = preg_replace("/[ \t]+/", ' ', $words);
+		if(strlen($words) < 3) {
+			$this->setError(_('Error: search query too short'));
+			return;
+		}
+		$words = htmlspecialchars($words);
+		$words = strtr($words, array('%' => '\%', '_' => '\_'));
+		$phrase = '';
+		$inQuote = false;
+		foreach(explode(' ', quotemeta($words)) as $word) {
+			if($inQuote) {
+				if(substr($word, -1) == "'") {
+					$word = substr($word, 0, -1);
+					$inQuote = false;
+					$phrase .= ' '.$word;
+					$this->phrases[] = $phrase;
+				} else {
+					$phrase .= ' '.$word;
+				}
+			} else {
+				if(substr($word, 0, 1) == "'") {
+					$word = substr($word, 1);
+					$inQuote = true;
+					if(substr($word, -1) == "'") {
+						// This is a special case where the phrase is just one word
+						$word = substr($word, 0, -1);
 						$inQuote = false;
-						$phrase .= ' '.$word;
-						$this->phrases[] = $phrase;
+						$this->words[] = $word;
 					} else {
-						$phrase .= ' '.$word;
+						$phrase = $word;
 					}
 				} else {
-					if(substr($word, 0, 3) == "\\\\'") {
-						$word = substr($word, 3);
-						$inQuote = true;
-						if(substr($word, -3) == "\\\\'") {
-							// This is a special case where the phrase is just one word
-							$word = substr($word, 0, -3);
-							$inQuote = false;
-							$this->phrases[] = $word;
-						} else {
-							$phrase = $word;
-						}
-					} else {
-						$this->words[] = $word;
-					}
+					$this->words[] = $word;
 				}
-
 			}
 		}
 	}
-	
+
 	/**
 	 * executeQuery - execute the SQL query to get the results
-	 */ 
+	 */
 	function executeQuery() {
 
-		if($this->searchId) {
-			$qpa = $this->getSearchByIdQuery();
-		} else {
-			$qpa = $this->getQuery();
-		}
-
-		if (forge_get_config('use_fti')) {
-			db_query_params ('SELECT set_config($1, $2, false)', 
-					 array('default_text_search_config',
-					       'simple'));
-		}
 		$this->result = db_query_qpa (
-			$qpa,
+			$this->getQuery(),
 			$this->rowsPerPage + 1,
 			$this->offset,
-			SYS_DB_SEARCH
+			'SYS_DB_SEARCH'
 		);
-
 		$this->rowsTotalCount = db_numrows($this->result);
 		$this->rowsCount = min($this->rowsPerPage, $this->rowsTotalCount);
 	}
-	
+
 	/**
 	 * getQuery - returns the query built to get the search results
 	 * This is an abstract method. It _MUST_ be implemented in children classes.
@@ -203,26 +185,32 @@ class SearchQuery extends Error {
 	}
 
 	function addMatchCondition($qpa, $fieldName) {
-		if(!count($arr)) {
+
+		if(!count($this->phrases)) {
 			$qpa = db_construct_qpa ($qpa, 'TRUE') ;
-		} else {
-			$regexs = str_replace(' ', "\\\s+", $arr);
-			for ($i = 0; $i < count ($regexs); $i++) {
-				if ($i > 0) {
-					$qpa = db_construct_qpa ($qpa,
-								 $this->operator) ;
-				}
+			return $qpa;
+		}
+
+		$regexs = array();
+		foreach ($this->phrases as $p) {
+			$regexs[] = strtolower (preg_replace ("/\s+/", "\s+", $p));
+		}
+
+		for ($i = 0; $i < count ($regexs); $i++) {
+			if ($i > 0) {
 				$qpa = db_construct_qpa ($qpa,
-							 $fieldName.' ~* $1',
-							 array ($regexs[$i])) ;
+							 $this->operator) ;
 			}
+			$qpa = db_construct_qpa ($qpa,
+						 $fieldName.' ~* $1',
+							 array ($regexs[$i])) ;
 		}
 		return $qpa;
 	}
 
 	function addIlikeCondition($qpa, $fieldName) {
 		$wordArgs = array_map ('strtolower',
-				       array_merge($this->words, str_replace(' ', "\\\s+", $this->phrases)));
+				       array_merge($this->words, $this->phrases));
 
 		for ($i = 0; $i < count ($wordArgs); $i++) {
 			if ($i > 0) {
@@ -235,7 +223,7 @@ class SearchQuery extends Error {
 		}
 		return $qpa ;
 	}
-	
+
 	/**
 	 * getOperator - get the operator we have to use in ILIKE condition
 	 *
@@ -248,16 +236,7 @@ class SearchQuery extends Error {
 			return ' OR ';
 		}
 	}
-	
-	/**
-	 * implementsSearchById - check if the current object implements the search by id feature by having a getSearchByIdQuery method
-	 *
-	 * @return boolean true if our object implements search by id, false otherwise.
-	 */
-	function implementsSearchById() {
-		return method_exists($this, 'getSearchByIdQuery');
-	}
-	
+
 	/**
 	 * getResult - returns the result set
 	 *
@@ -266,7 +245,7 @@ class SearchQuery extends Error {
 	function & getResult() {
 		return $this->result;
 	}
-	
+
 	/**
 	 * getRowsCount - returns number of rows for the current page
 	 *
@@ -275,7 +254,7 @@ class SearchQuery extends Error {
 	function getRowsCount() {
 		return $this->rowsCount;
 	}
-	
+
 	/**
 	 * getRowsTotalCount - returns total number of rows
 	 *
@@ -284,7 +263,7 @@ class SearchQuery extends Error {
 	function getRowsTotalCount() {
 		return $this->rowsTotalCount;
 	}
-	
+
 	/**
 	 * getOffset - returns the offset
 	 *
@@ -293,7 +272,7 @@ class SearchQuery extends Error {
 	function getOffset() {
 		return $this->offset;
 	}
-	
+
 	/**
 	 * getRowsPerPage - returns number of rows per page
 	 *
@@ -302,7 +281,7 @@ class SearchQuery extends Error {
 	function getRowsPerPage() {
 		return $this->rowsPerPage;
 	}
-	
+
 	/**
 	 * getWords - returns the array containing words we are searching for
 	 *
@@ -311,7 +290,16 @@ class SearchQuery extends Error {
 	function getWords() {
 		return $this->words;
 	}
-	
+
+	/**
+	 * getPhrases - returns the array containing phrases we are searching for
+	 *
+	 * @return array phrases we are searching for
+	 */
+	function getPhrases() {
+		return $this->phrases;
+	}
+
 	/**
 	 * setSections - set the sections list
 	 *
@@ -319,24 +307,28 @@ class SearchQuery extends Error {
 	 */
 	function setSections($sections) {
 		if(is_array($sections)) {
-			$this->sections = array_keys ($sections) ;
+			$this->sections = array_values($sections) ;
 		} else {
 			$this->sections = $sections;
 		}
 	}
 
 	/**
-	 * getFormattedWords - get words formatted in order to be used in the FTI stored procedures
+	 * getFTIwords - get words formatted in order to be used in the FTI stored procedures
 	 *
-	 * @return string words we are searching for, separated by a pipe
-	 */	
-	function getFormattedWords() {
-		if ($this->isExact) {
-			$words = implode('&', $this->words);
-		} else {
-			$words = implode('|', $this->words);
+	 * @return string words we are searching for, separated by
+	 */
+	function getFTIwords() {
+		$bits = $this->words;
+		foreach ($this->phrases as $p) {
+			$bits[] = '('.implode ('&', explode (' ', $p)).')';
 		}
-		return $words;
+		if ($this->isExact) {
+			$query = implode('&', $bits);
+		} else {
+			$query = implode('|', $bits);
+		}
+		return $query;
 	}
 }
 
@@ -344,5 +336,3 @@ class SearchQuery extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
