@@ -4,6 +4,7 @@
  *
  * Copyright 1999-2001, VA Linux Systems, Inc
  * Copyright 2004, Guillaume Smet/Open Wide
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -26,17 +27,6 @@ require_once $gfcommon.'search/SearchQuery.class.php';
 
 class SkillSearchQuery extends SearchQuery {
 
-	/**
-	 * Constructor
-	 *
-	 * @param string $words words we are searching for
-	 * @param int $offset offset
-	 * @param boolean $isExact if we want to search for all the words or if only one matching the query is sufficient
-	 */
-	function SkillSearchQuery($words, $offset, $isExact) {	
-		$this->SearchQuery($words, $offset, $isExact);	
-	}
-
 	/**
 	 * getQuery - get the query built to get the search results
 	 *
@@ -44,25 +34,16 @@ class SkillSearchQuery extends SearchQuery {
 	 */
 	function getQuery() {
 
-
 		$qpa = db_construct_qpa () ;
 
 		if (forge_get_config('use_fti')) {
-			if(count($this->words)) {
-				$words = $this->getFormattedWords();
-				$qpa = db_construct_qpa ($qpa,
-							 'SELECT skills_data.skills_data_id, skills_data.type, skills_data.start, skills_data.finish, ts_headline(skills_data.title, q) as title, ts_headline(skills_data.keywords, q) as keywords FROM skills_data, users, skills_data_types, to_tsquery($1) AS q, skills_data_idx WHERE (vectors @@ q ',
-							 array ($words)) ;
-			} else {
-				$qpa = db_construct_qpa ($qpa,
-							 'SELECT skills_data.skills_data_id, skills_data.type, skills_data.start, skills_data.finish, FROM skills_data, users, skills_data_types  WHERE (vectors @@ q ') ;
-			}
-
+			$words = $this->getFTIwords();
+			$qpa = db_construct_qpa ($qpa,
+						 'SELECT skills_data.skills_data_id, skills_data.type, skills_data.start, skills_data.finish, ts_headline(skills_data.title, q) as title, ts_headline(skills_data.keywords, q) as keywords FROM skills_data, users, skills_data_types, to_tsquery($1) AS q, skills_data_idx WHERE (vectors @@ q ',
+						 array ($words)) ;
 			if (count ($this->phrases)) {
-				if (count ($this->words)) {
-					$qpa = db_construct_qpa ($qpa,
-								 $this->getOperator()) ;
-				}
+				$qpa = db_construct_qpa ($qpa,
+							 $this->getOperator()) ;
 				$qpa = db_construct_qpa ($qpa,
 							 ' ((') ;
 				$qpa = $this->addMatchCondition ($qpa, 'skills_data.title') ;
@@ -74,19 +55,12 @@ class SkillSearchQuery extends SearchQuery {
 			}
 			$qpa = db_construct_qpa ($qpa,
 						 ')') ;
-			if (count ($this->words)) {
-				$qpa = db_construct_qpa ($qpa,
-							 'AND skills_data.skills_data_id = skills_data_idx.skills_data_id ') ;
-			}
+			$qpa = db_construct_qpa ($qpa,
+						 'AND skills_data.skills_data_id = skills_data_idx.skills_data_id ') ;
 			$qpa = db_construct_qpa ($qpa,
 						 'AND (skills_data.user_id=users.user_id) AND (skills_data.type=skills_data_types.type_id) ') ;
-			if (count ($this->words)) {
-				$qpa = db_construct_qpa ($qpa,
-							 'ORDER BY ts_rank(vectors, q) DESC, finish DESC') ;
-			} else {
-				$qpa = db_construct_qpa ($qpa,
-							 'ORDER BY finish DESC') ;
-			}
+			$qpa = db_construct_qpa ($qpa,
+						 'ORDER BY ts_rank(vectors, q) DESC, finish DESC') ;
 		} else {
 			$qpa = db_construct_qpa ($qpa,
 						 'SELECT * FROM skills_data, users, skills_data_types WHERE ((') ;
@@ -105,5 +79,3 @@ class SkillSearchQuery extends SearchQuery {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
