@@ -4,6 +4,9 @@
  *
  * Copyright 2004, Sung Kim/GForge, LLC
  * Copyright 2009, Roland Mas
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013, Franck Villaume - TrivialDev
+ * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -26,68 +29,69 @@ require_once $gfcommon.'survey/Survey.class.php';
 
 class SurveyFactory extends Error {
 
-       /**
-        * The Group object.
-        *
-        * @var	 object  $Group.
-        */
+	/**
+	 * The Group object.
+	 *
+	 * @var	object	$Group.
+	 */
 	var $Group;
 
 	/**
 	 * The survey array.
 	 *
-	 * @var	 array	survey.
+	 * @var	array	survey.
 	 */
 	var $surveys;
 
 	/**
-	 *  Constructor. 
+	 * Constructor.
 	 *
-	 *	@param	object	The Group object to which this survey is associated.
-         *      @param  int     The survey_id
+	 * @param	object	$Group	The Group object to which this survey is associated.
 	 */
-	function SurveyFactory(&$Group) { 
+	function __construct(&$Group) {
 		$this->Error();
 		if (!$Group || !is_object($Group)) {
-			$this->setError(_('No valid Group Object'));
-			return false;
+			$this->setError(_('No Valid Group Object'));
+			return;
 		}
 
 		if ($Group->isError()) {
 			$this->setError(_('Survey').':: '.$Group->getErrorMessage());
-			return false;
+			return;
+		}
+		if (!$Group->usesSurvey()) {
+			$this->setError(sprintf(_('%s does not use the Survey tool'),
+			    $Group->getPublicName()));
+			return;
 		}
 		$this->Group =& $Group;
-
-		return true;
 	}
 
 	/**
-	 *	getGroup - get the Group object this SurveyQuestionFactory is associated with.
+	 * getGroup - get the Group object this SurveyQuestionFactory is associated with.
 	 *
-	 *	@return object	The Group object.
+	 * @return	object	The Group object.
 	 */
 	function &getGroup() {
 		return $this->Group;
 	}
 
 	/**
-	 *	getSurveyQuestion - get an array of Survey Question objects 
-         *                          for this Group and Survey id if survey_id is given.
+	 * getSurveyQuestion - get an array of Survey Question objects
+	 * for this Group and Survey id if survey_id is given.
 	 *
- 	 *	@return	array	The array of Survey Question objects.
+ 	 * @return	array	The array of Survey Question objects.
 	 */
 	function &getSurveys() {
-		/* We alread have it */
+		/* We already have it */
 		if ($this->surveys) {
 			return $this->surveys;
 		}
-		
-		$result = db_query_params ('SELECT * FROM surveys WHERE group_id=$1 ORDER BY survey_id DESC',
-					   array ($this->Group->getID()));
+		$result = db_query_params('SELECT * FROM surveys WHERE group_id=$1 ORDER BY survey_id DESC',
+						array ($this->Group->getID()));
 
 		if (!$result) {
-			$this->setError(_('No Survey is found').db_error());
+			$this->setError(_('No Survey is found').' '.db_error());
 			return false;
 		} else {
 			$this->surveys = array();
@@ -105,5 +109,3 @@ class SurveyFactory extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
