@@ -4,6 +4,8 @@
  *
  * Copyright 2004, Sung Kim/GForge, LLC
  * Copyright 2009, Roland Mas
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -26,74 +28,74 @@ require_once $gfcommon.'survey/SurveyQuestion.class.php';
 
 class SurveyQuestionFactory extends Error {
 
-       /**
-        * The Group object.
-        *
-        * @var	 object  $Group.
-        */
+	/**
+	 * The Group object.
+	 *
+	 * @var	 object  $Group.
+	 */
 	var $Group;
 
 	/**
 	 * The question array.
 	 *
-	 * @var	 array	questionss.
+	 * @var	 array	questions
 	 */
 	var $questions;
 
 	/**
-	 *  Constructor. 
+	 * Constructor.
 	 *
-	 *	@param	object	The Group object to which this survey question is associated.
-         *      @param  int     The survey_id
+	 * @param	object	$Group	The Group object to which this survey question is associated.
 	 */
-	function SurveyQuestionFactory(&$Group) { 
+	function __construct(&$Group) {
 		$this->Error();
 		if (!$Group || !is_object($Group)) {
-			$this->setError(_('No valid Group Object'));
-			return false;
+			$this->setError(_('No Valid Group Object'));
+			return;
 		}
 		if ($Group->isError()) {
 			$this->setError(_('Survey').':: '.$Group->getErrorMessage());
-			return false;
+			return;
+		}
+		if (!$Group->usesSurvey()) {
+			$this->setError(sprintf(_('%s does not use the Survey tool'),
+			    $Group->getPublicName()));
+			return;
 		}
 		$this->Group =& $Group;
-
-		return true;
 	}
 
 	/**
-	 *	getGroup - get the Group object this SurveyQuestionFactory is associated with.
+	 * getGroup - get the Group object this SurveyQuestionFactory is associated with.
 	 *
-	 *	@return object	The Group object.
+	 * @return	object	The Group object.
 	 */
 	function &getGroup() {
 		return $this->Group;
 	}
 
 	/**
-	 *	getSurveyQuestion - get an array of Survey Question objects 
-         *                          for this Group and Survey id if survey_id is given.
+	 * getSurveyQuestion - get an array of Survey Question objects
+	 *                     for this Group and Survey id if survey_id is given.
 	 *
- 	 *	@return	array	The array of Survey Question objects.
+ 	 * @return	array	The array of Survey Question objects.
 	 */
 	function &getSurveyQuestions() {
-		/* We alread have it */
+		/* We already have it */
 		if ($this->questions) {
 			return $this->questions;
 		}
 
-		$group_id = $this->Group->GetID();		
-		$result = db_query_params ('SELECT survey_questions.*,survey_question_types.type 
-			FROM survey_questions,survey_question_types 
-			WHERE survey_question_types.id=survey_questions.question_type 
+		$group_id = $this->Group->GetID();
+		$this->questions = array();
+		$result = db_query_params ('SELECT survey_questions.*,survey_question_types.type
+			FROM survey_questions,survey_question_types
+			WHERE survey_question_types.id=survey_questions.question_type
                         AND survey_questions.group_id=$1
 			ORDER BY survey_questions.question_id ASC',
 					   array ($group_id));
 
-		if (!$result) {
-			$this->setError(_('No Survey Question is found').db_error());
-			return false;
-		} else {
+		if ($result) {
 			while ($arr = db_fetch_array($result)) {
 				$this->questions[] = new SurveyQuestion($this->Group, $arr['question_id'], $arr);
 			}
@@ -108,5 +110,3 @@ class SurveyQuestionFactory extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
