@@ -4,6 +4,8 @@
  *
  * Copyright 2004, Sung Kim/GForge, LLC
  * Copyright 2009, Roland Mas
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -26,18 +28,18 @@ require_once $gfcommon.'survey/SurveyResponse.class.php';
 
 class SurveyResponseFactory extends Error {
 
-       /**
-        * The Survey object.
-        *
-        * @var	 object  $Survey.
-        */
+	/**
+	* The Survey object.
+	*
+	* @var	 object  $Survey.
+	*/
 	var $Survey;
 
-       /**
-        * The Question object.
-        *
-        * @var	 object  $Question.
-        */
+	/**
+	* The Question object.
+	*
+	* @var	 object  $Question.
+	*/
 	var $Question;
 
 	/**
@@ -55,74 +57,78 @@ class SurveyResponseFactory extends Error {
 	var $Result;
 
 	/**
-	 *  Constructor. 
+	 * The Aggregated Results array for all questions.
 	 *
-	 *	@param	object	The Survey object 
-	 *	@param	object	The Question object to which this survey Response is associated.
-         *      @param  int     The survey_id
+	 * @var	 array	Response
 	 */
-	function SurveyResponseFactory(&$Survey, &$Question ) { 
+	var $Results;
+
+	/**
+	 *  Constructor.
+	 *
+	 * @param	object	$survey		The Survey object
+	 * @param	object	$question	The Question object to which this survey Response is associated.
+	 */
+	function __construct(&$survey, &$question ) {
 		$this->Error();
 
-		if (!$Survey || !is_object($Survey)) {
+		if (!$survey || !is_object($survey)) {
 			$this->setError(_('No valid Survey Object'));
-			return false;
+			return;
 		}
-		if ($Survey->isError()) {
-			$this->setError(_('Survey').':: '.$Survey->getErrorMessage());
-			return false;
+		if ($survey->isError()) {
+			$this->setError(_('Survey').':: '.$survey->getErrorMessage());
+			return;
 		}
-		if (!$Question || !is_object($Question)) {
+		if (!$question || !is_object($question)) {
 			$this->setError(_('No valid Question Object'));
-			return false;
+			return;
 		}
-		if ($Question->isError()) {
-			$this->setError(_('Survey').':: '.$Question->getErrorMessage());
-			return false;
+		if ($question->isError()) {
+			$this->setError(_('Survey').':: '.$question->getErrorMessage());
+			return;
 		}
 
-		$this->Survey = &$Survey;
-		$this->Question = &$Question;
-
-		return true;
+		$this->Survey = &$survey;
+		$this->Question = &$question;
 	}
 
 	/**
-	 *	getGroup - get the Group object this SurveyResponse is associated with.
+	 * getGroup - get the Group object this SurveyResponse is associated with.
 	 *
-	 *	@return object	The Group object.
+	 * @return	object	The Group object.
 	 */
 	function &getGroup() {
 		$Survey = $this->getSurvey();
 		return $Survey->Group;
 	}
 
-        /**
-	 *	getSurvey - get the Survey object this SurveyResponse is associated with.
+	/**
+	 * getSurvey - get the Survey object this SurveyResponse is associated with.
 	 *
-	 *	@return object	The Survey object.
+	 * @return	object	The Survey object.
 	 */
 	function &getSurvey() {
 		return $this->Survey;
 	}
 
-        /**
-	 *	getQuestion - get the Question object this SurveyResponse is associated with.
+	/**
+	 * getQuestion - get the Question object this SurveyResponse is associated with.
 	 *
-	 *	@return object	The Question object.
+	 * @return	object	The Question object.
 	 */
 	function &getQuestion() {
 		return $this->Question;
 	}
 
 	/**
-	 *	getSurveyResponses - get an array of Survey Response objects 
-         *                           for the Survey and Question
+	 * getSurveyResponses - get an array of Survey Response objects
+	 *                      for the Survey and Question
 	 *
- 	 *	@return	array	The array of Survey Response objects.
+ 	 * @return	array	The array of Survey Response objects.
 	 */
-	function &getSurveyResponses() {
-		/* We alread have it */
+	function getSurveyResponses() {
+		/* We already have it */
 		if ($this->Responses) {
 			return $this->Responses;
 		}
@@ -133,7 +139,7 @@ class SurveyResponseFactory extends Error {
 		$survey_id = $survey->GetID();
 		$question = $this->getQuestion();
 		$question_id = $question->GetID();
-		
+
 		$result = db_query_params ('SELECT * FROM survey_responses WHERE survey_id=$1 AND question_id=$2 AND group_id=$3 ORDER BY post_date DESC',
 					   array ($survey_id,
 						  $question_id,
@@ -150,42 +156,71 @@ class SurveyResponseFactory extends Error {
 		return $this->Responses;
 	}
 
+	/**
+	 * getSurveyAllResponses - get an array of Survey Response objects
+	 *			for the Survey and Question
+	 *
+	 * @return	array	The array of Survey Response objects.
+	 */
+	function getSurveyAllResponses() {
+		/* We already have it */
+		if ($this->Responses) {
+			return $this->Responses;
+		}
+
+		$group = $this->getGroup();
+		$group_id = $group->GetID();
+		$survey = $this->getSurvey();
+		$survey_id = $survey->GetID();
+
+		$result = db_query_params('SELECT * FROM survey_responses WHERE survey_id=$1 AND group_id=$2 ORDER BY post_date DESC',
+			array($survey_id, $group_id));
+		if (!$result) {
+			$this->setError(_('No Survey Response is found').db_error());
+			return false;
+		} else {
+			while ($arr = db_fetch_array($result)) {
+				$this->Responses[] = new SurveyResponse($this->getGroup(), $arr);
+			}
+			db_free_result($result);
+		}
+		return $this->Responses;
+	}
 
 	/**
-	 *	getNumberOfSurveyResponses - get the number of Survey Responses
-         *                       
- 	 *	@return	int      the number of survey responses
+	 * getNumberOfSurveyResponses - get the number of Survey Responses
+	 *
+ 	 * @return	int      the number of survey responses
 	 */
 	function getNumberOfSurveyResponses() {
 		$arr = $this->getSurveyResponses();
 		if (!$arr || !is_array($arr)) {
 			return 0;
 		}
-
 		return count($arr);
 	}
 
 	/**
-	 *	getResults - get the array of result for yes/no and 1-5 question
-         *                       
- 	 *	@return	int      the array of result
-         *              for the yes/no question, it returns counts in arr[1] and arr[5];
-         *              for the 1-5 question, it returns counts in arr[1], arr[1], ..., arr[5];
-         *              for comments, we return arr[1], ...arr[n] with comments
+	 * getResults - get the array of result for yes/no and 1-5 question
+	 *
+	 * @return	int      the array of result
+	 *              for the yes/no question, it returns counts in arr[1] and arr[5];
+	 *              for the 1-5 question, it returns counts in arr[1], arr[1], ..., arr[5];
+	 *              for comments, we return arr[1], ...arr[n] with comments
 	 */
-	function &getResults() {
+	function getResults() {
 		if ($this->Result) {
 			return $this->Result;
 		}
 
-		$arr = &$this->getSurveyResponses();
+		$arr = $this->getSurveyResponses();
 		if (!$arr || !is_array($arr)) {
 			return false;
 		}
-		$count = count($arr); 
-		
+		$count = count($arr);
+
 		$question = $this->getQuestion();
-		if ($question->getQuestionType()=='1' || 
+		if ($question->getQuestionType()=='1' ||
 		    $question->getQuestionType()=='3') {
 			/* This is a radio-button question. Values 1-5 or yes(1) no (5)question  */
 			$is_radio = true;
@@ -193,17 +228,21 @@ class SurveyResponseFactory extends Error {
 		} else {
 			$is_radio=false;
 		}
-		
+
 		for($i=0; $i<$count; $i++) {
 			if ($arr[$i]->isError()) {
 				echo $arr[$i]->getErrorMessage();
 				continue;
 			}
-			
+
 			$response = $arr[$i]->getResponse();
-			
+
 			if($is_radio) {
 				/* We only counts */
+				// ugly hack to avoid php warning, and count correctly 'no answer' response.
+				if (is_string($response) && !strlen($response))
+					$response = 0;
+
 				$this->Result[$response]++;
 			} else {
 				/* Save response */
@@ -213,11 +252,38 @@ class SurveyResponseFactory extends Error {
 
 		return $this->Result;
 	}
+
+	/**
+	 * getDetailResults - get the array of result
+	 *
+	 * @return	int      the array of result
+	 *		return all responses for one survey
+	 */
+	function getDetailResults() {
+		if ($this->Results) {
+			return $this->Results;
+		}
+		$arr = $this->getSurveyAllResponses();
+		if (!$arr || !is_array($arr)) {
+			return false;
+		}
+		$count = count($arr);
+
+		for($i=0; $i<$count; $i++) {
+			$user_id = $arr[$i]->getUserId();
+			$qid = $arr[$i]->GetQuestionID();
+			if ($arr[$i]->isError()) {
+				echo $arr[$i]->getErrorMessage();
+				continue;
+			}
+			$response = $arr[$i]->getResponse();
+			$this->Result[$user_id][$qid] = $response;
+		}
+		return $this->Result;
+	}
 }
 
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
