@@ -34,71 +34,68 @@ define('ARTIFACT_EXTRAFIELDTYPE_STATUS',7);
 //define('ARTIFACT_EXTRAFIELDTYPE_ASSIGNEE',8);
 define('ARTIFACT_EXTRAFIELDTYPE_RELATION',9);
 define('ARTIFACT_EXTRAFIELDTYPE_INTEGER',10);
+/* reserved for aljeux extension, for merge into FusionForge */
+define('ARTIFACT_EXTRAFIELDTYPE_FORMULA',11);
+/* reserved for Evolvis extension, for merge into FusionForge */
+define('ARTIFACT_EXTRAFIELDTYPE_DATETIME',12);
 
 class ArtifactExtraField extends Error {
 
-	/** 
+	/**
 	 * The artifact type object.
 	 *
-	 * @var		object	$ArtifactType.
+	 * @var	object	$ArtifactType.
 	 */
 	var $ArtifactType; //object
 
 	/**
 	 * Array of artifact data.
 	 *
-	 * @var		array	$data_array.
+	 * @var	array	$data_array.
 	 */
 	var $data_array;
 
 	/**
-	 *	ArtifactExtraField - Constructer
-	 *
-	 *	@param	object	ArtifactType object.
-	 *  @param	array	(all fields from artifact_file_user_vw) OR id from database.
-	 *  @return	boolean	success.
+	 * __construct - Constructor
+	 * @param	$ArtifactType
+	 * @param	bool		$data
 	 */
-	function ArtifactExtraField(&$ArtifactType, $data=false) {
-		$this->Error(); 
+	function __construct(&$ArtifactType, $data=false) {
+		$this->Error();
 
 		//was ArtifactType legit?
 		if (!$ArtifactType || !is_object($ArtifactType)) {
-			$this->setError('ArtifactExtraField: No Valid ArtifactType');
-			return false;
+			$this->setError(_('Invalid Artifact Type'));
+			return;
 		}
 		//did ArtifactType have an error?
 		if ($ArtifactType->isError()) {
 			$this->setError('ArtifactExtraField: '.$ArtifactType->getErrorMessage());
-			return false;
+			return;
 		}
 		$this->ArtifactType =& $ArtifactType;
 
 		if ($data) {
 			if (is_array($data)) {
 				$this->data_array =& $data;
-				return true;
 			} else {
-				if (!$this->fetchData($data)) {
-					return false;
-				} else {
-					return true;
-				}
+				$this->fetchData($data);
 			}
 		}
 	}
 
 	/**
-	 *	create - create a row in the table that stores box names for a
-	 *	a tracker.  This function is only used to create rows for boxes 
-	 *	configured by the admin.
+	 * create - create a row in the table that stores box names for a
+	 * a tracker.  This function is only used to create rows for boxes
+	 * configured by the admin.
 	 *
-	 *	@param	string	Name of the extra field.
-	 *	@param	int	The type of field - radio, select, text, textarea
-	 *	@param	int	Attribute1 - for text (size) and textarea (rows)
-	 *	@param	int	Attribute2 - for text (maxlength) and textarea (cols)
-	 *	@param	int	is_required - true or false whether this is a required field or not.
-	 *	@param	string	alias - alias for this extra field (optional)
-	 *  @return 	true on success / false on failure.
+	 * @param	string	$name		Name of the extra field.
+	 * @param	int	$field_type	The type of field - radio, select, text, textarea
+	 * @param	int	$attribute1	For text (size) and textarea (rows)
+	 * @param	int	$attribute2	For text (maxlength) and textarea (cols)
+	 * @param	int	$is_required	True or false whether this is a required field or not.
+	 * @param	string	$alias		Alias for this extra field (optional)
+	 * @return	bool	true on success / false on failure.
 	 */
 	function create($name,$field_type,$attribute1,$attribute2,$is_required=0,$alias='') {
 		//
@@ -109,8 +106,8 @@ class ArtifactExtraField extends Error {
 			return false;
 		}
 		if (!$field_type) {
-			$this->setError("Type of custom field not selected");
-			return false;			
+			$this->setError(_('Type of custom field not selected'));
+			return false;
 		}
 		if (!forge_check_perm ('tracker_admin', $this->ArtifactType->Group->getID())) {
 			$this->setPermissionDeniedError();
@@ -126,29 +123,34 @@ class ArtifactExtraField extends Error {
 		}
 		if ($field_type == ARTIFACT_EXTRAFIELDTYPE_TEXT || $field_type == ARTIFACT_EXTRAFIELDTYPE_INTEGER) {
 			if (!$attribute1 || !$attribute2 || $attribute2 < $attribute1) {
-				$this->setError("Invalid size/maxlength for text field");
+				$this->setError(_('Invalid size/maxlength for text field'));
 				return false;
 			}
 		}
 		if ($field_type == ARTIFACT_EXTRAFIELDTYPE_TEXTAREA) {
 			if (!$attribute1 || !$attribute2) {
-				$this->setError("Invalid rows/cols for textarea field");
+				$this->setError(_('Invalid rows/cols for textarea field'));
+				return false;
+			}
+		} elseif ($field_type == ARTIFACT_EXTRAFIELDTYPE_STATUS) {
+			if ($this->ArtifactType->getCustomStatusField()) {
+				$this->setError(_('This Tracker already uses custom statuses'));
 				return false;
 			}
 		}
-		
+
 		if ($is_required) {
 			$is_required=1;
 		} else {
 			$is_required=0;
-		}	
-		
+		}
+
 		if (!($alias = $this->generateAlias($alias,$name))) {
 			return false;
 		}
-		
+
 		db_begin();
-		$result = db_query_params ('INSERT INTO artifact_extra_field_list (group_artifact_id,field_name,field_type,attribute1,attribute2,is_required,alias) 
+		$result = db_query_params ('INSERT INTO artifact_extra_field_list (group_artifact_id,field_name,field_type,attribute1,attribute2,is_required,alias)
 			VALUES ($1,$2,$3,$4,$5,$6,$7)',
 					   array ($this->ArtifactType->getID(),
 						  htmlspecialchars($name),
@@ -183,24 +185,25 @@ class ArtifactExtraField extends Error {
 						return false;
 					} else {
 						if (!$ao->create('Open', '1')) {
-							$feedback .= _('Error inserting an element').': '.$ao->getErrorMessage();
+							$feedback .= _('Insert Error')._(': ').$ao->getErrorMessage();
 							$ao->clearError();
 							db_rollback();
 							return false;
 						}
 						if (!$ao->create('Closed', '2')) {
-							$feedback .= _('Error inserting an element').': '.$ao->getErrorMessage();
+							$feedback .= _('Insert Error')._(': ').$ao->getErrorMessage();
 							$ao->clearError();
 							db_rollback();
 							return false;
 						}
 					}
 				}
-			} elseif (strstr(ARTIFACT_EXTRAFIELD_FILTER_INT,$field_type) !== false) {
+			}
+			if (strstr(ARTIFACT_EXTRAFIELD_FILTER_INT,$field_type) !== false) {
 //
 //	Must insert some default 100 rows for the data table so None queries will work right
 //
-				$resdefault = db_query_params ('INSERT INTO artifact_extra_field_data(artifact_id,field_data,extra_field_id) 
+				$resdefault = db_query_params ('INSERT INTO artifact_extra_field_data(artifact_id,field_data,extra_field_id)
 					SELECT artifact_id,100,$1 FROM artifact WHERE group_artifact_id=$2',
 							       array ($id,
 								      $this->ArtifactType->getID())) ;
@@ -218,18 +221,18 @@ class ArtifactExtraField extends Error {
 	}
 
 	/**
-	 *	fetchData - re-fetch the data for this ArtifactExtraField from the database.
+	 * fetchData - re-fetch the data for this ArtifactExtraField from the database.
 	 *
-	 *	@param	int		ID of the Box.
-	 *	@return	boolean	success.
+	 * @param	int	$id ID of the Box.
+	 * @return	boolean	success.
 	 */
 	function fetchData($id) {
 		$this->id=$id;
 		$res = db_query_params ('SELECT * FROM artifact_extra_field_list WHERE extra_field_id=$1',
 					array ($id)) ;
-		
+
 		if (!$res || db_numrows($res) < 1) {
-			$this->setError('ArtifactExtraField: Invalid ArtifactExtraField ID');
+			$this->setError(_('Invalid ArtifactExtraField ID'));
 			return false;
 		}
 		$this->data_array = db_fetch_array($res);
@@ -238,63 +241,63 @@ class ArtifactExtraField extends Error {
 	}
 
 	/**
-	 *	getArtifactType - get the ArtifactType Object this ArtifactExtraField is associated with.
+	 * getArtifactType - get the ArtifactType Object this ArtifactExtraField is associated with.
 	 *
-	 *	@return object	ArtifactType.
+	 * @return	object	ArtifactType.
 	 */
 	function &getArtifactType() {
 		return $this->ArtifactType;
 	}
-	
+
 	/**
-	 *	getID - get this ArtifactExtraField ID.
+	 * getID - get this ArtifactExtraField ID.
 	 *
-	 *	@return	int	The id #.
+	 * @return	int	The id #.
 	 */
 	function getID() {
 		return $this->data_array['extra_field_id'];
 	}
 
 	/**
-	 *	getName - get the name.
+	 * getName - get the name.
 	 *
-	 *	@return	string	The name.
+	 * @return	string	The name.
 	 */
 	function getName() {
 		return $this->data_array['field_name'];
 	}
 
 	/**
-	 *	getAttribute1 - get the attribute1 field.
+	 * getAttribute1 - get the attribute1 field.
 	 *
-	 *	@return int	The first attribute.
+	 * @return	int	The first attribute.
 	 */
 	function getAttribute1() {
 		return $this->data_array['attribute1'];
 	}
 
 	/**
-	 *	getAttribute2 - get the attribute2 field.
+	 * getAttribute2 - get the attribute2 field.
 	 *
-	 *	@return int	The second attribute.
+	 * @return	int	The second attribute.
 	 */
 	function getAttribute2() {
 		return $this->data_array['attribute2'];
 	}
 
 	/**
-	 *	getType - the type of field.
+	 * getType - the type of field.
 	 *
-	 *	@return	int	type.
+	 * @return	int	type.
 	 */
 	function getType() {
 		return $this->data_array['field_type'];
 	}
 
 	/**
-	 *	getTypeName - the name of type of field.
+	 * getTypeName - the name of type of field.
 	 *
-	 *	@return	string	type.
+	 * @return	string	type.
 	 */
 	function getTypeName() {
 		$arr = $this->getAvailableTypes();
@@ -302,46 +305,46 @@ class ArtifactExtraField extends Error {
 	}
 
 	/**
-	 *	isRequired - whether this field is required or not.
+	 * isRequired - whether this field is required or not.
 	 *
-	 *	@return	boolean required.
+	 * @return	boolean	required.
 	 */
 	function isRequired() {
 		return $this->data_array['is_required'];
 	}
 
 	/**
-	 *	getAvailableTypes - the types of text fields and their names available.
+	 * getAvailableTypes - the types of text fields and their names available.
 	 *
-	 *	@return	array	types.
+	 * @return	array	types.
 	 */
 	static function getAvailableTypes() {
 		return array(
-			1=>_('Select Box'),
-			2=>_('Check Box'),
-			3=>_('Radio Buttons'),
-			4=>_('Text Field'),
-			5=>_('Multi-Select Box'),
-			6=>_('Text Area'),
-			7=>_('Status'),
-			9=>_('Relation'),
-			10=>_('Integer')
+			ARTIFACT_EXTRAFIELDTYPE_SELECT => _('Select Box'),
+			ARTIFACT_EXTRAFIELDTYPE_CHECKBOX => _('Check Box'),
+			ARTIFACT_EXTRAFIELDTYPE_RADIO => _('Radio Buttons'),
+			ARTIFACT_EXTRAFIELDTYPE_TEXT => _('Text Field'),
+			ARTIFACT_EXTRAFIELDTYPE_MULTISELECT => _('Multi-Select Box'),
+			ARTIFACT_EXTRAFIELDTYPE_TEXTAREA => _('Text Area'),
+			ARTIFACT_EXTRAFIELDTYPE_STATUS => _('Status'),
+			ARTIFACT_EXTRAFIELDTYPE_RELATION => _('Relation between artifacts'),
+			ARTIFACT_EXTRAFIELDTYPE_INTEGER => _('Integer')
 			);
 	}
-	
+
 	/**
-	 *	getAlias - the alias that is used for this field
+	 * getAlias - the alias that is used for this field
 	 *
-	 *	@return	string	alias
+	 * @return	string	alias
 	 */
 	function getAlias() {
 		return $this->data_array['alias'];
 	}
-	
+
 	/**
-	 *	getAvailableValues - Get the list of available values for this extra field
+	 * getAvailableValues - Get the list of available values for this extra field
 	 *
-	 *	@return array
+	 * @return	array
 	 */
 	function getAvailableValues() {
 		$res = db_query_params ('SELECT * FROM artifact_extra_field_elements WHERE extra_field_id=$1',
@@ -354,17 +357,17 @@ class ArtifactExtraField extends Error {
 	}
 
 	/**
-	 *  update - update a row in the table used to store box names 
-	 *  for a tracker.  This function is only to update rowsf
-	 *  for boxes configured by
-	 *  the admin.
+	 * update - update a row in the table used to store box names
+	 * for a tracker.  This function is only to update rowsf
+	 * for boxes configured by
+	 * the admin.
 	 *
-	 *  @param	string	Name of the field.
-	 *	@param	int	Attribute1 - for text (size) and textarea (rows)
-	 *	@param	int	Attribute2 - for text (maxlength) and textarea (cols)
-	 *	@param	int	is_required - true or false whether this is a required field or not.
-	 *	@param	string	Alias for this field
-	 *  @return	boolean	success.
+	 * @param	string	$name		Name of the field.
+	 * @param	int	$attribute1	For text (size) and textarea (rows)
+	 * @param	int	$attribute2	For text (maxlength) and textarea (cols)
+	 * @param	int	$is_required	True or false whether this is a required field or not.
+	 * @param	string	$alias		Alias for this field
+	 * @return	bool	success.
 	 */
 	function update($name,$attribute1,$attribute2,$is_required=0,$alias="") {
 		if (!forge_check_perm ('tracker_admin', $this->ArtifactType->Group->getID())) {
@@ -378,7 +381,7 @@ class ArtifactExtraField extends Error {
 			$this->setError(_('a field name is required'));
 			return false;
 		}
-		$res = db_query_params ('SELECT field_name FROM artifact_extra_field_list 
+		$res = db_query_params ('SELECT field_name FROM artifact_extra_field_list
 				WHERE field_name=$1 AND group_artifact_id=$2 AND extra_field_id !=$3',
 			array($name,
 				$this->ArtifactType->getID(),
@@ -392,12 +395,12 @@ class ArtifactExtraField extends Error {
 		} else {
 			$is_required=0;
 		}
-		
+
 		if (!($alias = $this->generateAlias($alias,$name))) {
 			return false;
-		}		
+		}
 
-		$result = db_query_params ('UPDATE artifact_extra_field_list 
+		$result = db_query_params ('UPDATE artifact_extra_field_list
 			SET field_name=$1,
 			attribute1=$2,
 			attribute2=$3,
@@ -468,12 +471,13 @@ class ArtifactExtraField extends Error {
 		}
 
 	}
-	
+
 	/**
-	 * 	Validate an alias.
-	 *	Note that this function does not check for conflicts.
-	 *	@param	string	alias - alias to validate
-	 *	@return	bool	true if alias is valid, false otherwise and it sets the corresponding error
+	 * Validate an alias.
+	 * Note that this function does not check for conflicts.
+	 *
+	 * @param	string	alias - alias to validate
+	 * @return	bool	true if alias is valid, false otherwise and it sets the corresponding error
 	 */
 	function validateAlias($alias) {
 		// these are reserved alias names
@@ -493,28 +497,29 @@ class ArtifactExtraField extends Error {
 
 		// invalid chars?
 		if (preg_match("/[^[:alnum:]_@\\-]/", $alias)) {
-			$this->setError(_('The alias contains invalid characters. Only letters, numbers, hypens (-), arobase (@) and underscores (_) allowed.'));
+			$this->setError(_('The alias contains invalid characters. Only letters, numbers, hypens (-), at sign (@) and underscores (_) allowed.'));
 			return false;
-		} else if (in_array($alias, $reserved_alias)) {	// alias is reserved?
-			$this->setError(sprintf(_('\'%1$s\' is a reserved alias. Please provide another name.'), $alias));
+		} elseif (in_array($alias, $reserved_alias)) {	// alias is reserved?
+			$this->setError(sprintf(_('“%s” is a reserved alias. Please provide another name.'), $alias));
 			return false;
 		}
-		
+
 		return true;
 	}
-	
+
 	/**
-	 *	Generate an alias for this field. The alias can be entered by the user or
-	 *	be generated automatically from the name of the field.
-	 *	@param	string	Alias entered by the user
-	 *	@param	string	Name of the field entered by the user (it'll be used when $alias is empty)
-	 *	@return	string
+	 * Generate an alias for this field. The alias can be entered by the user or
+	 * be generated automatically from the name of the field.
+	 *
+	 * @param	string	$alias	Alias entered by the user
+	 * @param	string	$name	Name of the field entered by the user (it'll be used when $alias is empty)
+	 * @return	string
 	 */
 	function generateAlias($alias, $name) {
 		$alias = strtolower(trim($alias));
 		if (strlen($alias) == 0) {		// no alias was entered, generate alias from $name
 			$name = strtolower(trim($name));
-			// Convert the original name to a valid alias (i.e., if the extra field is 
+			// Convert the original name to a valid alias (i.e., if the extra field is
 			// called "Quality test", make an alias called "quality_test").
 			// The alias can be seen as a "unix name" for this field
 			$alias = preg_replace("/ /", "_", $name);
@@ -523,11 +528,11 @@ class ArtifactExtraField extends Error {
 		} elseif (!$this->validateAlias($alias)) {
 			// alias is invalid...
 			return false;
-		} 
+		}
 		// check if the name conflicts with another alias in the same artifact type
 		// in that case append a serial number to the alias
 		$serial = 1;
-		$conflict = false;	
+		$conflict = false;
 		do {
 			if ($this->data_array['extra_field_id']) {
 				$res = db_query_params ('SELECT * FROM artifact_extra_field_list
@@ -545,7 +550,7 @@ class ArtifactExtraField extends Error {
 			if (!$res) {
 				$this->setError(db_error());
 				return false;
-			} else if (db_numrows($res) > 0) {		// found another field with the same alias
+			} elseif (db_numrows($res) > 0) {		// found another field with the same alias
 				$conflict = true;
 				$serial++;
 				$alias = $alias.$serial;
@@ -584,6 +589,7 @@ class ArtifactExtraField extends Error {
 			return false;
 		}
 		$i = 1;
+		$data = array();
 		while ($i <= $max) {
 			if ($i == $new_pos) {
 				$data[] = $element_id;
@@ -622,5 +628,3 @@ class ArtifactExtraField extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
