@@ -3,6 +3,8 @@
  * FusionForge trackers
  *
  * Copyright 2002, GForge, LLC
+ * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2014, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -30,14 +32,14 @@ class ArtifactFactory extends Error {
 	/**
 	 * The ArtifactType object.
 	 *
-	 * @var	 object  $ArtifactType.
+	 * @var	 object	$ArtifactType.
 	 */
 	var $ArtifactType;
 
 	/**
 	 * The artifacts array.
 	 *
-	 * @var  array  artifacts.
+	 * @var	array	artifacts.
 	 */
 	var $artifacts = array();
 	var $order_col;
@@ -45,6 +47,7 @@ class ArtifactFactory extends Error {
 	var $status;
 	var $changed_from;
 	var $last_changed;
+	var $submitted_by;
 	var $assigned_to;
 	var $offset;
 	var $max_rows;
@@ -57,43 +60,40 @@ class ArtifactFactory extends Error {
 	var $summary;
 	var $description;
 	var $followups;
-	
+
 	var $query_type;		// query, default, custom
 	var $query_id;			// id of the query (when query_type=query)
 
 	/**
-	 *  Constructor.
+	 * __construct - Constructor.
 	 *
-	 *	@param	object	The ArtifactType object to which this ArtifactFactory is associated.
-	 *	@return	boolean	success.
+	 * @param	object	$ArtifactType	The ArtifactType object to which this ArtifactFactory is associated.
 	 */
-	function ArtifactFactory(&$ArtifactType) {
+	function __construct(&$ArtifactType) {
 		$this->Error();
 		if (!$ArtifactType || !is_object($ArtifactType)) {
 			$this->setError('ArtifactFactory:: No Valid ArtifactType Object');
-			return false;
+			return;
 		}
 		if ($ArtifactType->isError()) {
 			$this->setError('ArtifactFactory:: '.$ArtifactType->getErrorMessage());
-			return false;
+			return;
 		}
 		$this->ArtifactType =& $ArtifactType;
 		$this->changed_from = 0x7ffffff; // Any
-
-		return true;
 	}
 
 	/**
-	 *	setup - sets up limits and sorts before you call getTasks().
+	 * setup - sets up limits and sorts before you call getTasks().
 	 *
-	 *	@param	int	The offset - number of rows to skip.
-	 *	@param	string	The column to sort on.
-	 *	@param	string	The way to order - ASC or DESC.
-	 *	@param	int	The max number of rows to return.
-	 *	@param	string	Whether to set these prefs into the user_prefs table - use "custom".
-	 *	@param	int	Include this param if you want to limit to a certain assignee.
-	 *	@param	int	Include this param if you want to limit to a particular status.
-	 *	@param	array	Array of extra fields & elements to limit the query to.
+	 * @param	int	$offset		The offset - number of rows to skip.
+	 * @param	string	$order_col	The column to sort on.
+	 * @param	string	$sort		The way to order - ASC or DESC.
+	 * @param	int	$max_rows	The max number of rows to return.
+	 * @param	string	$set		Whether to set these prefs into the user_prefs table - use "custom".
+	 * @param	int	$_assigned_to	Include this param if you want to limit to a certain assignee.
+	 * @param	int	$_status	Include this param if you want to limit to a particular status.
+	 * @param	array	$_extra_fields	Array of extra fields & elements to limit the query to.
 	 */
 	function setup($offset,$order_col,$sort,$max_rows,$set,$_assigned_to,$_status,$_extra_fields=array()) {
 
@@ -151,7 +151,7 @@ class ArtifactFactory extends Error {
 			} elseif (isset($_COOKIE["GFTrackerQuery"])) {
 				$gf_tracker = unserialize($_COOKIE["GFTrackerQuery"]);
 				$query_id = (int)$gf_tracker[$this->ArtifactType->getID()];
-				if ($query_id) { 
+				if ($query_id) {
 					$this->query_type = 'query';
 					$this->query_id = $query_id;
 				}
@@ -178,6 +178,7 @@ class ArtifactFactory extends Error {
 
 			if ($this->query_type == 'query') {
 				$aq = new ArtifactQuery($this->ArtifactType, $this->query_id);
+				$this->submitted_by=$aq->getSubmitter();
 				$_assigned_to=$aq->getAssignee();
 				$_status=$aq->getStatus();
 				$_extra_fields=$aq->getExtraFields();
@@ -202,19 +203,18 @@ class ArtifactFactory extends Error {
 					   'close_date',
 					   'assigned_to',
 					   'submitted_by',
-					   'priority') ;
-		$efarr = $this->ArtifactType->getExtraFields(array(ARTIFACT_EXTRAFIELDTYPE_TEXT,
-						    ARTIFACT_EXTRAFIELDTYPE_TEXTAREA,
-						    ARTIFACT_EXTRAFIELDTYPE_INTEGER,
-						    ARTIFACT_EXTRAFIELDTYPE_SELECT,
-						    ARTIFACT_EXTRAFIELDTYPE_RADIO,
-						    ARTIFACT_EXTRAFIELDTYPE_STATUS));
+					   'priority',
+					   'last_modified_date',
+					   '_votes',
+					   '_voters',
+					   '_votage') ;
+		$efarr = $this->ArtifactType->getExtraFields();
 		$keys=array_keys($efarr);
 		for ($k=0; $k<count($keys); $k++) {
 			$i=$keys[$k];
 			$allowed_order_col[] = $efarr[$i]['extra_field_id'];
 		}
-		
+
 		$_order_col = util_ensure_value_in_set ($order_col,
 							$allowed_order_col);
 		$_sort_ord = util_ensure_value_in_set ($sort,
@@ -232,7 +232,7 @@ class ArtifactFactory extends Error {
 				if (is_array($_extra_fields)){
 					//print_r($_extra_fields);
 					$keys=array_keys($_extra_fields);
-					
+
 					foreach ($keys as $key) {
 						if ($_extra_fields[$key] != 'Array') {
 							$aux_extra_fields[$key] = $_extra_fields[$key];
@@ -244,7 +244,7 @@ class ArtifactFactory extends Error {
 				if (count($aux_extra_fields)>0) {
 					$extra_pref = '|'.serialize($aux_extra_fields);
 				}
-				
+
 				$pref_=$_assigned_to.'|'.$_status.'|'.$_order_col.'|'.$_sort_ord.'|'.$_changed.$extra_pref;
 				if ($pref_ != $u->getPreference('art_cust'.$this->ArtifactType->getID())) {
 					$u->setPreference('art_cust'.$this->ArtifactType->getID(),$pref_);
@@ -265,11 +265,10 @@ class ArtifactFactory extends Error {
 		$this->setChangedFrom($_changed);
 	}
 
-	
 	/**
-	 *	setChangedFrom - sets up changed-from and last-changed before you call getTasks().
+	 * setChangedFrom - sets up changed-from and last-changed before you call getTasks().
 	 *
-	 *	@param	int	The changed_from - offset time(sec) from now
+	 * @param	int	$changed_from	The changed_from - offset time(sec) from now
 	 */
 	function setChangedFrom($changed_from) {
 		$this->changed_from = ($changed_from <= 0) ? 0x7fffffff : $changed_from;
@@ -277,9 +276,9 @@ class ArtifactFactory extends Error {
 	}
 
 	/**
-	 *	getDefaultQuery - get the default query
+	 * getDefaultQuery - get the default query
 	 *
-	 *	@return	int	
+	 * @return	int
 	 */
 	function getDefaultQuery() {
 		if ($this->query_type == 'query')
@@ -287,11 +286,11 @@ class ArtifactFactory extends Error {
 		else
 			return '';
 	}
-	
+
 	/**
-	 *	getArtifacts - get an array of Artifact objects.
+	 * getArtifacts - get an array of Artifact objects.
 	 *
-	 *	@return	array	The array of Artifact objects.
+	 * @return	Artifact[]	Array of Artifact objects.
 	 */
 	function getArtifacts() {
 		if (!empty($this->artifacts)) {
@@ -300,7 +299,7 @@ class ArtifactFactory extends Error {
 
 		$params = array() ;
 		$paramcount = 1 ;
-		
+
 		$selectsql = 'SELECT DISTINCT ON (group_artifact_id, artifact_id) artifact_vw.* FROM artifact_vw';
 
 		$wheresql = ' WHERE group_artifact_id=$'.$paramcount++ ;
@@ -344,6 +343,18 @@ class ArtifactFactory extends Error {
 			$params[] = $this->status;
 		}
 
+		// Add filter if submitted_by is selected.
+		if ($this->submitted_by) {
+			if (is_array($this->submitted_by)) {
+				$wheresql .= ' AND submitted_by = ANY ($'.$paramcount++ ;
+				$params[] = db_int_array_to_any_clause ($this->submitted_by) ;
+				$wheresql .= ')' ;
+			} else {
+				$wheresql .= ' AND submitted_by = $'.$paramcount++ ;
+				$params[] = $this->submitted_by ;
+			}
+		}
+
 		//if assigned to selected, and more to where clause
 		if ($this->assigned_to) {
 			if (is_array($this->assigned_to)) {
@@ -407,14 +418,14 @@ class ArtifactFactory extends Error {
 		}
 		//add constraint on the followups string.
 		if ($this->followups) {
-			$wheresql .= 'LEFT OUTER JOIN artifact_message am USING (artifact_id)
-						WHERE am.body LIKE $'.$paramcount++;
+			$selectsql .= ' LEFT OUTER JOIN artifact_message am USING (artifact_id)';
+			$wheresql .= ' AND am.body LIKE $'.$paramcount++;
 			$params[] = $this->followups;
 		}
 
 		$sortorder = util_ensure_value_in_set ($this->sort,
 						       array ('ASC', 'DESC')) ;
-		
+
 		$sortcol = util_ensure_value_in_set ($this->order_col,
 						     array ('extra',
 							    'artifact_id',
@@ -423,14 +434,17 @@ class ArtifactFactory extends Error {
 							    'close_date',
 							    'assigned_to',
 							    'submitted_by',
-							    'priority'));
+							    'priority',
+							    '_votage',
+							    '_voters',
+							    '_votes'));
 
-		if ($sortcol != 'extra') {
+		if ($sortcol != 'extra' && $sortcol != '_votes' && $sortcol != '_voters' && $sortcol != '_votage' ) {
 			$ordersql = " ORDER BY Artifacts.group_artifact_id $sortorder, Artifacts.$sortcol $sortorder" ;
 		} else {
 			$ordersql = ''  ;
 		}
-			
+
 		$result = db_query_params ('SELECT * FROM (' . $selectsql . $wheresql . ') AS Artifacts' . $ordersql,
 					   $params) ;
 		$rows = db_numrows($result);
@@ -443,17 +457,51 @@ class ArtifactFactory extends Error {
 				$this->artifacts[] = new Artifact($this->ArtifactType, $arr);
 			}
 		}
-		if ($sortcol == 'extra') {
+		if ($sortcol == 'extra' || $sortcol == '_votes' || $sortcol == '_voters' || $sortcol == '_votage') {
 			sortArtifactList ($this->artifacts, $this->order_col, $this->sort) ;
 		}
 		return $this->artifacts;
 	}
 
+	/**
+	 * getArtifactsByReleases - get an array of Artifact objects.
+	 *
+	 * @param	$extra_field_id
+	 * @param	$releases
+	 * @return	array		The array of Artifact objects.
+	 */
+	function getArtifactsByReleases($extra_field_id, $releases) {
+		$artifacts = array();
+
+		$sql = 'SELECT a.*
+		FROM artifact_extra_field_data aefd, artifact_extra_field_elements aefe, artifact_vw a
+		WHERE aefd.extra_field_id=aefe.extra_field_id
+		AND CAST (aefd.field_data AS integer)=aefe.element_id
+		AND aefd.artifact_id=a.artifact_id
+		AND aefd.extra_field_id=$1';
+
+		$query_params = array($extra_field_id);
+
+		if ($releases) {
+			$query_params[] = db_string_array_to_any_clause($releases);
+			$sql .= ' AND aefe.element_name = ANY ($2)';
+		}
+
+		$sql .= ' ORDER BY a.artifact_id';
+
+		$result = db_query_params($sql, $query_params);
+		if ($result && db_numrows($result)) {
+			while ($arr = db_fetch_array($result)) {
+				$artifacts[] = new Artifact($this->ArtifactType, $arr);
+			}
+		}
+
+		return $artifacts;
+	}
+
 }
 
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
