@@ -25,107 +25,61 @@ require_once $gfcommon.'include/Error.class.php';
 
 class ArtifactHistory extends Error {
 
-	/** 
+	/**
 	 * The artifact object.
 	 *
-	 * @var		object	$Artifact.
+	 * @var	object	$Artifact.
 	 */
 	var $Artifact; //object
 
 	/**
 	 * Array of artifact data.
 	 *
-	 * @var		array	$data_array.
+	 * @var	array	$data_array.
 	 */
 	var $data_array;
 
 	/**
-	 *  ArtifactHistory - constructor.
+	 * ArtifactHistory - constructor.
 	 *
-	 *	@param	object	Artifact object.
-	 *  @param	array	(all fields from artifact_history_user_vw) OR id from database.
-	 *  @return	boolean	success.
+	 * @param	Artifact	$Artifact	Artifact object.
+	 * @param	array|bool	$data		(all fields from artifact_history_user_vw) OR id from database.
 	 */
-	function ArtifactHistory(&$Artifact, $data=false) {
-		$this->Error(); 
+	function __construct(&$Artifact, $data=false) {
+		$this->Error();
 
 		//was Artifact legit?
 		if (!$Artifact || !is_object($Artifact)) {
-			$this->setError('ArtifactHistory: No Valid Artifact');
-			return false;
+			$this->setError(_('Invalid Artifact'));
+			return;
 		}
 		//did Artifact have an error?
 		if ($Artifact->isError()) {
 			$this->setError('ArtifactHistory: '.$Artifact->getErrorMessage());
-			return false;
+			return;
 		}
 		$this->Artifact =& $Artifact;
 
 		if ($data) {
 			if (is_array($data)) {
 				$this->data_array =& $data;
-				return true;
 			} else {
-				if (!$this->fetchData($data)) {
-					return false;
-				} else {
-					return true;
-				}
+				$this->fetchData($data);
 			}
 		}
 	}
 
 	/**
-	 *	create - create a new item in the database.
+	 * fetchData - re-fetch the data for this ArtifactHistory from the database.
 	 *
-	 *	@param	string	Item name.
-	 *	@param	int		User_id of assignee.
-	 *  @return id on success / false on failure.
-	 * /
-	function create($name, $auto_assign_to) {
-		//
-		//	data validation
-		//
-		if (!$name || !$auto_assign_to) {
-			$this->setError(_('ArtifactCategory: name and assignee are Required'));
-			return false;
-		}
-		if (!forge_check_perm ('tracker', $this->Artifact->ArtifactType->getID()), 'manager') {
-			$this->setPermissionDeniedError();
-			return false;
-		}
-		$result = db_query_params ('INSERT INTO artifact_category (group_artifact_id,category_name,auto_assign_to) 
-			VALUES ($1,$2,$3)',
-					   array ($this->Artifact->getID(),
-						  htmlspecialchars($name),
-						  $auto_assign_to)) ;
-
-
-		if ($result && db_affected_rows($result) > 0) {
-			$this->clearError();
-			return true;
-		} else {
-			$this->setError(db_error());
-			return false;
-		}
-
-		//	Now set up our internal data structures
-		if (!$this->fetchData($id)) {
-			return false;
-		}
-	}*/
-
-	/**
-	 *	fetchData - re-fetch the data for this ArtifactHistory from the database.
-	 *
-	 *	@param	int		ID of the category.
-	 *	@return	boolean	success.
+	 * @param	int	$id ID of the category.
+	 * @return	boolean	success.
 	 */
 	function fetchData($id) {
 		$res = db_query_params ('SELECT * FROM artifact_category WHERE id=$1',
 					array ($id)) ;
 		if (!$res || db_numrows($res) < 1) {
-			$this->setError('ArtifactHistory: Invalid ArtifactHistory ID');
+			$this->setError(_('Invalid ArtifactHistory ID'));
 			return false;
 		}
 		$this->data_array = db_fetch_array($res);
@@ -134,36 +88,36 @@ class ArtifactHistory extends Error {
 	}
 
 	/**
-	 *	getArtifact - get the Artifact Object this ArtifactHistory is associated with.
+	 * getArtifact - get the Artifact Object this ArtifactHistory is associated with.
 	 *
-	 *	@return object	Artifact.
+	 * @return	object	Artifact.
 	 */
 	function &getArtifact() {
 		return $this->Artifact;
 	}
-	
+
 	/**
-	 *	getID - get this ArtifactHistory's ID.
+	 * getID - get this ArtifactHistory's ID.
 	 *
-	 *	@return	int	The id #.
+	 * @return	int	The id #.
 	 */
 	function getID() {
 		return $this->data_array['id'];
 	}
 
 	/**
-	 *	getName - get the name.
+	 * getName - get the name.
 	 *
-	 *	@return	string	The name.
+	 * @return	string	The name.
 	 */
 	function getName() {
 		return $this->data_array['category_name'];
 	}
 
 	/**
-	 *	getAssignee - get the user_id of the person to assign this category to.
+	 * getAssignee - get the user_id of the person to assign this category to.
 	 *
-	 *	@return int user_id.
+	 * @return int user_id.
 	 */
 	function getAssignee() {
 		return $this->data_array['auto_assign_to'];
@@ -174,5 +128,3 @@ class ArtifactHistory extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
