@@ -20,7 +20,7 @@
  * with FusionForge; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
- 
+
 require_once $gfcommon.'include/Error.class.php';
 require_once $gfcommon.'tracker/ArtifactQuery.class.php';
 
@@ -40,34 +40,30 @@ class ArtifactQueryFactory extends Error {
 	var $ArtifactQueries = null;
 
 	/**
-	 *  Constructor.
+	 * Constructor.
 	 *
-	 *	@param	object	The Group object to which this ArtifactQueryFactory is associated
-	 *	@return	boolean	success.
+	 * @param	object	$ArtifactType	The Group object to which this ArtifactQueryFactory is associated
 	 */
-	function ArtifactQueryFactory(&$ArtifactType) {
+	function __construct(&$ArtifactType) {
 		$this->Error();
 		if (!$ArtifactType || !is_object($ArtifactType)) {
 			$this->setError('ArtifactQueryFactory:: No ArtifactType Object');
-			return false;
+			return;
 		}
 		if ($ArtifactType->isError()) {
 			$this->setError('ArtifactQueryFactory:: '.$ArtifactType->getErrorMessage());
-			return false;
+			return;
 		}
 		$this->ArtifactType =& $ArtifactType;
-
-
-		return true;
 	}
-	
+
 	function &getArtifactQueries() {
 		if (!is_null($this->ArtifactQueries)) {
 			return $this->ArtifactQueries;
 		}
-		
+
 		$this->ArtifactQueries = array();
-		
+
 		$res = db_query_params ('SELECT * FROM artifact_query WHERE user_id=$1
 					 AND group_artifact_id=$2',
 					array (user_getid(),
@@ -75,12 +71,12 @@ class ArtifactQueryFactory extends Error {
 		if (!$res) {
 			$this->setError("ArtifactQueryFactory:: Database error");
 		}
-		
+
 		while ($data = db_fetch_array($res)) {
 			$artifactQuery = new ArtifactQuery($this->ArtifactType, $data["artifact_query_id"]);
 			$this->ArtifactQueries[] = $artifactQuery;
 		}
-		
+
 		return $this->ArtifactQueries;
 	}
 }
@@ -89,5 +85,3 @@ class ArtifactQueryFactory extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
