@@ -4,6 +4,7 @@
  *
  * Copyright 2002, GForge, LLC
  * Copyright 2009, Roland Mas
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -43,44 +44,46 @@ class ArtifactTypeFactory extends Error {
 	/**
 	 * The data type (DAO)
 	 *
-  	 * @var 	string dataType
+	 * @var 	string dataType
 	 */
 	var $dataType;
 
 	/**
-	 *  Constructor.
+	 * __construct - ArtifactTypeFactory constructor.
 	 *
-	 *	@param	object	The Group object to which this ArtifactTypeFactory is associated
-	 *	@return	boolean	success.
+	 * @param	Group	$Group The Group object to which this ArtifactTypeFactory is associated
 	 */
-	function ArtifactTypeFactory(&$Group) {
+	function __construct(&$Group) {
 		$this->Error();
 		if (!$Group || !is_object($Group)) {
-			$this->setError('ArtifactTypeFactory:: No Valid Group Object');
-			return false;
+			$this->setError(_('No Valid Group Object'));
+			return;
 		}
 		if ($Group->isError()) {
-			$this->setError('ArtifactTypeFactory:: '.$Group->getErrorMessage());
-			return false;
+			$this->setError('ArtifactTypeFactory: '.$Group->getErrorMessage());
+			return;
+		}
+		if (!$Group->usesTracker()) {
+			$this->setError(sprintf(_('%s does not use the Tracker tool'),
+			    $Group->getPublicName()));
+			return;
 		}
 		$this->Group =& $Group;
-
-		return true;
 	}
 
 	/**
-	 *	getGroup - get the Group object this ArtifactType is associated with.
+	 * getGroup - get the Group object this ArtifactType is associated with.
 	 *
-	 *	@return	object	The Group object.
+	 * @return	object	The Group object.
 	 */
 	function &getGroup() {
 		return $this->Group;
 	}
 
 	/**
-	 *	getAllArtifactTypeIds - return a list of tracker ids.
+	 * getAllArtifactTypeIds - return a list of tracker ids.
 	 *
-	 *	@return	array	The array of ArtifactType objects.
+	 * @return	array	The array of ArtifactType objects.
 	 */
 	function &getAllArtifactTypeIds() {
 		$result = array () ;
@@ -98,11 +101,11 @@ class ArtifactTypeFactory extends Error {
 	}
 
 	/**
-	 *	getArtifactTypes - return an array of ArtifactType objects.
+	 * getArtifactTypes - return an array of ArtifactType objects.
 	 *
-	 *	@return	array	The array of ArtifactType objects.
+	 * @return	array	The array of ArtifactType objects.
 	 */
-	function &getArtifactTypes() {
+	function getArtifactTypes() {
 		if ($this->ArtifactTypes) {
 			return $this->ArtifactTypes;
 		}
@@ -122,21 +125,9 @@ class ArtifactTypeFactory extends Error {
 		}
 		return $this->ArtifactTypes;
 	}
-
-	/**
-	 * getPublicFlag - a utility method to load up the current user's permissions
- 	 *
-	 * @return 	string 	The public_flag field to plug into a SQL string
-	 */	
-	function &getPublicFlag() {
-		return $public_flag;
-	}
-
 }
 
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
