@@ -34,21 +34,21 @@ class ArtifactsForUser extends Error {
 	var $Artifact;
 
 	/**
-	* Creates a new ArtifactsFor User object
+	* __construct - Creates a new ArtifactsForUser object
 	*
-	* @param	user	the User object for which to collect artifacts
+	* @param	object	$user	the User object for which to collect artifacts
 	*/
-	function ArtifactsForUser(&$user) {
-		$this->User =& $user;	
-		return true;
+	function __construct(&$user) {
+		$this->User =& $user;
 	}
 
 	/**
-	*	getArtifactsFromSQL - Gets an array of Artifacts
-	*	
-	*	@param	sql	The sql that returns artifact_id
-	*	@return	Artifact[]	The array of Artifacts
-	*/
+	 * getArtifactsFromSQLwithParams - Gets an array of Artifacts
+	 *
+	 * @param	string		$sql	The sql that returns artifact_id
+	 * @param	array		$params	Array of values associated to sql query
+	 * @return	Artifact[]	The array of Artifacts
+	 */
 	function &getArtifactsFromSQLwithParams ($sql, $params) {
 		$artifacts = array();
 		$result = db_query_params ($sql, $params);
@@ -57,9 +57,9 @@ class ArtifactsForUser extends Error {
 			return $artifacts;
 		}
 		for ($i=0; $i < $rows; $i++) {
-			$id  = db_result($result,$i,'artifact_id');
+			$artifact_id = db_result($result,$i,'artifact_id');
 			$arr = db_fetch_array($result);
-			$afi = new ArtifactFromID($id,$arr);
+			$afi = new ArtifactFromID($artifact_id,$arr);
 			if ($afi->isError()) {
 				$this->setError($afi->getErrorMessage());
 			} elseif($afi->Artifact->ArtifactType->Group->getStatus() == 'A') {
@@ -70,19 +70,19 @@ class ArtifactsForUser extends Error {
 	}
 
 	/**
-	*	getAssignedArtifacts	- Get the users's assigned artifacts
-	*	@return	Artifact[]	The array of Artifacts
+	* getAssignedArtifactsByGroup - Get the users's assigned artifacts
+	* @return	Artifact[]	The array of Artifacts
 	*/
 	function &getAssignedArtifactsByGroup() {
 		return $this->getArtifactsFromSQLwithParams('SELECT * FROM artifact_vw av WHERE av.assigned_to=$1 AND av.status_id=1 ORDER BY av.group_artifact_id, av.artifact_id DESC',
 							    array($this->User->getID())) ;
-								  
+
 	}
 
 	/**
-	*	getSubmittedArtifactsByGroup
+	* getSubmittedArtifactsByGroup
 	*
-	*	@return Artifact[] The array of Artifacts
+	* @return	Artifact[]	The array of Artifacts
 	*/
 	function &getSubmittedArtifactsByGroup() {
 		return $this->getArtifactsFromSQLwithParams('SELECT * FROM artifact_vw av WHERE av.submitted_by=$1 AND av.status_id=1 ORDER BY av.group_artifact_id, av.artifact_id DESC',
@@ -90,22 +90,22 @@ class ArtifactsForUser extends Error {
 	}
 
 	/**
-	*	getMonitoredArtifacts
+	* getMonitoredArtifacts
 	*
-	*	@return Artifact[] The array of Artifacts
+	* @return	Artifact[]	The array of Artifacts
 	*/
 	function & getMonitoredArtifacts() {
 		$artifacts = array();
 
 		$result=db_query_params ('SELECT groups.group_name,groups.group_id,
 artifact_group_list.group_artifact_id,
-artifact_group_list.name 
-FROM groups,artifact_group_list,artifact_type_monitor 
-WHERE groups.group_id=artifact_group_list.group_id 
-AND groups.status =$1 
-AND artifact_group_list.group_artifact_id=artifact_type_monitor.group_artifact_id 
-AND artifact_type_monitor.user_id=$2 
-ORDER BY group_name DESC',
+artifact_group_list.name
+FROM groups,artifact_group_list,artifact_type_monitor
+WHERE groups.group_id=artifact_group_list.group_id
+AND groups.status =$1
+AND artifact_group_list.group_artifact_id=artifact_type_monitor.group_artifact_id
+AND artifact_type_monitor.user_id=$2
+ORDER BY group_name ASC',
 					 array('A',
 					       $this->User->getID()));
 		$rows=db_numrows($result);
@@ -117,7 +117,6 @@ ORDER BY group_name DESC',
 			$group_artifact_id = db_result($result,$i,'group_artifact_id');
 			$group = group_get_object($group_id);
 			$artifact = new ArtifactType($group,$group_artifact_id);
-			$ag = $artifact->getGroup();
 			if ($artifact->isError()) {
 				$this->setError($artifact->getErrorMessage());
 			} else {
@@ -132,5 +131,3 @@ ORDER BY group_name DESC',
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
