@@ -1,63 +1,70 @@
 <?php
 /**
  * Copyright (c) Xerox Corporation, Codendi Team, 2001-2009. All rights reserved
+ * Copyright 2012, Franck Villaume - TrivialDev
  *
- * This file is a part of Codendi.
+ * This file is a part of Fusionforge.
  *
- * Codendi is free software; you can redistribute it and/or modify
+ * Fusionforge is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * Codendi is distributed in the hope that it will be useful,
+ * Fusionforge is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Codendi. If not, see <http://www.gnu.org/licenses/>.
+ * along with Fusionforge. If not, see <http://www.gnu.org/licenses/>.
  */
 
-require_once('common/widget/WidgetLayoutManager.class.php');
+require_once 'common/widget/WidgetLayoutManager.class.php';
 
-require_once('common/widget/Widget_MySurveys.class.php');
-require_once('common/widget/Widget_MyProjects.class.php');
-require_once('common/widget/Widget_MyBookmarks.class.php');
-require_once('common/widget/Widget_MyMonitoredForums.class.php');
+require_once 'common/widget/Widget_MySurveys.class.php';
+require_once 'common/widget/Widget_MyProjects.class.php';
+require_once 'common/widget/Widget_MyBookmarks.class.php';
+require_once 'common/widget/Widget_MyMonitoredForums.class.php';
 //require_once('common/widget/Widget_MyMonitoredFp.class.php');
-require_once('common/widget/Widget_MyLatestSvnCommits.class.php');
-require_once('common/widget/Widget_MyArtifacts.class.php');
+require_once 'common/widget/Widget_MyLatestSvnCommits.class.php';
+require_once 'common/widget/Widget_MyProjectsLastDocuments.class.php';
+require_once 'common/widget/Widget_MyArtifacts.class.php';
 //require_once('common/widget/Widget_MyBugs.class.php');
 //require_once('common/widget/Widget_MySrs.class.php');
-require_once('common/widget/Widget_MyTasks.class.php');
-require_once('common/widget/Widget_MyRss.class.php');
+require_once 'common/widget/Widget_MyTasks.class.php';
+require_once 'common/widget/Widget_MyRss.class.php';
 
-require_once('common/widget/Widget_MyAdmin.class.php');
+require_once 'common/widget/Widget_MyAdmin.class.php';
 /*
-   require_once('common/widget/Widget_MyTwitterFollow.class.php');
-   require_once('common/widget/Widget_MySystemEvent.class.php');
+   require_once 'common/widget/Widget_MyTwitterFollow.class.php';
+   require_once 'common/widget/Widget_MySystemEvent.class.php';
 //require_once('common/widget/Widget_MyWikiPage.class.php');
 */require_once('common/widget/Widget_ProjectDescription.class.php');
 //require_once('common/widget/Widget_ProjectClassification.class.php');
 
-require_once('common/widget/Widget_ProjectMembers.class.php');
-require_once('common/widget/Widget_ProjectInfo.class.php');
-require_once('common/widget/Widget_ProjectLatestFileReleases.class.php');
-require_once('common/widget/Widget_ProjectLatestNews.class.php');
-require_once('common/widget/Widget_ProjectPublicAreas.class.php');
-require_once('common/widget/Widget_ProjectRss.class.php');/*
-							     require_once('common/widget/Widget_ProjectLatestSvnCommits.class.php');
-							     require_once('common/widget/Widget_ProjectLatestCvsCommits.class.php');
-							     require_once('common/widget/Widget_ProjectTwitterFollow.class.php');
+require_once 'common/widget/Widget_ProjectMembers.class.php';
+require_once 'common/widget/Widget_ProjectInfo.class.php';
+require_once 'common/widget/Widget_ProjectLatestFileReleases.class.php';
+require_once 'common/widget/Widget_ProjectLatestDocuments.class.php';
+require_once('common/widget/Widget_ProjectDocumentsActivity.class.php');
+
+require_once 'common/widget/Widget_ProjectLatestNews.class.php';
+require_once 'common/widget/Widget_ProjectPublicAreas.class.php';
+require_once 'common/widget/Widget_ProjectRss.class.php';/*
+							     require_once 'common/widget/Widget_ProjectLatestSvnCommits.class.php';
+							     require_once 'common/widget/Widget_ProjectLatestCvsCommits.class.php';
+							     require_once 'common/widget/Widget_ProjectTwitterFollow.class.php';
 //require_once('common/widget/Widget_ProjectWikiPage.class.php');
-require_once('common/widget/Widget_ProjectSvnStats.class.php');
+require_once 'common/widget/Widget_ProjectSvnStats.class.php';
 							   */
 
-require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
+require_once 'common/widget/Widget_MyMonitoredDocuments.class.php';
 
 /**
- * Widget
- */
+* "Codendi" Layout Widget
+*
+*/
+
 /* abstract */ class Widget {
 
 	var $content_id;
@@ -80,6 +87,10 @@ require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
 	function getTitle() {
 		return '';
 	}
+	/**
+	 * TODO : Enter description here ...
+	 * @return string
+	 */
 	function getContent() {
 		return '';
 	}
@@ -89,7 +100,7 @@ require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
 		$prefs .= '<fieldset><legend>'. _("Preferences") .'</legend>';
 		$prefs .= $this->getPreferences();
 		$prefs .= '<br />';
-		$prefs .= '<input type="submit" name="cancel" value="'. _("Cancel") .'" /> ';
+		$prefs .= '<input type="submit" name="cancel" value="'. _("Cancel") .'" /> ';
 		$prefs .= '<input type="submit" value="'. _("Submit") .'" />';
 		$prefs .= '</fieldset>';
 		$prefs .= '</form>';
@@ -143,12 +154,13 @@ require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
 	}
 	/**
 	 * cloneContent
-	 * 
+	 *
 	 * Take the content of a widget, clone it and return the id of the new content
-	 * 
+	 *
 	 * @param $id the id of the content to clone
 	 * @param $owner_id the owner of the widget of the new widget
 	 * @param $owner_type the type of the owner of the new widget (see WidgetLayoutManager)
+	 * @return int
 	 */
 	function cloneContent($id, $owner_id, $owner_type) {
 		return $this->getInstanceId();
@@ -157,6 +169,11 @@ require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
 	}
 	function destroy($id) {
 	}
+	/**
+	 * getInstance - Returns an instance of a widget given its name
+	 * @param string $widget_name
+	 * @return Widget instance
+	 */
 	static  function & getInstance($widget_name) {
 		$o = null;
 		switch($widget_name) {
@@ -175,6 +192,9 @@ require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
 			case 'mymonitoreddocuments':
 				$o = new Widget_MyMonitoredDocuments();
 				break;
+			case 'myprojectslastdocuments':
+				$o = new Widget_MyProjectsLastDocuments();
+				break;
 			case 'myartifacts':
 				$o = new Widget_MyArtifacts();
 				break;
@@ -184,11 +204,10 @@ require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
 			case 'mytasks':
 				$o = new Widget_MyTasks();
 				break;
-
 			case 'myadmin':
-				if (forge_check_global_perm ('forge_admin')
-					|| forge_check_global_perm ('approve_projects')
-					|| forge_check_global_perm ('approve_news')) {
+				if (forge_check_global_perm('forge_admin')
+					|| forge_check_global_perm('approve_projects')
+					|| forge_check_global_perm('approve_news')) {
 					$o = new Widget_MyAdmin();
 				}
 				break;/*
@@ -198,9 +217,9 @@ require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
 			case 'mymonitoredfp':
 				$o = new Widget_MyMonitoredFp();
 				break;
-				case 'mylatestsvncommits':
+			case 'mylatestsvncommits':
 				$o = new Widget_MyLatestSvnCommits();
-				break; 
+				break;
 				case 'mybugs':
 				$o = new Widget_MyBugs();
 				break;
@@ -211,32 +230,39 @@ require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
 				$o = new Widget_MyWikiPage();
 				break;
 				case 'mysystemevent':
-				if (user_is_super_user()) { //This widget is only for super admin
-				$o = new Widget_MySystemEvent();
-				}
-				break;
+					// This widget is only for super admin
+					if (forge_check_global_perm('forge_admin')) {
+						$o = new Widget_MySystemEvent();
+					}
+					break;
 				case 'projectclassification':
 				$o = new Widget_ProjectClassification();
 				break;*/
-				case 'projectdescription':
+			case 'projectdescription':
 				$o = new Widget_ProjectDescription();
 				break;
-				case 'projectmembers':
+			case 'projectmembers':
 				$o = new Widget_ProjectMembers();
 				break;
-				case 'projectinfo':
+			case 'projectinfo':
 				$o = new Widget_ProjectInfo();
 				break;
-				case 'projectlatestfilereleases':
+			case 'projectlatestfilereleases':
 				$o = new Widget_ProjectLatestFileReleases();
 				break;
-				case 'projectlatestnews':
+			case 'projectlatestdocuments':
+				$o = new Widget_ProjectLatestDocuments();
+				break;
+			case 'projectdocumentsactivity':
+				$o = new Widget_ProjectDocumentsActivity();
+				break;
+			case 'projectlatestnews':
 				$o = new Widget_ProjectLatestNews();
 				break;
-				case 'projectpublicareas':
+			case 'projectpublicareas':
 				$o = new Widget_ProjectPublicAreas();
 				break;
-				case 'projectrss':
+			case 'projectrss':
 				$o = new Widget_ProjectRss();
 				break;/*
 				case 'projecttwitterfollow':
@@ -257,6 +283,7 @@ require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
 			default:
 				//$em = EventManager::instance();
 				//$em->processEvent('widget_instance', array('widget' => $widget_name, 'instance' => &$o));
+				// calls the plugin's hook to get an instance of the widget
 				plugin_hook('widget_instance', array('widget' => $widget_name, 'instance' => &$o));
 				break;
 		}
@@ -265,20 +292,26 @@ require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
 		}
 		return $o;
 	}
+	/**
+	 * getCodendiWidgets - Static
+	 * @param unknown_type $owner_type
+	 * @return multitype:
+	 */
 	static function getCodendiWidgets($owner_type) {
 		switch ($owner_type) {
 			case WidgetLayoutManager::OWNER_TYPE_USER:
-				$widgets = array('myadmin', 'mysurveys', 'myprojects', 'mybookmarks', 
+				$widgets = array('myadmin', 'mysurveys', 'myprojects', 'mybookmarks',
 						'mymonitoredforums', 'mymonitoredfp', 'myartifacts', 'mybugs', //'mywikipage' //not yet
 						'mytasks', 'mysrs', 'mylatestsvncommits', 'mytwitterfollow',
-						'mysystemevent', 'myrss', 'mymonitoreddocuments',
+						'mysystemevent', 'myrss', 'mymonitoreddocuments', 'myprojectslastdocuments',
 						);
 				break;
 			case WidgetLayoutManager::OWNER_TYPE_GROUP:
-				$widgets = array('projectdescription', 'projectmembers', 'projectinfo', 
-						'projectlatestfilereleases', 'projectlatestnews', 'projectpublicareas', //'projectwikipage' //not yet
-						'projectlatestsvncommits', 'projectlatestcvscommits', 'projecttwitterfollow', 
-						'projectsvnstats', 'projectrss', 
+				// project home widgets
+				$widgets = array('projectdescription', 'projectmembers', 'projectinfo',
+						'projectlatestfilereleases', 'projectlatestdocuments', 'projectlatestnews', 'projectpublicareas', //'projectwikipage' //not yet
+						'projectlatestsvncommits', 'projectlatestcvscommits', 'projecttwitterfollow',
+						'projectsvnstats', 'projectrss', 'projectdocumentsactivity',
 						);
 				break;
 			case WidgetLayoutManager::OWNER_TYPE_HOME:
@@ -289,10 +322,12 @@ require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
 				break;
 		}
 
+		// add widgets of the plugins, declared through hooks
 		$plugins_widgets = array();
 		//$em =& EventManager::instance();
 		//$em->processEvent('widgets', array('codendi_widgets' => &$plugins_widgets, 'owner_type' => $owner_type));
 		plugin_hook('widgets', array('codendi_widgets' => &$plugins_widgets, 'owner_type' => $owner_type));
+		plugin_hook('widgets', array('fusionforge_widgets' => &$plugins_widgets, 'owner_type' => $owner_type));
 
 		if (is_array($plugins_widgets)) {
 			$widgets = array_merge($widgets, $plugins_widgets);
@@ -328,7 +363,7 @@ require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
 	}
 
 	function getCategory() {
-		return 'General';
+		return _('General');
 	}
 	function getDescription() {
 		return '';
@@ -345,4 +380,3 @@ require_once('common/widget/Widget_MyMonitoredDocuments.class.php');
 		return '/widgets/widget.php?owner='. $owner_type.$owner_id .'&amp;action=iframe&amp;name['. $this->id .']='. $this->getInstanceId();
 	}
 }
-?>
