@@ -2,70 +2,74 @@
 /**
  * Copyright (c) Xerox Corporation, Codendi Team, 2001-2009. All rights reserved
  * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
- * This file is a part of Codendi.
+ * This file is a part of Fusionforge.
  *
- * Codendi is free software; you can redistribute it and/or modify
+ * Fusionforge is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * Codendi is distributed in the hope that it will be useful,
+ * Fusionforge is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Codendi. If not, see <http://www.gnu.org/licenses/>.
+ * along with Fusionforge. If not, see <http://www.gnu.org/licenses/>.
  */
 
-require_once('common/widget/WidgetLayout.class.php');
-require_once('common/widget/Widget.class.php');
+require_once $gfcommon.'widget/WidgetLayout.class.php';
+require_once $gfcommon.'widget/Widget.class.php';
 require_once $gfcommon.'include/preplugins.php';
+
 /**
  * WidgetLayoutManager
- * 
+ *
  * Manage layouts for users, groups and homepage
  */
 class WidgetLayoutManager {
 	const OWNER_TYPE_USER  = 'u';
+	/**
+	 * Layout for project home
+	 * @var string
+	 */
 	const OWNER_TYPE_GROUP = 'g';
 	const OWNER_TYPE_HOME  = 'h';
 
 	/**
 	 * displayLayout
-	 * 
-	 * Display the default layout for the "owner". It my be the home page, the project summary page or /my/ page.
 	 *
-	 * @param  owner_id  
-	 * @param  owner_type  
+	 * Display the default layout for the "owner". It may be the home page, the project summary page or /my/ page.
+	 *
+	 * @param	int		$owner_id
+	 * @param	string	$owner_type
 	 */
 	function displayLayout($owner_id, $owner_type) {
 		$sql = "SELECT * from owner_layouts where owner_id=$1 and owner_type=$2";
-		$res = db_query_params($sql,array($owner_id,$owner_type));
+		$res = db_query_params($sql, array($owner_id, $owner_type));
 		if($res && db_numrows($res)<1) {
-			if($owner_type==self::OWNER_TYPE_USER) {
+			if($owner_type == self::OWNER_TYPE_USER) {
 				$this->createDefaultLayoutForUser($owner_id);
 				$this->displayLayout($owner_id,$owner_type);
-			}
-			else {
+			} else {
 				$this->createDefaultLayoutForProject($owner_id,1);
 				$this->displayLayout($owner_id,$owner_type);
 			}
-		}
-		else {
-			$sql = "SELECT l.* 
-				FROM layouts AS l INNER JOIN owner_layouts AS o ON(l.id = o.layout_id) 
-				WHERE o.owner_type = $1 
-				AND o.owner_id = $2 
+		} else {
+			$sql = "SELECT l.*
+				FROM layouts AS l INNER JOIN owner_layouts AS o ON(l.id = o.layout_id)
+				WHERE o.owner_type = $1
+				AND o.owner_id = $2
 				AND o.is_default = 1
 				";
-			$req = db_query_params($sql,array($owner_type,$owner_id));
+			$req = db_query_params($sql, array($owner_type ,$owner_id));
 			if ($data = db_fetch_array($req)) {
 				$readonly = !$this->_currentUserCanUpdateLayout($owner_id, $owner_type);
 //				if (!$readonly) {
 //					echo '<p class="customize"><a href="/widgets/widgets.php?owner='. $owner_type.$owner_id .'&amp;layout_id='. $data['id'] .'">'. _("Customize") .'</a></p>';
-//				} else if ($owner_type === self::OWNER_TYPE_GROUP) {
+//				} elseif ($owner_type === self::OWNER_TYPE_GROUP) {
 //					echo '<br />';
 //				}
 				$layout = new WidgetLayout($data['id'], $data['name'], $data['description'], $data['scope']);
@@ -94,16 +98,16 @@ class WidgetLayoutManager {
 					unset($row);
 				}
 				$layout->display($readonly, $owner_id, $owner_type);
-			}      
+			}
 		}
 	}
 
 	/**
 	 * _currentUserCanUpdateLayout
-	 * 
-	 * @return boolean true if the user dan uppdate the layout (add/remove widget, collapse, set preferences, ...)
-	 * @param  owner_id  
-	 * @param  owner_type  
+	 *
+	 * @param	int		$owner_id
+	 * @param	string	$owner_type
+	 * @return	boolean true if the user can update the layout (add/remove widget, collapse, set preferences, ...)
 	 */
 	function _currentUserCanUpdateLayout($owner_id, $owner_type) {
 		$readonly = true;
@@ -115,7 +119,7 @@ class WidgetLayoutManager {
 				}
 				break;
 			case self::OWNER_TYPE_GROUP:
-				if (UserManager::instance()->getCurrentUser()->is_super_user==true || user_ismember($request->get('group_id'), 'A')) { //Only project admin
+				if (forge_check_perm('project_admin', $owner_id, NULL)) { //Only project admin
 					$readonly = false;
 				}
 				break;
@@ -129,7 +133,7 @@ class WidgetLayoutManager {
 	}
 	/**
 	 * createDefaultLayoutForUser
-	 * 
+	 *
 	 * Create the first layout for the user and add some initial widgets:
 	 * - MyArtifacts
 	 * - MyProjects
@@ -139,12 +143,14 @@ class WidgetLayoutManager {
 	 * - MyMonitoredForums
 	 * - and widgets of plugins if they want to listen to the event default_widgets_for_new_owner
 	 *
-	 * @param  owner_id The id of the newly created user
+	 * @param	int	$owner_id The id of the newly created user
 	 */
 	function createDefaultLayoutForUser($owner_id) {
 		$owner_type = self::OWNER_TYPE_USER;
+		db_begin();
+		$success = true;
 		$sql = "INSERT INTO owner_layouts(layout_id, is_default, owner_id, owner_type) VALUES (1, 1, $1, $2)";
-		if (db_query_params($sql,array($owner_id,$owner_type))) {
+		if (db_query_params($sql, array($owner_id, $owner_type))) {
 
 			$sql = "INSERT INTO layouts_contents(owner_id, owner_type, layout_id, column_id, name, rank) VALUES ";
 
@@ -156,7 +162,10 @@ class WidgetLayoutManager {
 			$args[] = "($1, $2, 1, 2, 'mymonitoredfp', 1)";
 
 			foreach($args as $a) {
-				db_query_params($sql.$a,array($owner_id,$owner_type));
+				if (!db_query_params($sql.$a,array($owner_id,$owner_type))) {
+					$success = false;
+					break;
+				}
 			}
 
 			/*  $em =& EventManager::instance();
@@ -165,25 +174,31 @@ class WidgetLayoutManager {
 			    foreach($widgets as $widget) {
 			    $sql .= ",($13, $14, 1, $15, $16, $17)";
 			    }*/
+		} else
+			$success = false;
+		if (!$success) {
+			$success = db_error();
+			db_rollback();
+			exit_error(sprintf(_('DB Error: %s'), $success), 'widgets');
 		}
-		echo db_error();
+		db_commit();
 	}
 
 	/**
 	 * createDefaultLayoutForProject
-	 * 
+	 *
 	 * Create the first layout for a new project, based on its parent template.
 	 * Add some widgets based also on its parent configuration and on its service configuration.
 	 *
-	 * @param  group_id  the id of the newly created project
-	 * @param  template_id  the id of the project template
+	 * @param	int	$group_id  the id of the newly created project
+	 * @param	int	$template_id  the id of the project template
 	 */
 	function createDefaultLayoutForProject($group_id, $template_id) {
 		$pm = ProjectManager::instance();
 		$project = $pm->getProject($group_id);
-		$sql = "INSERT INTO owner_layouts(layout_id, is_default, owner_id, owner_type) 
-			SELECT layout_id, is_default, $1, owner_type 
-			FROM owner_layouts 
+		$sql = "INSERT INTO owner_layouts(layout_id, is_default, owner_id, owner_type)
+			SELECT layout_id, is_default, $1, owner_type
+			FROM owner_layouts
 			WHERE owner_type = $2
 			AND owner_id = $3
 			";
@@ -200,10 +215,10 @@ class WidgetLayoutManager {
 						$w->setOwner($template_id, self::OWNER_TYPE_GROUP);
 						if ($w->canBeUsedByProject($project)) {
 							$content_id = $w->cloneContent($w->content_id, $group_id, self::OWNER_TYPE_GROUP);
-							$sql = "INSERT INTO layouts_contents(owner_id, owner_type, content_id, layout_id, column_id, name, rank, is_minimized, is_removed, display_preferences) 
+							$sql = "INSERT INTO layouts_contents(owner_id, owner_type, content_id, layout_id, column_id, name, rank, is_minimized, is_removed, display_preferences)
 								VALUES ($1,$2,$3,$4,$5,$6,$7,$8,$9,$10);
 							";
-							db_query_params($sql,array($group_id , self::OWNER_TYPE_GROUP , $content_id ,  $data['layout_id'] ,  $data['column_id'] ,  $data['name'] ,  $data['rank'] ,  $data['is_minimized'] ,  $data['is_removed'] ,  $data['display_preferences'] ));
+							db_query_params($sql, array($group_id , self::OWNER_TYPE_GROUP , $content_id ,  $data['layout_id'] ,  $data['column_id'] ,  $data['name'] ,  $data['rank'] ,  $data['is_minimized'] ,  $data['is_removed'] ,  $data['display_preferences'] ));
 							echo db_error();
 						}
 					}
@@ -214,45 +229,80 @@ class WidgetLayoutManager {
 	}
 
 	/**
-	 * displayAvailableWidgets
-	 * 
-	 * Display all widget that the user can add to the layout
+	 * displayAvailableWidgets - Display all widgets that the user can add to the layout
 	 *
-	 * @param  owner_id 
-	 * @param  owner_type 
-	 * @param  layout_id 
+	 * @param	int		$owner_id
+	 * @param	string	$owner_type
+	 * @param	int		$layout_id
 	 */
 	function displayAvailableWidgets($owner_id, $owner_type, $layout_id) {
+		// select already used widgets
 		$used_widgets = array();
-		$sql = "SELECT * 
-			FROM layouts_contents 
+		$sql = "SELECT *
+			FROM layouts_contents
 			WHERE owner_type = $1
-			AND owner_id = $2 
-			AND layout_id = $3 
+			AND owner_id = $2
+			AND layout_id = $3
 			AND content_id = 0 AND column_id <> 0";
 		$res = db_query_params($sql,array($owner_type,$owner_id,$layout_id));
 		while($data = db_fetch_array($res)) {
 			$used_widgets[] = $data['name'];
 		}
+		// display contextual toolbar
 		echo '<ul class="widget_toolbar">';
 		$url = "/widgets/widgets.php?owner=".HTTPRequest::instance()->get('owner').
 			"&amp;layout_id=".HTTPRequest::instance()->get('layout_id');
 
-		if ($update_layout = HTTPRequest::instance()->get('update') == 'layout') {
+		$update_layout = (HTTPRequest::instance()->get('update') == 'layout');
+		if ($update_layout) {
+			// customized selected
 			echo '<li><a href="'. $url .'">'. _("Add widgets") .'</a></li>';
-			echo '<li class="current"><a href="'. $url.'&amp;update=layout' .'">'. _("Customize layout") .'</a></li>';
+			echo '<li class="current"><a href="'. $url.'&amp;update=layout' .'">'. _("Customize Layout") .'</a></li>';
 			$action = 'layout';
 		} else {
+			// add selected, or default when first displayed
 			echo '<li class="current"><a href="'. $url .'">'. _("Add widgets") .'</a></li>';
-			echo '<li><a href="'. $url.'&amp;update=layout' .'">'. _("Customize layout") .'</a></li>';
+			echo '<li><a href="'. $url.'&amp;update=layout' .'">'. _("Customize Layout") .'</a></li>';
 			$action = 'widget';
 		}
 		echo '</ul>';
 		echo '<form action="/widgets/updatelayout.php?owner='. $owner_type.$owner_id .'&amp;action='. $action .'&amp;layout_id='. $layout_id .'" method="post">';
 		if ($update_layout) {
+			?>
+			<script type='text/javascript'>//<![CDATA[
+				var controllerLayoutBuilder;
+				jQuery(document).ready(function() {
+					controllerLayoutBuilder = new LayoutBuilderController({
+						buttonAddRow:		jQuery('.layout-manager-row-add'),
+						buttonAddColumn:	jQuery('.layout-manager-column-add'),
+						buttonRemoveColumn:	jQuery('.layout-manager-column-remove')
+					});
+					jQuery('#save').click(function(){
+						if (jQuery('#layout_custom').is(':checked')) {
+							var form = jQuery('#layout-manager').parents('form').first();
+							jQuery('#layout-manager').find('.layout-manager-row').each(function(i, e) {
+								jQuery('<input>', {
+									type: 'hidden',
+									name: 'new_layout[]',
+									value: jQuery(e).find('.layout-manager-column input[type=number]').map(function(){ return this.value;}).get().join(',')
+									}).appendTo(form);
+							});
+						}
+					});
+					jQuery('.layout-manager-chooser').each(function(i, e) {
+						jQuery(e).find('input[type=radio]').change(function() {
+							jQuery('.layout-manager-chooser').each(function(i, e) {
+								jQuery(e).removeClass('layout-manager-chooser_selected');
+							});
+							jQuery(e).addClass('layout-manager-chooser_selected');
+						});
+					});
+				});
+			//]]></script>
+			<?php
 			$sql = "SELECT * FROM layouts WHERE scope='S' ORDER BY id ";
 			$req_layouts = db_query_params($sql,array());
-			echo '<table cellspacing="0" cellpadding="0">';
+			echo '<table>';
 			$is_custom = true;
 			while ($data = db_fetch_array($req_layouts)) {
 				$checked = $layout_id == $data['id'] ? 'checked="checked"' : '';
@@ -275,20 +325,20 @@ class WidgetLayoutManager {
 			echo '<input type="radio" name="layout_id" value="-1" id="layout_custom" '. $checked .'/>';
 			echo '</td><td>';
 			echo '<label for="layout_custom">';
-			echo html_image('layout/custom.png', array('style' => 'vertical-align:top;float:left;'));
+			echo html_image('layout/custom.png', '', '', array('style' => 'vertical-align:top;float:left;'));
 			echo '</label>';
 			echo '</td><td>';
-			echo '<label for="layout_custom"><strong>'. 'Custom' .'</strong><br />';
-			echo 'Define your own layout:';
+			echo '<label for="layout_custom"><strong>'. _('Custom') .'</strong><br />';
+			echo _('Define your own layout:');
 			echo '</label>';
-			echo '<table id="layout-manager" cellpadding="0" cellspacing="0">
+			echo '<table id="layout-manager">
 				<tr>
 				<td>
 				<div class="layout-manager-row-add">+</div>';
 			$sql = 'SELECT * FROM layouts_rows WHERE layout_id = $1 ORDER BY rank';
 			$req_rows = db_query_params($sql,array($layout_id));
 			while ($data = db_fetch_array($req_rows)) {
-				echo '<table class="layout-manager-row" cellspacing="5" cellpadding="2" border="0">
+				echo '<table class="layout-manager-row">
 					<tr>
 					<td class="layout-manager-column-add">+</td>';
 				$sql = 'SELECT * FROM layouts_rows_columns WHERE layout_row_id = $1';
@@ -297,7 +347,7 @@ class WidgetLayoutManager {
 					echo '<td class="layout-manager-column">
 						<div class="layout-manager-column-remove">x</div>
 						<div class="layout-manager-column-width">
-						<input type="text" value="'. $data['width'] .'" size="1" maxlength="3" />%
+						<input type="number" value="'. $data['width'] .'" size="1" maxlength="3" />%
 						</div>
 						</td>
 						<td class="layout-manager-column-add">+</td>';
@@ -313,16 +363,13 @@ class WidgetLayoutManager {
 			echo '</table>';
 			echo '<input type="submit" id="save" value="'. _("Submit") .'" />';
 		} else {
+			// display the widget selection form
 			$after = '';
-			echo '<table cellpadding="0" cellspacing="0">
+			echo '<table>
 				<tbody>
-				<tr valign="top">
+				<tr class="top">
 				<td>';
-			echo '<table cellpadding="2" cellspacing="0">
-				<tbody>';
 			$after .= $this->_displayWidgetsSelectionForm(sprintf(_("%s Widgets"),  forge_get_config('forge_name')), Widget::getCodendiWidgets($owner_type), $used_widgets);
-			echo '</tbody>
-				</table>';
 			echo '</td>
 				<td id="widget-content-categ">'. $after .'</td>
 				</tr>
@@ -333,10 +380,10 @@ class WidgetLayoutManager {
 	}
 
 	function updateLayout($owner_id, $owner_type, $layout, $custom_layout) {
-		$sql = "SELECT l.* 
-			FROM layouts AS l INNER JOIN owner_layouts AS o ON(l.id = o.layout_id) 
+		$sql = "SELECT l.*
+			FROM layouts AS l INNER JOIN owner_layouts AS o ON(l.id = o.layout_id)
 			WHERE o.owner_type = $1
-			AND o.owner_id = $2 
+			AND o.owner_id = $2
 			AND o.is_default = 1
 			";
 		$req = db_query_params($sql,array($owner_type,$owner_id));
@@ -362,26 +409,26 @@ class WidgetLayoutManager {
 					}
 					//If the structure contains at least one column, create a new layout
 					if (count($rows)) {
-						$sql = "INSERT INTO layouts(name, description, scope) 
+						$sql = "INSERT INTO layouts(name, description, scope)
 							VALUES ('custom', '', 'P')";
-						if ($res = db_query_params($sql,array())) {
-							if ($new_layout_id = db_insertid($res,'layouts', 'id')) {
+						if ($res = db_query_params($sql, array())) {
+							if ($new_layout_id = db_insertid($res, 'layouts', 'id')) {
 								//Create rows & columns
 								$rank = 0;
 								foreach($rows as $cols) {
-									$sql = "INSERT INTO layouts_rows(layout_id, rank) 
+									$sql = "INSERT INTO layouts_rows(layout_id, rank)
 										VALUES ($1,$2)";
-									if ($res = db_query_params($sql,array($new_layout_id,$rank++))) {
+									if ($res = db_query_params($sql, array($new_layout_id, $rank++))) {
 										if ($row_id = db_insertid($res,'layouts_rows', 'id')) {
-												foreach($cols as $width) {
-													$sql = "INSERT INTO layouts_rows_columns(layout_row_id, width) 
-														VALUES ($1,$2)";
-													db_query_params($sql,array($row_id,$width));
-												}
+											foreach($cols as $width) {
+												$sql = "INSERT INTO layouts_rows_columns(layout_row_id, width)
+													VALUES ($1,$2)";
+												db_query_params($sql, array($row_id, $width));
 											}
 										}
 									}
 								}
+							}
 						}
 					}
 				} else {
@@ -402,36 +449,36 @@ class WidgetLayoutManager {
 						if (list(,$new_col) = each($new['columns'])) {
 							$last_new_col_id = $new_col['id'];
 						}
-						$sql = "UPDATE layouts_contents 
+						$sql = "UPDATE layouts_contents
 							SET layout_id  = $1
-							, column_id  =$2 
+							, column_id  =$2
 							WHERE owner_type =$3
 							AND owner_id   =$4
 							AND layout_id  =$5
 							AND column_id  =$6;";
 						db_query_params($sql,array($new_layout_id,$last_new_col_id,$owner_type,$owner_id,$old_layout_id,$old_col['id']));
 					}
-					$sql = "UPDATE owner_layouts 
+					$sql = "UPDATE owner_layouts
 						SET layout_id  = $1
-						WHERE owner_type = $2 
-						AND owner_id   = $3 
+						WHERE owner_type = $2
+						AND owner_id   = $3
 						AND layout_id  = $4";
-					db_query_params($sql,array($new_layout_id,$owner_type,$owner_id,$old_layout_id));
+					db_query_params($sql, array($new_layout_id, $owner_type, $owner_id, $old_layout_id));
 
 					//If the old layout is custom remove it
 					if ($old_scope != 'S') {
 						$structure = $this->_retrieveStructureOfLayout($old_layout_id);
 						foreach($structure['rows'] as $row) {
-							$sql = "DELETE FROM layouts_rows 
+							$sql = "DELETE FROM layouts_rows
 								WHERE id  = $1";
-							db_query_params($sql,array($row['id']));
-							$sql = "DELETE FROM layouts_rows_columns 
+							db_query_params($sql, array($row['id']));
+							$sql = "DELETE FROM layouts_rows_columns
 								WHERE layout_row_id  = $1";
-							db_query_params($sql,array($row['id']));
+							db_query_params($sql, array($row['id']));
 						}
-						$sql = "DELETE FROM layouts 
+						$sql = "DELETE FROM layouts
 							WHERE id  = $1";
-						db_query_params($sql,array($old_layout_id));
+						db_query_params($sql, array($old_layout_id));
 					}
 
 				}
@@ -456,22 +503,23 @@ class WidgetLayoutManager {
 	}
 
 	/**
-	 * _displayWidgetsSelectionForm
+	 * _displayWidgetsSelectionForm - displays a widget selection form
 	 *
-	 * @param  title  
-	 * @param  widgets  
-	 * @param  used_widgets  
-	 */
+	 * @param  title
+	 * @param  widgets
+	 * @param  used_widgets
+     * @return string
+     */
 	function _displayWidgetsSelectionForm($title, $widgets, $used_widgets) {
 		$hp = Codendi_HTMLPurifier::instance();
 		$additionnal_html = '';
 		if (count($widgets)) {
-			echo '<tr><td colspan="2">';
 			$categs = $this->getCategories($widgets);
 			$widget_rows = array();
 			if (count($categs)) {
+				// display the categories selector in left panel
 				foreach($categs as $c => $ws) {
-					$widget_rows[$c] = '<a class="widget-categ-switcher" href="#widget-categ-'. $c .'"><span>'.  str_replace('-',' ', $hp->purify($c, CODENDI_PURIFIER_CONVERT_HTML))  .'</span></a>';
+					$widget_rows[$c] = '<a class="widget-categ-switcher" id="widget-categ-switcher-'. $c .'" href="#widget-categ-'. $c .'" onClick="jQuery(\'.widget-categ-class-void\').hide();jQuery(\'.widget-categ-switcher\').removeClass(\'selected\');jQuery(\'#widget-categ-'. $c .'\').show();jQuery(\'#widget-categ-switcher-'. $c .'\').addClass(\'selected\');" ><span>'.  str_replace('_',' ', $hp->purify($c, CODENDI_PURIFIER_CONVERT_HTML))  .'</span></a>';
 				}
 				uksort($widget_rows, 'strnatcasecmp');
 				echo '<ul id="widget-categories">';
@@ -479,15 +527,13 @@ class WidgetLayoutManager {
 					echo '<li>'. $row .'</li>';
 				}
 				echo '</ul>';
-				echo '</td></tr>';
 			} else {
-				echo '</td></tr>';
 				foreach($widgets as $widget_name) {
 					if ($widget = Widget::getInstance($widget_name)) {
 						if ($widget->isAvailable()) {
 							$row = '';
 							$row .= '<td>'. $widget->getTitle() . $widget->getInstallPreferences() .'</td>';
-							$row .= '<td align="right">';
+							$row .= '<td class="align-right">';
 							if ($widget->isUnique() && in_array($widget_name, $used_widgets)) {
 								$row .= '<em>'. _("Already used") .'</em>';
 							} else {
@@ -507,10 +553,11 @@ class WidgetLayoutManager {
 				foreach($categs as $c => $ws) {
 					$i = 0;
 					$widget_rows = array();
+					// display widgets of the category
 					foreach($ws as $widget_name => $widget) {
 						$row = '';
 						$row .= '<div class="widget-preview '. $widget->getPreviewCssClass() .'">';
-						$row .= '<strong>'. $widget->getTitle()  .'</strong>';
+						$row .= '<h3>'. $widget->getTitle()  .'</h3>';
 						$row .= '<p>'. $widget->getDescription() .'</p>';
 						$row .= $widget->getInstallPreferences();
 						$row .= '</div><div style="text-align:right; border-bottom:1px solid #ddd; padding-bottom:10px; margin-bottom:20px;">';
@@ -523,7 +570,7 @@ class WidgetLayoutManager {
 						$widget_rows[$widget->getTitle()] = $row;
 					}
 					uksort($widget_rows, 'strnatcasecmp');
-					$additionnal_html .= '<div id="widget-categ-'. $c .'"><h4 class="boxtitle">'. $hp->purify($c, CODENDI_PURIFIER_CONVERT_HTML) .'</h4>';
+					$additionnal_html .= '<div id="widget-categ-'. $c .'" style="display:none" class="widget-categ-class-void" ><h2 class="boxtitle">'. str_replace('_',' ',$hp->purify($c, CODENDI_PURIFIER_CONVERT_HTML)) .'</h2>';
 					foreach($widget_rows as $row) {
 						$additionnal_html .= $row;
 					}
@@ -533,12 +580,20 @@ class WidgetLayoutManager {
 		}
 		return $additionnal_html;
 	}
+
+	/**
+	 * getCategories - sort the widgets in their different categories
+	 *
+	 * @param array $widgets
+	 * @return array (category => widgets)
+	 */
 	function getCategories($widgets) {
 		$categ = array();
 		foreach($widgets as $widget_name) {
 			if ($widget = Widget::getInstance($widget_name)) {
 				if ($widget->isAvailable()) {
-					$cs = explode(',', $widget->getCategory());
+					$category = str_replace(' ', '_', $widget->getCategory());
+					$cs = explode(',', $category);
 					foreach($cs as $c) {
 						if ($c = trim($c)) {
 							if (!isset($categ[$c])) {
@@ -555,12 +610,12 @@ class WidgetLayoutManager {
 	/**
 	 * addWidget
 	 *
-	 * @param  owner_id  
-	 * @param  owner_type  
-	 * @param  layout_id  
-	 * @param  name  
-	 * @param  widget  
-	 * @param  request  
+	 * @param	int		$owner_id
+	 * @param	string	$owner_type
+	 * @param	int		$layout_id
+	 * @param	string	$name
+	 * @param	object	$widget
+	 * @param	object	$request
 	 */
 	function addWidget($owner_id, $owner_type, $layout_id, $name, &$widget, &$request) {
 		//Search for the right column. (The first used)
@@ -571,7 +626,7 @@ class WidgetLayoutManager {
 					ON (c.layout_row_id = r.id)
 					WHERE r.layout_id = $1) AS col
 			ON (u.column_id = col.id)
-			WHERE u.owner_type = $2 
+			WHERE u.owner_type = $2
 			AND u.owner_id = $3
 			AND u.layout_id = $4
 			AND u.column_id <> 0
@@ -581,7 +636,7 @@ class WidgetLayoutManager {
 		$column_id = db_result($res, 0, 'id');
 		if (!$column_id) {
 			$sql = "SELECT r.rank AS rank, c.id as id
-				FROM layouts_rows AS r 
+				FROM layouts_rows AS r
 				INNER JOIN layouts_rows_columns AS c
 				ON (c.layout_row_id = r.id)
 				WHERE r.layout_id = $1
@@ -599,7 +654,7 @@ class WidgetLayoutManager {
 		}
 
 		//See if it already exists but not used
-		$sql = "SELECT column_id FROM layouts_contents 
+		$sql = "SELECT column_id FROM layouts_contents
 			WHERE owner_type =$1
 			AND owner_id = $2
 			AND layout_id = $3
@@ -624,17 +679,19 @@ class WidgetLayoutManager {
 			echo db_error();
 		} else {
 			//Insert
-			$sql = "INSERT INTO layouts_contents(owner_type, owner_id, layout_id, column_id, name, content_id, rank) 
-				SELECT R1.owner_type, R1.owner_id, R1.layout_id, R1.column_id, $1, $2, coalesce(R2.rank, 1) - 1 
-				FROM ( SELECT $3::character varying(1) AS owner_type, $4::integer AS owner_id, $5::integer AS layout_id, $6::integer AS column_id ) AS R1 
-				LEFT JOIN layouts_contents AS R2 USING ( owner_type, owner_id, layout_id, column_id ) 
-				ORDER BY rank ASC 
+			$sql = "INSERT INTO layouts_contents(owner_type, owner_id, layout_id, column_id, name, content_id, rank)
+				SELECT R1.owner_type, R1.owner_id, R1.layout_id, R1.column_id, $1, $2, coalesce(R2.rank, 1) - 1
+				FROM ( SELECT $3::character varying(1) AS owner_type, $4::integer AS owner_id, $5::integer AS layout_id, $6::integer AS column_id ) AS R1
+				LEFT JOIN layouts_contents AS R2 USING ( owner_type, owner_id, layout_id, column_id )
+				ORDER BY rank ASC
 				LIMIT 1";
-			$myfile=fopen('/tmp/debug','a');
-			$params = array($name,$content_id,$owner_type,$owner_id,$layout_id,$column_id);
-			fwrite($myfile, $sql." devient:\n");
-			fwrite($myfile, str_replace(array("$1","$2","$3","$4","$5","$6"),$params,$sql));
-			fwrite($myfile, "\n request content=".$request->get('content_id'));
+			if (forge_get_config('sysdebug_enable')) {
+				$myfile=fopen('/tmp/debug','a');
+				$params = array($name,$content_id,$owner_type,$owner_id,$layout_id,$column_id);
+				fwrite($myfile, $sql." devient:\n");
+				fwrite($myfile, str_replace(array("$1","$2","$3","$4","$5","$6"),$params,$sql));
+				fwrite($myfile, "\n request content=".$request->get('content_id'));
+			}
 			db_query_params($sql,array($name,$content_id,$owner_type,$owner_id,$layout_id,$column_id));
 			echo db_error();
 		}
@@ -649,20 +706,21 @@ class WidgetLayoutManager {
 				$hp = Codendi_HTMLPurifier::instance();
 				$link = '/projects/'.  $hp->purify($project->getUnixName(), CODENDI_PURIFIER_CONVERT_HTML) ;
 			}
-		} else if ($owner_type == self::OWNER_TYPE_USER) {
+		} elseif ($owner_type == self::OWNER_TYPE_USER) {
 			$link = '/my/';
 		}
-		$GLOBALS['feedback'] .= vsprintf(_('Your <a href="%s">dashboard</a> has been updated.'),  $link);
+		$GLOBALS['feedback'] .= _('Your dashboard has been updated.');
 	}
 
 	/**
 	 * removeWidget
 	 *
-	 * @param  owner_id  
-	 * @param  owner_type  
-	 * @param  layout_id  
-	 * @param  name  
-	 * @param  instance_id  
+	 * @param	int		$owner_id
+	 * @param	string	$owner_type
+	 * @param	int		$layout_id
+	 * @param	string	$name
+	 * @param	int		$instance_id
+	 * @param	object	$widget
 	 */
 	function removeWidget($owner_id, $owner_type, $layout_id, $name, $instance_id, &$widget) {
 		$sql = "DELETE FROM layouts_contents WHERE owner_type =$1 AND owner_id = $2 AND layout_id = $3 AND name = $4 AND content_id = $5";
@@ -675,11 +733,11 @@ class WidgetLayoutManager {
 	/**
 	 * mimizeWidget
 	 *
-	 * @param  owner_id  
-	 * @param  owner_type  
-	 * @param  layout_id  
-	 * @param  name  
-	 * @param  instance_id  
+	 * @param	int		$owner_id
+	 * @param	string	$owner_type
+	 * @param	int		$layout_id
+	 * @param	string	$name
+	 * @param	int		$instance_id
 	 */
 	function mimizeWidget($owner_id, $owner_type, $layout_id, $name, $instance_id) {
 		$sql = "UPDATE layouts_contents SET is_minimized = 1 WHERE owner_type = $1 AND owner_id = $2 AND layout_id = $3 AND name = $4 AND content_id = $5";
@@ -690,11 +748,11 @@ class WidgetLayoutManager {
 	/**
 	 * maximizeWidget
 	 *
-	 * @param  owner_id  
-	 * @param  owner_type  
-	 * @param  layout_id  
-	 * @param  name  
-	 * @param  instance_id  
+	 * @param	int		$owner_id
+	 * @param	string	$owner_type
+	 * @param	int		$layout_id
+	 * @param	string	$name
+	 * @param	int		$instance_id
 	 */
 	function maximizeWidget($owner_id, $owner_type, $layout_id, $name, $instance_id) {
 		$sql = "UPDATE layouts_contents SET is_minimized = 0 WHERE owner_type =$1 AND owner_id =$2 AND layout_id = $3 AND name = $4 AND content_id = $5";
@@ -705,11 +763,11 @@ class WidgetLayoutManager {
 	/**
 	 * displayWidgetPreferences
 	 *
-	 * @param  owner_id  
-	 * @param  owner_type  
-	 * @param  layout_id  
-	 * @param  name  
-	 * @param  instance_id  
+	 * @param	int		$owner_id
+	 * @param	string	$owner_type
+	 * @param	int		$layout_id
+	 * @param	string	$name
+	 * @param	int		$instance_id
 	 */
 	function displayWidgetPreferences($owner_id, $owner_type, $layout_id, $name, $instance_id) {
 		$sql = "UPDATE layouts_contents SET display_preferences = 1, is_minimized = 0 WHERE owner_type = $1 AND owner_id = $2 AND layout_id = $3 AND name = $4 AND content_id = $5";
@@ -720,11 +778,11 @@ class WidgetLayoutManager {
 	/**
 	 * hideWidgetPreferences
 	 *
-	 * @param  owner_id  
-	 * @param  owner_type  
-	 * @param  layout_id  
-	 * @param  name  
-	 * @param  instance_id  
+	 * @param	int		$owner_id
+	 * @param	string	$owner_type
+	 * @param	int		$layout_id
+	 * @param	string	$name
+	 * @param	int		$instance_id
 	 */
 	function hideWidgetPreferences($owner_id, $owner_type, $layout_id, $name, $instance_id) {
 		$sql = "UPDATE layouts_contents SET display_preferences = 0 WHERE owner_type = $1 AND owner_id = $2 AND layout_id = $3 AND name = $4 AND content_id = $5";
@@ -735,18 +793,16 @@ class WidgetLayoutManager {
 	/**
 	 * reorderLayout
 	 *
-	 * @param  owner_id  
-	 * @param  owner_type  
-	 * @param  layout_id  
-	 * @param  name  
-	 * @param  instance_id  
+	 * @param	int		$owner_id
+	 * @param	string	$owner_type
+	 * @param	int		$layout_id
+	 * @param	object	$request
 	 */
 	function reorderLayout($owner_id, $owner_type, $layout_id, &$request) {
 		$keys = array_keys($_REQUEST);
 		foreach($keys as $key) {
 			if (preg_match('`widgetlayout_col_\d+`', $key)) {
 
-
 				$split = explode('_', $key);
 				$column_id = (int)$split[count($split)-1];
 
@@ -774,53 +830,50 @@ class WidgetLayoutManager {
 							$_and .= ' OR ';
 						} else {
 							$_and .= ' AND (';
-									}
-									$_and .= " (name = '".$name[1]."' AND content_id = ". $name[0] .") ";
-									}
-									$_and .= ')';
-									$sql = "UPDATE layouts_contents
-									SET column_id = 0
-									WHERE owner_type = $1 
-									AND owner_id = $2
-									AND column_id = $3".
-									$_and;
-									$res = db_query_params($sql,array($owner_type, $owner_id, $column_id));
-									echo db_error();
-									}
+						}
+						$_and .= " (name = '".$name[1]."' AND content_id = ". $name[0] .") ";
+					}
+					$_and .= ')';
+					$sql = "UPDATE layouts_contents
+						SET column_id = 0
+						WHERE owner_type = $1
+						AND owner_id = $2
+						AND column_id = $3". $_and;
+					$res = db_query_params($sql,array($owner_type, $owner_id, $column_id));
+					echo db_error();
+				}
 
-									//Insert new contents
-									$added_names = $this->_array_diff_names($names, $originals);
-									if (count($added_names)) {
-									$_and = '';
-									foreach($added_names as $name) {
-									if ($_and) {
-										$_and .= ' OR ';
-									} else {
-										$_and .= ' AND (';
-												}
-												$_and .= " (name = '".$name[1]."' AND content_id = ". $name[0] .") ";
-												}
-												$_and .= ')';
-												//old and new column must be part of the same layout
-												$sql = 'UPDATE layouts_contents
-												SET column_id = $1 
-												WHERE owner_type = $2 
-												AND owner_id = $3' .
-												$_and ."
-												AND layout_id = $4";
-												$res = db_query_params($sql,array($column_id,$owner_type,$owner_id,$layout_id));
-												echo db_error();
-												}
+				//Insert new contents
+				$added_names = $this->_array_diff_names($names, $originals);
+				if (count($added_names)) {
+					$_and = '';
+					foreach($added_names as $name) {
+						if ($_and) {
+							$_and .= ' OR ';
+						} else {
+							$_and .= ' AND (';
+						}
+						$_and .= " (name = '".$name[1]."' AND content_id = ". $name[0] .") ";
+					}
+					$_and .= ')';
+					//old and new column must be part of the same layout
+					$sql = 'UPDATE layouts_contents
+						SET column_id = $1
+						WHERE owner_type = $2
+						AND owner_id = $3' . $_and ."
+						AND layout_id = $4";
+					$res = db_query_params($sql,array($column_id,$owner_type,$owner_id,$layout_id));
+					echo db_error();
+				}
 
-
-												//Update ranks
-												$rank = 0;
-												$values = array();
-												foreach($names as $name) {
-													$sql = 'UPDATE layouts_contents SET rank = $1 WHERE owner_type =$2 AND owner_id = $3 AND column_id = $4 AND name = $5 AND content_id = $6';
-													db_query_params($sql, array($rank++,$owner_type,$owner_id,$column_id,$name[1],$name[0]));
-													echo db_error();
-												}
+				//Update ranks
+				$rank = 0;
+				$values = array();
+				foreach($names as $name) {
+					$sql = 'UPDATE layouts_contents SET rank = $1 WHERE owner_type =$2 AND owner_id = $3 AND column_id = $4 AND name = $5 AND content_id = $6';
+					db_query_params($sql, array($rank++,$owner_type,$owner_id,$column_id,$name[1],$name[0]));
+					echo db_error();
+				}
 			}
 		}
 	}
@@ -843,4 +896,3 @@ class WidgetLayoutManager {
 		return $diff;
 	}
 }
-?>
