@@ -2,14 +2,14 @@
 /**
  * Copyright (c) Xerox Corporation, Codendi Team, 2001-2009. All rights reserved
  *
- * This file is a part of Codendi.
+ * This file is a part of Fusionforge.
  *
- * Codendi is free software; you can redistribute it and/or modify
+ * Fusionforge is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * Codendi is distributed in the hope that it will be useful,
+ * Fusionforge is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
@@ -18,18 +18,20 @@
  * along with Codendi. If not, see <http://www.gnu.org/licenses/>.
  */
 
-require_once('Widget.class.php');
+require_once 'Widget.class.php';
 
 /**
- * Widget_ProjectMembers
+ * Widget_ProjectInfo
  */
 class Widget_ProjectInfo extends Widget {
 	public function __construct() {
 		$this->Widget('projectinfo');
 	}
+
 	public function getTitle() {
-		return _('Project Info');
+		return _('Project Information');
 	}
+
 	public function getContent() {
 		$request =& HTTPRequest::instance();
 		$group_id = $request->get('group_id');
@@ -40,9 +42,8 @@ class Widget_ProjectInfo extends Widget {
 			$list_tag = list_project_tag($group_id);
 			echo '<p>'.html_image('ic/tag.png'). ' ';
 			if ($list_tag) {
-				print _('Tags').': '. $list_tag;
-			}
-			else {
+				echo _('Tags')._(': '). $list_tag;
+			} else {
 				$project = group_get_object($group_id);
 				if (forge_check_perm ('project_admin', $project->getID())) {
 					print '<a href="/project/admin/?group_id=' . $group_id . '" >' . _('No tag defined for this project') . '</a>.';
@@ -61,7 +62,7 @@ class Widget_ProjectInfo extends Widget {
 
 		// registration date
 		$project_start_date = $project->getStartDate();
-		print(_('Registered: ') . 
+		print(_('Registered')._(': ').
 				'<span property="doap:created" content="'.date('Y-m-d', $project_start_date).'">'.
 				date(_('Y-m-d H:i'), $project_start_date).
 				"</span>\n");
@@ -79,20 +80,20 @@ class Widget_ProjectInfo extends Widget {
 			if (!$actv_res) {
 				$actv_res=0;
 			}
-			print '<br />'.sprintf (_('Activity Ranking: %d'), $actv_res)."\n";
-			print '<br />'.sprintf(_('View project <a href="%1$s" >Statistics</a>'),util_make_url ('/project/stats/?group_id='.$group_id))."\n";
+			print '<br />'.sprintf (_('Activity Ranking: <strong>%d</strong>'), $actv_res)."\n";
+			print '<br />'.sprintf(_('View project <a href="%s">Statistics</a>'),util_make_url ('/project/stats/?group_id='.$group_id))."\n";
 			if ( ($project->usesTracker() && forge_get_config('use_tracker')) || ($project->usesPm() && forge_get_config('use_pm')) ) {
-				print sprintf(_(' or <a href="%1$s">Activity</a>'),util_make_url ('/project/report/?group_id='.$group_id))."\n";
+				print sprintf(_(' or <a href="%s">Activity</a>'),util_make_url ('/project/report/?group_id='.$group_id))."\n";
 			}
-			print '<br />'.sprintf(_('View list of <a href="%1$s">RSS feeds</a> available for this project.'), util_make_url ('/export/rss_project.php?group_id='.$group_id)). ' ' . html_image('ic/rss.png',16,16,array())."\n";
+			print '<br />'.sprintf(_('View list of <a href="%s">RSS feeds</a> available for this project.'), util_make_url ('/export/rss_project.php?group_id='.$group_id)). ' ' . html_image('ic/rss.png',16,16,array());
 		}
 
 		if(forge_get_config('use_people')) {
-			$jobs_res = db_query_params ('SELECT name 
-					FROM people_job,people_job_category 
-					WHERE people_job.category_id=people_job_category.category_id 
-					AND people_job.status_id=1 
-					AND group_id=$1 
+			$jobs_res = db_query_params ('SELECT name
+					FROM people_job,people_job_category
+					WHERE people_job.category_id=people_job_category.category_id
+					AND people_job.status_id=1
+					AND group_id=$1
 					GROUP BY name',
 					array ($group_id),
 					2);
@@ -108,7 +109,7 @@ class Widget_ProjectInfo extends Widget {
 							db_result($jobs_res,0,"name"));
 					print "</p>\n";
 					//print '<div rel="fusionforge:has_job" typeof="fusionforge:Job" xmlns:fusionforge="http://fusionforge.org/fusionforge#">';
-					//print '<span rel="dc:title" content="'. db_result($jobs_res,0,"name").'" xmlns:dc="http://purl.org/dc/elements/1.1/">'; 
+					//print '<span rel="dc:title" content="'. db_result($jobs_res,0,"name").'" xmlns:dc="http://purl.org/dc/elements/1.1/">';
 					//print '</span>';
 					//echo '</div>';
 					//end of job description part
@@ -116,18 +117,17 @@ class Widget_ProjectInfo extends Widget {
 			}
 		}
 
-
-		$hook_params = array () ;
-		$hook_params['group_id'] = $group_id ;
-		plugin_hook ("project_after_description",$hook_params) ;
-
+		$hook_params = array();
+		$hook_params['group_id'] = $group_id;
+		plugin_hook("project_after_description",$hook_params);
+		plugin_hook('hierarchy_views', array($group_id, 'home'));
 	}
+
 	public function canBeUsedByProject(&$project) {
 		return true;
 	}
+
 	function getDescription() {
 		return _('Some infos about the project.');
 	}
 }
-
-?>
