@@ -1,28 +1,32 @@
 <?php
 /**
+ * Generic RSS Widget Class
+ *
  * Copyright (c) Xerox Corporation, Codendi Team, 2001-2009. All rights reserved
+ * Copyright 2012, Franck Villaume - TrivialDev
+ * http://fusionforge.org
  *
- * This file is a part of Codendi.
+ * This file is a part of Fusionforge.
  *
- * Codendi is free software; you can redistribute it and/or modify
+ * Fusionforge is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * Codendi is distributed in the hope that it will be useful,
+ * Fusionforge is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Codendi. If not, see <http://www.gnu.org/licenses/>.
+ * along with Fusionforge. If not, see <http://www.gnu.org/licenses/>.
  */
 
-require_once('Widget.class.php');
+require_once 'Widget.class.php';
 
 /**
  * Widget_Rss
- * 
+ *
  * Rss reader
  */
 /* abstract */ class Widget_Rss extends Widget {
@@ -34,7 +38,7 @@ require_once('Widget.class.php');
 	}
 	function getTitle() {
 		$hp = Codendi_HTMLPurifier::instance();
-		return $this->rss_title ?  $hp->purify($this->rss_title, CODENDI_PURIFIER_CONVERT_HTML)  : 'RSS Reader';
+		return $this->rss_title ?  $hp->purify($this->rss_title, CODENDI_PURIFIER_CONVERT_HTML)  : _('RSS Reader');
 	}
 	function getContent() {
 		$hp = Codendi_HTMLPurifier::instance();
@@ -45,31 +49,29 @@ require_once('Widget.class.php');
 					return idn_to_unicode($param);
 				}
 			}
-			require_once('common/rss/simplepie.inc');
-			if (!is_dir(forge_get_config('sys_var_path') .'/rss')) {
-				mkdir(forge_get_config('sys_var_path') .'/rss');
+			require_once 'common/rss/simplepie.inc';
+			if (!is_dir(forge_get_config('data_path') .'/rss')) {
+				if (!mkdir(forge_get_config('data_path') .'/rss')) {
+					$content .= '<p class="error_msg" >'._('Cannot create backend directory. Contact forge administrator.').'</p>';
+				}
 			}
-			$rss = new SimplePie($this->rss_url, forge_get_config('sys_var_path') .'/rss', null, forge_get_config('sys_proxy'));
+			$rss = new SimplePie($this->rss_url, forge_get_config('data_path') .'/rss', null, forge_get_config('sys_proxy'));
 			$max_items = 10;
 			$items = array_slice($rss->get_items(), 0, $max_items);
-			$content .= '<table width="100%">';
+			$content .= '<table class="fullwidth">';
 			$i = 0;
 			foreach($items as $item){
-				if ($i % 2 == 0) {
-					$class="bgcolor-white";
-				}
-				else {
-					$class="bgcolor-grey";
-				}
-
 				$i=$i+1;
 
-				$content .= '<tr class="'. $class .'"><td WIDTH="99%">';
+				$content .= '<tr '.$GLOBALS['HTML']->boxGetAltRowStyle($i).'><td WIDTH="99%">';
 				if ($image = $item->get_link(0, 'image')) {
 					//hack to display twitter avatar
 					$content .= '<img src="'.  $hp->purify($image, CODENDI_PURIFIER_CONVERT_HTML)  .'" style="float:left; margin-right:1em;" />';
 				}
-				$content .= '<a href="'. $item->get_link() .'">'. $item->get_title() .'</a>';  //Trust SimplePie for purifying
+				/* Do not trust SimplePie for purifying. */
+				$content .= html_e('a', array(
+					'href' => util_unconvert_htmlspecialchars($item->get_link()),
+				    ), util_html_secure($item->get_title()));
 				if ($item->get_date()) {
 					$content .= '<span style="color:#999;" title="'. date(_("Y-m-d H:i"), $item->get_date('U')) .'"> - '. $this->_date_ago($item->get_date('U'),time()) .'</span>';
 				}
@@ -87,21 +89,37 @@ require_once('Widget.class.php');
 	}
 	function getPreferences() {
 		$hp = Codendi_HTMLPurifier::instance();
-		$prefs  = '';
-		$prefs .= '<table><tr><td>Title:</td><td><input type="text" class="textfield_medium" name="rss[title]" value="'. $hp->purify($this->rss_title, CODENDI_PURIFIER_CONVERT_HTML) .'" /></td></tr>';
-		$prefs .= '<tr><td>Url:</td><td><input type="text" class="textfield_medium" name="rss[url]" value="'. $hp->purify($this->rss_url, CODENDI_PURIFIER_CONVERT_HTML) .'" /></td></tr>';
+		$prefs = '<table>';
+		$prefs .= '<tr>';
+		$prefs .= '<td>';
+		$prefs .= _('Title')._(':');
+		$prefs .= '</td>';
+		$prefs .= '<td>';
+		$prefs .= '<input type="text" class="textfield_medium" name="rss[title]" value="'. $hp->purify($this->rss_title, CODENDI_PURIFIER_CONVERT_HTML) .'" /></td></tr>';
+		$prefs .= '<tr>';
+		$prefs .= '<td>';
+		$prefs .= 'URL'._(':');
+		$prefs .= '</td>';
+		$prefs .= '<td>';
+		$prefs .= '<input type="url" class="textfield_medium" name="rss[url]" value="'. $hp->purify($this->rss_url, CODENDI_PURIFIER_CONVERT_HTML) .'" /></td></tr>';
 		$prefs .= '</table>';
 		return $prefs;
 	}
 	function getInstallPreferences() {
-		$prefs  = '';
-		$prefs .= '<table>';
-		$prefs .= '<tr><td>Url:</td><td><input type="text" class="textfield_medium" name="rss[url]" value="'. _("http://search.twitter.com/search.atom?q=fusionforge&amp;show_user=1") .'" /></td></tr>';
+		$prefs = '<table>';
+		$prefs .= '<tr>';
+		$prefs .= '<td>';
+		$prefs .= 'URL'._(':');
+		$prefs .= '</td>';
+		$prefs .= '<td>';
+		$prefs .= '<input type="url" class="textfield_medium" name="rss[url]" value="http://search.twitter.com/search.atom?q=alcatel-lucent&amp;show_user=1" />';
+		$prefs .= '</td>';
+		$prefs .= '</tr>';
 		$prefs .= '</table>';
 		return $prefs;
 	}
 	function cloneContent($id, $owner_id, $owner_type) {
-		$sql = "INSERT INTO widget_rss (owner_id, owner_type, title, url) 
+		$sql = "INSERT INTO widget_rss (owner_id, owner_type, title, url)
 			SELECT $1, $2, title, url
 			FROM widget_rss
 			WHERE owner_id = $3 AND owner_type = $4";
@@ -121,7 +139,7 @@ require_once('Widget.class.php');
 	function create(&$request) {
 		$content_id = false;
 		$vUrl = new Valid_String('url');
-		$vUrl->setErrorMessage("Can't add empty rss url");
+		$vUrl->setErrorMessage(_("Cannot add empty RSS URL"));
 		$vUrl->required();
 		if($request->validInArray('rss', $vUrl)) {
 			$rss = $request->get('rss');
@@ -129,15 +147,15 @@ require_once('Widget.class.php');
 			$vTitle->required();
 			if (!$request->validInArray('rss', $vTitle)) {
 				if (function_exists('idn_to_utf8()')) {
-					require_once('simplepie/simplepie.inc');
+					require_once 'simplepie/simplepie.inc';
 				}
 				else {
-					require_once('common/rss/simplepie.inc');
+					require_once 'common/rss/simplepie.inc';
 				}
-				if (!is_dir(forge_get_config('sys_var_path') .'/rss')) {
-					mkdir(forge_get_config('sys_var_path') .'/rss');
+				if (!is_dir(forge_get_config('data_path') .'/rss')) {
+					mkdir(forge_get_config('data_path') .'/rss');
 				}
-				$rss_reader = new SimplePie($rss['url'], forge_get_config('sys_var_path') .'/rss', null, forge_get_config('sys_proxy'));
+				$rss_reader = new SimplePie($rss['url'], forge_get_config('data_path') .'/rss', null, forge_get_config('sys_proxy'));
 				$rss['title'] = $rss_reader->get_title();
 			}
 			$sql = 'INSERT INTO widget_rss (owner_id, owner_type, title, url) VALUES ($1,$2,$3,$4)';
@@ -186,26 +204,24 @@ require_once('Widget.class.php');
 
 		if ($distance_in_minutes <= 1) {
 			return ($distance_in_minutes == 0) ? _('less than 1 minute') : _('1 minute');
-		} else if ($distance_in_minutes <= 44) {
+		} elseif ($distance_in_minutes <= 44) {
 			return vsprintf(_('%s minutes ago'), $distance_in_minutes);
-		} else if ($distance_in_minutes <= 89) {
+		} elseif ($distance_in_minutes <= 89) {
 			return _('About one hour') ;
-		} else if ($distance_in_minutes <= 1439) {
+		} elseif ($distance_in_minutes <= 1439) {
 			return vsprintf(_('about %s hours'), round($distance_in_minutes/60));
-		} else if ($distance_in_minutes <= 2879) {
+		} elseif ($distance_in_minutes <= 2879) {
 			return _('About one day') ;
-		} else if ($distance_in_minutes <= 43199) {
+		} elseif ($distance_in_minutes <= 43199) {
 			return vsprintf(_('%s days ago'), round($distance_in_minutes/1440));
-		} else if ($distance_in_minutes <= 86399) {
+		} elseif ($distance_in_minutes <= 86399) {
 			return _('About one month') ;
-		} else if ($distance_in_minutes <= 525959) {
+		} elseif ($distance_in_minutes <= 525959) {
 			return vsprintf(_('%s months ago'), round($distance_in_minutes/43200));
-		} else if ($distance_in_minutes <= 1051919) {
+		} elseif ($distance_in_minutes <= 1051919) {
 			return _('About one year') ;
 		} else {
 			return vsprintf(_('over %s years'), round($distance_in_minutes/525960));
 		}
 	}
-
 }
-?>
