@@ -20,8 +20,8 @@
  * with FusionForge; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
-        
-require dirname(__FILE__).'/../www/env.inc.php';
+
+require dirname(__FILE__).'/../common/include/env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'include/cron_utils.php';
 
@@ -31,23 +31,30 @@ require_once $gfcommon.'include/PluginManager.class.php' ;
 
 // SCM-specific plugins subsystem
 require_once $gfcommon.'include/SCMPlugin.class.php' ;
-			 
-setup_plugin_manager () ;
 
-$res = db_query_params ('SELECT group_id FROM groups WHERE status=$1 AND use_scm=1 ORDER BY group_id DESC',
-			array ('A')); 
+session_set_admin ();
+
+setup_plugin_manager();
+
+$res = db_query_params('SELECT group_id FROM groups WHERE status=$1 AND use_scm=1 ORDER BY group_id DESC',
+			array ('A'));
 if (!$res) {
 	$this->setError('Unable to get list of projects using SCM: '.db_error());
 	return false;
 }
 
+$output = '';
 while ($data = db_fetch_array ($res)) {
-	$hook_params = array ('group_id' => $data['group_id']) ;
-	plugin_hook ('scm_create_repo', $hook_params) ;
+	$hook_params = array('group_id' => $data['group_id'], 'output' => '') ;
+	plugin_hook_by_reference ('scm_create_repo', $hook_params) ;
+	$output .= $hook_params['output'];
 }
 
-$hook_params = array () ;
-plugin_hook ('scm_update_repolist', $hook_params) ;
+$hook_params = array ('output' => '') ;
+plugin_hook_by_reference ('scm_update_repolist', $hook_params) ;
+$output .= $hook_params['output'];
+
+cron_entry(27, $output);
 
 // Local Variables:
 // mode: php
