@@ -6,7 +6,7 @@
  * Copyright 2004 GForge, LLC
  *
  * @author Tim Perdue tim@gforge.org
- * @author Sung Kim 
+ * @author Sung Kim
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -53,17 +53,17 @@ class ForumGateway extends Error {
 
 	function ForumGateway() {
 		$this->Error();
-	
+
 		/* Copy mail message to tmp file */
 		$tmpfile = $this->copyMailTmp();
 		//DBG("Tmpname: ". $tmpfile);
 
 		/* parse email */
 		$ret = $this->parseMail($tmpfile);
-	
+
 		/* Delete temp file */
 		unlink($tmpfile);
-	
+
 		/* Check the return variable from parseMail */
 		if (!$ret) {
 			return false;
@@ -74,11 +74,11 @@ class ForumGateway extends Error {
 		if (!$ret) {
 			return false;
 		}
-	
+
 		return true;
 	}
-	
-	
+
+
 	/**
 	 * function - Copy mail(from stdin to tmp and return the tmp file
 	 *
@@ -90,14 +90,14 @@ class ForumGateway extends Error {
 		$tmpfile = tempnam ("/tmp", "forum_gateway.".util_randnum()."-".util_randnum());
 		$in = fopen("php://stdin", "r");
 		$out = fopen($tmpfile, "w");
-	
+
 		while($buffer = fgets($in, 4096)) {
 			fputs($out, $buffer);
 		}
-	
+
 		fclose($in);
 		fclose($out);
-	
+
 		return $tmpfile;
 	}
 
@@ -109,16 +109,12 @@ class ForumGateway extends Error {
 	 * @return boolean true if success
 	 */
 	function parseMail($input_file) {
-		global $argv;
-//DBG("parseMail start");
-		
+
 		if (!$mp = new MailParser($input_file)) {
 			$this->setError('Error In MailParser');
-//DBG("parseMail error1: ".$mp->getErrorMessage());
 			return false;
 		} elseif ($mp->isError()) {
 			$this->setError('Error In MailParser '.$mp->getErrorMessage());
-//DBG("parseMail error2: ".$mp->getErrorMessage());
  			// even if it is an error, try to get the address of the sender so we
  			// can send him back the error
  			$this->FromEmail = $mp->getFromEmail();
@@ -126,39 +122,12 @@ class ForumGateway extends Error {
 		}
 
 		$this->FromEmail = $mp->getFromEmail();
-//DBG("email: ".$this->FromEmail);
-//echo ")()()()()()()".$this->FromEmail."(*(*(*(*(*";
-		//
-		//subjects are in this required format: '[group - Forum][123456] My Subject'
-		//where 123456 is the msg_id of the forum message.
-		//we parse that ID to get the forum and thread that this should post to
-		//
 		$subj = $mp->getSubject();
 		if ($mp->isError())
 			$this->setError($mp->getErrorMessage());
 		if ($subj === false)
 			return false;
 
-//DBG("mp headers: ".implode("**\n",$mp->headers));
-//DBG("mp body: ".$mp->body);
-//DBG("SUBJ: ".$subj);
-//DBG("BODY: ".$mp->getBody());
-/*
-		$parent_start = (strpos($subj,'[',(strpos($subj,'[')+1))+1);
-		$parent_end = (strpos($subj,']',$parent_start)-1);
-		$this->Parent = substr($subj,$parent_start,($parent_end-$parent_start+1));
-		if (!$this->Parent || !is_numeric($this->Parent)) {
-//			$argv[1] - listname
-//			echo "No Parent ".$argv[0]."||".$argv[1];
-			$this->Parent=0;
-			$this->Subject = addslashes($subj);
-//			$this->setError('No Valid Parent ID Found in Subject Line');
-//			return false;
-		} else {
-//			echo "Parent: ".$this->Parent."||".$argv[0]."||".$argv[1];
-			$this->Subject = addslashes(substr($subj,$parent_end+3));
-		}
-*/
 		if (preg_match('/(\[)([0-9]*)(\])/',$subj,$arr)) {
 			$this->Parent=$arr[2];
 			$parent_end=(strpos($subj,'['.$arr[2].']')) + strlen('['.$arr[2].']');
@@ -168,15 +137,14 @@ class ForumGateway extends Error {
 			$this->Parent=0;
 		}
 		$this->Body =& $mp->getBody();
-//DBG( "body1:". $this->Body);
 
 		$begin = strpos($this->Body, FORUM_MAIL_MARKER);
 		if ($begin === false) { //do nothing
-				return true; 
-		}		
+			$this->Message = $this->Body;
+			return true;
+		}
 		// get the part of the message located after the marker
 		$this->Body = substr($this->Body, $begin+strlen(FORUM_MAIL_MARKER));
-//DBG( "body2:". $this->Body);
 		// now look for the ending marker
 		$end = strpos($this->Body, FORUM_MAIL_MARKER);
 		if ($end === false) {
@@ -184,18 +152,18 @@ class ForumGateway extends Error {
 		}
 		$message = substr($this->Body, 0, $end);
 		$message = trim($message);
-		
+
 		// maybe the last line was "> (FORUM_MAIL_MARKER)". In that case, delete the last ">"
 		$message = preg_replace('/>$/', '', $message);
 		$this->Message = $message;
-		
+
 		return true;
 	}
-	
+
 	/**
 	 * Insert data into the forum db
 	 *
-	 * @return - true or false
+	 * @return bool
 	 */
 	function addMessage() {
 		//
@@ -236,7 +204,7 @@ class ForumGateway extends Error {
 			return false;
 		}
 //DBG( "AddMessage 3\n");
-		if ($this->Message!=""){	
+		if ($this->Message!=""){
 			if (!$ForumMessage->create($this->Subject,$this->Message,$this->ThreadId,$this->Parent)) {
 //DBG( "AddMessage 4.".$ForumMessage->getErrorMessage()."\n");
 				$this->setError("ForumMessage Create Error: ".$ForumMessage->getErrorMessage());
@@ -252,7 +220,7 @@ class ForumGateway extends Error {
 
 
 	/*------------------------------------------------------------------------
-	 *  Utility functions 
+	 *  Utility functions
 	 *-----------------------------------------------------------------------*/
 
 	/* Find user_id from email */
@@ -261,7 +229,7 @@ class ForumGateway extends Error {
 		$from = strtolower($this->FromEmail);
 		// If no user id, user id is 0;
 		if (! $from) return 0;
-		$res = db_query_params ('SELECT user_id FROM users 
+		$res = db_query_params ('SELECT user_id FROM users
 			WHERE lower(email) = $1 AND status = $2',
 					array (strtolower($from),
 					       'A'));
@@ -271,7 +239,7 @@ class ForumGateway extends Error {
 			$user_id = db_result($res,0,'user_id');
 		}
 		db_free_result($res);
-	
+
 		return $user_id;
 	}
 
@@ -291,7 +259,7 @@ class ForumGateway extends Error {
 				//
 				// Find Forum id by parent
 				//
-				$res = db_query_params ('SELECT group_forum_id,thread_id 
+				$res = db_query_params ('SELECT group_forum_id,thread_id
 					FROM forum
 					WHERE msg_id=$1',
 							array ($this->Parent));
@@ -299,7 +267,7 @@ class ForumGateway extends Error {
 				//
 				//	Find forum by arguments passed by aliases file
 				//
-				$res = db_query_params ('SELECT group_forum_id, 0 AS thread_id 
+				$res = db_query_params ('SELECT group_forum_id, 0 AS thread_id
 					FROM forum_group_list
 					WHERE forum_name=$1
 					AND group_id=$2',
@@ -316,10 +284,10 @@ class ForumGateway extends Error {
 
 			$this->Forum = new Forum($Group,$this->ForumId);
 		}
-	
+
 		return $this->Forum;
 	}
- 
+
 }
 
 
@@ -329,19 +297,20 @@ class ForumGateway extends Error {
  * Add this in /etc/syslog.conf and see /var/log/debug file:
  * # Debug
  * *.=debug			/var/log/debug
- * 
+ *
  */
 function DBG($str) {
 	global $debug;
-system("echo \"forum: ".$str."\n\" >> /tmp/forum.log");
+
+	file_put_contents('/tmp/forum.log', "forum: ".$str."\n", FILE_APPEND);
 
 	if ($debug==1) {
 		syslog(LOG_DEBUG, "forum_gateway: ". $str);
-	} else if ($debug==2) {
+	} elseif ($debug==2) {
 		echo $str."\n";
 	}
 }
- 
+
 
 /* Main routine */
 $debug = 0;
