@@ -2,6 +2,7 @@
 <?php
 /**
  * Copyright 1999-2001 (c) VA Linux Systems
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -45,8 +46,8 @@ $err .= "\n\nBeginning stats_agg_logo_by_day ".date('Ymd H:i:s',time());
 $rel = db_query_params ('DELETE FROM stats_agg_logo_by_day WHERE day=$1',
 			array ($yesterday_formatted));
 $err .= db_error();
-$rel = db_query_params ('INSERT INTO stats_agg_logo_by_day 
-	SELECT day, count(*) 
+$rel = db_query_params ('INSERT INTO stats_agg_logo_by_day
+	SELECT day, count(*)
 	FROM activity_log WHERE type=0 AND day=$1 GROUP BY day',
 			array ($yesterday_formatted));
 $err .= db_error();
@@ -62,7 +63,7 @@ $rel = db_query_params ('DELETE FROM stats_agg_logo_by_group WHERE month=$1 AND
 				$day));
 $err .= db_error();
 $rel = db_query_params ('INSERT INTO stats_agg_logo_by_group SELECT $1::int AS month, $2::int AS newday,group_id,count(*) AS count
-	FROM activity_log WHERE type=0 AND day=$3 GROUP BY month,newday,group_id',
+	FROM activity_log WHERE type=0 AND day=$3 AND group_id <> 0 GROUP BY month,newday,group_id',
 			array ("$year$month",
 			       $day,
 			       $yesterday_formatted)) ;
@@ -78,7 +79,7 @@ $rel = db_query_params ('DELETE FROM stats_agg_site_by_group WHERE month=$1 AND
 			array ("$year$month",
 				$day));
 $err .= db_error();
-$rel = db_query_params ('INSERT INTO stats_agg_site_by_group SELECT $1::int AS month, $2::int AS newday,group_id,COUNT(*) AS count FROM activity_log WHERE type=0 AND day=$3 GROUP BY month,newday,group_id',
+$rel = db_query_params ('INSERT INTO stats_agg_site_by_group SELECT $1::int AS month, $2::int AS newday,group_id,COUNT(*) AS count FROM activity_log WHERE type=0 AND day=$3 AND group_id <> 0 GROUP BY month,newday,group_id',
 			array ("$year$month",
 			       $day,
 			       $yesterday_formatted)) ;
@@ -108,16 +109,10 @@ $rel = db_query_params ('DELETE FROM stats_project_developers WHERE month=$1 AND
 			array ("$year$month",
 				$day));
 $err .= db_error();
-if (USE_PFO_RBAC) {
 $rel = db_query_params ('INSERT INTO stats_project_developers (month,day,group_id,developers)
 SELECT  $1::int AS month, $2::int, pfo_role.home_group_id AS group_id, COUNT(DISTINCT(pfo_user_role.user_id)) AS developers FROM pfo_user_role, pfo_role WHERE pfo_user_role.role_id = pfo_role.role_id AND pfo_role.home_group_id IS NOT NULL GROUP BY pfo_role.home_group_id',
 			array ("$year$month",
 			       $day));
-} else {
-$rel = db_query_params ('INSERT INTO stats_project_developers (month,day,group_id,developers) SELECT $1::int AS month,$2::int AS day,group_id,count(*) AS count FROM user_group GROUP BY month,day,group_id',
-			array ("$year$month",
-			       $day));
-}
 $err .= db_error();
 
 db_commit();
@@ -128,14 +123,14 @@ $err .= db_error();
 //	populate stats_site table
 //
 $err .= "\n\nBeginning stats_site ".date('Ymd H:i:s',time());
-include('cronjobs/stats_site.inc');
+include 'cronjobs/stats_site.inc';
 site_stats_day($year,$month,$day);
 
 //
 //	populate stats_project table
 //
 $err .= "\n\nBeginning stats_project ".date('Ymd H:i:s',time());
-include('cronjobs/stats_projects.inc');
+include 'cronjobs/stats_projects.inc';
 project_stats_day($year,$month,$day);
 
 cron_entry(11,$err);
