@@ -6,6 +6,7 @@
  * Copyright 2005, Fabio Bertagnin
  * Copyright 2009, Roland Mas
  * Copyright 2010-2011, Franck Villaume - Capgemini
+ * Copyright 2012, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -30,13 +31,12 @@ require_once $gfcommon.'docman/Document.class.php';
 require_once $gfcommon.'docman/DocumentFactory.class.php';
 require_once $gfcommon.'docman/DocumentGroupFactory.class.php';
 
-$engine_path = dirname(__FILE__).'/../common/docman/engine/';
-$p = new Parsedata($engine_path);
+$p = new Parsedata();
 
 $timestarttrait = microtime_float();
 // documents list
 $resarr = array();
-$result = db_query_params('SELECT doc_data.docid, doc_data.group_id, doc_data.filename, doc_data.title, doc_data.filename, doc_data.description, doc_data.filetype from doc_data, groups where doc_data.group_id = groups.group_id and groups.force_docman_reindex = $1',
+$result = db_query_params('SELECT doc_data.docid, doc_data.group_id, doc_data.filename, doc_data.title, doc_data.description, doc_data.filetype from doc_data, groups where doc_data.group_id = groups.group_id and groups.force_docman_reindex = $1',
 			   array('1'));
 if (!$result) {
 	die(db_error());
@@ -53,22 +53,26 @@ $errorFlag = 0;
 foreach ($resarr as $item) {
 	$compt++;
 	$timestart = microtime_float();
-	$doc_dataData = db_query_params('SELECT data from doc_data where docid = $1', array($item["docid"]));
-	if (!$doc_dataData) {
-		die("unable to get data: ".db_error());
-	}
-	$data1 = base64_decode($doc_dataData["data"]);
-	$lenin = strlen($data1);
-	$res = $p->get_parse_data($data1, $item["title"], $item["description"], $item["filetype"]);
+	$group = group_get_object($item['group_id']);
+	$d = new Document($group, $item['docid']);
+	$datafile = tempnam(forge_get_config('data_path'), 'tmp');
+	$fh = fopen($datafile, 'w');
+	fwrite($fh, $d->getFileData(false));
+	fclose($fh);
+	$lenin = $d->getFileSize();
+	$res = $p->get_parse_data($datafile, htmlspecialchars($item['title']), htmlspecialchars($item['description']), $item['filetype'], $item['filename']);
 	$len = strlen($res);
+	if (file_exists($datafile)) {
+		unlink($datafile);
+	}
 	$resUp = db_query_params('UPDATE doc_data SET data_words=$1 WHERE docid=$2',
-			 array ($res, $item["docid"]));
+			 array ($res, $item['docid']));
 	if (!$resUp) {
-		die("unable to update data: ".db_error());
+		die('unable to update data: '.db_error());
 	}
 	$timeend = microtime_float();
 	$timetrait = $timeend - $timestart;
-	echo "analyze $item[filename]  type=$item[filetype]  octets in=$lenin  octets out=$len  time=$timetrait sec";
+	echo "Analyzed $item[filename] : type=$item[filetype]  octets in=$lenin  octets out=$len  time=$timetrait sec\n";
 }
 $timeendtrait = microtime_float();
 $timetot = $timeendtrait - $timestarttrait;
@@ -84,5 +88,3 @@ function microtime_float() {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
