@@ -1,4 +1,3 @@
-#! /usr/bin/php
 <?php
 /**
  * GForge Forum Renamer - forum names are now unix-format for email gateway
@@ -42,7 +41,7 @@ if (!$res) {
 for ($i=0; $i<db_numrows($res); $i++) {
 
 	$res2 = db_query_params ('UPDATE forum_group_list SET forum_name=$1 WHERE group_forum_id=$2',
-				 array (ereg_replace('[^_\.0-9a-z-]','-', strtolower(db_result($res,$i,'forum_name'))),
+				 array (preg_replace('/[^_\.0-9a-z-]/','-', strtolower(db_result($res,$i,'forum_name'))),
 					db_result($res,$i,'group_forum_id'))) ;
 	if (!$res2) {
 		echo db_error();
@@ -52,10 +51,10 @@ for ($i=0; $i<db_numrows($res); $i++) {
 }
 
 //
-//	Long-standing oddity in GForge - 
+//	Long-standing oddity in GForge -
 //	forums were ZERO-pen Discussion, not Oh-pen Discussion
 //
-$res = db_query_params ('UPDATE forum_group_list SET forum_name=$1 
+$res = db_query_params ('UPDATE forum_group_list SET forum_name=$1
 	WHERE forum_name=$2',
 			array('open-discussion',
 			'0pen-discussion')) ;
