@@ -1,6 +1,6 @@
 SET client_min_messages TO warning;
 
--- ********** Create auxiliar tables ********** 
+-- ********** Create auxiliar tables **********
 
 CREATE TABLE artifact_idx (
 	artifact_id integer,
@@ -62,7 +62,7 @@ CREATE TABLE users_idx (
 	vectors tsvector
 );
 
--- ********** Populate with current data and create index ********** 
+-- ********** Populate with current data and create index **********
 
 INSERT INTO artifact_idx (artifact_id, group_artifact_id, vectors) 
 SELECT artifact_id, group_artifact_id, to_tsvector(coalesce(details,'') ||' 
@@ -146,7 +146,7 @@ CREATE INDEX users_idxFTI ON users_idx USING gist(vectors);
 
 -- VACUUM FULL ANALYZE;
 
--- ********** Create trigger function to update idx tables ********** 
+-- ********** Create trigger function to update idx tables **********
 
 CREATE OR REPLACE FUNCTION update_vectors() RETURNS TRIGGER AS '
 DECLARE
@@ -260,7 +260,7 @@ BEGIN
 END;'
 LANGUAGE 'plpgsql';
 
--- ********** Set up triggers ********** 
+-- ********** Set up triggers **********
 
 CREATE TRIGGER artifact_ts_update AFTER UPDATE OR INSERT OR DELETE ON artifact
 FOR EACH ROW EXECUTE PROCEDURE update_vectors('artifact');
@@ -292,7 +292,7 @@ FOR EACH ROW EXECUTE PROCEDURE update_vectors('skills_data');
 CREATE TRIGGER users_ts_update AFTER UPDATE OR INSERT OR DELETE ON users
 FOR EACH ROW EXECUTE PROCEDURE update_vectors('users');
 
--- ********** Create types for results ********** 
+-- ********** Create types for results **********
 
 CREATE TYPE artifact_results AS (group_artifact_id integer,
 	artifact_id integer,
@@ -338,7 +338,7 @@ CREATE TYPE export_groups_results AS (group_name text,
 
 CREATE TYPE news_bytes_results AS (summary text,
 	post_date integer,
-	forum_id integer, 
+	forum_id integer,
 	realname text
 );
 
@@ -373,10 +373,10 @@ CREATE TYPE users_results AS (user_name text,
 	realname text
 );
 
--- ********** Create search store procedures ********** 
+-- ********** Create search store procedures **********
 
 CREATE OR REPLACE FUNCTION artifact_search(text, int) RETURNS SETOF artifact_results AS '
-	SELECT a.group_artifact_id, a.artifact_id, a.summary, a.open_date, u.realname FROM artifact a, 
+	SELECT a.group_artifact_id, a.artifact_id, a.summary, a.open_date, u.realname FROM artifact a,
 	(SELECT DISTINCT ON (ai.artifact_id) ai.artifact_id, COUNT(ami.id) AS total FROM artifact_idx ai LEFT OUTER JOIN artifact_message_idx ami USING (artifact_id),
 	to_tsquery($1) AS q
 	WHERE ai.group_artifact_id=$2
@@ -386,7 +386,7 @@ CREATE OR REPLACE FUNCTION artifact_search(text, int) RETURNS SETOF artifact_res
 	AND u.user_id=a.submitted_by
 	AND a.artifact_id=ai.artifact_id
 	ORDER BY idx.total DESC, ts_rank(ai.vectors, q) DESC'
-LANGUAGE 'SQL';
+LANGUAGE SQL;
 
 CREATE OR REPLACE FUNCTION doc_data_search(text, integer, text, boolean) RETURNS SETOF doc_data_results AS '
 	DECLARE
@@ -458,9 +458,9 @@ CREATE OR REPLACE FUNCTION forums_search(text, integer, text, boolean) RETURNS S
 		IF $4 THEN
 			FOR data IN SELECT forum.msg_id, ts_headline(forum.subject, q) AS subject, forum.post_date, users.realname, forum_group_list.forum_name
 			FROM forum, users, forum_group_list, to_tsquery($1) AS q
-			WHERE users.user_id = forum.posted_by 
-			AND forum_group_list.group_forum_id = forum.group_forum_id 
-			AND forum_group_list.is_public <> 9 
+			WHERE users.user_id = forum.posted_by
+			AND forum_group_list.group_forum_id = forum.group_forum_id
+			AND forum_group_list.is_public <> 9
 			AND forum_group_list.group_forum_id IN (\'$3\')
 			AND forum.msg_id IN (SELECT msg_id FROM forum_idx, to_tsquery($1) AS q 
 			WHERE group_id = $2 AND vectors @@ q ORDER BY ts_rank(vectors, q) DESC) LOOP
@@ -469,9 +469,9 @@ CREATE OR REPLACE FUNCTION forums_search(text, integer, text, boolean) RETURNS S
 		ELSE
 			FOR data IN SELECT forum.msg_id, ts_headline(forum.subject, q) AS subject, forum.post_date, users.realname, forum_group_list.forum_name
 			FROM forum, users, forum_group_list, to_tsquery($1) AS q
-			WHERE users.user_id = forum.posted_by 
-			AND forum_group_list.group_forum_id = forum.group_forum_id 
-			AND forum_group_list.is_public <> 9 
+			WHERE users.user_id = forum.posted_by
+			AND forum_group_list.group_forum_id = forum.group_forum_id
+			AND forum_group_list.is_public <> 9
 			AND forum_group_list.group_forum_id IN (\'$3\')
 			AND forum_group_list.is_public = 1
 			AND forum.msg_id IN (SELECT msg_id FROM forum_idx, to_tsquery($1) AS q 
@@ -493,9 +493,9 @@ CREATE OR REPLACE FUNCTION forums_search(text, integer, text, boolean) RETURNS S
 		ELSE
 			FOR data IN SELECT forum.msg_id, ts_headline(forum.subject, q) AS subject, forum.post_date, users.realname, forum_group_list.forum_name
 			FROM forum, users, forum_group_list, to_tsquery($1) AS q
-			WHERE users.user_id = forum.posted_by 
-			AND forum_group_list.group_forum_id = forum.group_forum_id 
-			AND forum_group_list.is_public <> 9 
+			WHERE users.user_id = forum.posted_by
+			AND forum_group_list.group_forum_id = forum.group_forum_id
+			AND forum_group_list.is_public <> 9
 			AND forum_group_list.is_public = 1
 			AND forum.msg_id IN (SELECT msg_id FROM forum_idx, to_tsquery($1) AS q 
 			WHERE group_id = $2 AND vectors @@ q ORDER BY ts_rank(vectors, q) DESC) LOOP
@@ -511,10 +511,10 @@ CREATE OR REPLACE FUNCTION forum_search(text, integer) RETURNS SETOF forum_resul
 	SELECT forum.msg_id, ts_headline(forum.subject, q) AS subject, forum.post_date, users.realname
 	FROM forum, users, to_tsquery($1) AS q 
 	WHERE users.user_id=forum.posted_by
-	AND msg_id IN (SELECT fi.msg_id FROM forum_idx fi, forum f, to_tsquery($1) AS q 
+	AND msg_id IN (SELECT fi.msg_id FROM forum_idx fi, forum f, to_tsquery($1) AS q
 	WHERE fi.msg_id = f.msg_id AND f.group_forum_id=$2
 	AND vectors @@ q ORDER BY ts_rank(vectors, q) DESC);'
-LANGUAGE 'SQL';
+LANGUAGE SQL;
 
 CREATE OR REPLACE FUNCTION frs_search(text, integer, text, boolean) RETURNS SETOF frs_results AS '
 	DECLARE
@@ -531,7 +531,7 @@ CREATE OR REPLACE FUNCTION frs_search(text, integer, text, boolean) RETURNS SETO
 			AND frs_file.release_id=frs_release.release_id
 			AND frs_package.group_id=$2
 			AND frs_package.package_id IN (\'$3\')
-			AND frs_release.release_id IN (SELECT r.release_id FROM frs_release_idx r 
+			AND frs_release.release_id IN (SELECT r.release_id FROM frs_release_idx r
 			LEFT JOIN frs_file_idx f ON r.release_id=f.release_id, to_tsquery($1) AS q
 			WHERE r.vectors @@ q OR f.vectors @@ q ORDER BY ts_rank(r.vectors, q) DESC, ts_rank(f.vectors, q) DESC) LOOP
 				RETURN NEXT data;
@@ -545,7 +545,7 @@ CREATE OR REPLACE FUNCTION frs_search(text, integer, text, boolean) RETURNS SETO
 			AND frs_package.group_id=$2
 			AND frs_package.package_id IN (\'$3\')
 			AND frs_package.is_public=1
-			AND frs_release.release_id IN (SELECT r.release_id FROM frs_release_idx r 
+			AND frs_release.release_id IN (SELECT r.release_id FROM frs_release_idx r
 			LEFT JOIN frs_file_idx f ON r.release_id=f.release_id, to_tsquery($1) AS q
 			WHERE r.vectors @@ q OR f.vectors @@ q ORDER BY ts_rank(r.vectors, q) DESC, ts_rank(f.vectors, q) DESC) LOOP
 				RETURN NEXT data;
@@ -559,7 +559,7 @@ CREATE OR REPLACE FUNCTION frs_search(text, integer, text, boolean) RETURNS SETO
 			AND frs_package.package_id = frs_release.package_id
 			AND frs_file.release_id=frs_release.release_id
 			AND frs_package.group_id=$2
-			AND frs_release.release_id IN (SELECT r.release_id FROM frs_release_idx r 
+			AND frs_release.release_id IN (SELECT r.release_id FROM frs_release_idx r
 			LEFT JOIN frs_file_idx f ON r.release_id=f.release_id, to_tsquery($1) AS q
 			WHERE r.vectors @@ q OR f.vectors @@ q ORDER BY ts_rank(r.vectors, q) DESC, ts_rank(f.vectors, q) DESC) LOOP
 				RETURN NEXT data;
@@ -572,7 +572,7 @@ CREATE OR REPLACE FUNCTION frs_search(text, integer, text, boolean) RETURNS SETO
 			AND frs_file.release_id=frs_release.release_id
 			AND frs_package.group_id=$2
 			AND frs_package.is_public=1
-			AND frs_release.release_id IN (SELECT r.release_id FROM frs_release_idx r 
+			AND frs_release.release_id IN (SELECT r.release_id FROM frs_release_idx r
 			LEFT JOIN frs_file_idx f ON r.release_id=f.release_id, to_tsquery($1) AS q
 			WHERE r.vectors @@ q OR f.vectors @@ q ORDER BY ts_rank(r.vectors, q) DESC, ts_rank(f.vectors, q) DESC) LOOP
 				RETURN NEXT data;
@@ -593,7 +593,7 @@ CREATE OR REPLACE FUNCTION groups_search(text) RETURNS SETOF groups_results AS '
 	WHERE status IN (\'A\', \'H\') AND is_public=\'1\' AND
 	group_id IN (SELECT group_id FROM groups_idx, to_tsquery($1) AS q
 	WHERE vectors @@ q ORDER BY ts_rank(vectors, q) DESC);'
-LANGUAGE 'SQL';
+LANGUAGE SQL;
 
 CREATE OR REPLACE FUNCTION export_groups_search(text) RETURNS SETOF export_groups_results AS '
 	SELECT ts_headline(group_name, q) as group_name,
@@ -604,10 +604,10 @@ CREATE OR REPLACE FUNCTION export_groups_search(text) RETURNS SETOF export_group
 	license,
 	register_time
 	FROM groups, to_tsquery($1) AS q
-	WHERE status IN (\'A\', \'H\') AND is_public=\'1\' AND short_description <> \'\' AND 
+	WHERE status IN (\'A\', \'H\') AND is_public=\'1\' AND short_description <> \'\' AND
 	group_id IN (SELECT group_id FROM groups_idx, to_tsquery($1) AS q
 	WHERE vectors @@ q ORDER BY ts_rank(vectors, q) DESC);'
-LANGUAGE 'SQL';
+LANGUAGE SQL;
 
 CREATE OR REPLACE FUNCTION news_bytes_search(text, integer) RETURNS SETOF news_bytes_results AS '
 	SELECT ts_headline(news_bytes.summary, q) as summary,
@@ -618,7 +618,7 @@ CREATE OR REPLACE FUNCTION news_bytes_search(text, integer) RETURNS SETOF news_b
 	WHERE (news_bytes.group_id=$2 AND news_bytes.is_approved <> ''4'' AND news_bytes.submitted_by=users.user_id) AND
 	news_bytes.id IN (SELECT id FROM news_bytes_idx,
 	to_tsquery($1) AS q WHERE vectors @@ q ORDER BY ts_rank(vectors, q) DESC);'
-LANGUAGE 'SQL';
+LANGUAGE SQL;
 
 CREATE OR REPLACE FUNCTION project_task_search(text, integer, text, boolean) RETURNS SETOF project_task_results AS '
 	DECLARE
@@ -709,7 +709,7 @@ CREATE OR REPLACE FUNCTION skills_data_search(text) RETURNS SETOF skills_data_re
 	AND skills_data.type=skills_data_types.type_id
 	AND skills_data.skills_data_id IN (SELECT skills_data_id FROM skills_data_idx, 
 	to_tsquery($1) AS q WHERE vectors @@ q ORDER BY ts_rank(vectors, q) DESC);'
-LANGUAGE 'SQL';
+LANGUAGE SQL;
 
 CREATE OR REPLACE FUNCTION trackers_search(text, integer, text, boolean) RETURNS SETOF trackers_results AS '
 	DECLARE
@@ -726,8 +726,8 @@ CREATE OR REPLACE FUNCTION trackers_search(text, integer, text, boolean) RETURNS
 			AND artifact_group_list.group_artifact_id = artifact.group_artifact_id
 			AND artifact_group_list.group_id = $2
 			AND artifact_group_list.group_artifact_id IN (\'$3\')
-			AND artifact.artifact_id IN (SELECT a.artifact_id FROM artifact a, 
-			(SELECT DISTINCT ON (ai.artifact_id) ai.artifact_id, COUNT(ami.id) AS total FROM artifact_idx ai 
+			AND artifact.artifact_id IN (SELECT a.artifact_id FROM artifact a,
+			(SELECT DISTINCT ON (ai.artifact_id) ai.artifact_id, COUNT(ami.id) AS total FROM artifact_idx ai
 			LEFT OUTER JOIN artifact_message_idx ami USING (artifact_id), artifact_group_list agl,
 			to_tsquery($1) AS q
 			WHERE ai.group_artifact_id=agl.group_artifact_id
@@ -749,8 +749,8 @@ CREATE OR REPLACE FUNCTION trackers_search(text, integer, text, boolean) RETURNS
 			AND artifact_group_list.group_id = $2
 			AND artifact_group_list.group_artifact_id IN (\'$3\')
 			AND artifact_group_list.is_public = 1
-			AND artifact.artifact_id IN (SELECT a.artifact_id FROM artifact a, 
-			(SELECT DISTINCT ON (ai.artifact_id) ai.artifact_id, COUNT(ami.id) AS total FROM artifact_idx ai 
+			AND artifact.artifact_id IN (SELECT a.artifact_id FROM artifact a,
+			(SELECT DISTINCT ON (ai.artifact_id) ai.artifact_id, COUNT(ami.id) AS total FROM artifact_idx ai
 			LEFT OUTER JOIN artifact_message_idx ami USING (artifact_id), artifact_group_list agl,
 			to_tsquery($1) AS q
 			WHERE ai.group_artifact_id=agl.group_artifact_id
@@ -773,8 +773,8 @@ CREATE OR REPLACE FUNCTION trackers_search(text, integer, text, boolean) RETURNS
 			WHERE users.user_id = artifact.submitted_by
 			AND artifact_group_list.group_artifact_id = artifact.group_artifact_id
 			AND artifact_group_list.group_id = $2
-			AND artifact.artifact_id IN (SELECT a.artifact_id FROM artifact a, 
-			(SELECT DISTINCT ON (ai.artifact_id) ai.artifact_id, COUNT(ami.id) AS total FROM artifact_idx ai 
+			AND artifact.artifact_id IN (SELECT a.artifact_id FROM artifact a,
+			(SELECT DISTINCT ON (ai.artifact_id) ai.artifact_id, COUNT(ami.id) AS total FROM artifact_idx ai
 			LEFT OUTER JOIN artifact_message_idx ami USING (artifact_id), artifact_group_list agl,
 			to_tsquery($1) AS q
 			WHERE ai.group_artifact_id=agl.group_artifact_id
@@ -795,8 +795,8 @@ CREATE OR REPLACE FUNCTION trackers_search(text, integer, text, boolean) RETURNS
 			AND artifact_group_list.group_artifact_id = artifact.group_artifact_id
 			AND artifact_group_list.group_id = $2
 			AND artifact_group_list.is_public = 1
-			AND artifact.artifact_id IN (SELECT a.artifact_id FROM artifact a, 
-			(SELECT DISTINCT ON (ai.artifact_id) ai.artifact_id, COUNT(ami.id) AS total FROM artifact_idx ai 
+			AND artifact.artifact_id IN (SELECT a.artifact_id FROM artifact a,
+			(SELECT DISTINCT ON (ai.artifact_id) ai.artifact_id, COUNT(ami.id) AS total FROM artifact_idx ai
 			LEFT OUTER JOIN artifact_message_idx ami USING (artifact_id), artifact_group_list agl,
 			to_tsquery($1) AS q
 			WHERE ai.group_artifact_id=agl.group_artifact_id
@@ -822,4 +822,4 @@ CREATE OR REPLACE FUNCTION users_search(text) RETURNS SETOF users_results AS '
 	FROM users, to_tsquery($1) AS q
 	WHERE status = \'A\' AND user_id IN (SELECT user_id FROM users_idx,
 	to_tsquery($1) AS q WHERE vectors @@ q ORDER BY ts_rank(vectors, q) DESC);'
-LANGUAGE 'SQL';
+LANGUAGE SQL;
