@@ -1,7 +1,7 @@
 #! /usr/bin/php
 <?php
 
-require_once dirname(__FILE__).'/../www/env.inc.php';
+require_once dirname(__FILE__).'/../common/include/env.inc.php';
 require_once $gfcommon.'include/pre.php';
 
 if (!$gfconn) {
@@ -22,7 +22,7 @@ if (count($argv) < 2) {
 		exit();
 	} else {
 		$date = check_version($version);
-		
+
 		if ($date != 0) {
 			set_version($version, $date);
 		}
@@ -31,16 +31,8 @@ if (count($argv) < 2) {
 
 function check_tables() {
 	db_begin();
-	$res = db_query_params ('SELECT COUNT(*) AS exists FROM pg_class WHERE relname = $1 AND relkind = $2',
-			array('database_startpoint',
-			'r')) ;
 
-	if (!$res) { // db error
-		echo "DB-ERROR-1: ".db_error()."\n";
-		db_rollback();
-		return false;
-	}
-	if (db_result($res, 0, 'exists') == '0') {
+	if (!db_check_table_exists('database_startpoint')) {
 		$res = db_query_params ('CREATE TABLE database_startpoint (db_version varchar(10), db_start_date int)',
 			array()) ;
 
@@ -50,16 +42,8 @@ function check_tables() {
 			return false;
 		}
 	}
-	$res = db_query_params ('SELECT COUNT(*) AS exists FROM pg_class WHERE relname = $1 AND relkind = $2',
-			array('database_changes',
-			'r')) ;
 
-	if (!$res) { // db error
-		echo "DB-ERROR-3: ".db_error()."\n";
-		db_rollback();
-		return false;
-	}
-	if (db_result($res, 0, 'exists') == '0') {
+	if (!db_check_table_exists('database_changes')) {
 		$res = db_query_params ('CREATE TABLE database_changes (filename text)',
 			array()) ;
 
@@ -69,6 +53,7 @@ function check_tables() {
 			return false;
 		}
 	}
+
 	db_commit();
 	return true;
 }
@@ -118,6 +103,6 @@ function set_version($version, $date) {
 		return false;
 	}
 	echo "FusionForge Database Version: $version ($date)\n";
-	db_commit();	
+	db_commit();
 }
 ?>
