@@ -8,23 +8,25 @@ use diagnostics ;
 
 use DBI ;
 use MIME::Base64 ;
-use HTML::Entities ;
 
 use vars qw/$dbh @reqlist $query/ ;
-use vars qw/$sys_default_domain $sys_scm_host $sys_download_host
+use vars qw/$sys_default_domain $sys_scm_host
     $sys_shell_host $sys_users_host $sys_docs_host $sys_lists_host
     $sys_dns1_host $sys_dns2_host $FTPINCOMING_DIR $FTPFILES_DIR
     $sys_urlroot $sf_cache_dir $sys_name $sys_themeroot
     $sys_news_group $sys_dbhost $sys_dbname $sys_dbuser $sys_dbpasswd
     $sys_ldap_base_dn $sys_ldap_host $admin_login $admin_password
-    $server_admin $domain_name $newsadmin_groupid $statsadmin_groupid
+    $domain_name
     $skill_list/ ;
 
 sub debug ( $ ) ;
 sub convert_column_to_charset ( $$$$$ ) ;
 
-require ("/usr/share/gforge/lib/include.pl") ; # Include a few predefined functions 
-require ("/usr/share/gforge/lib/sqlparser.pm") ; # Our magic SQL parser
+my $source_path = `forge_get_config source_path`;
+chomp $source_path;
+
+require ("$source_path/lib/include.pl") ; # Include all the predefined functions 
+require ("$source_path/lib/sqlparser.pm") ; # Our magic SQL parser
 
 debug "You'll see some debugging info during this installation." ;
 debug "Do not worry unless told otherwise." ;
