@@ -1,19 +1,28 @@
 #! /usr/bin/perl -w
 
+# TODO : document what this script is doing
+
 use DBI;
 use File::Temp ;
 use strict ;
 use vars qw/$dbh $ifile $ofile @ilist %hash $key $val $cur $line $dbh $sys_dbname $sys_dbuser $sys_dbpasswd $token/ ;
 
-require("/etc/gforge/local.pl"); 
-require ("/usr/share/gforge/lib/include.pl") ; 
+my $source_path = `forge_get_config source_path`;
+chomp $source_path;
+my $config_path = `forge_get_config config_path`;
+chomp $config_path;
+my $data_path = `forge_get_config data_path`;
+chomp $data_path;
+
+require ("$source_path/lib/include.pl") ; 
 
 %hash = () ;
 
 &db_connect ;
 
-$ifile = '/usr/share/gforge/etc/templates/httpd.vhosts' ;
-$ofile = '/var/lib/gforge/etc/templates/httpd.vhosts' ;
+
+$ifile = "$config_path/templates/httpd.vhosts" ;
+$ofile = "$data_path/etc/templates/httpd.vhosts" ;
 
 open (IFILE, $ifile)
     or die "Can't open input file '$ifile'" ;
@@ -33,6 +42,10 @@ while(my ($vhost_name, $docdir, $cgidir) = $c->fetchrow()) {
     $hash{docdir} = $docdir ;
     $hash{cgidir} = $cgidir ;
 
+    foreach my $k (qw/groupdir_prefix log_path/) {
+	$hash{$k} = &forge_get_config ($k) ;
+    }
+
     foreach my $tmpl_line (@ilist) {
 	my $line = $tmpl_line ;
 	chomp $line ;
