@@ -23,22 +23,22 @@
  */
 
 class ContribTrackerPlugin extends Plugin {
-	function ContribTrackerPlugin () {
+	function ContribTrackerPlugin() {
 		$this->Plugin() ;
-		$this->name = "contribtracker" ;
-		$this->text = "Contribution Tracker" ; // To show in the tabs, use...
-		$this->hooks[] = "groupmenu" ;	// To put into the project tabs
-		$this->hooks[] = "groupisactivecheckbox" ; // The "use ..." checkbox in editgroupinfo
-		$this->hooks[] = "groupisactivecheckboxpost" ; //
-		$this->hooks[] = "project_admin_plugins"; // to show up in the admin page for group
-		$this->hooks[] = "project_before_frs"; // project summary page
-                $this->hooks[] = "site_admin_option_hook"; // to show in the site admin page
+		$this->name = "contribtracker";
+		$this->text = "Contribution Tracker"; // To show in the tabs, use...
+		$this->_addHook("groupmenu");	// To put into the project tabs
+		$this->_addHook("groupisactivecheckbox"); // The "use ..." checkbox in editgroupinfo
+		$this->_addHook("groupisactivecheckboxpost"); //
+		$this->_addHook("project_admin_plugins"); // to show up in the admin page for group
+		$this->_addHook("project_before_frs"); // project summary page
+                $this->_addHook("site_admin_option_hook"); // to show in the site admin page
 	}
 
-	function CallHook ($hookname, &$params) {
+	function CallHook($hookname, &$params) {
 		if ($hookname == "groupmenu") {
 			$group_id=$params['group'];
-			$project = &group_get_object($group_id);
+			$project = group_get_object($group_id);
 			if (!$project || !is_object($project)) {
 				return;
 			}
@@ -50,14 +50,16 @@ class ContribTrackerPlugin extends Plugin {
 			}
 			if ( $project->usesPlugin ( $this->name ) ) {
 				$params['TITLES'][] = '<nobr>'._('Contribution tracker').'</nobr>' ;
+				$params['TOOLTIPS'][] = _('Follow the contributions by contributors to this project');
 				$params['DIRS'][]='/plugins/'.$this->name.'/?group_id=' . $group_id ;
+				$params['ADMIN'][]='';
 			}
 			(($params['toptab'] == $this->name) ? $params['selected']=(count($params['TITLES'])-1) : '' );
 		} elseif ($hookname == "groupisactivecheckbox") {
 			//Check if the group is active
 			// this code creates the checkbox in the project edit public info page to activate/deactivate the plugin
 			$group_id=$params['group'];
-			$group = &group_get_object($group_id);
+			$group = group_get_object($group_id);
 			echo "<tr>";
 			echo "<td>";
 			echo ' <input type="CHECKBOX" name="use_contribtrackerplugin" value="1" ';
@@ -76,7 +78,7 @@ class ContribTrackerPlugin extends Plugin {
 		} elseif ($hookname == "groupisactivecheckboxpost") {
 			// this code actually activates/deactivates the plugin after the form was submitted in the project edit public info page
 			$group_id=$params['group'];
-			$group = &group_get_object($group_id);
+			$group = group_get_object($group_id);
 			$use_contribtrackerplugin = getStringFromRequest('use_contribtrackerplugin');
 			if ( $use_contribtrackerplugin == 1 ) {
 				$group->setPluginUse ( $this->name );
@@ -86,7 +88,7 @@ class ContribTrackerPlugin extends Plugin {
 		} elseif ($hookname == "project_admin_plugins") {
 			// this displays the link in the project admin options page to its ContribTracker administration
 			$group_id = $params['group_id'];
-			$group = &group_get_object($group_id);
+			$group = group_get_object($group_id);
 			if ( $group->usesPlugin ( $this->name ) ) {
 				echo util_make_link ("/plugins/".$this->name."/project_admin.php?group_id=".$group->getID(),
 						     _('Contribution Tracker admin')) ;
@@ -96,7 +98,7 @@ class ContribTrackerPlugin extends Plugin {
 
 		elseif ($hookname == "project_before_frs") {
 			$group_id = $params['group_id'];
-			$group = &group_get_object ($group_id);
+			$group = group_get_object($group_id);
 
 			if ($group->usesPlugin($this->name)) {
 				global $HTML ;
@@ -167,22 +169,19 @@ class ContribTrackerPlugin extends Plugin {
 						      echo $HTML->boxBottom();
 				echo '</div>';
 			}
+		} elseif ($hookname == "site_admin_option_hook") {
+			?>
+			<li><?php echo util_make_link ('/plugins/'.$this->name.'/global_admin.php',
+						_('Edit actors and roles'). ' [' . _('Contribution tracker plugin') . ']'); ?></li>
+			<?php
 		}
-                elseif ($hookname == "site_admin_option_hook") {
-                        ?>
-                        <li><?php echo util_make_link ('/plugins/'.$this->name.'/global_admin.php',
-                                                       _('Edit actors and roles for the contribution tracker plugin')
-                                ); ?></li>
-                        <?php
-                } 
-
 	}
 
 	function getActors () {
 		$res = db_query_params ('SELECT actor_id FROM plugin_contribtracker_actor',
 					array ()) ;
 		$ids = util_result_column_to_array ($res, 0) ;
-		
+
 		$results = array () ;
 		foreach ($ids as $id) {
 			$results[] = new ContribTrackerActor ($id) ;
@@ -195,7 +194,7 @@ class ContribTrackerPlugin extends Plugin {
 		$res = db_query_params ('SELECT struct_id FROM plugin_contribtracker_legal_structure',
 					array ()) ;
 		$ids = util_result_column_to_array ($res, 0) ;
-		
+
 		$results = array () ;
 		foreach ($ids as $id) {
 			$results[] = new ContribTrackerLegalStructure ($id) ;
@@ -208,7 +207,7 @@ class ContribTrackerPlugin extends Plugin {
 		$res = db_query_params ('SELECT role_id FROM plugin_contribtracker_role',
 					array ()) ;
 		$ids = util_result_column_to_array ($res, 0) ;
-		
+
 		$results = array () ;
 		foreach ($ids as $id) {
 			$results[] = new ContribTrackerRole ($id) ;
@@ -221,7 +220,7 @@ class ContribTrackerPlugin extends Plugin {
 		$res = db_query_params ('SELECT contrib_id FROM plugin_contribtracker_contribution',
 					array ()) ;
 		$ids = util_result_column_to_array ($res, 0) ;
-		
+
 		$results = array () ;
 		foreach ($ids as $id) {
 			$results[] = new ContribTrackerContribution ($id) ;
@@ -236,7 +235,7 @@ class ContribTrackerPlugin extends Plugin {
 		$res = db_query_params ('SELECT contrib_id FROM plugin_contribtracker_contribution WHERE group_id = $1',
 					array ($group->getId())) ;
 		$ids = util_result_column_to_array ($res, 0) ;
-		
+
 		$results = array () ;
 		foreach ($ids as $id) {
 			$results[] = new ContribTrackerContribution ($id) ;
@@ -288,7 +287,7 @@ class ContribTrackerRole extends Error {
 			$this->setError(sprintf('ContribTrackerRole(): %s',db_error()));
 			return false;
 		}
-		
+
 		$this->data_array = db_fetch_array ($res) ;
 		return true ;
 	}
@@ -317,7 +316,7 @@ class ContribTrackerRole extends Error {
 			db_rollback () ;
 			return false ;
 		}
-			
+
 		db_commit () ;
 		return $this->fetchData ($id) ;
 	}
@@ -341,7 +340,7 @@ class ContribTrackerRole extends Error {
 			db_rollback () ;
 			return false ;
 		}
-			
+
 		db_commit () ;
 		return $this->fetchData ($id) ;
 	}
@@ -362,7 +361,7 @@ class ContribTrackerRole extends Error {
 		}
 
 		$this->data_array = array () ;
-		
+
 		return true ;
 	}
 
@@ -375,7 +374,7 @@ class ContribTrackerRole extends Error {
 	}
 	function getName () { return $this->data_array['name'] ; }
 	function getDescription () { return $this->data_array['description'] ; }
-	
+
 }
 
 class ContribTrackerLegalStructure extends Error {
@@ -396,7 +395,7 @@ class ContribTrackerLegalStructure extends Error {
 			$this->setError(sprintf('ContribTrackerLegalStructure(): %s',db_error()));
 			return false;
 		}
-		
+
 		$this->data_array = db_fetch_array ($res) ;
 		return true ;
 	}
@@ -424,7 +423,7 @@ class ContribTrackerLegalStructure extends Error {
 			db_rollback () ;
 			return false ;
 		}
-		
+
 		db_commit () ;
 		return $this->fetchData ($id) ;
 	}
@@ -447,7 +446,7 @@ class ContribTrackerLegalStructure extends Error {
 			db_rollback () ;
 			return false ;
 		}
-		
+
 		db_commit () ;
 		return $this->fetchData ($id) ;
 	}
@@ -468,7 +467,7 @@ class ContribTrackerLegalStructure extends Error {
 		}
 
 		$this->data_array = array () ;
-		
+
 		return true ;
 	}
 
@@ -500,7 +499,7 @@ class ContribTrackerActor extends Error {
 			$this->setError(sprintf('ContribTrackerActor(): %s',db_error()));
 			return false;
 		}
-		
+
 		$this->data_array = db_fetch_array ($res) ;
 		return true ;
 	}
@@ -533,7 +532,7 @@ class ContribTrackerActor extends Error {
 			db_rollback () ;
 			return false ;
 		}
-			
+
 		db_commit () ;
 		return $this->fetchData ($id) ;
 	}
@@ -561,7 +560,7 @@ class ContribTrackerActor extends Error {
 			db_rollback () ;
 			return false ;
 		}
-			
+
 		db_commit () ;
 		return $this->fetchData ($id) ;
 	}
@@ -582,7 +581,7 @@ class ContribTrackerActor extends Error {
 		}
 
 		$this->data_array = array () ;
-		
+
 		return true ;
 	}
 
@@ -606,7 +605,7 @@ class ContribTrackerActor extends Error {
 		$res = db_query_params ('SELECT participation_id FROM plugin_contribtracker_participation WHERE actor_id = $1',
 					array ($this->getId())) ;
 		$ids = util_result_column_to_array ($res, 0) ;
-		
+
 		$results = array () ;
 		foreach ($ids as $id) {
 			$results[] = new ContribTrackerParticipation ($id) ;
@@ -637,7 +636,7 @@ class ContribTrackerContribution extends Error {
 			$this->setError(sprintf('ContribTrackerContribution(): %s',db_error()));
 			return false;
 		}
-		
+
 		$this->data_array = db_fetch_array ($res) ;
 		return true ;
 	}
@@ -668,7 +667,7 @@ class ContribTrackerContribution extends Error {
 			db_rollback () ;
 			return false ;
 		}
-			
+
 		db_commit () ;
 		return $this->fetchData ($id) ;
 	}
@@ -694,7 +693,7 @@ class ContribTrackerContribution extends Error {
 			db_rollback () ;
 			return false ;
 		}
-			
+
 		db_commit () ;
 		return $this->fetchData ($id) ;
 	}
@@ -715,7 +714,7 @@ class ContribTrackerContribution extends Error {
 		}
 
 		$this->data_array = array () ;
-		
+
 		return true ;
 	}
 
@@ -730,14 +729,14 @@ class ContribTrackerContribution extends Error {
 	function getDate () { return $this->data_array['date'] ; }
 	function getDescription () { return $this->data_array['description'] ; }
 	function getGroup () {
-		return group_get_object ($this->data_array['group_id']) ;
+		return group_get_object($this->data_array['group_id']) ;
 	}
 
 	function getParticipations () {
 		$res = db_query_params ('SELECT participation_id FROM plugin_contribtracker_participation WHERE contrib_id = $1',
 					array ($this->getId())) ;
 		$ids = util_result_column_to_array ($res, 0) ;
-		
+
 		$results = array () ;
 		foreach ($ids as $id) {
 			$results[] = new ContribTrackerParticipation ($id) ;
@@ -774,7 +773,7 @@ class ContribTrackerParticipation extends Error {
 			$this->setError(sprintf('ContribTrackerParticipation(): %s',db_error()));
 			return false;
 		}
-		
+
 		$this->data_array = db_fetch_array ($res) ;
 		return true ;
 	}
@@ -807,7 +806,7 @@ class ContribTrackerParticipation extends Error {
 			db_rollback () ;
 			return false ;
 		}
-			
+
 		db_commit () ;
 		return $this->fetchData ($id) ;
 	}
@@ -836,7 +835,7 @@ class ContribTrackerParticipation extends Error {
 			db_rollback () ;
 			return false ;
 		}
-			
+
 		db_commit () ;
 		return $this->fetchData ($id) ;
 	}
@@ -875,7 +874,7 @@ class ContribTrackerParticipation extends Error {
 		db_commit () ;
 
 		$this->data_array = array () ;
-		
+
 		return true ;
 	}
 
@@ -891,7 +890,7 @@ class ContribTrackerParticipation extends Error {
 			return ;
 		}
 		$contrib_id = $this->getContribution()->getId() ;
-		
+
 		db_begin () ;
 		$res = db_query_params ('UPDATE plugin_contribtracker_participation SET index = 0 WHERE participation_id = $1',
 					array ($id)) ;
@@ -918,7 +917,7 @@ class ContribTrackerParticipation extends Error {
 			return ;
 		}
 		$contrib_id = $this->getContribution()->getId() ;
-		
+
 		db_begin () ;
 		$res = db_query_params ('UPDATE plugin_contribtracker_participation SET index = 0 WHERE participation_id = $1',
 					array ($id)) ;
@@ -960,5 +959,3 @@ class ContribTrackerParticipation extends Error {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
