@@ -7,13 +7,13 @@
  *
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
-$plugin = plugin_get_object ('contribtracker') ;
+$plugin = plugin_get_object('contribtracker') ;
 
-$group_id = getIntFromRequest ('group_id') ;
-session_require_perm ('project_admin', $group_id) ;
-$group = group_get_object ($group_id) ;
+$group_id = getIntFromRequest('group_id') ;
+session_require_perm('project_admin', $group_id) ;
+$group = group_get_object($group_id) ;
 
 $params = array () ;
 $params['toptab'] = 'contribtracker' ;
@@ -73,7 +73,7 @@ function check_updown () {
 	} else {
 		return 0 ;
 	}
-}	
+}
 
 // Get and validate parameters, error if tampered with
 switch ($action) {
@@ -90,7 +90,7 @@ case 'edit_contrib':
 case 'del_contrib':
 	$contrib_id = getIntFromRequest ('contrib_id') ;
 	check_contrib_id ($contrib_id, $group_id) ;
-	break ;	
+	break ;
 case 'post_edit_contrib':
 	$contrib_id = getIntFromRequest ('contrib_id') ;
 	check_contrib_id ($contrib_id, $group_id) ;
@@ -126,7 +126,7 @@ case 'add_part':
 	}
 	break ;
 }
-	
+
 // Do the required action
 
 switch ($action) {
@@ -186,9 +186,9 @@ case 'add_contrib':
 <form action="<?php echo util_make_url ('/plugins/'.$plugin->name.'/project_admin.php') ?>" method="post">
 <input type="hidden" name="action" value="post_add_contrib" />
 <input type="hidden" name="group_id" value="<?php echo $group_id ?>" />
-<?php echo _('Contribution name:') ?> <input type="text" name="contrib_name" size="20" /><br />
-<?php echo _('Contribution date:') ?> <input type="text" name="date" value="<?php echo strftime($date_format,time()) ?>"  /><br />
-<?php echo _('Contribution description:') ?><br />
+<?php echo _('Contribution name')._(':') ?> <input type="text" name="contrib_name" size="20" /><br />
+<?php echo _('Contribution date')._(':') ?> <input type="text" name="date" value="<?php echo strftime($date_format,time()) ?>"  /><br />
+<?php echo _('Contribution description')._(':') ?><br />
 <textarea name="contrib_desc" rows="20" cols="80"></textarea><br />
 <input type="submit" name="submit" value="<?php echo _('Submit') ?>" />
 </form>
@@ -207,16 +207,16 @@ case 'edit_contrib':
 <input type="hidden" name="action" value="post_edit_contrib" />
 <input type="hidden" name="group_id" value="<?php echo $group_id ?>" />
 <input type="hidden" name="contrib_id" value="<?php echo $contrib->getId() ?>" />
-<?php echo _('Contribution name:') ?> <input type="text" name="contrib_name" size="20" value="<?php echo htmlspecialchars ($contrib->getName()) ?>" /><br />
-<?php echo _('Contribution date:') ?> <input type="text" name="date" value="<?php echo strftime($date_format,time()) ?>" /><br />
-<?php echo _('Contribution description:') ?><br />
+<?php echo _('Contribution name')._(':') ?> <input type="text" name="contrib_name" size="20" value="<?php echo htmlspecialchars ($contrib->getName()) ?>" /><br />
+<?php echo _('Contribution date')._(':') ?> <input type="text" name="date" value="<?php echo strftime($date_format,time()) ?>" /><br />
+<?php echo _('Contribution description')._(':') ?><br />
 <textarea name="contrib_desc" rows="20" cols="80"><?php echo htmlspecialchars ($contrib->getDescription()) ?></textarea><br />
 <input type="submit" name="submit" value="<?php echo _('Save') ?>" />
 </form>
 <?php
 
 	 print '<h3>'._('Current participants').'</h3>' ;
-	  
+
 	$parts = $contrib->getParticipations () ;
 	print '<strong>'.ngettext('Participant:',
 				  'Participants:',
@@ -250,9 +250,9 @@ case 'edit_contrib':
 		print '</li>' ;
 	}
 	print '</ul>' ;
-	
+
 	  print '<h3>'._('Add a participant').'</h3>' ;
-	
+
 ?>
 <form action="<?php echo util_make_url ('/plugins/'.$plugin->name.'/project_admin.php') ?>" method="post">
 <input type="hidden" name="action" value="add_part" />
@@ -283,17 +283,17 @@ case 'display':
 	$contribs = $plugin->getContributionsByGroup ($group) ;
 	if (count ($contribs) != 0) {
 		print '<h1>'._('Existing contributions').'</h1>' ;
-		
+
 		foreach ($contribs as $c) {
 			print '<h3>'.$c->getName().'</h3>' ;
-			print '<strong>'._('Date:').'</strong> ' ;
+			print '<strong>'._('Date')._(':').'</strong> ' ;
 			print strftime (_('%Y-%m-%d'), $c->getDate ()) ;
 			print '<br />' ;
-			
-			print '<strong>'._('Description:').'</strong> ' ;
+
+			print '<strong>'._('Description')._(':').'</strong> ' ;
 			print htmlspecialchars ($c->getDescription ()) ;
 			print '<br />' ;
-			
+
 			$parts = $c->getParticipations () ;
 			print '<strong>'.ngettext('Participant:',
 						  'Participants:',
@@ -328,7 +328,7 @@ case 'display':
 		}
 	} else {
 		print '<h1>'._('No contributions for this project yet.').'</h1>' ;
-	}		
+	}
 ?>
 <form action="<?php echo util_make_url ('/plugins/'.$plugin->name.'/project_admin.php') ?>" method="post">
 <input type="hidden" name="action" value="add_contrib" />
@@ -345,5 +345,3 @@ site_project_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
