@@ -4,14 +4,14 @@
  *
  * Originally written by Jean-Philippe Giola, 2005
  *
- * This file is a part of codendi.
+ * This file is a part of Fusionforge.
  *
- * codendi is free software; you can redistribute it and/or modify
+ * Fusionforge is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * codendi is distributed in the hope that it will be useful,
+ * Fusionforge is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
@@ -19,28 +19,25 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * $Id$
  */
 
 /*
  * ForumML Archives Browsing page
- *  
+ *
  */
 
-require_once('env.inc.php');
-require_once('pre.php');
+require_once 'env.inc.php';
+require_once 'pre.php';
 require_once 'preplugins.php';
-require_once('forumml_utils.php');
-require_once('mailman/www/mailman_utils.php');
-require_once('mailman/include/MailmanList.class.php');
+require_once 'forumml_utils.php';
+require_once 'mailman/www/mailman_utils.php';
+require_once 'mailman/include/MailmanList.class.php';
 //require_once('common/plugin/PluginManager.class.php');
 require_once(dirname(__FILE__).'/../include/ForumML_FileStorage.class.php');
 require_once(dirname(__FILE__).'/../include/ForumML_HTMLPurifier.class.php');
 require_once(dirname(__FILE__).'/../include/ForumML_MessageManager.class.php');
 global $feedback;
 
-
 $pm = ProjectManager::instance();
 $Group = $pm->getProject($group_id);
 $plugin_manager =& PluginManager::instance();
@@ -52,7 +49,7 @@ if ($p && $plugin_manager->isPluginAvailable($p) && $p->isAllowed()) {
 
 	$vGrp = new Valid_UInt('group_id');
 	$vGrp->required();
-	if ($request->valid($vGrp)) {		
+	if ($request->valid($vGrp)) {
 		$group_id = $request->get('group_id');
 	} else {
 		$group_id = "";
@@ -95,10 +92,10 @@ if ($p && $plugin_manager->isPluginAvailable($p) && $p->isAllowed()) {
 		$list_id = $request->get('list');
 		$list = new MailmanList($group_id,$list_id);
 		if (!isLogged() || ($list->isPublic()!=1 && !$current_user->isMember($group_id))) {
-			exit_error(_('error'),_('You are not allowed to access this page'));
-		}		
+			exit_error(_('Error'),_('You are not allowed to access this page'));
+		}
 		if ($list->getStatus() !=3) {
-			exit_error(_('error'),_('This list is not active'));
+			exit_error(_('Error'),_('This list is not active'));
 		}
 	}
 
@@ -130,7 +127,7 @@ if ($p && $plugin_manager->isPluginAvailable($p) && $p->isAllowed()) {
 
 	$params['title'] = $Group->getPublicName().' - ForumML - '.$list_name;
 	if ($topicSubject) {
-		$params['title'] .= ' - '.$topicSubject;   
+		$params['title'] .= ' - '.$topicSubject;
 	}
 	$params['group'] = $group_id;
 	$params['toptab']='mail';
@@ -144,11 +141,11 @@ if ($p && $plugin_manager->isPluginAvailable($p) && $p->isAllowed()) {
 		if (isset($ret) && $ret) {
 			// wait few seconds before redirecting to archives page
 			echo "<script> setTimeout('window.location=\"/plugins/forumml/message.php?group_id=".$group_id."&list=".$list_id."&topic=".$topic."\"',3000) </script>";
-		}		
+		}
 	}
 
 	$list_link = '<a href="/plugins/forumml/message.php?group_id='.$group_id.'&list='.$list_id.'">'.$list_name.'</a>';
-	$title     = _('Mailing List '.$list_link);
+	$title = _('Mailing List').' '.$list_link;
 	if ($topic) {
 		$fmlMessageMgr = new ForumML_MessageManager();
 		$value = $fmlMessageMgr->getHeaderValue($topic, FORUMML_SUBJECT);
@@ -156,12 +153,12 @@ if ($p && $plugin_manager->isPluginAvailable($p) && $p->isAllowed()) {
 			$title = $value;
 		}
 	} else {
-		$title .= _(' Archives');
+		$title .= ' ' . _('Archives');
 	}
 	echo '<h2>'.$title.'</h2>';
 
 	if (! $request->exist('pv') || ($request->exist('pv') && $request->get('pv') == 0)) {
-		echo "<table border=0 width=100%>
+		echo "<table border='0' width='100%'>
 			<tr>";
 
 		echo "<td align='left'>";
@@ -195,21 +192,21 @@ if ($p && $plugin_manager->isPluginAvailable($p) && $p->isAllowed()) {
 		// Check if there are archives to browse
 		$res = getForumMLDao()->hasArchives($list_id);
 		if ($res->rowCount() > 0) {
-			// Call to show_thread() function to display the archives			
+			// Call to show_thread() function to display the archives
 			if (isset($topic) && $topic != 0) {
 				// specific thread
 				plugin_forumml_show_thread($p, $list_id, $topic, $purgeCache);
 			} else {
 				plugin_forumml_show_all_threads($p,$list_id,$list_name,$offset);
-			}	
+			}
 		} else {
-			echo "<H2>"._('Empty archives')."</H2>";
+			echo "<h2>"._('Empty archives')."</h2>";
 		}
 	} else {
-		// search archives		
+		// search archives
 		$pattern = "%".$request->get('search')."%";
 		$result = getForumMLDao()->searchArchives($list_id,$pattern);
-		echo "<H3>"._('Search result for ').$request->get('search')." (".$result->rowCount()." "._('Thread(s) found').")</H3>";
+		echo "<h3>"._('Search result for ').$request->get('search')." (".$result->rowCount()." "._('Thread(s) found').")</h3>";
 		if ($result->rowCount() > 0) {
 			plugin_forumml_show_search_results($p,$result,$group_id,$list_id);
 		}
@@ -220,5 +217,3 @@ if ($p && $plugin_manager->isPluginAvailable($p) && $p->isAllowed()) {
 } else {
 	header('Location: '.get_server_url());
 }
-
-?>
