@@ -22,11 +22,11 @@
  #
  # $Id$
  #
-require_once('env.inc.php');
-require_once('pre.php');
-require_once('preplugins.php');
-require_once('mailman/include/MailmanList.class.php');
-require_once('mailman/www/mailman_utils.php');
+require_once 'env.inc.php';
+require_once 'pre.php';
+require_once 'preplugins.php';
+require_once 'mailman/include/MailmanList.class.php';
+require_once 'mailman/www/mailman_utils.php';
 require_once(dirname(__FILE__).'/../include/ForumML_Attachment.class.php');
 global $feedback ;
 $plugin_manager = PluginManager::instance();
@@ -40,15 +40,15 @@ if ($p && $plugin_manager->isPluginAvailable($p) && $p->isAllowed()) {
     $vList->required();
     // Checks 'list' parameter
     if (! $request->valid($vList)) {
-        exit_error('error','No list specified');
+        exit_error('Error','No list specified');
     } else {
         $list_id = $request->get('list');
 	$list = new MailmanList($groupId,$list_id);
 	if (!isLogged() || ($list->isPublic()!=1 && !$current_user->isMember($groupId))) {
-		exit_error(_('error'),_('You are not allowed to access this page'));
-	}		
+		exit_error(_('Error'),_('You are not allowed to access this page'));
+	}
 	if ($list->getStatus() !=3) {
-		exit_error(_('error'),_('This list is not active'));
+		exit_error(_('Error'),_('This list is not active'));
 	}
     }
 
@@ -79,14 +79,12 @@ echo $attch['file_path'];
 		    readfile($attch['file_path']);
 		    exit;
 	    } else {
-		    $feedback.= _('Error : Attachment not found');
+		    $feedback.= _('Error: Attachment not found');
 	    }
     } else {
-		    $feedback.= _('Error : Missing parameter ');
+		$feedback.= _('Error: Missing parameter');
     }
     htmlRedirect('/plugins/forumml/message.php?group_id='.$groupId.'&list='.$list_id.'&topic='.$topic);
 } else {
 	header('Location: '.get_server_url());
 }
-
-?>
