@@ -12,7 +12,7 @@
  * it under the terms of the GNU General Public License as published
  * by the Free Software Foundation; either version 2 of the License,
  * or (at your option) any later version.
- * 
+ *
  * FusionForge is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
@@ -38,7 +38,7 @@ function globalsearch_admin_table_add () {
 	echo '<tr><td><strong>'._('Software only').'</strong></td><td><input type="checkbox" checked name="onlysw" value="t"/></td></tr>';
 	echo '<tr><td><strong>'._('Enabled').'</strong></td><td><input type="checkbox" checked name="enabled" value="t"/></td></tr>';
 	echo '<tr><td><strong>'._('Rank').'</strong></td><td><input type="text" name="rank" /></td></tr>';
-	
+
 	echo '</table><input type="submit" value="'._('Submit new associated forge').'" /></form>
                         <form name="cancel" action="'.$PHP_SELF.'" method="post">
                         <input type="submit" value="Cancel" />
@@ -150,8 +150,8 @@ function globalsearch_admin_table_edit ($id) {
 		echo '<tr><td><strong>'._('Software only').'</strong></td><td><input type="checkbox" '.(($old_onlysw == 't')?'checked':'') .' name="onlysw" value="t"/></td></tr>';
 		echo '<tr><td><strong>'._('Enabled').'</strong></td><td><input type="checkbox" '.(($old_enabled == 't')?'checked':'') .' name="enabled" value="t"/></td></tr>';
 		echo '<tr><td><strong>'._('Rank').'</strong></td><td><input type="text" name="rank" value="'.$old_rank.'"/></td></tr>';
-		
-		echo '</table><input type="submit" value="'._('Submit changes').'" /></form>
+
+		echo '</table><input type="submit" value="'._('Submit Changes').'" /></form>
                         <form name="cancel" action="'.$PHP_SELF.'" method="post">
                         <input type="submit" value="'._('Cancel').'" />
                         </form>';
@@ -203,7 +203,7 @@ function globalsearch_admin_table_show () {
                 $rows = db_numrows($result);
 
                 $cell_data=array();
-                $cell_data[]=array(ngettext('Associated forge','Associated forges',$rows).' <a href="'.$PHP_SELF.'?function=add">'._('[add new]').'</a>',
+                $cell_data[]=array(ngettext('Associated forge','Associated forges',$rows).' <a href="'.$PHP_SELF.'?function=add">['._('add new').']</a>',
                         'colspan="8"');
 
                 echo '<table border="0" width="100%">';
@@ -223,8 +223,8 @@ function globalsearch_admin_table_show () {
                         echo '<tr '. $HTML->boxGetAltRowStyle($j) . '>';
 
                         $id = db_result($result,$j,0);
-                        echo '<td><a href="'.$PHP_SELF.'?function=edit&amp;id='.$id.'">'._('[edit]').'</a> ';
-                        echo '<a href="'.$PHP_SELF.'?function=confirmdelete&amp;id='.$id.'">'._('[delete]').'</a> </td>';
+                        echo '<td><a href="'.$PHP_SELF.'?function=edit&amp;id='.$id.'">['._('edit').']</a> ';
+                        echo '<a href="'.$PHP_SELF.'?function=confirmdelete&amp;id='.$id.'">['._('delete').']</a> </td>';
 
 			echo '<td><strong>'.db_result ($result, $j, 'assoc_site_id').'</strong></td>';
 			echo '<td><strong>'.db_result ($result, $j, 'title').'</strong></td>';
@@ -240,13 +240,13 @@ function globalsearch_admin_table_show () {
                 echo db_error();
         }
 }
-	
+
 function globalsearch_status_name ($status_id) {
 	switch ($status_id) {
-	case 1: return _('New'); break; 
-	case 2: return _('OK'); break; 
-	case 3: return _('Error fetching data'); break; 
-	case 4: return _('Error parsing data'); break; 
+	case 1: return _('New'); break;
+	case 2: return _('OK'); break;
+	case 3: return _('Error fetching data'); break;
+	case 4: return _('Error parsing data'); break;
 	default: return _('Unknown status ID');
 	}
 }
@@ -255,5 +255,3 @@ function globalsearch_status_name ($status_id) {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
