@@ -11,7 +11,7 @@
  * it under the terms of the GNU General Public License as published
  * by the Free Software Foundation; either version 2 of the License,
  * or (at your option) any later version.
- * 
+ *
  * FusionForge is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
@@ -32,13 +32,13 @@
   *
   */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 
 $otherfreeknowledge = getIntFromRequest('otherfreeknowledge') ;
 $gwords = getStringFromRequest('gwords');
 $order = getStringFromRequest('order', 'rank');
-util_ensure_value_in_set ($order, 
+util_ensure_value_in_set ($order,
 			  array ('rank',
 				 'project_title',
 				 'project_description',
@@ -60,7 +60,7 @@ function highlight_target_words($word_array,$text) {
                 return '&nbsp;';
         }
         $re=implode($word_array,'|');
-        return eregi_replace("($re)",'<span style="background-color:pink">\1</span>',$text);
+        return preg_replace("/($re)/i",'<span style="background-color:pink">\1</span>',$text);
 }
 
 $HTML->header(array('title'=>'Search','pagename'=>'search'));
@@ -68,7 +68,7 @@ $HTML->header(array('title'=>'Search','pagename'=>'search'));
 echo "<p>";
 
 $gwords = htmlspecialchars(trim($gwords));
-$gwords = ereg_replace("[ \t]+", ' ', $gwords);
+$gwords = preg_replace("/\s+/", ' ', $gwords);
 
 // show search box which will return results on
 // this very page (default is to open new window)
@@ -122,7 +122,7 @@ foreach ($array as $val) {
 		}
 	}
 	$i++ ;
-	
+
 	$qpa = db_construct_qpa ($qpa, 'lower(project_title) LIKE $1', array ("%$val%")) ;
 }
 
@@ -138,21 +138,20 @@ foreach ($array as $val) {
 		}
 	}
 	$i++ ;
-	
+
 	$qpa = db_construct_qpa ($qpa, 'lower(project_description) LIKE $1', array ("%$val%")) ;
 }
 $qpa = db_construct_qpa ($qpa, ')) ORDER BY '.$order) ;
 
 $limit=25;
 
-$result = db_query_qpa ($qpa, $limit+1, $offset, SYS_DB_SEARCH);
+$result = db_query_qpa ($qpa, $limit+1, $offset, 'DB_SEARCH');
 $rows = $rows_returned = db_numrows($result);
 
 if (!$result || $rows < 1) {
         $no_rows = 1;
-        echo "<h2>".sprintf (_('No matches found for %1$s'),
-			     $gwords)."</h2>";
-        echo db_error();
+        echo "<h2>".sprintf (_('No matches found for “%s”'), $gwords)."</h2>";
+        echo db_error('DB_SEARCH');
 
 } else {
 
@@ -160,8 +159,7 @@ if (!$result || $rows < 1) {
                 $rows = $limit;
         }
 
-        echo "<h3>".sprintf (_('Search results for %1$s'),
-			     $gwords)."</h3><p>\n\n";
+        echo "<h3>".sprintf (_('Search results for “%s”'), $gwords)."</h3><p>\n\n";
 
         $title_arr = array();
         $title_arr[] = util_make_link ('/plugins/globalsearch/?gwords='.urlencode($gwords).'&amp;order=project_title&amp;gexact='.$gexact,
@@ -179,7 +177,7 @@ if (!$result || $rows < 1) {
                 } else {
                         $what = 'projects';
                 }
-                
+
                 print        "<tr ". $HTML->boxGetAltRowStyle($i)."><td><a href=\""
                         . db_result($result, $i, 'project_link')."\" target=\"blank\">"
                         . html_image("ic/msg.png","10","12",array("border"=>"0"))."&nbsp;"
@@ -226,5 +224,3 @@ $HTML->footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
