@@ -3,32 +3,33 @@
  * Copyright (c) Xerox Corporation, Codendi Team, 2001-2009. All rights reserved
  * Copyright (c) 2010 Alcatel-Lucent
  * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
- * This file is a part of Codendi.
+ * This file is a part of Fusionforge.
  *
- * Codendi is free software; you can redistribute it and/or modify
+ * Fusionforge is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * Codendi is distributed in the hope that it will be useful,
+ * Fusionforge is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Codendi. If not, see <http://www.gnu.org/licenses/>.
+ * along with Fusionforge. If not, see <http://www.gnu.org/licenses/>.
  */
 
-require_once('common/mvc/Views.class.php');
+require_once 'common/mvc/Views.class.php';
 /*require_once('common/include/HTTPRequest.class.php');
-  require_once('common/user/UserManager.class.php');
-  require_once('common/project/ProjectManager.class.php');*/
+  require_once 'common/user/UserManager.class.php';
+  require_once 'common/project/ProjectManager.class.php';*/
 //require_once('common/reference/CrossReferenceFactory.class.php');
 
-require_once('HudsonJob.class.php');
-require_once('common/dao/CodendiDataAccess.class.php');
-require_once('PluginHudsonJobDao.class.php');
+require_once 'HudsonJob.class.php';
+require_once 'common/dao/CodendiDataAccess.class.php';
+require_once 'PluginHudsonJobDao.class.php';
 
 class hudsonViews extends Views {
 
@@ -38,17 +39,17 @@ class hudsonViews extends Views {
 	}
 
 	function header() {
-		use_javascript('/scripts/prototype/prototype.js');
-		use_javascript('/scripts/scriptaculous/scriptaculous.js');
 
 		parent::header();
 //		echo $this->_getHelp();
 //		echo '<h1>'.$this->_getTitle().'</h1>';
 	}
+
 	function _getTitle() {
 //		return _("Continuous Integration");
 		return _("Hudson");
 	}
+
 	function _getHelp($section = '', $questionmark = false) {
 		if (trim($section) !== '' && $section{0} !== '#') {
 			$section = '#'.$section;
@@ -60,6 +61,7 @@ class hudsonViews extends Views {
 		}
 		return '<b><a href="javascript:help_window(\''.get_server_url().'help/guide/ContinuousIntegrationIntroduction.html'.$section.'\');">'.$help_label.'</a></b>';
 	}
+
 	function footer() {
 		parent::footer();
 	}
@@ -70,12 +72,11 @@ class hudsonViews extends Views {
 		$group_id = $request->get('group_id');
 		$user = UserManager::instance()->getCurrentUser();
 
-		$this->_display_jobs_table($group_id);       
+		$this->_display_jobs_table($group_id);
 		if ($user->isMember($request->get('group_id'), 'A')) {
 			$this->_display_add_job_form($group_id);
 		}
 		$this->_display_iframe();
-		$this->_hide_iframe();
 	}
 
 	function job_details() {
@@ -211,7 +212,7 @@ class hudsonViews extends Views {
 
 				echo '<a href="/plugins/hudson/?group_id='.$group_id.'">'._("Back to jobs list").'</a>';
 
-				echo '<h3>'._("Edit job").'</h3>';
+				echo '<h3>'._("Edit Job").'</h3>';
 				echo ' <form method="post">';
 				echo '  <p>';
 				echo '   <label for="new_hudson_job_url">'._("Job URL:").'</label>';
@@ -229,7 +230,9 @@ class hudsonViews extends Views {
 				echo '  </p>';
 				if ($project->usesService('svn')) {
 					echo '  <p>';
-					echo '   <label for="new_hudson_use_svn_trigger">'._("Trigger a build after SVN commits:").'</label>';
+					echo '   <label for="new_hudson_use_svn_trigger">';
+					echo sprintf(_("Trigger a build after %s commits:"), 'Subversion');
+					echo '</label>';
 					if ($row['use_svn_trigger'] == 1) {
 						$checked = ' checked="checked" ';
 					} else {
@@ -240,7 +243,9 @@ class hudsonViews extends Views {
 				}
 				if ($project->usesService('cvs')) {
 					echo '  <p>';
-					echo '   <label for="new_hudson_use_cvs_trigger">'._("Trigger a build after CVS commits:").'</label>';
+					echo '   <label for="new_hudson_use_cvs_trigger">';
+					echo sprintf(_("Trigger a build after %s commits:"), 'CVS');
+					echo '</label>';
 					if ($row['use_cvs_trigger'] == 1) {
 						$checked = ' checked="checked" ';
 					} else {
@@ -316,7 +321,7 @@ class hudsonViews extends Views {
 					$job = new HudsonJob($row['job_url']);
 
 					echo '  <td><img src="'.$job->getStatusIcon().'" alt="'.$job->getStatus().'" title="'.$job->getStatus().'" /></td>';
-					// function toggle_iframe is in script plugins/hudson/www/hudson_tab.js
+					// function toggle_iframe is in script plugins/hudson/www/scripts/hudson_tab.js
 					echo '  <td class="boxitem"><a href="'.$job->getUrl().'" onclick="toggle_iframe(this); return false;" title="'.vsprintf(_("Show job %s"),  array($row['name'])).'">'.$row['name'].'</a></td>';
 					if ($job->getLastSuccessfulBuildNumber() != '') {
 						echo '  <td><a href="'.$job->getLastSuccessfulBuildUrl().'" onclick="toggle_iframe(this); return false;" title="'.vsprintf(_("Show build #%s of job %s"),  array($job->getLastSuccessfulBuildNumber(), $row['name'])).'">'._("build").' #'.$job->getLastSuccessfulBuildNumber().'</a></td>';
@@ -375,9 +380,13 @@ class hudsonViews extends Views {
 				$dar->next();
 				$cpt++;
 			}
-			echo '</table>';   
+			echo '</table>';
 		} else {
-			echo '<p>'._("No Hudson jobs associated with this project. To add a job, select the link just below.").'</p>';
+			echo '<p>'._('No Hudson jobs associated with this project.');
+			if ($user->isMember($request->get('group_id'), 'A')) {
+				echo _('To add a job, select the link just below.');
+			}
+			echo '</p>';
 		}
 	}
 
@@ -385,13 +394,12 @@ class hudsonViews extends Views {
 		$project_manager = ProjectManager::instance();
 		$project = $project_manager->getProject($group_id);
 
-		// function toggle_addurlform is in script plugins/hudson/www/hudson_tab.js
-		echo '<a href="#" onclick="toggle_addurlform(); return false;">' . getIcon("ic/add.png") . ' '._("Add job").'</a>';
+		echo '<a href="#" onclick="jQuery(\'#hudson_add_job\').slideToggle(); return false;">' . getIcon("ic/add.png") . ' '._("Add job").'</a>';
 		echo ' '.$this->_getHelp('HudsonService', true);
-		echo '<div id="hudson_add_job">';
+		echo '<div id="hudson_add_job" style="display:none" >';
 		echo ' <form action="">'."\n";
 		echo '   <label for="hudson_job_url">'._("Job URL:").'</label>'."\n";
-		echo '   <input id="hudson_job_url" name="hudson_job_url" type="text" size="64" />'."\n";
+		echo '   <input id="hudson_job_url" name="hudson_job_url" type="url" size="64" placeholder="http://myCIserver/hudson/job/myJob" required="required" pattern="https?://.+" title="http[s]://myCIserver/hudson/job/myjob" />'."\n";
 		echo '   <input type="hidden" name="group_id" value="'.$group_id.'" />'."\n";
 		echo '   <input type="hidden" name="action" value="add_job" />'."\n";
 		echo '   <br />'."\n";
@@ -399,13 +407,13 @@ class hudsonViews extends Views {
 		echo '   <br />';
 		//echo '  <p>';
 		if ($project->usesService('svn')) {
-			echo _("Trigger a build after commits:");
+			echo sprintf(_("Trigger a build after %s commits:"), '');
 			if ($project->usesService('svn')) {
-				echo '   <label for="hudson_use_svn_trigger">'._("SVN").'</label>';
+				echo '   <label for="hudson_use_svn_trigger">Subversion</label>';
 				echo '   <input id="hudson_use_svn_trigger" name="hudson_use_svn_trigger" type="checkbox" />';
 			}
 			if ($project->usesService('cvs')) {
-				echo '   <label for="hudson_use_cvs_trigger">'._("CVS").'</label>';
+				echo '   <label for="hudson_use_cvs_trigger">CVS</label>';
 				echo '   <input id="hudson_use_cvs_trigger" name="hudson_use_cvs_trigger" type="checkbox" />';
 			}
 			//echo '  </p>';
@@ -418,18 +426,14 @@ class hudsonViews extends Views {
 		echo '   <input type="submit" value="Add job" />';
 		echo ' </form>';
 		echo '</div>';
-		echo "<script type=\"text/javascript\">Element.toggle('hudson_add_job', 'slide');</script>\n";
+		//echo "<script type=\"text/javascript\">jQuery('#hudson_add_job').slideToggle();</script>\n";
 	}
 
 	function _display_iframe($url = '') {
-		echo '<div id="hudson_iframe_div">';
-		htmlIframe($url, array('id' => 'hudson_iframe', 'class' => 'iframe_service'));
-		echo '</div>';
-	}
-	function _hide_iframe() {
-		echo "<script type=\"text/javascript\">Element.toggle('hudson_iframe_div', 'slide');</script>";
+		if (!empty($url)) {
+			echo '<div id="hudson_iframe_div">';
+			htmlIframe($url, array('id' => 'hudson_iframe', 'class' => 'iframe_service'));
+			echo '</div>';
+		}
 	}
 }
-
-
-?>
