@@ -7,13 +7,13 @@
  * The rest Copyright 2003-2004 (c) Guillaume Smet - Open Wide
  *
  * @version $Id$
- * 
+ *
  * Portions Copyright 2010 (c) Mélanie Le Bail
  */
-require_once ('env.inc.php');
+require_once 'env.inc.php';
 require_once 'pre.php';
 require_once 'preplugins.php';
-require_once('plugins_utils.php');
+require_once 'plugins_utils.php';
 require_once '../mailman_utils.php';
 
 $request =& HTTPRequest::instance();
@@ -35,7 +35,6 @@ if(isLogged()) {
 	}
 }
 
-
 $ml = new MailmanList($group_id,$request->get('id'));
 
 if ($request->exist('submit')) {
@@ -64,5 +63,3 @@ mailman_header(array(
 <?php
 
 mail_footer(array());
-
-?>
