@@ -7,7 +7,7 @@
  * The rest Copyright 2003-2004 (c) Guillaume Smet - Open Wide
  *
  * @version $Id$
- * 
+ *
  * Portions Copyright 2010 (c) Mélanie Le Bail
  */
 require_once 'env.inc.php';
@@ -31,10 +31,9 @@ $description=$request->get('description');
 $PHP_SELF = $request->get('PHP_SELF');
 $feedback = '';
 
-
 if ($group_id) {
 	if (!$Group || !is_object($Group) || $Group->isError()) {
-		
+
 		exit_no_group();
 	}
 
@@ -117,7 +116,11 @@ if ($group_id) {
 					'help'=>'CommunicationServices.html#MailingLists',
 					'admin' => '1'));
 		echo '<p>';
-		printf(_('Lists are named in this manner:<br /><strong>projectname-listname@%1$s</strong></p><p>It will take <span class="important">few minutes</span> for your list to be created.'), forge_get_config('lists_host'));
+		printf(_('Lists are named in this manner:<br /><strong>projectname-listname@%s</strong>'),
+				forge_get_config('lists_host'));
+		echo '</p>';
+		echo '<p>';
+		echo _('It will take <span class="important">few minutes</span> for your list to be created.');
 		echo '</p>';
 
 		$mlFactory = new MailmanListFactory($Group);
@@ -141,13 +144,13 @@ if ($group_id) {
 			<form method="post" action="<?php echo $PHP_SELF; ?>?group_id=<?php echo $group_id ?>">
 			<input type="hidden" name="post_changes" value="y" />
 			<input type="hidden" name="add_list" value="y" />
-			<p><strong><?php echo _('Mailing List Name:'); ?></strong><br />
+			<p><strong><?php echo _('Mailing List Name')._(':'); ?></strong><br />
 			<strong><?php echo $Group->getUnixName(); ?>-<input type="text" name="list_name" value="" size="10" maxlength="12" />@<?php echo forge_get_config('lists_host'); ?></strong><br /></p>
 			<p>
 			<strong><?php echo _('Is Public?'); ?></strong><br />
 			<input type="radio" name="is_public" value="1" checked="checked" /> <?php echo _('Yes'); ?><br />
 			<input type="radio" name="is_public" value="0" /> <?php echo _('No'); ?></p><p>
-			<strong><?php echo _('Description:'); ?></strong><br />
+			<strong><?php echo _('Description')._(':'); ?></strong><br />
 			<input type="text" name="description" value="" size="40" maxlength="80" /><br /></p>
 			<p>
 			<input type="submit" name="submit" value="<?php echo _('Add This List'); ?>" /></p>
@@ -180,7 +183,7 @@ if ($group_id) {
 			<input type="radio" name="is_public" value="1"<?php echo ($mailingList->isPublic() == 1 ? ' checked="checked"' : ''); ?> /> <?php echo _('Yes'); ?><br />
 			<input type="radio" name="is_public" value="0"<?php echo ($mailingList->isPublic() == 0 ? ' checked="checked"' : ''); ?> /> <?php echo _('No'); ?><br />
 			</p>
-			<p><strong><?php echo _('Description:'); ?></strong><br />
+			<p><strong><?php echo _('Description')._(':'); ?></strong><br />
 			<input type="text" name="description" value="<?php echo $mailingList->getDescription(); ?>" size="40" maxlength="80" /><br /></p>
 			<p>
 			<input type="submit" name="submit" value="<?php echo _('Update'); ?>" /></p>
@@ -210,7 +213,7 @@ if ($group_id) {
 			mail_footer(array());
 			exit;
 		}
-		echo '<p>'.sprintf(_('You can administrate lists from here. Please note that private lists can still be viewed by members of your project, but are not listed on %1$s.'), forge_get_config ('forge_name')).'</p>';
+		echo '<p>'.sprintf(_('You can administrate lists from here. Please note that private lists can still be viewed by members of your project, but are not listed on %s.'), forge_get_config ('forge_name')).'</p>';
 		echo '<ul>
 			<li>
 			<a href="'.$PHP_SELF.'?group_id='.$group_id.'&amp;add_list=1">'._('Add Mailing List').'</a>
@@ -233,4 +236,3 @@ if ($group_id) {
 } else {
         exit_no_group();
 }
-?>
