@@ -1,6 +1,6 @@
 #! /usr/bin/php
 <?php
-/* 
+/*
  * Copyright (C) 2010  Olaf Lenz
  *
  * This file is part of FusionForge.
@@ -43,13 +43,16 @@ foreach ($argv as $project) {
     system("rm -rf $project_dir");
   }
 
-  $schema = "plugin_mediawiki_$project";
-  strtr($schema, "-", "_");
+  $schema = strtr("plugin_mediawiki_$project", "-", "_");
   echo "  Dropping database schema $schema.\n";
   $res = db_query_params("DROP SCHEMA $schema CASCADE", array());
   if (!$res) {
     echo db_error();
   }
+  $res = db_query_params('DELETE FROM plugin_mediawiki_interwiki WHERE iw_prefix=$1', array($project));
+  if (!$res) {
+    echo db_error();
+  }
 }
 
   // Local Variables:
