@@ -1,6 +1,6 @@
 #! /usr/bin/php
 <?php
-/* 
+/*
  * Copyright (C) 2010  Olaf Lenz
  *
  * This file is part of FusionForge.
@@ -21,7 +21,7 @@
  */
 
   /** This script will set up the structure required to use the
-   mediawiki plugin. 
+   mediawiki plugin.
   */
 
 require_once dirname(__FILE__) . '/../../../www/env.inc.php';
@@ -37,11 +37,13 @@ $src_path = forge_get_config('src_path', 'mediawiki');
 if (!is_dir($projects_path)) {
 	echo "Creating $projects_path...\n";
 	mkdir($projects_path, 0755, true);
+	chmod($projects_path, 0755);
 }
 
 if (!is_dir($master_path)) {
 	echo "Creating $master_path...\n";
 	mkdir($master_path, 0755, true);
+	chmod($master_path, 0755);
 }
 
 function mysymlink($from, $to) {
@@ -54,14 +56,13 @@ function mysymlink($from, $to) {
 	}
 }
 
-
 # install links in master
 echo "Creating symlinks from $master_path to $src_path...\n";
 if (!($dh = opendir($src_path))) {
 	echo "Could not open mediawiki source directory $src_path!\n";
 } else {
-	$ignore_file = array( 
-		'.' => true, 
+	$ignore_file = array(
+		'.' => true,
 		'..' => true,
 		'config' => true,
 		'skins' => true,
@@ -70,7 +71,7 @@ if (!($dh = opendir($src_path))) {
 		't' => true,
 		);
 	while ($file = readdir($dh)) {
-		if (!$ignore_file[$file]) {
+		if (!isset($ignore_file[$file]) || !$ignore_file[$file]) {
 			$from = "$src_path/$file";
 			$to = "$master_path/$file";
 			mysymlink($from, $to);
@@ -108,15 +109,15 @@ $to = "$todir/fusionforge.css";
 mysymlink($from, $to);
 
 // link the rest of the files from monobook skin
-$fromdir = "$mediawiki_src_path/skins/monobook";
+$fromdir = "$src_path/skins/monobook";
 
 $dh = opendir($fromdir);
-$ignore_file = array( 
-	'.' => true, 
+$ignore_file = array(
+	'.' => true,
 	'..' => true,
 	);
 while ($file = readdir($dh)) {
-	if (!$ignore_file[$file]) {
+	if (!isset($ignore_file[$file]) || !$ignore_file[$file]) {
 		$from = "$fromdir/$file";
 		$to = "$todir/$file";
 		mysymlink($from, $to);
