@@ -1,5 +1,5 @@
 <?php
-/* 
+/*
  * Copyright (C) 2010 Roland Mas, Olaf Lenz
  *
  * This file is part of FusionForge.
@@ -23,15 +23,22 @@
  *  Mediawiki plugin of FusionForge.
  */
 
+/* C style inclusion guard. Yes, I know. Don’t comment on it. */
+if (!isset($fusionforge_plugin_mediawiki_LocalSettings_included)) {
+$fusionforge_plugin_mediawiki_LocalSettings_included = true;
+
 require_once dirname(__FILE__) . '/../../../www/env.inc.php';
 require_once $gfcommon.'include/pre.php';
+require_once $gfcommon.'include/RBACEngine.class.php';
 sysdebug_lazymode(true);
 
 $IP = forge_get_config('master_path', 'mediawiki');
 
 if (!isset ($fusionforgeproject)) {
-	$fusionforgeproject = 'siteadmin' ;
+	$gr=new Group(1);
+	$fusionforgeproject=$gr->getUnixName();
 }
+
 $exppath = explode ('/', $_SERVER['PHP_SELF']) ;
 
 # determine $fusionforgeproject from the URL
@@ -39,8 +46,11 @@ while (count ($exppath) >= 4) {
         if (($exppath[0] == 'plugins') &&
 	    ($exppath[1] == 'mediawiki') &&
 	    ($exppath[2] == 'wiki') &&
-	    (($exppath[4] == 'index.php') || ($exppath[4] == 'api.php'))
-	    ) {
+	    in_array($exppath[4], array(
+		'api.php',
+		'index.php',
+		'load.php',
+	    ))) {
                 $fusionforgeproject = $exppath[3] ;
                 break ;
         } else {
@@ -49,17 +59,18 @@ while (count ($exppath) >= 4) {
 }
 
 $gconfig_dir = forge_get_config('mwdata_path', 'mediawiki');
-$project_dir = forge_get_config('projects_path', 'mediawiki') . "/" 
+$project_dir = forge_get_config('projects_path', 'mediawiki') . "/"
 	. $fusionforgeproject ;
 
 if (!is_dir($project_dir)) {
-	exit_error (sprintf(_('Mediawiki for project %s not created yet, please wait for a few minutes.'), $fusionforgeproject)) ;
+	exit_error (sprintf(_('Mediawiki for project %s not created yet, please wait for a few minutes.'), $fusionforgeproject.':'.$project_dir) . "\n") ;
 }
 
-
 $path = array( $IP, "$IP/includes", "$IP/languages" );
 set_include_path( implode( PATH_SEPARATOR, $path ) . PATH_SEPARATOR . get_include_path() );
 
+require_once( "$IP/includes/AutoLoader.php" );
+require_once( "$IP/includes/Defines.php" );
 require_once( "$IP/includes/DefaultSettings.php" );
 
 if ( $wgCommandLineMode ) {
@@ -67,6 +78,7 @@ if ( $wgCommandLineMode ) {
                 die( "This script must be run from the command line\n" );
         }
 }
+
 $g = group_get_object_by_name($fusionforgeproject) ;
 $wgSitename         = $g->getPublicName() . " Wiki";
 $wgScriptPath       = "/plugins/mediawiki/wiki/$fusionforgeproject" ;
@@ -74,9 +86,15 @@ $wgScriptPath       = "/plugins/mediawiki/wiki/$fusionforgeproject" ;
 $wgEmergencyContact = forge_get_config('admin_email');
 $wgPasswordSender = forge_get_config('admin_email');
 
-$wgDBtype           = "postgres";
+$wgDBtype           = "forge";
 $wgDBserver         = forge_get_config('database_host') ;
-$wgDBname           = forge_get_config('database_name');
+if (forge_get_config('mw_dbtype', 'mediawiki')=='mysql'){
+	// At the time writing schema in mysql is synonym for database
+	$wgDBname           = 'plugin_mediawiki_'.$fusionforgeproject;
+	$wgDBprefix         = 'mw';
+} else {
+	$wgDBname           = forge_get_config('database_name');
+}
 $wgDBuser           = forge_get_config('database_user') ;
 $wgDBpassword       = forge_get_config('database_password') ;
 $wgDBadminuser           = forge_get_config('database_user') ;
@@ -97,6 +115,25 @@ $wgShowExceptionDetails = true ;
 $wgLanguageCode = strtolower(forge_get_config('default_country_code'));
 
 $wgDefaultSkin = 'fusionforge';
+$wgHtml5 = false;
+$wgWellFormedXml = true;
+
+/* DEBUG
+$wgDebugLogFile         = '/tmp/wiki.log';
+$wgDebugLogPrefix       = '';
+$wgDebugRedirects       = true;
+$wgDebugRawPage         = true;
+$wgDebugComments        = true;
+$wgLogQueries           = true;
+$wgDebugDumpSql         = true;
+$wgDebugLogGroups       = array();
+$wgShowDebug            = true;
+$wgSpecialVersionShowHooks =  true;
+$wgShowSQLErrors        = true;
+$wgColorErrors          = true;
+$wgShowExceptionDetails = true;
+$wgShowHostnames = true;
+*/
 
 $GLOBALS['sys_dbhost'] = forge_get_config('database_host') ;
 $GLOBALS['sys_dbport'] = forge_get_config('database_port') ;
@@ -117,6 +154,14 @@ $GLOBALS['sys_session_expire'] = forge_get_config('session_expire');
 $GLOBALS['REMOTE_ADDR'] = getStringFromServer('REMOTE_ADDR') ;
 $GLOBALS['HTTP_USER_AGENT'] = getStringFromServer('HTTP_USER_AGENT') ;
 
+require_once("$IP/includes/Exception.php");
+require_once("$IP/includes/db/Database.php");
+if (forge_get_config('mw_dbtype', 'mediawiki')=='mysql'){
+	require_once 'DatabaseForgeMysql.php';
+}else{
+	require_once 'DatabaseForgePgsql.php';
+}
+
 function FusionForgeRoleToMediawikiGroupName ($role, $project) {
 	if ($role instanceof RoleAnonymous) {
 		return '*';
@@ -138,14 +183,10 @@ function FusionForgeRoleToMediawikiGroupName ($role, $project) {
 function FusionForgeMWAuth( $user, &$result ) {
 	global $fusionforgeproject, $wgGroupPermissions ;
 
-	$cookie = getStringFromCookie ('session_ser') ;
-        if ($cookie != '') {
-                $s = session_check_session_cookie ($cookie);
-        } else {
-                $s = false ;
-        }
-        if ($s) {
-                $u = user_get_object ($s);
+	session_set();
+
+        if (session_loggedin()) {
+                $u = session_get_user();
 		$g = group_get_object_by_name ($fusionforgeproject) ;
 
                 $mwname = ucfirst($u->getUnixName ()) ;
@@ -160,29 +201,26 @@ function FusionForgeMWAuth( $user, &$result ) {
                 $user->mId=$mwu->getID();
                 $user->loadFromId() ;
 
-		$user->loadGroups() ;
 		$current_groups = $user->getGroups() ;
 
-		if (USE_PFO_RBAC) {
-			$available_roles = RBACEngine::getInstance()->getAvailableRoles() ;
-			$rs = array () ;
-			foreach ($available_roles as $r) {
-				$linked_projects = $r->getLinkedProjects () ;
+		$available_roles = RBACEngine::getInstance()->getAvailableRoles() ;
+		$rs = array () ;
+		foreach ($available_roles as $r) {
+			$linked_projects = $r->getLinkedProjects () ;
 
-				foreach ($linked_projects as $lp) {
-					if ($lp->getID() == $g->getID()) {
-						$rs[] = $r ;
-					}
+			if ($r->hasGlobalPermission('forge_admin')) {
+				$rs[] = $r ;
+				continue ;
+			}
+
+			foreach ($linked_projects as $lp) {
+				if ($lp->getID() == $g->getID()) {
+					$rs[] = $r ;
+					continue ;
 				}
 			}
-		} else {
-			$perm =& $g->getPermission ();
-			$r = $u->getRole($g) ;
-			if (isset ($r) && $r && !$r->isError()) {
-				$rs = array ($r) ;
-			}
 		}
-		
+
 		// Sync MW groups for current user with FF roles
 		$rnames = array () ;
 		foreach ($rs as $r) {
@@ -217,13 +255,24 @@ function SetupPermissionsFromRoles () {
 
 	$g = group_get_object_by_name ($fusionforgeproject) ;
 	// Setup rights for all roles referenced by project
-	$rs = $g->getRoles() ;
+	$rids = $g->getRolesID() ;
+	$e = RBACEngine::getInstance();
+	$grs = $e->getGlobalRoles();
+	foreach ($grs as $r) {
+		$rids[] = $r->getID();
+	}
+	$rids = array_unique($rids);
+	$rs = array();
+	foreach ($rids as $rid) {
+		$rs[] = $e->getRoleById($rid);
+	}
+
 	foreach ($rs as $r) {
 		$gr = FusionForgeRoleToMediawikiGroupName ($r, $g) ;
-		
+
 		// Read access
 		$wgGroupPermissions[$gr]['read'] = $r->hasPermission ('plugin_mediawiki_read', $g->getID()) ;
-		
+
 		// Day-to-day edit privileges
 		$wgGroupPermissions[$gr]['edit']               = $r->hasPermission ('plugin_mediawiki_edit', $g->getID(), 'editexisting') ;
 		$wgGroupPermissions[$gr]['writeapi']           = $r->hasPermission ('plugin_mediawiki_edit', $g->getID(), 'editexisting') ;
@@ -235,25 +284,20 @@ function SetupPermissionsFromRoles () {
 		$wgGroupPermissions[$gr]['move-rootuserpages'] = $r->hasPermission ('plugin_mediawiki_edit', $g->getID(), 'editmove') ;
 		$wgGroupPermissions[$gr]['delete']             = $r->hasPermission ('plugin_mediawiki_edit', $g->getID(), 'editmove') ;
 		$wgGroupPermissions[$gr]['undelete']           = $r->hasPermission ('plugin_mediawiki_edit', $g->getID(), 'editmove') ;
-		
+
 		// File upload privileges
 		$wgGroupPermissions[$gr]['upload']          = $r->hasPermission ('plugin_mediawiki_upload', $g->getID(), 'upload') ;
 		$wgGroupPermissions[$gr]['reupload-own']    = $r->hasPermission ('plugin_mediawiki_upload', $g->getID(), 'upload') ;
 		$wgGroupPermissions[$gr]['reupload']        = $r->hasPermission ('plugin_mediawiki_upload', $g->getID(), 'reupload') ;
 		$wgGroupPermissions[$gr]['reupload-shared'] = $r->hasPermission ('plugin_mediawiki_upload', $g->getID(), 'reupload') ;
 		$wgGroupPermissions[$gr]['upload_by_url']   = $r->hasPermission ('plugin_mediawiki_upload', $g->getID(), 'reupload') ;
-		
+
 		// Administrative tasks
 		$wgGroupPermissions[$gr]['editinterface'] = $r->hasPermission ('plugin_mediawiki_admin', $g->getID()) ;
 		$wgGroupPermissions[$gr]['import']        = $r->hasPermission ('plugin_mediawiki_admin', $g->getID()) ;
 		$wgGroupPermissions[$gr]['importupload']  = $r->hasPermission ('plugin_mediawiki_admin', $g->getID()) ;
 		$wgGroupPermissions[$gr]['siteadmin']     = $r->hasPermission ('plugin_mediawiki_admin', $g->getID()) ;
-	}	
 
-	$rs = RBACEngine::getInstance()->getGlobalRoles();
-	foreach ($rs as $r) {
-		$gr = FusionForgeRoleToMediawikiGroupName ($r, $g) ;
-		
 		// Interwiki management restricted to forge admins
 		$wgGroupPermissions[$gr]['interwiki'] = $r->hasGlobalPermission ('forge_admin') ;
 	}
@@ -273,7 +317,7 @@ if (isset($_SERVER['SERVER_SOFTWARE'])) {
 		var $dstappendself = false;
 
 		function getTitle($subpage="") {
-			return 'SpecialForgeRedir';
+			return $this;
 		}
 
 		function getRedirect($subpage="") {
@@ -334,6 +378,9 @@ SetupPermissionsFromRoles();
 
 $wgFavicon = '/images/icon.png' ;
 $wgBreakFrames = false ;
+if (forge_get_config('unbreak_frames', 'mediawiki')) {
+	$wgEditPageFrameOptions = false;
+}
 ini_set ('memory_limit', '100M') ;
 
 // LOAD THE SITE-WIDE AND PROJECT-SPECIFIC EXTRA-SETTINGS
@@ -343,7 +390,7 @@ if (is_file(forge_get_config('config_path')."/plugins/mediawiki/LocalSettings.ph
 
 // debian style system-wide mediawiki extensions
 if (is_file("/etc/mediawiki-extensions/extensions.php")) {
-        include( "/etc/mediawiki-extensions/extensions.php" );
+        include '/etc/mediawiki-extensions/extensions.php';
 }
 
 if (file_exists("$wgUploadDirectory/.wgLogo.png")) {
@@ -363,3 +410,6 @@ if (is_file("$project_dir/ProjectSettings.php")) {
 // mode: php
 // c-file-style: "bsd"
 // End:
+
+/* !isset($fusionforge_plugin_mediawiki_LocalSettings_included) */
+}
