@@ -8,7 +8,7 @@
  *
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 
 $group_id = getIntFromRequest('group_id');
@@ -32,7 +32,7 @@ $params['sectionvals'] = array ($group->getPublicName());
 
 site_project_header($params);
 
-if (file_exists ('/var/lib/gforge/plugins/mediawiki/wikidata/'.$group->getUnixName().'/LocalSettings.php')) {
+if (file_exists (forge_get_config('data_path').'/plugins/mediawiki/wikidata/'.$group->getUnixName().'/LocalSettings.php')) {
 	echo '<iframe src="'.util_make_url('/plugins/mediawiki/wiki/'.$group->getUnixName().'/index.php').'" frameborder="0" width=100% height=700></iframe>' ;
 } else {
 	print '<h2>'._('Wiki not created yet, please wait for a few minutes.').'</h2>';
@@ -44,5 +44,3 @@ site_project_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
