@@ -21,6 +21,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+require_once 'common/include/rdfutils.php';
+
 class oslcPlugin extends Plugin {
 	public function __construct($id=0) {
 		$this->Plugin($id) ;
@@ -34,8 +36,7 @@ class oslcPlugin extends Plugin {
 		$this->_addHook("userisactivecheckbox"); // The "use ..." checkbox in user account
 		$this->_addHook("userisactivecheckboxpost"); //
 		$this->_addHook("project_admin_plugins"); // to show up in the admin page fro group
-		$this->_addHook("user_link_with_tooltip"); 
-		$this->_addHook("javascript_file"); // Add js files for oslc plugin
+		$this->_addHook("project_rdf_metadata"); // will provide some RDF metadata for the project's DOAP profile to 'doaprdf' plugin
 	}
 
 	function CallHook ($hookname, &$params) {
@@ -44,12 +45,12 @@ class oslcPlugin extends Plugin {
 			$text = $this->text; // this is what shows in the tab
 			if ($G_SESSION->usesPlugin("oslc")) {
 				$param = '?type=user&id=' . $G_SESSION->getId() . "&pluginname=" . $this->name; // we indicate the part we're calling is the user one
-				echo ' | ' . $HTML->PrintSubMenu (array ($text),
-						  array ('/plugins/oslc/index.php' . $param ));				
+				echo $HTML->PrintSubMenu (array ($text),
+						  array ('/plugins/oslc/index.php' . $param ));
 			}
 		} elseif ($hookname == "groupmenu") {
 			$group_id=$params['group'];
-			$project = &group_get_object($group_id);
+			$project = group_get_object($group_id);
 			if (!$project || !is_object($project)) {
 				return;
 			}
@@ -62,16 +63,18 @@ class oslcPlugin extends Plugin {
 			if ( $project->usesPlugin ( $this->name ) ) {
 				$params['TITLES'][]=$this->text;
 				$params['DIRS'][]=util_make_uri('/plugins/oslc/');
+				$params['ADMIN'][]='';
 			} else {
 				$params['TITLES'][]=$this->text." is [Off]";
 				$params['DIRS'][]='';
-			}	
+				$params['ADMIN'][]='';
+			}
 			(($params['toptab'] == $this->name) ? $params['selected']=(count($params['TITLES'])-1) : '' );
 		} elseif ($hookname == "groupisactivecheckbox") {
 			//Check if the group is active
 			// this code creates the checkbox in the project edit public info page to activate/deactivate the plugin
 			$group_id=$params['group'];
-			$group = &group_get_object($group_id);
+			$group = group_get_object($group_id);
 			echo "<tr>";
 			echo "<td>";
 			echo ' <input type="checkbox" name="use_oslcplugin" value="1" ';
@@ -88,7 +91,7 @@ class oslcPlugin extends Plugin {
 		} elseif ($hookname == "groupisactivecheckboxpost") {
 			// this code actually activates/deactivates the plugin after the form was submitted in the project edit public info page
 			$group_id=$params['group'];
-			$group = &group_get_object($group_id);
+			$group = group_get_object($group_id);
 			$use_oslcplugin = getStringFromRequest('use_oslcplugin');
 			if ( $use_oslcplugin == 1 ) {
 				$group->setPluginUse ( $this->name );
@@ -144,23 +147,33 @@ class oslcPlugin extends Plugin {
 		} elseif ($hookname == "project_admin_plugins") {
 			// this displays the link in the project admin options page to it's  oslc administration
 			$group_id = $params['group_id'];
-			$group = &group_get_object($group_id);
+			$group = group_get_object($group_id);
 			if ( $group->usesPlugin ( $this->name ) ) {
 				echo '<p>'.util_make_link ("/plugins/oslc/admin/index.php?id=".$group->getID().'&type=admin&pluginname='.$this->name,
 						     _('oslc Admin')).'</p>' ;
 			}
 		}
-		elseif ($hookname == "user_link_with_tooltip"){
-			require_once dirname( __FILE__ ).'/CompactRessource.class.php';
-			$CR = new CompactRessource($params);
-			$params['user_link'] = $CR->compactUserLink($params['username'], $params['user_id']);
-		}
-		elseif ($hookname == "javascript_file") {
-			echo '<script type="text/javascript" src="/plugins/oslc/scripts/pluginOSLCHoverScripts.js"></script>'."\n";
+		elseif($hookname == "project_rdf_metadata") {
+
+			# TODO : create another resource
+			$group_id=$params['group'];
+
+			if (! isset($params['prefixes']['oslc'])) {
+				$params['prefixes']['oslc'] = 'http://open-services.net/ns/core#';
+			}
+
+			$serviceprovider = util_make_url ("/plugins/oslc/cm/oslc-cm-services/".$group_id);
+
+			$res = $params['in_Resource'];
+
+			rdfutils_setPropToUri($res, 'oslc:serviceProvider', $serviceprovider);
+
+			$params['out_Resources'][] = $res;
+
 		}
 		elseif ($hookname == "blahblahblah") {
 			// ...
-		} 
+		}
 	}
 }
 
@@ -168,5 +181,3 @@ class oslcPlugin extends Plugin {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
