@@ -5,19 +5,19 @@ class ProjectLabelsPlugin extends Plugin {
 		$this->Plugin() ;
 		$this->name = "projectlabels" ;
 		$this->text = "Project labels";
-		$this->hooks[] = "project_before_description" ;
+		$this->hooks[] = "project_before_widgets" ;
 		$this->hooks[] = "site_admin_option_hook" ;
 	}
 
 	function CallHook ($hookname, &$params) {
 		global $HTML;
-		
+
 		if ($hookname == "site_admin_option_hook") {
 			echo '<li>' . util_make_link ('/plugins/projectlabels/index.php',
-						      _('Project labels')) . '</li>';
-		} elseif ($hookname == "project_before_description") {
+						      _('Project labels'). ' [' . _('Project labels plugin') . ']') . '</li>';
+		} elseif ($hookname == "project_before_widgets") {
 			$group_id=$params['group_id'];
-			$project = &group_get_object($group_id);
+			$project = group_get_object($group_id);
 			if (!$project || !is_object($project))
 				return;
 			if ($project->isError())
@@ -38,5 +38,3 @@ class ProjectLabelsPlugin extends Plugin {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
