@@ -15,7 +15,7 @@ $func = getStringFromRequest ('func') ;
 
 if ($func == 'addlabel') {
 	$label_name = addslashes (getStringFromRequest ('label_name')) ;
-	$label_text = addslashes (getStringFromRequest ('label_text')) ;
+	$label_text = getStringFromRequest ('label_text') ;
 	$res = db_query_params ('INSERT INTO plugin_projectlabels_labels (label_name, label_text)
                          VALUES($1,$2)',
 			array($label_name,
@@ -27,7 +27,7 @@ if ($func == 'addlabel') {
 	} else {
 		echo _('Project label added.');
 	}
-	
+
 }
 if ($func == 'delete') {
 	db_begin () ;
@@ -42,7 +42,7 @@ if ($func == 'delete') {
 	} else {
 		$res = db_query_params ('DELETE FROM plugin_projectlabels_labels WHERE label_id=$1',
 			array($label_id));
-		
+
 		if (!$res) {
 			printf (_('Cannot delete label: %s'),
 				db_error()) ;
@@ -64,7 +64,7 @@ if ($func == 'addlabeltoproject') {
 		$res = db_query_params ('INSERT INTO plugin_projectlabels_group_labels (label_id, group_id) VALUES ($1, $2)',
 					array ($label_id,
 					       $g->getID()));
-		
+
 		if (!$res || db_affected_rows($res) < 1) {
 			printf (_('Cannot add label onto project: %s'),
 				db_error()) ;
@@ -74,7 +74,7 @@ if ($func == 'addlabeltoproject') {
 	} else {
 		echo _('No such project.') ;
 	}
-	
+
 }
 if ($func == 'removelabelfromproject') {
 	$label_id = getIntFromRequest ('label_id', 0) ;
@@ -88,12 +88,12 @@ if ($func == 'removelabelfromproject') {
 	} else {
 		echo _('The label has been removed from the project.') ;
 	}
-	
+
 }
 if ($func == 'editlabel') {
 	$label_id = getIntFromRequest ('label_id', 0) ;
 	$label_name = addslashes (getStringFromRequest ('label_name')) ;
-	$label_text = addslashes (getStringFromRequest ('label_text')) ;
+	$label_text = getStringFromRequest ('label_text') ;
 	$res = db_query_params ('UPDATE plugin_projectlabels_labels SET label_name = $1, label_text = $2
 		         WHERE label_id=$3',
 			array($label_name,
@@ -118,11 +118,11 @@ if ($func == 'edit') {
 <input type="hidden" name="label_id" value="<?php echo $label_id ?>" />
 <?php echo utils_requiredField(); ?>
 	 <?php echo _('Label name:') ; ?><br/>
-<input type="text" size="15" maxlength="32" name="label_name" value="<?php echo stripslashes ($row['label_name']) ; ?>"/> <br/>
+<input type="text" required="required" size="15" maxlength="32" name="label_name" value="<?php echo stripslashes ($row['label_name']) ; ?>"/> <br/>
 						  <?php echo _('Displayed text (or HTML) for the label:') ; ?><br/>
 <textarea tabindex='1' accesskey="," name="label_text" rows='5'
-														       cols='80'><?php echo stripslashes($row['label_text']) ; ?></textarea><br/>
-																							   <?php echo _('This label currently looks like this:') ." " . stripslashes($row['label_text']) ; ?>
+														       cols='80'><?php echo $row['label_text'] ; ?></textarea><br/>
+																							   <?php echo _('This label currently looks like this:') ." " . $row['label_text'] ; ?>
 <input type="submit" value="<?php echo _('Save this label') ?>" />
 </form>
 <?php
@@ -130,7 +130,7 @@ if ($func == 'edit') {
 ?>
 
 <p>
-<?php 
+<?php
 
 $res = db_query_params ('SELECT label_id, label_name, label_text FROM plugin_projectlabels_labels
 		 ORDER BY label_name ASC',
@@ -143,8 +143,8 @@ if (db_numrows($res) >= 1) {
 	while ($row = db_fetch_array($res)) {
 		echo "<h3>".stripslashes ($row['label_name'])."</h3>" ;
 		echo "<br />" . _('This label currently looks like this:') ." ";
-		echo stripslashes ($row['label_text']) . "<br />" ;
-		
+		echo $row['label_text'] . "<br />" ;
+
 		$res2 = db_query_params ('SELECT groups.unix_group_name, groups.group_name, groups.group_id FROM groups, plugin_projectlabels_group_labels
                  WHERE plugin_projectlabels_group_labels.group_id = groups.group_id
                  AND plugin_projectlabels_group_labels.label_id=$1
@@ -154,7 +154,7 @@ if (db_numrows($res) >= 1) {
 			echo ngettext ('This label is used on the following group:',
 				       'This label is used on the following groups:',
 				       db_numrows ($res2)) ;
-				       
+
 			echo "<br />";
 			while ($row2 = db_fetch_array($res2)) {
 				printf ('%1$s (%2$s)',
@@ -169,7 +169,7 @@ if (db_numrows($res) >= 1) {
 		}
 		?>
 <form name="addlabeltoproject" method="post" action="<?php echo util_make_url ('/plugins/projectlabels/') ; ?>">
-	 <?php echo _('Unix name of the project:') . " " ; ?>
+	 <?php echo _('Project Unix Name')._(': '); ?>
 <input type=text name=group_uname>
 <input type="hidden" name="func" value="addlabeltoproject">
 <input type="submit" value="<?php echo _('Add label to project') ?>">
@@ -185,7 +185,7 @@ if (db_numrows($res) >= 1) {
 ?>
 </p>
 
-		  <p><?php 
+		  <p><?php
 
 		  echo "<h2>"._('Add new labels')."</h2>" ;
 		  echo _('You can create new labels with the form below.') ?></p>
@@ -195,7 +195,7 @@ if (db_numrows($res) >= 1) {
 <input type="hidden" name="func" value="addlabel" />
 <?php echo utils_requiredField(); ?>
 		  <?php echo _('Name of the label:') ; ?><br/>
-<input type="text" size="15" maxlength="32" name="label_name" value="<?php echo _('potm') ; ?>"/> <br/>
+<input type="text" required="required" size="15" maxlength="32" name="label_name" value="<?php echo _('potm') ; ?>"/> <br/>
 		  <?php echo _('Displayed text (or HTML) for the label:') ; ?><br/>
 <textarea tabindex='1' accesskey="," name="label_text" rows='5'
 		  cols='80'><p><b><?php echo _('Project of the month!') ; ?></b></p>
@@ -211,5 +211,3 @@ site_admin_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
