@@ -2,8 +2,9 @@
 /**
  * Project Admin page to manage quotas disk and database
  *
- * 
- * Fabio Bertagnin November 2005
+ * Copyright 2005, Fabio Bertagnin
+ * Copyright 2011, Franck Villaume - Capgemini
+ * http://fusionforge.org
  *
  * This file is part of FusionForge.
  *
@@ -22,15 +23,17 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
+require_once dirname(__FILE__)."/../../env.inc.php";
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'admin/admin_utils.php';
 
+$quota_management = plugin_get_object('quota_management');
+
 $_quota_block_size = 1024;
 $_quota_block_size = trim(shell_exec("echo $BLOCK_SIZE")) + 0;
 if ($_quota_block_size == 0) $_quota_block_size = 1024;
 
-site_admin_header(array('title'=>_('Site admin')));
+site_admin_header(array('title'=>_('Site Admin')));
 ?>
 <h4>
 	<?php echo _('Ressources usage and quota'); ?>
@@ -42,12 +45,10 @@ site_admin_header(array('title'=>_('Site admin')));
 $quotas = array();
 
 // all projects list
-$res_db = db_query_params ('SELECT group_id, group_name, unix_group_name, quota_soft, quota_hard FROM groups ORDER BY group_id ',
-			array ());
-if (db_numrows($res_db) > 0) 
-{
-	while($e = db_fetch_array($res_db))
-	{
+$res_db = db_query_params('SELECT group_id, group_name, unix_group_name, quota_soft, quota_hard FROM groups ORDER BY group_id ',
+			array());
+if (db_numrows($res_db) > 0) {
+	while($e = db_fetch_array($res_db)) {
 		$quotas["$e[group_id]"]["group_id"] = $e["group_id"];
 		$quotas["$e[group_id]"]["name"] = $e["group_name"];
 		$quotas["$e[group_id]"]["unix_name"] = $e["unix_group_name"];
@@ -61,40 +62,31 @@ if (db_numrows($res_db) > 0)
 }
 
 // documents database size
-$res_db = db_query_params ('SELECT group_id, SUM(octet_length(data)) as size, SUM(octet_length(data_words)) as size1 FROM doc_data GROUP BY group_id ',
-			array ());
-if (db_numrows($res_db) > 0) 
-{
-	while($e = db_fetch_array($res_db))
-	{
+$res_db = db_query_params('SELECT group_id, SUM(octet_length(data)) as size, SUM(octet_length(data_words)) as size1 FROM doc_data GROUP BY group_id ',
+			array());
+if (db_numrows($res_db) > 0) {
+	while($e = db_fetch_array($res_db)) {
 		$q = array();
-		print_debug("doc grp=$e[group_id] size=$e[size]");
 		$quotas["$e[group_id]"]["database_size"] += $e["size"];
 		$quotas["$e[group_id]"]["database_size"] += $e["size1"];
 	}
 }
 
 // news database size
-$res_db = db_query_params ('SELECT group_id, SUM(octet_length(summary) + octet_length(details)) as size FROM news_bytes GROUP BY group_id',
-			array ());
-if (db_numrows($res_db) > 0) 
-{
-	while($e = db_fetch_array($res_db))
-	{
-		print_debug("news grp=$e[group_id] size=$e[size]");
+$res_db = db_query_params('SELECT group_id, SUM(octet_length(summary) + octet_length(details)) as size FROM news_bytes GROUP BY group_id',
+			array());
+if (db_numrows($res_db) > 0) {
+	while($e = db_fetch_array($res_db)) {
 		$quotas["$e[group_id]"]["database_size"] += $e["size"];
 	}
 }
 
 // forums database size
-$res_db = db_query_params ('SELECT forum_group_list.group_id as group_id, SUM(octet_length(subject)+octet_length(body)) as size FROM forum INNER JOIN forum_group_list ON forum.group_forum_id = forum_group_list.group_forum_id GROUP BY group_id',
+$res_db = db_query_params('SELECT forum_group_list.group_id as group_id, SUM(octet_length(subject)+octet_length(body)) as size FROM forum INNER JOIN forum_group_list ON forum.group_forum_id = forum_group_list.group_forum_id GROUP BY group_id',
 			array ());
-if (db_numrows($res_db) > 0) 
-{
-	while($e = db_fetch_array($res_db))
-	{
-		print_debug("forum grp=$e[group_id] size=$e[size]");
-		$quotas["$e[group_id]"]["database_size"] += convert_bytes_to_mega($e["size"]);
+if (db_numrows($res_db) > 0) {
+	while($e = db_fetch_array($res_db)) {
+		$quotas["$e[group_id]"]["database_size"] += $quota_management->convert_bytes_to_mega($e["size"]);
 	}
 }
 
@@ -106,48 +98,40 @@ $group_dir = $chroot_dir.forge_get_config('groupdir_prefix')."/";
 $cvs_dir = $chroot_dir.$cvsdir_prefix."/";
 $svn_dir = $chroot_dir.$svndir_prefix."/";
 
-
-foreach ($quotas as $p)
-{
+foreach ($quotas as $p) {
 	$group_id = $p["group_id"];
 	// upload dir disk space
-	$dir = $upload_dir .  $p["unix_name"];
-	$size = get_dir_size($dir);
+	$dir = $upload_dir.$p["unix_name"];
+	$size = $quota_management->get_dir_size($dir);
 	$quotas["$group_id"]["disk_size_other"] += $size;
-	print_debug("upload=$dir size=$size");
 	// ftp dir disk space
-	$dir = $ftp_dir .  $p["unix_name"];
-	$size = get_dir_size($dir);
+	$dir = $ftp_dir.$p["unix_name"];
+	$size = $quota_management->get_dir_size($dir);
 	$quotas["$group_id"]["disk_size_1"] += $size;
-	print_debug("ftp=$dir size=$size");
 	// home dir disk space
-	$dir = $group_dir .  $p["unix_name"];
-	$size = get_dir_size($dir);
+	$dir = $group_dir.$p["unix_name"];
+	$size = $quota_management->get_dir_size($dir);
 	$quotas["$group_id"]["disk_size_1"] += $size;
-	print_debug("home=$dir size=$size");
 	// cvs dir disk space
-	$dir = $cvs_dir .  $p["unix_name"];
-	$size = get_dir_size($dir);
+	$dir = $cvs_dir.$p["unix_name"];
+	$size = $quota_management->get_dir_size($dir);
 	$quotas["$group_id"]["disk_size_scm"] += $size;
-	print_debug("cvs=$dir size=$size");
 	// svn dir disk space
-	$dir = $svn_dir .  $p["unix_name"];
-	$size = get_dir_size($dir);
+	$dir = $svn_dir.$p["unix_name"];
+	$size = $quota_management->get_dir_size($dir);
 	$quotas["$group_id"]["disk_size_scm"] += $size;
-	print_debug("svn=$dir size=$size");
 }
 
 // users disk space size
 $chroot_dir = forge_get_config('chroot');
 $ftp_dir = $chroot_dir."/home/users/";
 $users = array();
-$res_db = db_query_params ('SELECT user_id, user_name, realname, unix_status FROM users ORDER BY user_id ',
-			array ());
-if (db_numrows($res_db) > 0) 
+$res_db = db_query_params('SELECT user_id, user_name, realname, unix_status FROM users ORDER BY user_id ',
+			array());
+if (db_numrows($res_db) > 0)
 {
 	while($e = db_fetch_array($res_db))
 	{
-		print_debug("users name=$e[user_name] status=$e[unix_status]");
 		if ($e["unix_status"] != "N")
 		{
 			$users["$e[user_id]"]["user_id"] = $e["user_id"];
@@ -160,12 +144,10 @@ if (db_numrows($res_db) > 0)
 }
 foreach ($users as $u)
 {
-	print_debug("---------------------------------------");
 	$user_id = $u["user_id"];
 	$dir = $ftp_dir .  $u["user_name"];
-	$size = get_dir_size($dir);
-	$users["$user_id"]["disk_size"] += convert_bytes_to_mega($size);
-	print_debug("$user_id user=$u[user_name] dir=$dir size=$size");
+	$size = $quota_management->get_dir_size($dir);
+	$users["$user_id"]["disk_size"] += $quota_management->convert_bytes_to_mega($size);
 }
 
 ?>
@@ -177,13 +159,13 @@ foreach ($users as $u)
 		<td style="border-top:thick solid #808080" colspan="7">
 			<span style="font-size:10px">
 				(&nbsp;
-				<?php echo _('project'); ?>* : 
-				<?php echo _('Ftp, Home'); ?>
+				<?php echo _('project'); ?>* :
+				<?php echo 'FTP, ' . _('Home'); ?>
 				&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
-				<?php echo _('scm'); ?>* : 
-				<?php echo _('Cvs, Svn'); ?>
+				<?php echo _('SCM'); ?>* :
+				<?php echo 'CVS, Subversion'; ?>
 				&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
-				<?php echo _('others'); ?>* : 
+				<?php echo _('others'); ?>* :
 				<?php echo _('Download - without quota control'); ?>
 				&nbsp;)
 			</span>
@@ -204,7 +186,7 @@ foreach ($users as $u)
 			<?php echo _('project'); ?>*
 		</td>
 		<td style="border-top:thin solid #808080;background:#e0e0e0" align="right">
-			<?php echo _('scm'); ?>*
+			<?php echo _('SCM'); ?>*
 		</td>
 		<td style="border-top:thin solid #808080;background:#e0e0e0" align="right">
 			<?php echo _('others'); ?>*
@@ -222,6 +204,9 @@ foreach ($users as $u)
 	<?php
 	$total_database = 0;
 	$total_disk = 0;
+	$total_disk_1 = 0;
+	$total_disk_other = 0;
+	$total_disk_scm = 0;
 	foreach ($quotas as $q)
 	{
 		$total_database += $q["database_size"];
@@ -234,7 +219,7 @@ foreach ($users as $u)
 		$color2 = "#ffffff";
 		$color0 = $color1;
 		$colorq = $color2;
-		if ($q["quota_soft"] > 0) 
+		if ($q["quota_soft"] > 0)
 		{
 			$color0 = "#E5ECB1";
 			$colorq = $color0;
@@ -259,32 +244,32 @@ foreach ($users as $u)
 				<?php echo $q["name"]; ?>
 			</td>
 			<td style="border-top:thin solid #808080;background:<?php echo $color1; ?>" align="right">
-				<?php echo add_numbers_separator(convert_bytes_to_mega($q["database_size"])); ?>
-				<?php echo _('Mb'); ?>
+				<?php echo $quota_management->add_numbers_separator($quota_management->convert_bytes_to_mega($q["database_size"])); ?>
+				<?php echo _('MB'); ?>
 			</td>
 			<td style="border-top:thin solid #808080;background:<?php echo $color0; ?>" align="right">
-				<?php echo add_numbers_separator(convert_bytes_to_mega($q["disk_size_1"])); ?>
-				<?php echo _('Mb'); ?>
+				<?php echo $quota_management->add_numbers_separator($quota_management->convert_bytes_to_mega($q["disk_size_1"])); ?>
+				<?php echo _('MB'); ?>
 			</td>
 			<td style="border-top:thin solid #808080;background:<?php echo $color0; ?>" align="right">
-				<?php echo add_numbers_separator(convert_bytes_to_mega($q["disk_size_scm"])); ?>
-				<?php echo _('Mb'); ?>
+				<?php echo $quota_management->add_numbers_separator($quota_management->convert_bytes_to_mega($q["disk_size_scm"])); ?>
+				<?php echo _('MB'); ?>
 			</td>
 			<td style="border-top:thin solid #808080;background:<?php echo $color1; ?>" align="right">
-				<?php echo add_numbers_separator(convert_bytes_to_mega($q["disk_size_other"])); ?>
-				<?php echo _('Mb'); ?>
+				<?php echo $quota_management->add_numbers_separator($quota_management->convert_bytes_to_mega($q["disk_size_other"])); ?>
+				<?php echo _('MB'); ?>
 			</td>
 			<td style="border-top:thin solid #808080;background:<?php echo $color1; ?>;font-weight:bold" align="right">
-				<?php echo add_numbers_separator(convert_bytes_to_mega($local_disk_size)); ?> 
-				<?php echo _('Mb'); ?>
+				<?php echo $quota_management->add_numbers_separator($quota_management->convert_bytes_to_mega($local_disk_size)); ?>
+				<?php echo _('MB'); ?>
 			</td>
 			<td style="border-top:thin solid #808080;background:<?php echo $colorq; ?>" align="right">
-				<?php 
+				<?php
 					if ($q["quota_soft"] > 0)
 					{
-						echo add_numbers_separator(convert_bytes_to_mega($q["quota_soft"])); 
+						echo $quota_management->add_numbers_separator($quota_management->convert_bytes_to_mega($q["quota_soft"]));
 						echo " ";
-						echo _('Mb'); 
+						echo _('MB');
 					}
 					else
 					{
@@ -293,12 +278,12 @@ foreach ($users as $u)
 				?>
 			</td>
 			<td style="border-top:thin solid #808080;background:<?php echo $colorq; ?>" align="right">
-				<?php 
+				<?php
 					if ($q["quota_hard"] > 0)
 					{
-						echo add_numbers_separator(convert_bytes_to_mega($q["quota_hard"])); 
+						echo $quota_management->add_numbers_separator($quota_management->convert_bytes_to_mega($q["quota_hard"]));
 						echo " ";
-						echo _('Mb'); 
+						echo _('MB');
 					}
 					else
 					{
@@ -317,24 +302,24 @@ foreach ($users as $u)
 		</td>
 		<td style="border-top:thick solid #808080;border-bottom:thick solid #808080"><br /></td>
 		<td style="border-top:thick solid #808080;border-bottom:thick solid #808080;background:#e0e0e0" align="right">
-			<?php echo add_numbers_separator(convert_bytes_to_mega($total_database)); ?>
-			<?php echo _('Mb'); ?>
+			<?php echo $quota_management->add_numbers_separator($quota_management->convert_bytes_to_mega($total_database)); ?>
+			<?php echo _('MB'); ?>
 		</td>
 		<td style="border-top:thick solid #808080;border-bottom:thick solid #808080;background:#e0e0e0" align="right">
-			<?php echo add_numbers_separator(convert_bytes_to_mega($total_disk_1)); ?>
-			<?php echo _('Mb'); ?>
+			<?php echo $quota_management->add_numbers_separator($quota_management->convert_bytes_to_mega($total_disk_1)); ?>
+			<?php echo _('MB'); ?>
 		</td>
 		<td style="border-top:thick solid #808080;border-bottom:thick solid #808080;background:#e0e0e0" align="right">
-			<?php echo add_numbers_separator(convert_bytes_to_mega($total_disk_scm)); ?>
-			<?php echo _('Mb'); ?>
+			<?php echo $quota_management->add_numbers_separator($quota_management->convert_bytes_to_mega($total_disk_scm)); ?>
+			<?php echo _('MB'); ?>
 		</td>
 		<td style="border-top:thick solid #808080;border-bottom:thick solid #808080;background:#e0e0e0" align="right">
-			<?php echo add_numbers_separator(convert_bytes_to_mega($total_disk_other)); ?>
-			<?php echo _('Mb'); ?>
+			<?php echo $quota_management->add_numbers_separator($quota_management->convert_bytes_to_mega($total_disk_other)); ?>
+			<?php echo _('MB'); ?>
 		</td>
 		<td style="border-top:thick solid #808080;border-bottom:thick solid #808080;background:#e0e0e0" align="right">
-			<?php echo add_numbers_separator(convert_bytes_to_mega($total_database+$total_disk_1+$total_disk_scm+$total_disk_other)); ?>
-			<?php echo _('Mb'); ?>
+			<?php echo $quota_management->add_numbers_separator($quota_management->convert_bytes_to_mega($total_database+$total_disk_1+$total_disk_scm+$total_disk_other)); ?>
+			<?php echo _('MB'); ?>
 		</td>
 		<td style="border-top:thick solid #808080;border-bottom:thick solid #808080"><br /></td>
 		<td style="border-top:thick solid #808080;border-bottom:thick solid #808080"><br /></td>
@@ -371,8 +356,8 @@ foreach ($users as $u)
 			<td style="border-top:thin solid #808080"><br /></td>
 			<td style="border-top:thin solid #808080"><br /></td>
 			<td style="border-top:thin solid #808080" align="right">
-				<?php echo add_numbers_separator($u["disk_size"]); ?>
-				<?php echo _('Mb'); ?>
+				<?php echo $quota_management->add_numbers_separator($u["disk_size"]); ?>
+				<?php echo _('MB'); ?>
 			</td>
 		</tr>
 		<?php
@@ -387,53 +372,16 @@ foreach ($users as $u)
 		<td style="border-top:thick solid #808080;border-bottom:thick solid #808080"><br /></td>
 		<td style="border-top:thick solid #808080;border-bottom:thick solid #808080"><br /></td>
 		<td style="border-top:thick solid #808080;border-bottom:thick solid #808080" align="right">
-			<?php echo add_numbers_separator($total); ?>
-			<?php echo _('Mb'); ?>
+			<?php echo $quota_management->add_numbers_separator($total); ?>
+			<?php echo _('MB'); ?>
 		</td>
 	</tr>
 </table>
 <?php
 
-
-print_debug(print_r($quotas, true));
-print_debug(print_r($users, true));
-
 site_admin_footer(array());
-?>
-
-<?php
-
-function convert_bytes_to_mega ($mega)
-{
-	$b = round($mega / (1024*1024), 0);
-	return $b;
-}
-
-function print_debug ($text)
-{
-//	echo "<pre>$text</pre>";
-}
-function add_numbers_separator ($val, $sep=' ')
-{
-	$size = "$val";
-	$size = strrev($size);
-	$size = wordwrap($size, 3, $sep, 1);
-	$size = strrev($size);
-	return $size;
-}
-function get_dir_size ($dir)
-{
-	$size = "";
-	$cmd = "/usr/bin/du -bs $dir";
-	$res = shell_exec ($cmd);
-	$a = explode("\t", $res);
-	if (isset($a[1])) $size = $a[0];
-	return "$size";
-}
 
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
