@@ -1,7 +1,9 @@
 <?php
-/** FusionForge Bazaar plugin
+/**
+ * FusionForge Bazaar plugin
  *
  * Copyright 2009, Roland Mas
+ * Copyright 2013-2014, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge.
  *
@@ -9,7 +11,7 @@
  * it under the terms of the GNU General Public License as published
  * by the Free Software Foundation; either version 2 of the License,
  * or (at your option) any later version.
- * 
+ *
  * FusionForge is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
@@ -40,10 +42,10 @@ class BzrPlugin extends SCMPlugin {
 		$this->main_branch_names[] = 'main' ;
 		$this->main_branch_names[] = 'head' ;
 		$this->main_branch_names[] = 'HEAD' ;
-		
+
 		$this->register () ;
 	}
-	
+
 	function getDefaultServer() {
 		return forge_get_config('default_server', 'scmbzr') ;
 	}
@@ -51,13 +53,13 @@ class BzrPlugin extends SCMPlugin {
 	function printShortStats ($params) {
 		$project = $this->checkParams ($params) ;
 		if (!$project) {
-			return false ;
+			return;
 		}
-		
-		if ($project->usesPlugin($this->name)) {
-			$result = db_query_params('SELECT sum(commits) AS commits, sum(adds) AS adds FROM stats_cvs_group WHERE group_id=$1',
+
+		if ($project->usesPlugin($this->name) && forge_check_perm('scm', $project->getID(), 'read')) {
+			$result = db_query_params('SELECT sum(updates) AS updates, sum(adds) AS adds FROM stats_cvs_group WHERE group_id=$1',
 						  array ($project->getID())) ;
-			$commit_num = db_result($result,0,'commits');
+			$commit_num = db_result($result,0,'updates');
 			$add_num    = db_result($result,0,'adds');
 			if (!$commit_num) {
 				$commit_num=0;
@@ -65,12 +67,16 @@ class BzrPlugin extends SCMPlugin {
 			if (!$add_num) {
 				$add_num=0;
 			}
-			echo ' (Bazaar: '.sprintf(_('<strong>%1$s</strong> commits, <strong>%2$s</strong> adds'), number_format($commit_num, 0), number_format($add_num, 0)).")";
+			echo ' (Bazaar: '.sprintf(_('<strong>%1$s</strong> updates, <strong>%2$s</strong> adds'), number_format($commit_num, 0), number_format($add_num, 0)).")";
 		}
 	}
-	
+
 	function getBlurb () {
-		return '<p>' . _('Documentation for Bazaar (sometimes referred to as "bzr") is available <a href="http://bazaar-vcs.org/Documentation">here</a>.') . '</p>';
+		return '<p>'
+				. sprintf(_('Documentation for %1$s is available at <a href="%2$s">%2$s</a>.'),
+							'Bazaar (“bzr”)',
+							'http://bazaar-vcs.org/Documentation')
+				. '</p>';
 	}
 
 	function getInstructionsForAnon ($project) {
@@ -89,61 +95,77 @@ class BzrPlugin extends SCMPlugin {
 	function getInstructionsForRW ($project) {
 		$b = '' ;
 		if (session_loggedin()) {
-			$u =& user_get_object(user_getid()) ;
+			$u = user_get_object(user_getid()) ;
 			$d = $u->getUnixName() ;
 			$b .= '<h2>';
-			$b .= _('Developer Bazaar Access via SSH');
+			$b .= sprintf(_('Developer %s Access via SSH'), 'Bazaar');
 			$b .= '</h2>';
 			$b .= '<p>';
-			$b .= _('Only project developers can access the Bazaar branches via this method. SSH must be installed on your client machine. Enter your site password when prompted.');
+			$b .= sprintf(_('Only project developers can access the %s tree via this method.'), 'Bazaar');
+			$b .= ' ';
+			$b .= _('SSH must be installed on your client machine.');
+			$b .= ' ';
+			$b .= _('Enter your site password when prompted.');
 			$b .= '</p>';
-			$b .= '<p><tt>bzr checkout bzr+ssh://'.$d.'@' . $project->getSCMBox() . forge_get_config('repos_path', 'scmbzr') .'/'. $project->getUnixName().'/'._('branchname').'</tt></p>' ;
+			$b .= '<p><tt>bzr checkout bzr+ssh://'.$d.'@' . $this->getBoxForProject($project) . forge_get_config('repos_path', 'scmbzr') .'/'. $project->getUnixName().'/'._('branchname').'</tt></p>' ;
 		} else {
 			$b .= '<h2>';
-			$b .= _('Developer Bazaar Access via SSH');
+			$b .= sprintf(_('Developer %s Access via SSH'), 'Bazaar');
 			$b .= '</h2>';
 			$b .= '<p>';
-			$b .= _('Only project developers can access the Bazaar branches via this method. SSH must be installed on your client machine. Substitute <i>developername</i> with the proper value. Enter your site password when prompted.');
+			$b .= sprintf(_('Only project developers can access the %s tree via this method.'), 'Bazaar');
+			$b .= ' ';
+			$b .= _('SSH must be installed on your client machine.');
+			$b .= ' ';
+			$b .= _('Substitute <em>developername</em> with the proper value.');
+			$b .= ' ';
+			$b .= _('Enter your site password when prompted.');
 			$b .= '</p>';
-			$b .= '<p><tt>bzr checkout bzr+ssh://<i>'._('developername').'</i>@' . $project->getSCMBox() . forge_get_config('repos_path', 'scmbzr') .'/'. $project->getUnixName().'/'._('branchname').'</tt></p>' ;
+			$b .= '<p><tt>bzr checkout bzr+ssh://<i>'._('developername').'</i>@' . $this->getBoxForProject($project) . forge_get_config('repos_path', 'scmbzr') .'/'. $project->getUnixName().'/'._('branchname').'</tt></p>' ;
 		}
 		return $b ;
 	}
 
 	function getSnapshotPara ($project) {
-		return ;
+		return;
 	}
 
 	function getBrowserLinkBlock ($project) {
 		global $HTML ;
-		$b = $HTML->boxMiddle(_('Bazaar Repository Browser'));
+		$b = $HTML->boxMiddle(sprintf(_('%s Repository Browser'), 'Bazaar'));
 		$b .= '<p>';
-		$b .= _('Browsing the Bazaar tree gives you a view into the current status of this project\'s code. You may also view the complete histories of any file in the repository.');
+		$b .= sprintf(_("Browsing the %s tree gives you a view into the current status of this project's code."), 'Bazaar');
+		$b .= ' ';
+		$b .= _('You may also view the complete histories of any file in the repository.');
 		$b .= '</p>';
 		$b .= '<p>[' ;
 		$b .= util_make_link ("/scm/browser.php?group_id=".$project->getID(),
-				      _('Browse Bazaar Repository')
+								sprintf(_('Browse %s Repository'), 'Bazaar')
 			) ;
 		$b .= ']</p>' ;
 		return $b ;
 	}
 
 	function getStatsBlock ($project) {
-		return ;
+		return;
 	}
 
 	function printBrowserPage ($params) {
 		global $HTML;
-
 		$project = $this->checkParams ($params) ;
 		if (!$project) {
-			return false ;
+			return;
 		}
-                
+
 		if ($project->usesPlugin ($this->name)) {
 			if ($this->browserDisplayable ($project)) {
-				print '<iframe src="'.util_make_url ("/scm/loggerhead/".$project->getUnixName()).'" frameborder="0" width=100% height=700></iframe>' ;
-			}
+				print '<iframe id="scm_iframe" src="'.util_make_url ("/scm/loggerhead/".$project->getUnixName()).'" frameborder="0" width="100%" ></iframe>' ;
+				html_use_jqueryautoheight();
+				echo $HTML->getJavascripts();
+				echo '<script type="text/javascript">//<![CDATA[
+					jQuery(\'#scm_iframe\').iframeAutoHeight({heightOffset: 50});
+					//]]></script>';
+				}
 		}
 	}
 
@@ -152,43 +174,61 @@ class BzrPlugin extends SCMPlugin {
 		if (!$project) {
 			return false ;
 		}
-				
+
 		if (! $project->usesPlugin ($this->name)) {
 			return false;
 		}
 
+		$project_name = $project->getUnixName();
+
 		$repo = forge_get_config('repos_path', 'scmbzr') . '/' . $project->getUnixName() ;
-		$unix_group = 'scm_' . $project->getUnixName() ;
+		$unix_group = 'scm_' . $project_name ;
 
 		$repo_exists = false ;
 		if (is_dir ($repo)) {
 			$pipe = popen ("bzr info $repo 2>/dev/null", "r") ;
 			$line = fgets ($pipe) ;
 			fclose ($pipe) ;
-		
-			if (preg_match ("/^Shared repository/", $line) != 0) {
+
+			if (preg_match ("/^Shared repository/", $line) != 0
+			    || preg_match ("/^Repository branch/", $line) != 0) {
 				$repo_exists = true ;
 			}
 		}
-		
+
 		if (!$repo_exists) {
+			$tmp_repo = util_mkdtemp('.bzr', $project_name);
+			if ($tmp_repo == false) {
+				return false;
+			}
+
+			system ("bzr init-repo --no-trees $tmp_repo >/dev/null") ;
+			system ("find $tmp_repo/.bzr -type d | xargs chmod g+s") ;
+			system ("chmod -R g+wX,o+rX-w $tmp_repo/.bzr") ;
+			system ("chgrp $unix_group $tmp_repo/.bzr") ;
+
 			system ("mkdir -p $repo") ;
-			system ("bzr init-repo --no-trees $repo >/dev/null") ;
-			system ("find $repo -type d | xargs chmod g+s") ;
+			system ("chgrp $unix_group $repo") ;
+			system ("chmod g+s $repo") ;
+			system ("mv $tmp_repo/.bzr $repo/.bzr");
+			rmdir ($tmp_repo);
 		}
 
-		system ("chgrp -R $unix_group $repo") ;
 		if ($project->enableAnonSCM()) {
-			system ("chmod -R g+wX,o+rX-w $repo") ;
+			system ("chmod o+rX-w $repo") ;
 		} else {
-			system ("chmod -R g+wX,o-rwx $repo") ;
+			system ("chmod o-rwx $repo") ;
 		}
 	}
 
         function updateRepositoryList ($params) {
                 $groups = $this->getGroups () ;
 
-		$dir = '/var/lib/gforge/plugins/scmbzr/public-repositories' ;
+		$dir = forge_get_config('data_path').'/plugins/scmbzr/public-repositories' ;
+
+		if (!is_dir($dir)) {
+			mkdir ($dir, 0644, true);
+		}
 
 		$oldlist = array () ;
 		$dh = opendir ($dir) ;
@@ -239,7 +279,7 @@ class BzrPlugin extends SCMPlugin {
                 if (!$project) {
                         return false ;
                 }
-                
+
                 if (! $project->usesPlugin ($this->name)) {
                         return false;
                 }
@@ -258,8 +298,10 @@ class BzrPlugin extends SCMPlugin {
 
                         $updates = 0 ;
                         $adds = 0 ;
-			$usr_updates = array () ;
 			$usr_adds = array () ;
+			$usr_updates = array () ;
+			$usr_deletes = array () ;
+			$usr_commits = array () ;
 
 			$toprepo = forge_get_config('repos_path', 'scmbzr') ;
 			$repo = $toprepo . '/' . $project->getUnixName() ;
@@ -283,7 +325,7 @@ class BzrPlugin extends SCMPlugin {
                                 db_rollback () ;
                                 return false ;
                         }
-        
+
                         $res = db_query_params ('DELETE FROM stats_cvs_user WHERE month=$1 AND day=$2 AND group_id=$3',
                                                 array ($month_string,
                                                        $day,
@@ -302,6 +344,8 @@ class BzrPlugin extends SCMPlugin {
 			$state = '' ;
 			$curadds = 0 ;
 			$curupdates = 0 ;
+			$curcommits = 0 ;
+			$curdeletes = 0 ;
                         while (! feof ($pipe) &&
                                $line = rtrim (fgets ($pipe))) {
 				if ($line == $sep) {
@@ -341,51 +385,63 @@ class BzrPlugin extends SCMPlugin {
 					case 'added':
 						$curadds++ ;
 						break ;
+					case 'deletes':
+						$curdeletes++ ;
+						break ;
 					}
 				}
+				$curcommits++ ;
 			}
 			if ($curdate == $date) {
 				$adds = $adds + $curadds ;
 				$updates = $updates + $curupdates ;
+				$deletes = $deletes + $curdeletes ;
+				$commits = $commits + $curcommits ;
 			}
-                        
+
                         // inserting group results in stats_cvs_groups
-			if ($updates > 0 || $adds > 0) {
-				if (!db_query_params ('INSERT INTO stats_cvs_group (month,day,group_id,checkouts,commits,adds) VALUES ($1,$2,$3,$4,$5,$6)',
+			if ($updates > 0 || $adds > 0 || $deletes > 0 || $commits > 0) {
+				if (!db_query_params ('INSERT INTO stats_cvs_group (month,day,group_id,checkouts,commits,adds,updates,deletes) VALUES ($1,$2,$3,$4,$5,$6)',
 						      array ($month_string,
 							     $day,
 							     $project->getID(),
 							     0,
+							     $commits,
+							     $adds,
 							     $updates,
-							     $adds))) {
+							     $deletes))) {
 					echo "Error while inserting into stats_cvs_group\n" ;
 					db_rollback () ;
 					return false ;
 				}
 			}
-                                
+
                         // building the user list
-                        $user_list = array_unique( array_merge( array_keys( $usr_adds ), array_keys( $usr_updates ) ) );
+                        $user_list = array_unique( array_merge( array_keys( $usr_adds ), array_keys( $usr_updates ), array_keys( $usr_commits ) ) );
 
                         foreach ( $user_list as $user ) {
                                 // trying to get user id from user name
-                                $u = &user_get_object_by_name ($user) ;
+                                $u = user_get_object_by_name ($user) ;
                                 if ($u) {
                                         $user_id = $u->getID();
                                 } else {
                                         continue;
                                 }
-				
+
+				$uc = $usr_commits[$user] ? $usr_commits[$user] : 0 ;
 				$uu = $usr_updates[$user] ? $usr_updates[$user] : 0 ;
 				$ua = $usr_adds[$user] ? $usr_adds[$user] : 0 ;
-				if ($uu > 0 || $ua > 0) {
-					if (!db_query_params ('INSERT INTO stats_cvs_user (month,day,group_id,user_id,commits,adds) VALUES ($1,$2,$3,$4,$5,$6)',
+				$ud = $usr_deletes[$user] ? $usr_deletes[$user] : 0 ;
+				if ($uu > 0 || $ua > 0 || $uc > 0 || $ud > 0) {
+					if (!db_query_params ('INSERT INTO stats_cvs_user (month,day,group_id,user_id,commits,adds,updates,deletes) VALUES ($1,$2,$3,$4,$5,$6)',
 							      array ($month_string,
 								     $day,
 								     $project->getID(),
 								     $user_id,
+								     $uc,
+								     $ua,
 								     $uu,
-								     $ua))) {
+								     $ud))) {
 						echo "Error while inserting into stats_cvs_user\n" ;
 						db_rollback () ;
 						return false ;
@@ -414,25 +470,23 @@ class BzrPlugin extends SCMPlugin {
 
 	function generateSnapshots ($params) {
 
-
-
 		$project = $this->checkParams ($params) ;
 		if (!$project) {
 			return false ;
 		}
-		
+
 		$group_name = $project->getUnixName() ;
 
-		$snapshot = forge_get_config('scm_snapshots_path').'/'.$group_name.'-scm-latest.tar.gz';
-		$tarball = forge_get_config('scm_tarballs_path').'/'.$group_name.'-scmroot.tar.gz';
+		$snapshot = forge_get_config('scm_snapshots_path').'/'.$group_name.'-scm-latest.tar'.util_get_compressed_file_extension();
+		$tarball = forge_get_config('scm_tarballs_path').'/'.$group_name.'-scmroot.tar'.util_get_compressed_file_extension();
 
 		if (! $project->usesPlugin ($this->name)) {
 			return false;
 		}
 
 		if (! $project->enableAnonSCM()) {
-			unlink ($snapshot) ;
-			unlink ($tarball) ;
+			if (file_exists ($snapshot)) unlink ($snapshot) ;
+			if (file_exists ($tarball)) unlink ($tarball) ;
 			return false;
 		}
 
@@ -440,8 +494,8 @@ class BzrPlugin extends SCMPlugin {
 		$repo = $toprepo . '/' . $project->getUnixName() ;
 
 		if (!is_dir ($repo) || !is_file ("$repo/format")) {
-			unlink ($snapshot) ;
-			unlink ($tarball) ;
+			if (file_exists ($snapshot)) unlink ($snapshot) ;
+			if (file_exists ($tarball)) unlink ($tarball) ;
 			return false ;
 		}
 
@@ -452,19 +506,19 @@ class BzrPlugin extends SCMPlugin {
 		$today = date ('Y-m-d') ;
 		$branch = $this->findMainBranch ($project) ;
 		if ($branch != '') {
-			system ("bzr export --root=$group_name-scm-$today $tmp/snapshot.tar.gz $repo/$bname") ;
-			chmod ("$tmp/snapshot.tar.gz", 0644) ;
-			copy ("$tmp/snapshot.tar.gz", $snapshot) ;
-			unlink ("$tmp/snapshot.tar.gz") ;
+			system ("bzr export --root=$group_name-scm-$today --format=tar - $repo/$bname |".forge_get_config('compression_method')."> $tmp/snapshot") ;
+			chmod ("$tmp/snapshot", 0644) ;
+			copy ("$tmp/snapshot", $snapshot) ;
+			unlink ("$tmp/snapshot") ;
 			system ("rm -rf $tmp/$dir") ;
 		} else {
 			unlink ($snapshot) ;
 		}
 
-		system ("tar czCf $toprepo $tmp/tarball.tar.gz " . $project->getUnixName()) ;
-		chmod ("$tmp/tarball.tar.gz", 0644) ;
-		copy ("$tmp/tarball.tar.gz", $tarball) ;
-		unlink ("$tmp/tarball.tar.gz") ;
+		system ("tar cCf $toprepo - ".$project->getUnixName() ."|".forge_get_config('compression_method')."> $tmp/tarball") ;
+		chmod ("$tmp/tarball", 0644) ;
+		copy ("$tmp/tarball", $tarball) ;
+		unlink ("$tmp/tarball") ;
 		system ("rm -rf $tmp") ;
 	}
   }
@@ -473,5 +527,3 @@ class BzrPlugin extends SCMPlugin {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
