@@ -3,7 +3,7 @@
  *
  * Copyright 2003-2009, Roland Mas
  * Copyright 2004, GForge, LLC
- * Copyright (C) 2010 Alain Peyrat - Alcatel-Lucent
+ * Copyright (C) 2010-2012 Alain Peyrat - Alcatel-Lucent
  *
  * This file is part of FusionForge.
  *
@@ -11,7 +11,7 @@
  * it under the terms of the GNU General Public License as published
  * by the Free Software Foundation; either version 2 of the License,
  * or (at your option) any later version.
- * 
+ *
  * FusionForge is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
@@ -43,7 +43,7 @@ class CCasePlugin extends SCMPlugin {
 
 	function CallHook ($hookname, &$params) {
 		global $HTML ;
-		
+
 		switch ($hookname) {
 		case "scm_page":
 			$group_id = $params['group_id'] ;
@@ -74,21 +74,21 @@ class CCasePlugin extends SCMPlugin {
 		global $HTML ;
 
 		$project = group_get_object($group_id);
-		
+
 		if ($project->usesPlugin ("scmccase")) {
 			$vob_tag = preg_replace("/GROUPNAME/", $project->getUnixName (), forge_get_config('tag_pattern', 'scmccase')) ;
-	
+
 			print '<h2>ClearCase</h2>
 		                <p>Documentation for ClearCase is probably available somewhere.
                                 </p>' ;
 
 			// Table for summary info
 
-			print '<table width="100%"><tr valign="top"><td width="65%">' ;
+			print '<table class="fullwidth"><tr class="top"><td class="twothirdswidth">' ;
 
 			// Developer access
-			
-			echo "<b>".print(_('ClearCase Access'))."</b>" ;
+
+			echo "<b>"._('ClearCase Access')."</b>" ;
 
 			print "<p>" ;
 			printf (_('Either mount the VOB with <tt>cleartool mount %1$s</tt> or select the <tt>%1$s</tt> VOB in your ClearCase Explorer.'),
@@ -97,27 +97,30 @@ class CCasePlugin extends SCMPlugin {
 
 			// Summary info
 
-			print '</td><td width="35%">' ;
+			print '</td><td class="onethirdwidth">' ;
 
 			// CCase Browsing
 
 			$anonymous = 1;
 			if (session_loggedin()) {
-				$perm =& $project->getPermission ();
+				$perm =& $project->getPermission();
 				$anonymous = !$perm->isMember();
 			}
-			
+
 			if ($project->enableAnonCVS() || !$anonymous) {
 				echo $HTML->boxTop(_('History'));
-				
-				echo '<b>'._('Browse the ClearCase tree').'</b><p>'._('Browsing the ClearCase tree gives you a great view into the current status of this project\'s code. You may also view the complete histories of any file in the repository.').'</p>' ;
-				
+
+				echo '<b>'._('Browse the ClearCase tree').'</b>';
+				echo '<p>';
+				echo sprintf(_("Browsing the %s tree gives you a view into the current status of this project's code."), 'ClearCase');
+				echo ' ';
+				echo _('You may also view the complete histories of any file in the repository.');
+				echo '</p>';
 				$browse_url = "http://" . $this->GetGroupServer($group_id) . "/ccweb" ;
 				// $browse_url = $browse_url . "?vob_tag=".$vob_tag ;
-				echo "<p>" ;
-				printf (_('<a href="%1$s">Browse</a> CCase tree'),
-					$browse_url) ;
-				echo "</p>" ;
+				echo "<p>";
+				printf ('<a href="%1$s">%2$s</a>', $browse_url, _('Browse the ClearCase tree')) ;
+				echo "</p>";
 
 				echo $HTML->boxBottom();
 			}
@@ -125,10 +128,10 @@ class CCasePlugin extends SCMPlugin {
 			print '</td></tr></table>' ;
 		}
 	}
-	
+
 	function scm_admin_update ($params) {
 		$group = group_get_object($params['group_id']);
-		
+
 		if ($params['scmccase_ccase_server'] && $params['scmccase_ccase_server'] != "") {
 			$this->SetGroupServer ($params['group_id'], $params['scmccase_ccase_server']) ;
 		} else {
@@ -138,7 +141,7 @@ class CCasePlugin extends SCMPlugin {
 
 	function display_scm_admin_page ($params) {
 		$group = group_get_object($params['group_id']);
-		
+
 		if ( $group->usesPlugin ( $this->name ) ) {
 			print '<input type="text" name="scmccase_ccase_server" value="'.$this->GetGroupServer ($params['group_id']).'"> <strong>'._('ClearCase server').'</strong><br /><br />' ;
 		}
@@ -163,11 +166,10 @@ class CCasePlugin extends SCMPlugin {
 		$add_count=number_format($add_num, 0);
 		echo ' (CCase: <strong>'.$commit_count.'</strong> ';
 		printf(ngettext("commit","commits",$commit_count),$commit_count);
-		echo ', <strong>'.$add_count.'</strong> '; 
+		echo ', <strong>'.$add_count.'</strong> ';
 		printf(ngettext("add","adds",$add_count),$add_count);
 		echo ')';
 	}
-	
 
 	function GetDefaultServer () {
 		return forge_get_config('default_server', 'scmccase') ;
@@ -210,7 +212,7 @@ class CCasePlugin extends SCMPlugin {
 		} elseif ($project->isError()) {
 			return false;
 		}
-               
+
 		if (! $project->usesPlugin ($this->name)) {
 			return false;
 		}
@@ -223,5 +225,3 @@ class CCasePlugin extends SCMPlugin {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
