@@ -1,7 +1,9 @@
 <?php
-/** FusionForge Darcs plugin
+/**
+ * FusionForge Darcs plugin
  *
  * Copyright 2009, Roland Mas
+ * Copyright 2013-2014, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge.
  *
@@ -9,7 +11,7 @@
  * it under the terms of the GNU General Public License as published
  * by the Free Software Foundation; either version 2 of the License,
  * or (at your option) any later version.
- * 
+ *
  * FusionForge is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
@@ -33,10 +35,10 @@ class DarcsPlugin extends SCMPlugin {
 		$this->hooks[] = 'scm_update_repolist' ;
 		$this->hooks[] = 'scm_browser_page' ;
 		$this->hooks[] = 'scm_gather_stats' ;
-		
+
 		$this->register () ;
 	}
-	
+
 	function getDefaultServer() {
 		return forge_get_config('default_server', 'scmdarcs') ;
 	}
@@ -65,10 +67,10 @@ class DarcsPlugin extends SCMPlugin {
 	function printShortStats ($params) {
 		$project = $this->checkParams ($params) ;
 		if (!$project) {
-			return false ;
+			return;
 		}
-		
-		if ($project->usesPlugin($this->name)) {
+
+		if ($project->usesPlugin($this->name) && forge_check_perm('scm', $project->getID(), 'read')) {
 			$result = db_query_params('SELECT sum(commits) AS commits, sum(adds) AS adds FROM stats_cvs_group WHERE group_id=$1',
 						  array ($project->getID())) ;
 			$commit_num = db_result($result,0,'commits');
@@ -79,12 +81,16 @@ class DarcsPlugin extends SCMPlugin {
 			if (!$add_num) {
 				$add_num=0;
 			}
-			echo ' (Darcs: '.sprintf(_('<strong>%1$s</strong> commits, <strong>%2$s</strong> adds'), number_format($commit_num, 0), number_format($add_num, 0)).")";
+			echo ' (Darcs: '.sprintf(_('<strong>%1$s</strong> updates, <strong>%2$s</strong> adds'), number_format($commit_num, 0), number_format($add_num, 0)).")";
 		}
 	}
-	
+
 	function getBlurb () {
-		return '<p>' . _('Documentation for Darcs is available <a href="http://darcs.net/">here</a>.') . '</p>';
+		return '<p>'
+				. sprintf(_('Documentation for %1$s is available at <a href="%2$s">%2$s</a>.'),
+							'Darcs',
+							'http://darcs.net/')
+				. '</p>';
 	}
 
  	function getInstructionForDarcs ($project, $rw) {
@@ -98,7 +104,7 @@ class DarcsPlugin extends SCMPlugin {
  			}
  			if ($rw)
  			{
- 				$url = $project->getSCMBox() . ':'. $this->getRootRepositories($project) . '/' . $default_repo;
+ 				$url = $this->getBoxForProject($project) . ':'. $this->getRootRepositories($project) . '/' . $default_repo;
  			}
  			else
  			{
@@ -107,20 +113,20 @@ class DarcsPlugin extends SCMPlugin {
 			$b = '<p><tt>darcs get ' . $url . '</tt></p>';
  			if (count($repo_names) > 1)
  			{
- 				$b .= _('<p>where REPO can be: ') . implode(_(', '), $repo_names) . '</p>';
+ 				$b .= '<p>'._('where REPO can be: ') . implode(_(', '), $repo_names) . '</p>';
  			}
  		}
  		else if (is_dir($this->getRootRepositories($project)))
  		{
- 			$b = _('<p><em>No repositories defined.</em></p>');
+ 			$b = '<p><em>'._('No repositories defined.').'</em></p>';
  		}
  		else
  		{
- 			$b = _('<p><em>Repository not yet created, wait an hour.</em></p>');
+ 			$b = '<p><em>'._('Repository not yet created, wait an hour.').'</em></p>';
  		};
  		return $b ;
  	}
- 
+
 	function getInstructionsForAnon ($project) {
 		$b = '<h2>';
 		$b .=  _('Anonymous Darcs Access');
@@ -135,10 +141,16 @@ class DarcsPlugin extends SCMPlugin {
 
 	function getInstructionsForRW ($project) {
 		$b = '<h2>';
-		$b .= _('Developer Darcs Access via SSH');
+		$b .= sprintf(_('Developer %s Access via SSH'), 'Darcs');
 		$b .= '</h2>';
 		$b .= '<p>';
-		$b .= ('Only project developers can access the Darcs tree via this method. SSH must be installed on your client machine. Substitute <i>developername</i> with the proper values. Enter your site password when prompted.');
+		$b .= sprintf(_('Only project developers can access the %s tree via this method.'), 'Darcs');
+		$b .= ' ';
+		$b .= _('SSH must be installed on your client machine.');
+		$b .= ' ';
+		$b .= _('Substitute <em>developername</em> with the proper value.');
+		$b .= ' ';
+		$b .= _('Enter your site password when prompted.');
 		$b .= '</p>';
 		$b .= $this->getInstructionForDarcs($project, true);
 		return $b ;
@@ -147,7 +159,7 @@ class DarcsPlugin extends SCMPlugin {
 	function getSnapshotPara ($project) {
 
 		$b = "" ;
-		$filename = $project->getUnixName().'-scm-latest.tar.gz';
+		$filename = $project->getUnixName().'-scm-latest.tar'.util_get_compressed_file_extension();
 		if (file_exists(forge_get_config('scm_snapshots_path').'/'.$filename)) {
 			$b .= '<p>[' ;
 			$b .= util_make_link ("/snapshots.php?group_id=".$project->getID(),
@@ -160,9 +172,11 @@ class DarcsPlugin extends SCMPlugin {
 
 	function getBrowserLinkBlock ($project) {
 		global $HTML ;
-		$b = $HTML->boxMiddle(_('Darcs Repository Browser'));
+		$b = $HTML->boxMiddle(sprintf(_('%s Repository Browser'), 'Darcs'));
 		$b .= '<p>';
-		$b .= _('Browsing the Darcs tree gives you a view into the current status of this project\'s code. You may also view the complete histories of any file in the repository.');
+		$b .= sprintf(_("Browsing the %s tree gives you a view into the current status of this project's code."), 'Darcs');
+		$b .= ' ';
+		$b .= _('You may also view the complete histories of any file in the repository.');
 		$b .= '</p>';
  		$repo_names = $this->getRepositories($project);
  		if (count($repo_names) > 0)
@@ -171,13 +185,13 @@ class DarcsPlugin extends SCMPlugin {
  			{
  				$b .= '<p>[' ;
  				$b .= util_make_link ("/scm/browser.php?group_id=".$project->getID()."&repo_name=".$repo_name,
- 									_('Browse Darcs Repository '. $repo_name));
+ 									sprintf(_('Browse %s Repository'), 'Darcs') .' ' . $repo_name);
  				$b .= ']</p>' ;
  			}
  		}
  		else
  		{
- 			$b .= _('<p>No repositories to browse</p>');
+ 			$b .= '<p>'._('No repositories to browse').'</p>';
  		}
 		return $b ;
 	}
@@ -188,20 +202,20 @@ class DarcsPlugin extends SCMPlugin {
 
 		$result = db_query_params('SELECT u.realname, u.user_name, u.user_id, sum(commits) as commits, sum(adds) as adds, sum(adds+commits) as combined FROM stats_cvs_user s, users u WHERE group_id=$1 AND s.user_id=u.user_id AND (commits>0 OR adds >0) GROUP BY u.user_id, realname, user_name, u.user_id ORDER BY combined DESC, realname',
 					  array ($project->getID()));
-		
+
 		if (db_numrows($result) > 0) {
 			$b .= $HTML->boxMiddle(_('Repository Statistics'));
 
 			$tableHeaders = array(
 				_('Name'),
 				_('Adds'),
-				_('Commits')
+				_('Updates')
 				);
 			$b .= $HTML->listTableTop($tableHeaders);
-			
+
 			$i = 0;
 			$total = array('adds' => 0, 'commits' => 0);
-			
+
 			while($data = db_fetch_array($result)) {
 				$b .= '<tr '. $HTML->boxGetAltRowStyle($i) .'>';
 				$b .= '<td width="50%">' ;
@@ -225,18 +239,22 @@ class DarcsPlugin extends SCMPlugin {
 
 	function printBrowserPage ($params) {
 		global $HTML;
-
 		$project = $this->checkParams ($params) ;
 		if (!$project) {
-			return false ;
+			return;
 		}
-		
+
 		if ($project->usesPlugin ($this->name)) {
 			if ($this->browserDisplayable ($project)) {
-				print '<iframe src="'.
+				print '<iframe id="scm_iframe" src="'.
 					util_make_url ("/plugins/scmdarcs/cgi-bin/darcsweb.cgi?r=".
 					$project->getUnixName()). '/' . $params['repo_name'] .
-					'" frameborder="0" width=100% height=700></iframe>' ;
+					'" frameborder="0" width="100%" ></iframe>' ;
+				html_use_jqueryautoheight();
+				echo $HTML->getJavascripts();
+				echo '<script type="text/javascript">//<![CDATA[
+					jQuery(\'#scm_iframe\').iframeAutoHeight({heightOffset: 50});
+					//]]></script>';
 			}
 		}
 	}
@@ -246,7 +264,7 @@ class DarcsPlugin extends SCMPlugin {
 		if (!$project) {
 			return false ;
 		}
-				
+
 		if (! $project->usesPlugin ($this->name)) {
 			return false;
 		}
@@ -291,8 +309,7 @@ class DarcsPlugin extends SCMPlugin {
 				}
 			}
 		}
-	
-			
+
 		foreach ($this->getRepositories($project) as $repo_name)
 		{
 			$repo =  $toprepo . '/' . $repo_name ;
@@ -318,7 +335,6 @@ class DarcsPlugin extends SCMPlugin {
 				. "\n") ;
 	}
 
-
 	function updateRepositoryList ($params) {
 		$groups = $this->getGroups () ;
 		$list = array () ;
@@ -328,7 +344,11 @@ class DarcsPlugin extends SCMPlugin {
 			}
 		}
 
-		$fname = '/etc/gforge/plugins/scmdarcs/config.py' ;
+		$config_dir = forge_get_config('config_path').'/plugins/scmdarcs';
+		if (!is_dir($config_dir)) {
+			mkdir($config_dir, 0755, true);
+		}
+		$fname = $config_dir.'/config.py' ;
 
 		$f = fopen ($fname.'.new', 'w') ;
 
@@ -347,15 +367,15 @@ class DarcsPlugin extends SCMPlugin {
 				{
 					# Default repository name, we create a default entry for it
 					fwrite ($f,
-						$this->darcswebRepository($project, 
-																			"$unix_name", 
-																			"$unix_name/$repo_name", 
+						$this->darcswebRepository($project,
+																			"$unix_name",
+																			"$unix_name/$repo_name",
 																			"$toprepo/$repo_name"));
 				}
-				fwrite ($f, 
-					$this->darcswebRepository($project, 
-																		"$unix_name/$repo_name", 
-																		"$unix_name/$repo_name", 
+				fwrite ($f,
+					$this->darcswebRepository($project,
+																		"$unix_name/$repo_name",
+																		"$unix_name/$repo_name",
 																		"$toprepo/$repo_name"));
 			}
 		}
@@ -366,22 +386,22 @@ class DarcsPlugin extends SCMPlugin {
 
 	function generateSnapshots ($params) {
 
-
 		$project = $this->checkParams ($params) ;
 		if (!$project) {
 			return false ;
 		}
-		
+
 		$group_name = $project->getUnixName() ;
 
-		$tarball = forge_get_config('scm_tarballs_path').'/'.$group_name.'-scmroot.tar.gz';
+		$snapshot = forge_get_config('scm_snapshots_path').'/'.$group_name.'-scm-latest.tar'.util_get_compressed_file_extension();
+		$tarball = forge_get_config('scm_tarballs_path').'/'.$group_name.'-scmroot.tar'.util_get_compressed_file_extension();
 
 		if (! $project->usesPlugin ($this->name)) {
 			return false;
 		}
 
 		if (! $project->enableAnonSCM()) {
-			unlink ($tarball) ;
+			if (file_exists ($tarball)) unlink ($tarball) ;
 			return false;
 		}
 
@@ -390,7 +410,7 @@ class DarcsPlugin extends SCMPlugin {
 		$repo = $this->getRootRepositories($project);
 
 		if (!is_dir ($repo)) {
-			unlink ($tarball) ;
+			if (file_exists ($tarball)) unlink ($tarball) ;
 			return false ;
 		}
 
@@ -402,49 +422,49 @@ class DarcsPlugin extends SCMPlugin {
 		$dir = $project->getUnixName ()."-$today" ;
 		system ("mkdir -p $tmp/$dir") ;
 		system ("cd $tmp ; darcs $repo $dir > /dev/null 2>&1") ;
-		system ("tar czCf $tmp $tmp/snapshot.tar.gz $dir") ;
-		chmod ("$tmp/snapshot.tar.gz", 0644) ;
-		copy ("$tmp/snapshot.tar.gz", $snapshot) ;
-		unlink ("$tmp/snapshot.tar.gz") ;
+		system ("tar cCf $tmp - $dir |".forge_get_config('compression_method')."> $tmp/snapshot") ;
+		chmod ("$tmp/snapshot", 0644) ;
+		copy ("$tmp/snapshot", $snapshot) ;
+		unlink ("$tmp/snapshot") ;
 		system ("rm -rf $tmp/$dir") ;
 
-		system ("tar czCf $toprepo $tmp/tarball.tar.gz " . $project->getUnixName()) ;
-		chmod ("$tmp/tarball.tar.gz", 0644) ;
-		copy ("$tmp/tarball.tar.gz", $tarball) ;
-		unlink ("$tmp/tarball.tar.gz") ;
+		system ("tar cCf $toprepo - ".$project->getUnixName() ."|".forge_get_config('compression_method')."> $tmp/tarball") ;
+		chmod ("$tmp/tarball", 0644) ;
+		copy ("$tmp/tarball", $tarball) ;
+		unlink ("$tmp/tarball") ;
 		system ("rm -rf $tmp") ;
 	}
 
 	function gatherStats ($params) {
 		global  $adds, $deletes, $updates, $commits,
 			$usr_adds, $usr_deletes, $usr_updates;
-		
+
 		$project = $this->checkParams ($params) ;
 		if (!$project) {
 			return false ;
 		}
-		
+
 		if (! $project->usesPlugin ($this->name)) {
 			return false;
 		}
-		
+
 		if ($params['mode'] == 'day') {
 			db_begin();
-		
+
 			$year = $params ['year'] ;
 			$month = $params ['month'] ;
 			$day = $params ['day'] ;
 			$month_string = sprintf( "%04d%02d", $year, $month );
 			$start_time = gmmktime( 0, 0, 0, $month, $day, $year);
 			$end_time = $start_time + 86400;
-		
+
 			$updates = 0 ;
 			$adds = 0 ;
 			$deletes = 0;
 			$usr_adds = array () ;
 			$usr_updates = array () ;
 			$usr_deletes = array ();
-		
+
 			$toprepo = $this->getRootRepositories($project) ;
 			$from_date = date("c", $start_time);
 			$to_date   = date("c", $end_time);
@@ -459,7 +479,7 @@ class DarcsPlugin extends SCMPlugin {
 				db_rollback () ;
 				return false ;
 			}
-		
+
 			$res = db_query_params ('DELETE FROM stats_cvs_user WHERE month=$1 AND day=$2 AND group_id=$3',
 						array ($month_string,
 						       $day,
@@ -469,7 +489,7 @@ class DarcsPlugin extends SCMPlugin {
 				db_rollback () ;
 				return false ;
 			}
-		
+
 			foreach ($this->getRepositories($project) as $repo_name)
 			{
 				$repo = $toprepo . '/' . $repo_name;
@@ -480,20 +500,20 @@ class DarcsPlugin extends SCMPlugin {
 				}
 				else
 				{
-					echo "$repo\n";
+					// echo "$repo\n";
 				}
-		
+
 				$pipe = popen("darcs changes --repodir='$repo' "
 								."--match 'date \"between $from_date and $to_date\"' "
 								."--xml -s\n", 'r');
-			
+
 				$xml_parser = xml_parser_create();
 				xml_set_element_handler($xml_parser, "DarcsPluginStartElement", "DarcsPluginEndElement");
-			
+
 				// Analyzing history stream
 				while (!feof($pipe) &&
 							 $data = fgets ($pipe, 4096)) {
-					
+
 					if (!xml_parse ($xml_parser, $data, feof ($pipe))) {
 						debug("Unable to parse XML with error " .
 									xml_error_string(xml_get_error_code($xml_parser)) .
@@ -504,12 +524,12 @@ class DarcsPlugin extends SCMPlugin {
 						break;
 					}
 				}
-				
+
 				xml_parser_free ($xml_parser);
 			}
-			
+
 			// inserting group results in stats_cvs_groups
-		
+
 			if (!db_query_params ('INSERT INTO stats_cvs_group (month,day,group_id,checkouts,commits,adds) VALUES ($1,$2,$3,$4,$5,$6)',
 					      array ($month_string,
 						     $day,
@@ -521,11 +541,11 @@ class DarcsPlugin extends SCMPlugin {
 				db_rollback () ;
 				return false ;
 			}
-				
-			// build map for email -> login 
-		
+
+			// build map for email -> login
+
 			$email_login = array();
-			$email_login_fn = $repo."/_darcs/email-login.txt"; 
+			$email_login_fn = $repo."/_darcs/email-login.txt";
 			if (!file_exists($email_login_fn))
 			{
 				$email_login_fn = $repo."/.email-login.txt";
@@ -534,7 +554,7 @@ class DarcsPlugin extends SCMPlugin {
 			{
 				unset($email_login_fn);
 			};
-			
+
 			if (isset($email_login_fn))
 			{
 				$fh = fopen($email_login_fn, 'r');
@@ -548,10 +568,10 @@ class DarcsPlugin extends SCMPlugin {
 				};
 				fclose($fh);
 			};
-		
+
 			// building the user list
 			$user_list = array_unique( array_merge( array_keys( $usr_adds ), array_keys( $usr_updates ) ) );
-		
+
 			foreach ( $user_list as $user ) {
 				// trying to get user id from darcs user name
 				$id = $user;
@@ -565,27 +585,27 @@ class DarcsPlugin extends SCMPlugin {
 				{
 				  $id = $email_login[$id];
 				}
-		
-				$u = &user_get_object_by_name ($id) ;
+
+				$u = user_get_object_by_name ($id) ;
 				if ($u) {
 					$user_id = $u->getID();
 				} else {
 					continue;
 				}
-					
+
 				if (!db_query_params ('INSERT INTO stats_cvs_user (month,day,group_id,user_id,commits,adds) VALUES ($1,$2,$3,$4,$5,$6)',
 						      array ($month_string,
 							     $day,
 							     $project->getID(),
 							     $user_id,
-							     $usr_updates[$user] ? $usr_updates[$user] : 0,
-							     $usr_adds[$user] ? $usr_adds[$user] : 0))) {
+							     isset ($usr_updates[$user]) ? $usr_updates[$user] : 0,
+							     isset ($usr_adds[$user]) ? $usr_adds[$user] : 0))) {
 					echo "Error while inserting into stats_cvs_user\n" ;
 					db_rollback () ;
 					return false ;
 				}
 			}
-		
+
 			db_commit();
 		}
 	}
@@ -611,14 +631,14 @@ class DarcsPlugin extends SCMPlugin {
 				{
 					array_push($nm, $res['repo_name']);
 				}
-				print '<p><strong>'._('Repository to be created: ') . '</strong>' . 
+				print '<p><strong>'._('Repository to be created: ') . '</strong>' .
 					implode(_(', '), $nm) . '</p>';
 			}
 
-			print '<p><strong>Create new repository:</strong></p>';
-			print '<p>'._('Repository name: ').
-				'<input type="string" name="scm_create_repo_name" size=16 maxlength=128 /></p>';
-			print '<p>'._('Clone: ').
+			print '<p><strong>'._('Create new repository:') . '</strong></p>';
+			print '<p>'._('Repository name')._(': ');
+			print '<input type="string" name="scm_create_repo_name" size=16 maxlength=128 /></p>';
+			print '<p>'._('Clone')._(': ').
 				'<select name="scm_clone_repo_name">';
 			print '<option value="">&lt;none&gt;</option>';
 			foreach ($this->getRepositories($project) as $repo_name)
@@ -638,6 +658,9 @@ class DarcsPlugin extends SCMPlugin {
 			return false;
 		}
 
+		if (!isset($params['scm_create_repo_name'])) {
+			return false;
+		}
 		$new_repo_name = $params['scm_create_repo_name'];
 		$clone_repo_name = $params['scm_clone_repo_name'];
 		if ($new_repo_name != '')
@@ -666,7 +689,7 @@ class DarcsPlugin extends SCMPlugin {
 			}
 
 			db_begin ();
-			if (!db_query_params ('INSERT INTO plugin_scmdarcs_create_repos (group_id,repo_name,clone_repo_name) 
+			if (!db_query_params ('INSERT INTO plugin_scmdarcs_create_repos (group_id,repo_name,clone_repo_name)
 				VALUES ($1,$2,$3)',
 				array($project->getID(), $new_repo_name, $clone_repo_name)))
 			{
@@ -680,10 +703,10 @@ class DarcsPlugin extends SCMPlugin {
 		}
 	}
 
-}	
-		
+}
+
 function DarcsPluginStartElement($parser, $name, $attrs) {
-	global $last_user, $commits, 
+	global $last_user, $commits,
 		$adds, $updates, $deletes,
 		$usr_adds, $usr_updates, $usr_deletes;
 	switch($name) {
@@ -726,12 +749,10 @@ function DarcsPluginStartElement($parser, $name, $attrs) {
 		break;
 	}
 }
-	
+
 function DarcsPluginEndElement ($parser, $name) {
 }
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
