@@ -1,5 +1,4 @@
 <?php
-// $Id: RPC2.php 7638 2010-08-11 11:58:40Z vargenau $
 /*
  * The guts of this code have been moved to lib/XmlRpcServer.php.
  *
@@ -11,9 +10,8 @@
 
 // Intercept GET requests from confused users.  Only POST is allowed here!
 if (empty($GLOBALS['HTTP_SERVER_VARS']))
-    $GLOBALS['HTTP_SERVER_VARS']  =& $_SERVER;
-if ($HTTP_SERVER_VARS['REQUEST_METHOD'] != "POST")
-{
+    $GLOBALS['HTTP_SERVER_VARS'] =& $_SERVER;
+if ($_SERVER['REQUEST_METHOD'] != "POST") {
     die('This is the address of the XML-RPC interface.' .
         '  You must use XML-RPC calls to access information here.');
 }
@@ -22,10 +20,10 @@ if ($HTTP_SERVER_VARS['REQUEST_METHOD'] != "POST")
 define ("WIKI_XMLRPC", true);
 
 // Start up the main code
-include_once("index.php");
-include_once("lib/main.php");
+include_once 'index.php';
+include_once 'lib/main.php';
 
-include_once("lib/XmlRpcServer.php");
+include_once 'lib/XmlRpcServer.php';
 
 $server = new XmlRpcServer;
 $server->service();
@@ -36,5 +34,4 @@ $server->service();
 // c-basic-offset: 4
 // c-hanging-comment-ender-p: nil
 // indent-tabs-mode: nil
-// End: 
-?>
+// End:
