@@ -1,4 +1,4 @@
-<?php // $Id: ErrorManager.php 8031 2011-04-11 08:36:32Z vargenau $
+<?php
 
 if (isset($GLOBALS['ErrorManager'])) return;
 
@@ -12,9 +12,9 @@ if (defined('E_STRICT')
     error_reporting(E_ALL & ~E_STRICT);
 }
 */
-define ('EM_FATAL_ERRORS', E_ERROR | E_PARSE | E_CORE_ERROR | E_COMPILE_ERROR | E_USER_ERROR | ~2048 & ((check_php_version(5,3)) ? ~E_DEPRECATED : ~0));
+define ('EM_FATAL_ERRORS', E_ERROR | E_PARSE | E_CORE_ERROR | E_COMPILE_ERROR | E_USER_ERROR | ~2048 & ((check_php_version(5, 3)) ? ~E_DEPRECATED : ~0));
 define ('EM_WARNING_ERRORS',
-    E_WARNING | E_CORE_WARNING | E_COMPILE_WARNING | E_USER_WARNING | ((check_php_version(5,3)) ? E_DEPRECATED : 0));
+    E_WARNING | E_CORE_WARNING | E_COMPILE_WARNING | E_USER_WARNING | ((check_php_version(5, 3)) ? E_DEPRECATED : 0));
 define ('EM_NOTICE_ERRORS', E_NOTICE | E_USER_NOTICE);
 
 /* It is recommended to leave assertions on.
@@ -24,13 +24,14 @@ define ('EM_NOTICE_ERRORS', E_NOTICE | E_USER_NOTICE);
 */
 //also turn it on if phpwiki_version notes no release
 if (defined('DEBUG') and DEBUG)
-    assert_options (ASSERT_ACTIVE, 1);
+    assert_options(ASSERT_ACTIVE, 1);
 else
-    assert_options (ASSERT_ACTIVE, 0);
-assert_options (ASSERT_CALLBACK, 'wiki_assert_handler');
+    assert_options(ASSERT_ACTIVE, 0);
+assert_options(ASSERT_CALLBACK, 'wiki_assert_handler');
 
-function wiki_assert_handler ($file, $line, $code) {
-    ErrorManager_errorHandler( $code, sprintf("<br />%s:%s: %s: Assertion failed <br />", $file, $line, $code), $file, $line);
+function wiki_assert_handler($file, $line, $code)
+{
+    ErrorManager_errorHandler($code, sprintf("<br />%s:%s: %s: Assertion failed <br />", $file, $line, $code), $file, $line);
 }
 
 /**
@@ -49,7 +50,8 @@ class ErrorManager
      * As this is a singleton class, you should never call this.
      * @access private
      */
-    function ErrorManager() {
+    function ErrorManager()
+    {
         $this->_handlers = array();
         $this->_fatal_handler = false;
         $this->_postpone_mask = 0;
@@ -63,7 +65,8 @@ class ErrorManager
      * @access public
      * @return int The current postponed error mask.
      */
-    function getPostponedErrorMask() {
+    function getPostponedErrorMask()
+    {
         return $this->_postpone_mask;
     }
 
@@ -78,7 +81,8 @@ class ErrorManager
      * @access public
      * @param $newmask int The new value for the mask.
      */
-    function setPostponedErrorMask($newmask) {
+    function setPostponedErrorMask($newmask)
+    {
         $this->_postpone_mask = $newmask;
         if (function_exists('PrintXML'))
             PrintXML($this->_flush_errors($newmask));
@@ -91,7 +95,8 @@ class ErrorManager
      * Report any queued error messages.
      * @access public
      */
-    function flushPostponedErrors() {
+    function flushPostponedErrors()
+    {
         if (function_exists('PrintXML'))
             PrintXML($this->_flush_errors());
         else
@@ -103,7 +108,8 @@ class ErrorManager
      * - pdf or image - output.
      * @access public
      */
-    function destroyPostponedErrors () {
+    function destroyPostponedErrors()
+    {
         $this->_postponed_errors = array();
     }
 
@@ -114,7 +120,8 @@ class ErrorManager
      *
      * @return object HTML describing any queued errors (or false, if none).
      */
-    function getPostponedErrorsAsHTML() {
+    function getPostponedErrorsAsHTML()
+    {
         $flushed = $this->_flush_errors();
         if (!$flushed)
             return false;
@@ -131,8 +138,8 @@ class ErrorManager
             return $flushed;
         $class = $worst_err->getHtmlClass();
         $html = HTML::div(array('class' => $class),
-                          HTML::div(array('class' => 'errors'),
-                                   "PHP " . $worst_err->getDescription()));
+            HTML::div(array('class' => 'errors'),
+                "PHP " . $worst_err->getDescription()));
         $html->pushContent($flushed);
         return $html;
     }
@@ -177,7 +184,8 @@ class ErrorManager
      * @access public
      * @param $handler WikiCallback  Handler to call.
      */
-    function pushErrorHandler($handler) {
+    function pushErrorHandler($handler)
+    {
         array_unshift($this->_handlers, $handler);
     }
 
@@ -185,7 +193,8 @@ class ErrorManager
      * Pop an error handler off the handler stack.
      * @access public
      */
-    function popErrorHandler() {
+    function popErrorHandler()
+    {
         return array_shift($this->_handlers);
     }
 
@@ -199,7 +208,8 @@ class ErrorManager
      * @access public
      * @param $handler WikiCallback  Callback to call on fatal errors.
      */
-    function setFatalHandler($handler) {
+    function setFatalHandler($handler)
+    {
         $this->_fatal_handler = $handler;
     }
 
@@ -212,13 +222,14 @@ class ErrorManager
      * @access public
      * @param $error object A PhpError object.
      */
-    function handleError($error) {
+    function handleError($error)
+    {
         static $in_handler;
 
         if (!empty($in_handler)) {
             $msg = $error->_getDetail();
             $msg->unshiftContent(HTML::h2(fmt("%s: error while handling error:",
-                                              "ErrorManager")));
+                "ErrorManager")));
             $msg->printXML();
             return;
         }
@@ -227,7 +238,7 @@ class ErrorManager
         // so display now all errors directly.
         if (!empty($GLOBALS['request']->_finishing)) {
             $this->_postpone_mask = 0;
-    }
+        }
 
         $in_handler = true;
 
@@ -235,9 +246,8 @@ class ErrorManager
             if (!$handler) continue;
             $result = $handler->call($error);
             if (!$result) {
-                continue;       // Handler did not handle error.
-            }
-            elseif (is_object($result)) {
+                continue; // Handler did not handle error.
+            } elseif (is_object($result)) {
                 // handler filtered the result. Still should pass to
                 // the rest of the chain.
                 if ($error->isFatal()) {
@@ -245,8 +255,7 @@ class ErrorManager
                     $result->errno = $error->errno;
                 }
                 $error = $result;
-            }
-            else {
+            } else {
                 // Handler handled error.
                 if (!$error->isFatal()) {
                     $in_handler = false;
@@ -260,12 +269,10 @@ class ErrorManager
         // Handle it ourself.
         if ($error->isFatal()) {
             $this->_noCacheHeaders();
-            echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
-            echo "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\"\n";
-        echo "\"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n";
+            echo "<!DOCTYPE html>\n";
             echo "<html>\n";
             echo "<head>\n";
-            echo "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" />\n";
+            echo "<meta charset=\"UTF-8\" />\n";
             echo "<title>Fatal Error</title>\n";
             echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"themes/default/phpwiki.css\" />\n";
             echo "</head>\n";
@@ -273,31 +280,30 @@ class ErrorManager
             echo "<div style=\"font-weight:bold; color:red\">Fatal Error:</div>\n";
 
             if (defined('DEBUG') and (DEBUG & _DEBUG_TRACE)) {
-                echo "error_reporting=",error_reporting(),"\n<br />";
+                echo "error_reporting=", error_reporting(), "\n<br />";
                 $error->printSimpleTrace(debug_backtrace());
             }
-        $this->_die($error);
-        }
-        else if (($error->errno & error_reporting()) != 0) {
-            if  (($error->errno & $this->_postpone_mask) != 0) {
+            $this->_die($error);
+        } elseif (($error->errno & error_reporting()) != 0) {
+            if (($error->errno & $this->_postpone_mask) != 0) {
                 if ((function_exists('isa') and isa($error, 'PhpErrorOnce'))
                     or (!function_exists('isa') and
-                    (
-                     // stdlib independent isa()
-                     (strtolower(get_class($error)) == 'phperroronce')
-                     or (is_subclass_of($error, 'PhpErrorOnce'))))) {
+                        (
+                            // stdlib independent isa()
+                            (strtolower(get_class($error)) == 'phperroronce')
+                                or (is_subclass_of($error, 'PhpErrorOnce'))))
+                ) {
                     $error->removeDoublettes($this->_postponed_errors);
-                    if ( $error->_count < 2 )
+                    if ($error->_count < 2)
                         $this->_postponed_errors[] = $error;
                 } else {
                     $this->_postponed_errors[] = $error;
                 }
-            }
-            else {
+            } else {
                 //echo "postponed errors: ";
                 $this->_noCacheHeaders();
                 if (defined('DEBUG') and (DEBUG & _DEBUG_TRACE)) {
-                    echo "error_reporting=",error_reporting(),"\n";
+                    echo "error_reporting=", error_reporting(), "\n";
                     $error->printSimpleTrace(debug_backtrace());
                 }
                 $error->printXML();
@@ -306,32 +312,36 @@ class ErrorManager
         $in_handler = false;
     }
 
-    function warning($msg, $errno = E_USER_NOTICE) {
+    function warning($msg, $errno = E_USER_NOTICE)
+    {
         $this->handleError(new PhpWikiError($errno, $msg, '?', '?'));
     }
 
     /**
      * @access private
      */
-    function _die($error) {
+    function _die($error)
+    {
         global $WikiTheme;
         //echo "\n\n<html><body>";
         $error->printXML();
         PrintXML($this->_flush_errors());
         if ($this->_fatal_handler)
             $this->_fatal_handler->call($error);
-    if (!$WikiTheme->DUMP_MODE)
-        exit -1;
+        if (!$WikiTheme->DUMP_MODE) {
+            exit();
+        }
     }
 
     /**
      * @access private
      */
-    function _flush_errors($keep_mask = 0) {
+    function _flush_errors($keep_mask = 0)
+    {
         $errors = &$this->_postponed_errors;
         if (empty($errors)) return '';
         $flushed = HTML();
-        for ($i=0; $i<count($errors); $i++) {
+        for ($i = 0; $i < count($errors); $i++) {
             $error =& $errors[$i];
             if (!is_object($error)) {
                 continue;
@@ -344,7 +354,8 @@ class ErrorManager
         return $flushed;
     }
 
-    function _noCacheHeaders() {
+    function _noCacheHeaders()
+    {
         global $request;
         static $already = false;
 
@@ -356,8 +367,8 @@ class ErrorManager
 
         // FIXME: Howto announce that to Request->cacheControl()?
         if (!headers_sent()) {
-            header( "Cache-control: no-cache" );
-            header( "Pragma: nocache" );
+            header("Cache-control: no-cache");
+            header("Pragma: nocache");
         }
         $already = true;
     }
@@ -373,8 +384,13 @@ class ErrorManager
  */
 function ErrorManager_errorHandler($errno, $errstr, $errfile, $errline)
 {
+    // TODO: Temporary hack to have errors displayed on dev machines.
+    if (defined('DEBUG') and DEBUG and $errno < 2048) {
+        print "<br/>PhpWiki Warning: ($errno, $errstr, $errfile, $errline)";
+    }
+
     if (!isset($GLOBALS['ErrorManager'])) {
-      $GLOBALS['ErrorManager'] = new ErrorManager;
+        $GLOBALS['ErrorManager'] = new ErrorManager;
     }
 
     if (defined('DEBUG') and DEBUG) {
@@ -385,33 +401,33 @@ function ErrorManager_errorHandler($errno, $errstr, $errfile, $errline)
     $GLOBALS['ErrorManager']->handleError($error);
 }
 
-
 /**
  * A class representing a PHP error report.
  *
  * @see The PHP documentation for set_error_handler at
  *      http://php.net/manual/en/function.set-error-handler.php .
  */
-class PhpError {
+class PhpError
+{
     /**
      * The PHP errno
      */
-    //var $errno;
+    public $errno;
 
     /**
      * The PHP error message.
      */
-    //var $errstr;
+    public $errstr;
 
     /**
      * The source file where the error occurred.
      */
-    //var $errfile;
+    public $errfile;
 
     /**
      * The line number (in $this->errfile) where the error occured.
      */
-    //var $errline;
+    public $errline;
 
     /**
      * Construct a new PhpError.
@@ -420,9 +436,10 @@ class PhpError {
      * @param $errfile string
      * @param $errline int
      */
-    function PhpError($errno, $errstr, $errfile, $errline) {
-        $this->errno   = $errno;
-        $this->errstr  = $errstr;
+    function PhpError($errno, $errstr, $errfile, $errline)
+    {
+        $this->errno = $errno;
+        $this->errstr = $errstr;
         $this->errfile = $errfile;
         $this->errline = $errline;
     }
@@ -431,15 +448,17 @@ class PhpError {
      * Determine whether this is a fatal error.
      * @return boolean True if this is a fatal error.
      */
-    function isFatal() {
-        return ($this->errno & (2048|EM_WARNING_ERRORS|EM_NOTICE_ERRORS)) == 0;
+    function isFatal()
+    {
+        return ($this->errno & (2048 | EM_WARNING_ERRORS | EM_NOTICE_ERRORS)) == 0;
     }
 
     /**
      * Determine whether this is a warning level error.
      * @return boolean
      */
-    function isWarning() {
+    function isWarning()
+    {
         return ($this->errno & EM_WARNING_ERRORS) != 0;
     }
 
@@ -447,10 +466,13 @@ class PhpError {
      * Determine whether this is a notice level error.
      * @return boolean
      */
-    function isNotice() {
+    function isNotice()
+    {
         return ($this->errno & EM_NOTICE_ERRORS) != 0;
     }
-    function getHtmlClass() {
+
+    function getHtmlClass()
+    {
         if ($this->isNotice()) {
             return 'hint';
         } elseif ($this->isWarning()) {
@@ -460,7 +482,8 @@ class PhpError {
         }
     }
 
-    function getDescription() {
+    function getDescription()
+    {
         if ($this->isNotice()) {
             return 'Notice';
         } elseif ($this->isWarning()) {
@@ -474,31 +497,32 @@ class PhpError {
      * Get a printable, HTML, message detailing this error.
      * @return object The detailed error message.
      */
-    function _getDetail() {
-        $dir = defined('PHPWIKI_DIR') ? PHPWIKI_DIR : substr(dirname(__FILE__),0,-4);
-        if (substr(PHP_OS,0,3) == 'WIN') {
-           $dir = str_replace('/','\\',$dir);
-           $this->errfile = str_replace('/','\\',$this->errfile);
-           $dir .= "\\";
+    function _getDetail()
+    {
+        $dir = defined('PHPWIKI_DIR') ? PHPWIKI_DIR : substr(dirname(__FILE__), 0, -4);
+        if (substr(PHP_OS, 0, 3) == 'WIN') {
+            $dir = str_replace('/', '\\', $dir);
+            $this->errfile = str_replace('/', '\\', $this->errfile);
+            $dir .= "\\";
         } else
-           $dir .= '/';
+            $dir .= '/';
         $errfile = preg_replace('|^' . preg_quote($dir) . '|', '', $this->errfile);
         $lines = explode("\n", $this->errstr);
         if (DEBUG & _DEBUG_VERBOSE) {
-          $msg = sprintf("%s:%d %s[%d]: %s",
-                         $errfile, $this->errline,
-                         $this->getDescription(), $this->errno,
-                         array_shift($lines));
-        }/* elseif (! $this->isFatal()) {
+            $msg = sprintf("%s:%d %s[%d]: %s",
+                $errfile, $this->errline,
+                $this->getDescription(), $this->errno,
+                array_shift($lines));
+        } /* elseif (! $this->isFatal()) {
           $msg = sprintf("%s:%d %s: \"%s\"",
                          $errfile, $this->errline,
                          $this->getDescription(),
                          array_shift($lines));
         }*/ else {
-          $msg = sprintf("%s:%d %s: \"%s\"",
-                         $errfile, $this->errline,
-                         $this->getDescription(),
-                         array_shift($lines));
+            $msg = sprintf("%s:%d %s: \"%s\"",
+                $errfile, $this->errline,
+                $this->getDescription(),
+                array_shift($lines));
         }
 
         $html = HTML::div(array('class' => $this->getHtmlClass()), HTML::p($msg));
@@ -518,28 +542,31 @@ class PhpError {
      * Print an HTMLified version of this error.
      * @see asXML()
      */
-    function printXML() {
+    function printXML()
+    {
         PrintXML($this->_getDetail());
     }
 
     /**
      * Return an HTMLified version of this error.
      */
-    function asXML() {
+    function asXML()
+    {
         return AsXML($this->_getDetail());
     }
 
     /**
      * Return a plain-text version of this error.
      */
-    function asString() {
+    function asString()
+    {
         return AsString($this->_getDetail());
     }
 
-    function printSimpleTrace($bt) {
-        global $HTTP_SERVER_VARS;
-        $nl = isset($HTTP_SERVER_VARS['REQUEST_METHOD']) ? "<br />" : "\n";
-        echo $nl."Traceback:".$nl;
+    function printSimpleTrace($bt)
+    {
+        $nl = isset($_SERVER['REQUEST_METHOD']) ? "<br />" : "\n";
+        echo $nl . "Traceback:" . $nl;
         foreach ($bt as $i => $elem) {
             if (!array_key_exists('file', $elem)) {
                 continue;
@@ -556,19 +583,22 @@ class PhpError {
  * This is essentially the same as a PhpError, except that the
  * error message is quieter: no source line, etc...
  */
-class PhpWikiError extends PhpError {
+class PhpWikiError extends PhpError
+{
     /**
      * Construct a new PhpError.
      * @param $errno   int
      * @param $errstr  string
      */
-    function PhpWikiError($errno, $errstr, $errfile, $errline) {
+    function PhpWikiError($errno, $errstr, $errfile, $errline)
+    {
         $this->PhpError($errno, $errstr, $errfile, $errline);
     }
 
-    function _getDetail() {
+    function _getDetail()
+    {
         return HTML::div(array('class' => $this->getHtmlClass()),
-                         HTML::p($this->getDescription() . ": $this->errstr"));
+            HTML::p($this->getDescription() . ": $this->errstr"));
     }
 }
 
@@ -578,23 +608,27 @@ class PhpWikiError extends PhpError {
  * Similar to PhpError, except only the first same error message is printed,
  * with number of occurences.
  */
-class PhpErrorOnce extends PhpError {
+class PhpErrorOnce extends PhpError
+{
 
-    function PhpErrorOnce($errno, $errstr, $errfile, $errline) {
+    function PhpErrorOnce($errno, $errstr, $errfile, $errline)
+    {
         $this->_count = 1;
         $this->PhpError($errno, $errstr, $errfile, $errline);
     }
 
-    function _sameError($error) {
+    function _sameError($error)
+    {
         if (!$error) return false;
         return ($this->errno == $error->errno and
-                $this->errfile == $error->errfile and
+            $this->errfile == $error->errfile and
                 $this->errline == $error->errline);
     }
 
     // count similar handlers, increase _count and remove the rest
-    function removeDoublettes(&$errors) {
-        for ($i=0; $i < count($errors); $i++) {
+    function removeDoublettes(&$errors)
+    {
+        for ($i = 0; $i < count($errors); $i++) {
             if (!isset($errors[$i])) continue;
             if ($this->_sameError($errors[$i])) {
                 $errors[$i]->_count++;
@@ -605,37 +639,38 @@ class PhpErrorOnce extends PhpError {
         return $this->_count;
     }
 
-    function _getDetail($count=0) {
+    function _getDetail($count = 0)
+    {
         if (!$count) $count = $this->_count;
-    $dir = defined('PHPWIKI_DIR') ? PHPWIKI_DIR : substr(dirname(__FILE__),0,-4);
-        if (substr(PHP_OS,0,3) == 'WIN') {
-           $dir = str_replace('/','\\',$dir);
-           $this->errfile = str_replace('/','\\',$this->errfile);
-           $dir .= "\\";
+        $dir = defined('PHPWIKI_DIR') ? PHPWIKI_DIR : substr(dirname(__FILE__), 0, -4);
+        if (substr(PHP_OS, 0, 3) == 'WIN') {
+            $dir = str_replace('/', '\\', $dir);
+            $this->errfile = str_replace('/', '\\', $this->errfile);
+            $dir .= "\\";
         } else
-           $dir .= '/';
+            $dir .= '/';
         $errfile = preg_replace('|^' . preg_quote($dir) . '|', '', $this->errfile);
         if (is_string($this->errstr))
             $lines = explode("\n", $this->errstr);
-    elseif (is_object($this->errstr))
+        elseif (is_object($this->errstr))
             $lines = array($this->errstr->asXML());
         $errtype = (DEBUG & _DEBUG_VERBOSE) ? sprintf("%s[%d]", $this->getDescription(), $this->errno)
-                                            : sprintf("%s", $this->getDescription());
+            : sprintf("%s", $this->getDescription());
         if ((DEBUG & _DEBUG_VERBOSE) or $this->isFatal()) {
-        $msg = sprintf("%s:%d %s: %s %s",
-                       $errfile, $this->errline,
-                       $errtype,
-                       array_shift($lines),
-                       $count > 1 ? sprintf(" (...repeated %d times)",$count) : ""
-                       );
-    } else {
-          $msg = sprintf("%s: \"%s\" %s",
-             $errtype,
-             array_shift($lines),
-             $count > 1 ? sprintf(" (...repeated %d times)",$count) : "");
-    }
+            $msg = sprintf("%s:%d %s: %s %s",
+                $errfile, $this->errline,
+                $errtype,
+                array_shift($lines),
+                $count > 1 ? sprintf(" (...repeated %d times)", $count) : ""
+            );
+        } else {
+            $msg = sprintf("%s: \"%s\" %s",
+                $errtype,
+                array_shift($lines),
+                $count > 1 ? sprintf(" (...repeated %d times)", $count) : "");
+        }
         $html = HTML::div(array('class' => $this->getHtmlClass()),
-                          HTML::p($msg));
+            HTML::p($msg));
         if ($lines) {
             $list = HTML::ul();
             foreach ($lines as $line)
@@ -647,11 +682,7 @@ class PhpErrorOnce extends PhpError {
     }
 }
 
-if (check_php_version(5,2)) {
-    require_once(dirname(__FILE__).'/HtmlElement5.php');
-} else {
-    require_once(dirname(__FILE__).'/HtmlElement.php');
-}
+require_once(dirname(__FILE__) . '/HtmlElement.php');
 
 if (!isset($GLOBALS['ErrorManager'])) {
     $GLOBALS['ErrorManager'] = new ErrorManager;
@@ -664,4 +695,3 @@ if (!isset($GLOBALS['ErrorManager'])) {
 // c-hanging-comment-ender-p: nil
 // indent-tabs-mode: nil
 // End:
-?>
