@@ -1,6 +1,6 @@
-<?php // $Id: FileFinder.php 7964 2011-03-05 17:05:30Z vargenau $
+<?php
 
-require_once(dirname(__FILE__).'/stdlib.php');
+require_once(dirname(__FILE__) . '/stdlib.php');
 
 /**
  * A class for finding files.
@@ -13,14 +13,15 @@ require_once(dirname(__FILE__).'/stdlib.php');
  */
 class FileFinder
 {
-    //var $_pathsep, $_path;
+    public $_pathsep, $_path;
 
     /**
      * Constructor.
      *
      * @param $path array A list of directories in which to search for files.
      */
-    function FileFinder ($path = false) {
+    function FileFinder($path = false)
+    {
         $this->_pathsep = $this->_get_syspath_separator();
         if (!isset($this->_path) and $path === false)
             $path = $this->_get_include_path();
@@ -33,12 +34,12 @@ class FileFinder
      * @param $file string File to search for.
      * @return string The filename (including path), if found, otherwise false.
      */
-    function findFile ($file, $missing_okay = false) {
+    function findFile($file, $missing_okay = false)
+    {
         if ($this->_is_abs($file)) {
             if (file_exists($file))
                 return $file;
-        }
-        elseif ( ($dir = $this->_search_path($file)) ) {
+        } elseif (($dir = $this->_search_path($file))) {
             return $dir . $this->_use_path_separator($dir) . $file;
         }
         return $missing_okay ? false : $this->_not_found($file);
@@ -49,17 +50,21 @@ class FileFinder
      * Accepts array of paths also.
      * This might not work on Windows95 or FAT volumes. (not tested)
      */
-    function slashifyPath ($path) {
+    function slashifyPath($path)
+    {
         return $this->forcePathSlashes($path, $this->_pathsep);
     }
 
     /**
      * Force using '/' as path seperator.
      */
-    function forcePathSlashes ($path, $sep='/') {
+    function forcePathSlashes($path, $sep = '/')
+    {
         if (is_array($path)) {
             $result = array();
-            foreach ($path as $dir) { $result[] = $this->forcePathSlashes($dir,$sep); }
+            foreach ($path as $dir) {
+                $result[] = $this->forcePathSlashes($dir, $sep);
+            }
             return $result;
         } else {
             if (isWindows() or $this->_isOtherPathsep()) {
@@ -67,10 +72,10 @@ class FileFinder
                 else $from = "\\";
                 // PHP is stupid enough to use \\ instead of \
                 if (isWindows()) {
-                    if (substr($path,0,2) != '\\\\')
-                        $path = str_replace('\\\\','\\',$path);
+                    if (substr($path, 0, 2) != '\\\\')
+                        $path = str_replace('\\\\', '\\', $path);
                     else // UNC paths
-                        $path = '\\\\' . str_replace('\\\\','\\',substr($path,2));
+                        $path = '\\\\' . str_replace('\\\\', '\\', substr($path, 2));
                 }
                 return strtr($path, $from, $sep);
             } else
@@ -88,12 +93,13 @@ class FileFinder
      * @param $file string File to include.
      * @return bool True if file was successfully included.
      */
-    function includeOnce ($file) {
-        if ( ($ret = @include_once($file)) )
+    function includeOnce($file)
+    {
+        if (($ret = @include_once($file)))
             return $ret;
 
         if (!$this->_is_abs($file)) {
-            if ( ($dir = $this->_search_path($file)) && is_file($dir . $this->_pathsep . $file)) {
+            if (($dir = $this->_search_path($file)) && is_file($dir . $this->_pathsep . $file)) {
                 $this->_append_to_include_path($dir);
                 return include_once($file);
             }
@@ -101,7 +107,8 @@ class FileFinder
         return $this->_not_found($file);
     }
 
-    function _isOtherPathsep() {
+    function _isOtherPathsep()
+    {
         return $this->_pathsep != '/';
     }
 
@@ -114,10 +121,11 @@ class FileFinder
      * @access private
      * @return string path_separator.
      */
-    function _get_syspath_separator () {
+    function _get_syspath_separator()
+    {
         if (!empty($this->_pathsep)) return $this->_pathsep;
         elseif (isWindowsNT()) return "/"; // we can safely use '/'
-        elseif (isWindows()) return "\\";  // FAT might use '\'
+        elseif (isWindows()) return "\\"; // FAT might use '\'
         // VMS or LispM is really weird, we ignore it.
         else return '/';
     }
@@ -134,10 +142,11 @@ class FileFinder
      * @access private
      * @return string path_separator.
      */
-    function _use_path_separator ($path) {
+    function _use_path_separator($path)
+    {
         if (isWindows95()) {
             if (empty($path)) return "\\";
-            else return (strchr($path,"\\")) ? "\\" : '/';
+            else return (strchr($path, "\\")) ? "\\" : '/';
         } else {
             return $this->_get_syspath_separator();
         }
@@ -150,12 +159,13 @@ class FileFinder
      * @param $path string Path.
      * @return bool True if path is absolute.
      */
-    function _is_abs($path) {
-        if (substr($path,0,1) == '/') {
+    function _is_abs($path)
+    {
+        if (substr($path, 0, 1) == '/') {
             return true;
         } elseif (isWindows() and preg_match("/^[a-z]:/i", $path)
-                  and (substr($path,2,1) == "/" or substr($path,2,1) == "\\"))
-        {
+            and (substr($path, 2, 1) == "/" or substr($path, 2, 1) == "\\")
+        ) {
             return true;
         } else {
             return false;
@@ -169,9 +179,10 @@ class FileFinder
      * @param $path string Path.
      * @return bool New path (destructive)
      */
-    function _strip_last_pathchar(&$path) {
-        if (substr($path,-1) == '/' or substr($path,-1) == "\\")
-            $path = substr($path,0,-1);
+    function _strip_last_pathchar(&$path)
+    {
+        if (substr($path, -1) == '/' or substr($path, -1) == "\\")
+            $path = substr($path, 0, -1);
         return $path;
     }
 
@@ -182,15 +193,12 @@ class FileFinder
      * @param $file string Name of missing file.
      * @return bool false.
      */
-    function _not_found($file) {
-        if (function_exists("_"))
-            trigger_error(sprintf(_("%s: file not found"), $file), E_USER_ERROR);
-        else
-            trigger_error(sprintf("%s: file not found", $file), E_USER_ERROR);
+    function _not_found($file)
+    {
+        trigger_error(sprintf(_("%s: file not found"), $file), E_USER_ERROR);
         return false;
     }
 
-
     /**
      * Search our path for a file.
      *
@@ -199,7 +207,8 @@ class FileFinder
      * @return string Directory which contains $file, or false.
      * [5x,44ms]
      */
-    function _search_path ($file) {
+    function _search_path($file)
+    {
         foreach ($this->_path as $dir) {
             // ensure we use the same pathsep
             if ($this->_isOtherPathsep()) {
@@ -208,7 +217,7 @@ class FileFinder
                 if (file_exists($dir . $this->_pathsep . $file))
                     return $dir;
             } elseif (@file_exists($dir . $this->_pathsep . $file))
-                   return $dir;
+                return $dir;
         }
         return false;
     }
@@ -222,7 +231,8 @@ class FileFinder
      * @access private
      * @return string path_separator.
      */
-    function _get_ini_separator () {
+    function _get_ini_separator()
+    {
         return isWindows() ? ';' : ':';
         // return preg_match('/^Windows/', php_uname())
     }
@@ -233,7 +243,8 @@ class FileFinder
      * @access private
      * @return array Include path.
      */
-    function _get_include_path() {
+    function _get_include_path()
+    {
         if (defined("INCLUDE_PATH"))
             $path = INCLUDE_PATH;
         else {
@@ -254,7 +265,8 @@ class FileFinder
      * @access private
      * @param $dir string Directory to add.
      */
-    function _append_to_include_path ($dir) {
+    function _append_to_include_path($dir)
+    {
         $dir = $this->slashifyPath($dir);
         if (!in_array($dir, $this->_path)) {
             $this->_path[] = $dir;
@@ -282,7 +294,8 @@ class FileFinder
      * @access private
      * @param $dir string Directory to add.
      */
-    function _prepend_to_include_path ($dir) {
+    function _prepend_to_include_path($dir)
+    {
         $dir = $this->slashifyPath($dir);
         // remove duplicates
         if ($i = array_search($dir, $this->_path) !== false) {
@@ -297,11 +310,12 @@ class FileFinder
     // Most specific first.
     // de_DE.iso8859-1@euro => de_DE.iso8859-1, de_DE, de
     // This code might needed somewhere else also.
-    function locale_versions ($lang) {
+    function locale_versions($lang)
+    {
         // Try less specific versions of the locale
         $langs[] = $lang;
         foreach (array('@', '.', '_') as $sep) {
-            if ( ($tail = strchr($lang, $sep)) )
+            if (($tail = strchr($lang, $sep)))
                 $langs[] = substr($lang, 0, -strlen($tail));
         }
         return $langs;
@@ -310,10 +324,11 @@ class FileFinder
     /**
      * Try to figure out the appropriate value for $LANG.
      *
-     *@access private
-     *@return string The value of $LANG.
+     * @access private
+     * @return string The value of $LANG.
      */
-    function _get_lang() {
+    function _get_lang()
+    {
         if (!empty($GLOBALS['LANG']))
             return $GLOBALS['LANG'];
 
@@ -361,20 +376,17 @@ class PearFileFinder
      * A good set of defaults is provided, so you can probably leave
      * this parameter blank.
      */
-    function PearFileFinder ($path = array()) {
+    function PearFileFinder($path = array())
+    {
         $this->FileFinder(array_merge(
-                          $path,
-                          array('/usr/share/php4',
-                                '/usr/share/php',
-                                '/usr/lib/php4',
-                                '/usr/lib/php',
-                                '/usr/local/share/php4',
-                                '/usr/local/share/php',
-                                '/usr/local/lib/php4',
-                                '/usr/local/lib/php',
-                                '/System/Library/PHP',
-                                '/Apache/pear'        // Windows
-                                )));
+            $path,
+            array('/usr/share/php',
+                '/usr/lib/php',
+                '/usr/local/share/php',
+                '/usr/local/lib/php',
+                '/System/Library/PHP',
+                '/Apache/pear' // Windows
+            )));
     }
 }
 
@@ -390,12 +402,13 @@ class PearFileFinder
  * "de_DE.iso8859-1", "de_DE" and "de".
  */
 class LocalizedFileFinder
-extends FileFinder
+    extends FileFinder
 {
     /**
      * Constructor.
      */
-    function LocalizedFileFinder () {
+    function LocalizedFileFinder()
+    {
         $this->_pathsep = $this->_get_syspath_separator();
         $include_path = $this->_get_include_path();
         $path = array();
@@ -427,12 +440,13 @@ extends FileFinder
  * "de_DE.iso8859-1", "de_DE" and "de".
  */
 class LocalizedButtonFinder
-extends FileFinder
+    extends FileFinder
 {
     /**
      * Constructor.
      */
-    function LocalizedButtonFinder () {
+    function LocalizedButtonFinder()
+    {
         global $WikiTheme;
         $this->_pathsep = $this->_get_syspath_separator();
         $include_path = $this->_get_include_path();
@@ -457,19 +471,19 @@ extends FileFinder
 }
 
 // Search PHP's include_path to find file or directory.
-function FindFile ($file, $missing_okay = false, $slashify = false)
+function FindFile($file, $missing_okay = false, $slashify = false)
 {
     static $finder;
     if (!isset($finder)) {
         $finder = new FileFinder;
         // remove "/lib" from dirname(__FILE__)
-        $wikidir = preg_replace('/.lib$/','',dirname(__FILE__));
+        $wikidir = preg_replace('/.lib$/', '', dirname(__FILE__));
         // let the system favor its local pear?
-        $finder->_append_to_include_path(dirname(__FILE__)."/pear");
+        $finder->_append_to_include_path(dirname(__FILE__) . "/pear");
         $finder->_prepend_to_include_path($wikidir);
         // Don't override existing INCLUDE_PATH config.
         if (!defined("INCLUDE_PATH"))
-         define("INCLUDE_PATH", implode($finder->_get_ini_separator(), $finder->_path));
+            define("INCLUDE_PATH", implode($finder->_get_ini_separator(), $finder->_path));
     }
     $s = $finder->findFile($file, $missing_okay);
     if ($slashify)
@@ -479,7 +493,7 @@ function FindFile ($file, $missing_okay = false, $slashify = false)
 
 // Search PHP's include_path to find file or directory.
 // Searches for "locale/$LANG/$file", then for "$file".
-function FindLocalizedFile ($file, $missing_okay = false, $re_init = false)
+function FindLocalizedFile($file, $missing_okay = false, $re_init = false)
 {
     static $finder;
     if ($re_init or !isset($finder))
@@ -487,7 +501,7 @@ function FindLocalizedFile ($file, $missing_okay = false, $re_init = false)
     return $finder->findFile($file, $missing_okay);
 }
 
-function FindLocalizedButtonFile ($file, $missing_okay = false, $re_init = false)
+function FindLocalizedButtonFile($file, $missing_okay = false, $re_init = false)
 {
     static $buttonfinder;
     if ($re_init or !isset($buttonfinder))
@@ -504,7 +518,8 @@ function FindLocalizedButtonFile ($file, $missing_okay = false, $re_init = false
  *
  * NormalizeLocalFileName("lib/config.php") => /home/user/phpwiki/lib/config.php
  */
-function NormalizeLocalFileName($file) {
+function NormalizeLocalFileName($file)
+{
     static $finder;
     if (!isset($finder)) {
         $finder = new FileFinder;
@@ -514,7 +529,7 @@ function NormalizeLocalFileName($file) {
         return $finder->slashifyPath($file);
     else {
         if (defined("PHPWIKI_DIR")) $wikidir = PHPWIKI_DIR;
-        else $wikidir = preg_replace('/.lib$/','',dirname(__FILE__));
+        else $wikidir = preg_replace('/.lib$/', '', dirname(__FILE__));
         $wikidir = $finder->_strip_last_pathchar($wikidir);
         $pathsep = $finder->_use_path_separator($wikidir);
         return $finder->slashifyPath($wikidir . $pathsep . $file);
@@ -525,7 +540,8 @@ function NormalizeLocalFileName($file) {
 /**
  * Prefixes with DATA_PATH and slashify
  */
-function NormalizeWebFileName($file) {
+function NormalizeWebFileName($file)
+{
     static $finder;
     if (!isset($finder)) {
         $finder = new FileFinder;
@@ -542,22 +558,25 @@ function NormalizeWebFileName($file) {
     }
 }
 
-function isWindows() {
+function isWindows()
+{
     static $win;
     if (isset($win)) return $win;
     //return preg_match('/^Windows/', php_uname());
-    $win = (substr(PHP_OS,0,3) == 'WIN');
+    $win = (substr(PHP_OS, 0, 3) == 'WIN');
     return $win;
 }
 
-function isWindows95() {
+function isWindows95()
+{
     static $win95;
     if (isset($win95)) return $win95;
     $win95 = isWindows() and !isWindowsNT();
     return $win95;
 }
 
-function isWindowsNT() {
+function isWindowsNT()
+{
     static $winnt;
     if (isset($winnt)) return $winnt;
     // FIXME: Do this using PHP_OS instead of php_uname().
@@ -565,7 +584,7 @@ function isWindowsNT() {
     if (function_usable('php_uname'))
         $winnt = preg_match('/^Windows NT/', php_uname());
     else
-        $winnt = false;         // FIXME: punt.
+        $winnt = false; // FIXME: punt.
     return $winnt;
 }
 
@@ -576,4 +595,3 @@ function isWindowsNT() {
 // c-hanging-comment-ender-p: nil
 // indent-tabs-mode: nil
 // End:
-?>
