@@ -1,5 +1,4 @@
-<?php // -*-php-*-
-// $Id: PearDB_ffpgsql.php 8091 2011-06-01 13:44:50Z vargenau $
+<?php
 
 /*
  * Copyright (C) 2001-2009 $ThePhpWikiProgrammingTeam
@@ -44,51 +43,55 @@
  * ALONE BASIS."
  */
 
-
-require_once('lib/ErrorManager.php');
-require_once('lib/WikiDB/backend/PearDB_pgsql.php');
+require_once 'lib/ErrorManager.php';
+require_once 'lib/WikiDB/backend/PearDB_pgsql.php';
 
 class WikiDB_backend_PearDB_ffpgsql
-extends WikiDB_backend_PearDB_pgsql
+    extends WikiDB_backend_PearDB_pgsql
 {
-    function WikiDB_backend_PearDB_ffpgsql($dbparams) {
+    function WikiDB_backend_PearDB_ffpgsql($dbparams)
+    {
         $dbparams['dsn'] = str_replace('ffpgsql:', 'pgsql:', $dbparams['dsn']);
         parent::WikiDB_backend_PearDB_pgsql($dbparams);
 
-        $p = strlen(PAGE_PREFIX)+1;
+        $p = strlen(PAGE_PREFIX) + 1;
         $page_tbl = $this->_table_names['page_tbl'];
         $this->page_tbl_fields = "$page_tbl.id AS id, substring($page_tbl.pagename from $p) AS pagename, $page_tbl.hits AS hits";
 
         pg_set_client_encoding("iso-8859-1");
     }
 
-    function get_all_pagenames() {
+    function get_all_pagenames()
+    {
         $dbh = &$this->_dbh;
         extract($this->_table_names);
         $pat = PAGE_PREFIX;
-        $p = strlen($pat)+1;
+        $p = strlen($pat) + 1;
         return $dbh->getCol("SELECT substring(pagename from $p)"
-                            . " FROM $nonempty_tbl, $page_tbl"
-                            . " WHERE $nonempty_tbl.id=$page_tbl.id"
-                            . " AND substring($page_tbl.pagename from 0 for $p) = '$pat'");
+            . " FROM $nonempty_tbl, $page_tbl"
+            . " WHERE $nonempty_tbl.id=$page_tbl.id"
+            . " AND substring($page_tbl.pagename from 0 for $p) = '$pat'");
     }
 
-    function numPages($filter=false, $exclude='') {
+    function numPages($filter = false, $exclude = '')
+    {
         $dbh = &$this->_dbh;
         extract($this->_table_names);
         $pat = PAGE_PREFIX;
-        $p = strlen($pat)+1;
+        $p = strlen($pat) + 1;
         return $dbh->getOne("SELECT count(*)"
-                            . " FROM $nonempty_tbl, $page_tbl"
-                            . " WHERE $nonempty_tbl.id=$page_tbl.id"
-                            . " AND substring($page_tbl.pagename from 0 for $p) = '$pat'");
+            . " FROM $nonempty_tbl, $page_tbl"
+            . " WHERE $nonempty_tbl.id=$page_tbl.id"
+            . " AND substring($page_tbl.pagename from 0 for $p) = '$pat'");
     }
 
-    function get_pagedata($pagename) {
-        return parent::get_pagedata(PAGE_PREFIX.$pagename);
+    function get_pagedata($pagename)
+    {
+        return parent::get_pagedata(PAGE_PREFIX . $pagename);
     }
 
-    function update_pagedata($pagename, $newdata) {
+    function update_pagedata($pagename, $newdata)
+    {
         $dbh = &$this->_dbh;
         $page_tbl = $this->_table_names['page_tbl'];
 
@@ -97,9 +100,9 @@ extends WikiDB_backend_PearDB_pgsql
             // Note that this will fail silently if the page does not
             // have a record in the page table.  Since it's just the
             // hit count, who cares?
-	        $pagename = PAGE_PREFIX.$pagename;
+            $pagename = PAGE_PREFIX . $pagename;
             $dbh->query(sprintf("UPDATE $page_tbl SET hits=%d WHERE pagename='%s'",
-                                $newdata['hits'], $dbh->escapeSimple($pagename)));
+                $newdata['hits'], $dbh->escapeSimple($pagename)));
             return;
         }
 
@@ -109,12 +112,12 @@ extends WikiDB_backend_PearDB_pgsql
             $data = array();
             $this->_get_pageid($pagename, true); // Creates page record
         }
-      
+
         if (isset($data['hits'])) {
-             $hits = (int)$data['hits'];
-             unset($data['hits']);
+            $hits = (int)$data['hits'];
+            unset($data['hits']);
         } else {
-             $hits = 0;
+            $hits = 0;
         }
 
         foreach ($newdata as $key => $val) {
@@ -136,65 +139,70 @@ extends WikiDB_backend_PearDB_pgsql
                             $dbh->escapeSimple($this->_serialize($data)),
                             $dbh->escapeSimple($pagename)));
         */
-        $pagename = PAGE_PREFIX.$pagename;
+        $pagename = PAGE_PREFIX . $pagename;
         $dbh->query("UPDATE $page_tbl"
-                    . " SET hits=?, pagedata=?"
-                    . " WHERE pagename=?",
-                    array($hits, $this->_serialize($data), $pagename));
+                . " SET hits=?, pagedata=?"
+                . " WHERE pagename=?",
+            array($hits, $this->_serialize($data), $pagename));
         $this->unlock(array($page_tbl));
     }
 
-    function get_latest_version($pagename) {
-        return parent::get_latest_version(PAGE_PREFIX.$pagename);
+    function get_latest_version($pagename)
+    {
+        return parent::get_latest_version(PAGE_PREFIX . $pagename);
     }
 
-    function get_previous_version($pagename, $version) {
-        return parent::get_previous_version(PAGE_PREFIX.$pagename, $version);
+    function get_previous_version($pagename, $version)
+    {
+        return parent::get_previous_version(PAGE_PREFIX . $pagename, $version);
     }
 
-    function get_versiondata($pagename, $version, $want_content = false) {
+    function get_versiondata($pagename, $version, $want_content = false)
+    {
         $dbh = &$this->_dbh;
         extract($this->_table_names);
         extract($this->_expressions);
 
         // assert(is_string($pagename) and $pagename != "");
         // assert($version > 0);
-      
+
         //trigger_error("GET_REVISION $pagename $version $want_content", E_USER_NOTICE);
         // FIXME: optimization: sometimes don't get page data?
         if ($want_content) {
             $fields = $this->page_tbl_fields
                 . ",$page_tbl.pagedata as pagedata,"
                 . $this->version_tbl_fields;
-        }
-        else {
+        } else {
             $fields = $this->page_tbl_fields . ","
                 . "mtime, minor_edit, versiondata,"
                 . "$iscontent AS have_content";
         }
 
-        $pagename = PAGE_PREFIX.$pagename;
+        $pagename = PAGE_PREFIX . $pagename;
         $result = $dbh->getRow(sprintf("SELECT $fields"
-                                       . " FROM $page_tbl, $version_tbl"
-                                       . " WHERE $page_tbl.id=$version_tbl.id"
-                                       . "  AND pagename='%s'"
-                                       . "  AND version=%d",
-                                       $dbh->escapeSimple($pagename), $version),
-                               DB_FETCHMODE_ASSOC);
+                    . " FROM $page_tbl, $version_tbl"
+                    . " WHERE $page_tbl.id=$version_tbl.id"
+                    . "  AND pagename='%s'"
+                    . "  AND version=%d",
+                $dbh->escapeSimple($pagename), $version),
+            DB_FETCHMODE_ASSOC);
 
         return $this->_extract_version_data($result);
     }
 
-    function get_cached_html($pagename) {
-        return parent::get_cached_html(PAGE_PREFIX.$pagename);
+    function get_cached_html($pagename)
+    {
+        return parent::get_cached_html(PAGE_PREFIX . $pagename);
     }
 
-    function set_cached_html($pagename, $data) {
-        return parent::set_cached_html(PAGE_PREFIX.$pagename, $data);
+    function set_cached_html($pagename, $data)
+    {
+        return parent::set_cached_html(PAGE_PREFIX . $pagename, $data);
     }
 
-    function _get_pageid($pagename, $create_if_missing = false) {
-      
+    function _get_pageid($pagename, $create_if_missing = false)
+    {
+
         // check id_cache
         global $request;
         $cache =& $request->_dbi->_cache->_id_cache;
@@ -204,15 +212,15 @@ extends WikiDB_backend_PearDB_pgsql
             }
         }
 
-	// attributes play this game.
+        // attributes play this game.
         if ($pagename === '') return 0;
 
         $dbh = &$this->_dbh;
         $page_tbl = $this->_table_names['page_tbl'];
-        $pagename = PAGE_PREFIX.$pagename;
-      
+        $pagename = PAGE_PREFIX . $pagename;
+
         $query = sprintf("SELECT id FROM $page_tbl WHERE pagename='%s'",
-                         $dbh->escapeSimple($pagename));
+            $dbh->escapeSimple($pagename));
 
         if (!$create_if_missing)
             return $dbh->getOne($query);
@@ -225,20 +233,21 @@ extends WikiDB_backend_PearDB_pgsql
             // requires createSequence and on mysql lock the interim table ->getSequenceName
             //$id = $dbh->nextId($page_tbl . "_id");
             $dbh->query(sprintf("INSERT INTO $page_tbl"
-                                . " (id,pagename,hits)"
-                                . " VALUES (%d,'%s',0)",
-                                $id, $dbh->escapeSimple($pagename)));
+                    . " (id,pagename,hits)"
+                    . " VALUES (%d,'%s',0)",
+                $id, $dbh->escapeSimple($pagename)));
             $this->unlock(array($page_tbl));
         }
         return $id;
     }
 
-    function purge_page($pagename) {
+    function purge_page($pagename)
+    {
         $dbh = &$this->_dbh;
         extract($this->_table_names);
-      
+
         $this->lock();
-        if ( ($id = $this->_get_pageid($pagename, false)) ) {
+        if (($id = $this->_get_pageid($pagename, false))) {
             $dbh->query("DELETE FROM $nonempty_tbl WHERE id=$id");
             $dbh->query("DELETE FROM $recent_tbl   WHERE id=$id");
             $dbh->query("DELETE FROM $version_tbl  WHERE id=$id");
@@ -249,8 +258,7 @@ extends WikiDB_backend_PearDB_pgsql
                 // altogether.
                 $dbh->query("UPDATE $page_tbl SET hits=0, pagedata='' WHERE id=$id");
                 $result = 0;
-            }
-            else {
+            } else {
                 $dbh->query("DELETE FROM $page_tbl WHERE id=$id");
                 $result = 1;
             }
@@ -261,26 +269,26 @@ extends WikiDB_backend_PearDB_pgsql
         return $result;
     }
 
-    function get_links($pagename, $reversed=true, $include_empty=false,
-                       $sortby='', $limit='', $exclude='',
+    function get_links($pagename, $reversed = true, $include_empty = false,
+                       $sortby = '', $limit = '', $exclude = '',
                        $want_relations = false)
     {
         $dbh = &$this->_dbh;
         extract($this->_table_names);
 
         if ($reversed)
-            list($have,$want) = array('linkee', 'linker');
+            list($have, $want) = array('linkee', 'linker');
         else
-            list($have,$want) = array('linker', 'linkee');
+            list($have, $want) = array('linker', 'linkee');
         $orderby = $this->sortby($sortby, 'db', array('pagename'));
         if ($orderby) $orderby = " ORDER BY $want." . $orderby;
         if ($exclude) // array of pagenames
-            $exclude = " AND $want.pagename NOT IN ".$this->_sql_set($exclude);
+            $exclude = " AND $want.pagename NOT IN " . $this->_sql_set($exclude);
         else
-            $exclude='';
+            $exclude = '';
 
         $pat = PAGE_PREFIX;
-        $p = strlen($pat)+1;
+        $p = strlen($pat) + 1;
 
         $qpagename = $dbh->escapeSimple($pagename);
         // MeV+APe 2007-11-14
@@ -300,28 +308,29 @@ extends WikiDB_backend_PearDB_pgsql
             . $orderby;
         if ($limit) {
             // extract from,count from limit
-            list($from,$count) = $this->limit($limit);
+            list($from, $count) = $this->limit($limit);
             $result = $dbh->limitQuery($sql, $from, $count);
         } else {
             $result = $dbh->query($sql);
         }
-      
+
         return new WikiDB_backend_PearDB_iter($this, $result);
     }
 
-    function get_all_pages($include_empty=false, $sortby='', $limit='', $exclude='') {
+    function get_all_pages($include_empty = false, $sortby = '', $limit = '', $exclude = '')
+    {
         $dbh = &$this->_dbh;
         extract($this->_table_names);
 
         $pat = PAGE_PREFIX;
-        $p = strlen($pat)+1;
+        $p = strlen($pat) + 1;
 
         $orderby = $this->sortby($sortby, 'db');
         if ($orderby) $orderby = ' ORDER BY ' . $orderby;
         if ($exclude) // array of pagenames
-            $exclude = " AND $page_tbl.pagename NOT IN ".$this->_sql_set($exclude);
+            $exclude = " AND $page_tbl.pagename NOT IN " . $this->_sql_set($exclude);
         else
-            $exclude='';
+            $exclude = '';
 
         if (strstr($orderby, 'mtime ')) { // multiple columns possible
             if ($include_empty) {
@@ -330,18 +339,17 @@ extends WikiDB_backend_PearDB_pgsql
                     . " FROM $page_tbl, $recent_tbl, $version_tbl"
                     . " WHERE $page_tbl.id=$recent_tbl.id"
                     . " AND $page_tbl.id=$version_tbl.id AND latestversion=version"
-		            . " AND substring($page_tbl.pagename from 0 for $p) = '$pat'"
+                    . " AND substring($page_tbl.pagename from 0 for $p) = '$pat'"
                     . $exclude
                     . $orderby;
-            }
-            else {
+            } else {
                 $sql = "SELECT "
                     . $this->page_tbl_fields
                     . " FROM $nonempty_tbl, $page_tbl, $recent_tbl, $version_tbl"
                     . " WHERE $nonempty_tbl.id=$page_tbl.id"
                     . " AND $page_tbl.id=$recent_tbl.id"
                     . " AND $page_tbl.id=$version_tbl.id AND latestversion=version"
-		            . " AND substring($page_tbl.pagename from 0 for $p) = '$pat'"
+                    . " AND substring($page_tbl.pagename from 0 for $p) = '$pat'"
                     . $exclude
                     . $orderby;
             }
@@ -352,22 +360,21 @@ extends WikiDB_backend_PearDB_pgsql
                     . " FROM $page_tbl"
                     . ($exclude ? " WHERE $exclude" : '')
                     . ($exclude ? " AND " : " WHERE ")
-                    	. " substring($page_tbl.pagename from 0 for $p) = '$pat'"
+                    . " substring($page_tbl.pagename from 0 for $p) = '$pat'"
                     . $orderby;
-            }
-            else {
+            } else {
                 $sql = "SELECT "
                     . $this->page_tbl_fields
                     . " FROM $nonempty_tbl, $page_tbl"
                     . " WHERE $nonempty_tbl.id=$page_tbl.id"
-		            . " AND substring($page_tbl.pagename from 0 for $p) = '$pat'"
+                    . " AND substring($page_tbl.pagename from 0 for $p) = '$pat'"
                     . $exclude
                     . $orderby;
             }
         }
         if ($limit && $orderby) {
             // extract from,count from limit
-            list($from,$count) = $this->limit($limit);
+            list($from, $count) = $this->limit($limit);
             $result = $dbh->limitQuery($sql, $from, $count);
             $options = array('limit_by_db' => 1);
         } else {
@@ -377,12 +384,13 @@ extends WikiDB_backend_PearDB_pgsql
         return new WikiDB_backend_PearDB_iter($this, $result, $options);
     }
 
-    function most_popular($limit=20, $sortby='-hits') {
+    function most_popular($limit = 20, $sortby = '-hits')
+    {
         $dbh = &$this->_dbh;
         extract($this->_table_names);
         $pat = PAGE_PREFIX;
-        $p = strlen($pat)+1;
-        if ($limit < 0){
+        $p = strlen($pat) + 1;
+        if ($limit < 0) {
             $order = "hits ASC";
             $limit = -$limit;
             $where = "";
@@ -405,17 +413,18 @@ extends WikiDB_backend_PearDB_pgsql
             . " AND substring($page_tbl.pagename from 0 for $p) = '$pat'"
             . $where
             . $orderby;
-         if ($limit) {
-             list($from, $count) = $this->limit($limit);
-             $result = $dbh->limitQuery($sql, $from, $count);
-         } else {
-             $result = $dbh->query($sql);
-         }
+        if ($limit) {
+            list($from, $count) = $this->limit($limit);
+            $result = $dbh->limitQuery($sql, $from, $count);
+        } else {
+            $result = $dbh->query($sql);
+        }
 
         return new WikiDB_backend_PearDB_iter($this, $result);
     }
 
-    function most_recent($params) {
+    function most_recent($params)
+    {
         $limit = 0;
         $since = 0;
         $include_minor_revisions = false;
@@ -429,43 +438,38 @@ extends WikiDB_backend_PearDB_pgsql
         $pick = array();
         if ($since)
             $pick[] = "mtime >= $since";
-	
-      
+
         if ($include_all_revisions) {
             // Include all revisions of each page.
             $table = "$page_tbl, $version_tbl";
             $join_clause = "$page_tbl.id=$version_tbl.id";
 
             if ($exclude_major_revisions) {
-		// Include only minor revisions
+                // Include only minor revisions
                 $pick[] = "minor_edit <> 0";
-            }
-            elseif (!$include_minor_revisions) {
-		// Include only major revisions
+            } elseif (!$include_minor_revisions) {
+                // Include only major revisions
                 $pick[] = "minor_edit = 0";
             }
-        }
-        else {
+        } else {
             $table = "$page_tbl, $recent_tbl";
             $join_clause = "$page_tbl.id=$recent_tbl.id";
             $table .= ", $version_tbl";
             $join_clause .= " AND $version_tbl.id=$page_tbl.id";
-          
+
             if ($exclude_major_revisions) {
                 // Include only most recent minor revision
                 $pick[] = 'version=latestminor';
-            }
-            elseif (!$include_minor_revisions) {
+            } elseif (!$include_minor_revisions) {
                 // Include only most recent major revision
                 $pick[] = 'version=latestmajor';
-            }
-            else {
+            } else {
                 // Include only the latest revision (whether major or minor).
-                $pick[] ='version=latestversion';
+                $pick[] = 'version=latestversion';
             }
         }
         $order = "DESC";
-        if($limit < 0){
+        if ($limit < 0) {
             $order = "ASC";
             $limit = -$limit;
         }
@@ -475,46 +479,47 @@ extends WikiDB_backend_PearDB_pgsql
             $where_clause .= " AND " . join(" AND ", $pick);
 
         $pat = PAGE_PREFIX;
-        $p = strlen($pat)+1;
+        $p = strlen($pat) + 1;
 
         // FIXME: use SQL_BUFFER_RESULT for mysql?
         $sql = "SELECT "
-               . $this->page_tbl_fields . ", " . $this->version_tbl_fields
-               . " FROM $table"
-               . " WHERE $where_clause"
-	           . " AND substring($page_tbl.pagename from 0 for $p) = '$pat'"
-               . " ORDER BY mtime $order";
+            . $this->page_tbl_fields . ", " . $this->version_tbl_fields
+            . " FROM $table"
+            . " WHERE $where_clause"
+            . " AND substring($page_tbl.pagename from 0 for $p) = '$pat'"
+            . " ORDER BY mtime $order";
         if ($limit) {
-             list($from, $count) = $this->limit($limit);
-             $result = $dbh->limitQuery($sql, $from, $count);
+            list($from, $count) = $this->limit($limit);
+            $result = $dbh->limitQuery($sql, $from, $count);
         } else {
             $result = $dbh->query($sql);
         }
         return new WikiDB_backend_PearDB_iter($this, $result);
     }
 
-    function wanted_pages($exclude_from='', $exclude='', $sortby='', $limit='') {
+    function wanted_pages($exclude_from = '', $exclude = '', $sortby = '', $limit = '')
+    {
         $dbh = &$this->_dbh;
         extract($this->_table_names);
         $pat = PAGE_PREFIX;
-        $p = strlen($pat)+1;
-        if ($orderby = $this->sortby($sortby, 'db', array('pagename','wantedfrom')))
+        $p = strlen($pat) + 1;
+        if ($orderby = $this->sortby($sortby, 'db', array('pagename', 'wantedfrom')))
             $orderby = 'ORDER BY ' . $orderby;
 
         if ($exclude_from) // array of pagenames
-            $exclude_from = " AND pp.pagename NOT IN ".$this->_sql_set($exclude_from);
+            $exclude_from = " AND pp.pagename NOT IN " . $this->_sql_set($exclude_from);
         if ($exclude) // array of pagenames
-            $exclude = " AND p.pagename NOT IN ".$this->_sql_set($exclude);
+            $exclude = " AND p.pagename NOT IN " . $this->_sql_set($exclude);
 
-        $p = strlen(PAGE_PREFIX)+1;
+        $p = strlen(PAGE_PREFIX) + 1;
         $sql = "SELECT substring(p.pagename from $p) AS wantedfrom, substring(pp.pagename from $p) AS pagename"
             . " FROM $page_tbl p, $link_tbl linked"
-            .   " LEFT JOIN $page_tbl pp ON linked.linkto = pp.id"
-            .   " LEFT JOIN $nonempty_tbl ne ON linked.linkto = ne.id"
+            . " LEFT JOIN $page_tbl pp ON linked.linkto = pp.id"
+            . " LEFT JOIN $nonempty_tbl ne ON linked.linkto = ne.id"
             . " WHERE ne.id IS NULL"
-            .       " AND p.id = linked.linkfrom"
-            .		" AND substring(p.pagename from 0 for $p) = '$pat'"
-            .		" AND substring(pp.pagename from 0 for $p) = '$pat'"
+            . " AND p.id = linked.linkfrom"
+            . " AND substring(p.pagename from 0 for $p) = '$pat'"
+            . " AND substring(pp.pagename from 0 for $p) = '$pat'"
             . $exclude_from
             . $exclude
             . $orderby;
@@ -528,12 +533,13 @@ extends WikiDB_backend_PearDB_pgsql
         return new WikiDB_backend_PearDB_generic_iter($this, $result);
     }
 
-    function rename_page ($pagename, $to) {
+    function rename_page($pagename, $to)
+    {
         $dbh = &$this->_dbh;
         extract($this->_table_names);
-      
+
         $this->lock();
-        if (($id = $this->_get_pageid($pagename, false)) ) {
+        if (($id = $this->_get_pageid($pagename, false))) {
             if ($new = $this->_get_pageid($to, false)) {
                 // Cludge Alert!
                 // This page does not exist (already verified before), but exists in the page table.
@@ -547,21 +553,24 @@ extends WikiDB_backend_PearDB_pgsql
                 $dbh->query("DELETE FROM $page_tbl WHERE id=$new");
             }
             $dbh->query(sprintf("UPDATE $page_tbl SET pagename='%s' WHERE id=$id",
-                                $dbh->escapeSimple(PAGE_PREFIX.$to)));
+                $dbh->escapeSimple(PAGE_PREFIX . $to)));
         }
         $this->unlock();
         return $id;
     }
 
-    function is_wiki_page($pagename) {
-        return parent::is_wiki_page(PAGE_PREFIX.$pagename);
+    function is_wiki_page($pagename)
+    {
+        return parent::is_wiki_page(PAGE_PREFIX . $pagename);
     }
 
-    function increaseHitCount($pagename) {
-        return parent::increaseHitCount(PAGE_PREFIX.$pagename);
+    function increaseHitCount($pagename)
+    {
+        return parent::increaseHitCount(PAGE_PREFIX . $pagename);
     }
 
-    function _serialize($data) {
+    function _serialize($data)
+    {
         return WikiDB_backend_PearDB::_serialize($data);
     }
 
@@ -569,29 +578,30 @@ extends WikiDB_backend_PearDB_pgsql
      * Pack tables.
      * NOTE: Disable vacuum, wikiuser is not the table owner
      */
-    function optimize() {
+    function optimize()
+    {
         return 0;
     }
 
     /**
      * Title search.
      */
-    function text_search($search, $fulltext=false, $sortby='', $limit='',
-                         $exclude='')
+    function text_search($search, $fulltext = false, $sortby = '', $limit = '',
+                         $exclude = '')
     {
         $dbh = &$this->_dbh;
         extract($this->_table_names);
         $pat = PAGE_PREFIX;
-        $len = strlen($pat)+1;
+        $len = strlen($pat) + 1;
         $orderby = $this->sortby($sortby, 'db');
         if ($sortby and $orderby) $orderby = ' ORDER BY ' . $orderby;
 
-        $searchclass = get_class($this)."_search";
+        $searchclass = get_class($this) . "_search";
         // no need to define it everywhere and then fallback. memory!
         if (!class_exists($searchclass))
             $searchclass = "WikiDB_backend_PearDB_search";
         $searchobj = new $searchclass($search, $dbh);
-      
+
         $table = "$nonempty_tbl, $page_tbl";
         $join_clause = "$nonempty_tbl.id=$page_tbl.id";
         $fields = $this->page_tbl_fields;
@@ -604,73 +614,75 @@ extends WikiDB_backend_PearDB_pgsql
             $join_clause .= " AND $page_tbl.id=$version_tbl.id AND latestversion=version";
 
             $fields .= ", $page_tbl.pagedata as pagedata, " . $this->version_tbl_fields;
-	    // TODO: title still ignored, need better rank and subselect
+            // TODO: title still ignored, need better rank and subselect
             $callback = new WikiMethodCb($searchobj, "_fulltext_match_clause");
             $search_string = $search->makeTsearch2SqlClauseObj($callback);
-            $search_string = str_replace(array("%"," "), array("","&"), $search_string);
+            $search_string = str_replace('%', '', $search_string);
             $search_clause = "substring(plugin_wiki_page.pagename from 0 for $len) = '$pat') AND (";
 
-            $search_clause .= "idxFTI @@ to_tsquery('$search_string')";
+            $search_clause .= "idxFTI @@ to_tsquery('english', '$search_string')";
             if (!$orderby)
-               $orderby = " ORDER BY ts_rank(idxFTI, to_tsquery('$search_string')) DESC";
+                $orderby = " ORDER BY ts_rank(idxFTI, to_tsquery('english', '$search_string')) DESC";
         } else {
             $callback = new WikiMethodCb($searchobj, "_pagename_match_clause");
             $search_clause = "substring(plugin_wiki_page.pagename from 0 for $len) = '$pat') AND (";
             $search_clause .= $search->makeSqlClauseObj($callback);
         }
-      
+
         $sql = "SELECT $fields FROM $table"
             . " WHERE $join_clause"
             . "  AND ($search_clause)"
             . $orderby;
-         if ($limit) {
-             list($from, $count) = $this->limit($limit);
-             $result = $dbh->limitQuery($sql, $from, $count);
-         } else {
-             $result = $dbh->query($sql);
-         }
-      
+        if ($limit) {
+            list($from, $count) = $this->limit($limit);
+            $result = $dbh->limitQuery($sql, $from, $count);
+        } else {
+            $result = $dbh->query($sql);
+        }
+
         $iter = new WikiDB_backend_PearDB_iter($this, $result);
         $iter->stoplisted = @$searchobj->stoplisted;
         return $iter;
     }
 
-     function exists_link($pagename, $link, $reversed=false) {
-         $dbh = &$this->_dbh;
-         extract($this->_table_names);
+    function exists_link($pagename, $link, $reversed = false)
+    {
+        $dbh = &$this->_dbh;
+        extract($this->_table_names);
 
-         if ($reversed)
-             list($have, $want) = array('linkee', 'linker');
-         else
-             list($have, $want) = array('linker', 'linkee');
-         $qpagename = $dbh->escapeSimple($pagename);
-         $qlink = $dbh->escapeSimple($link);
-         $row = $dbh->GetRow("SELECT $want.pagename as result"
-                                 . " FROM $link_tbl, $page_tbl linker, $page_tbl linkee, $nonempty_tbl"
-                                 . " WHERE linkfrom=linker.id AND linkto=linkee.id"
-                                 . " AND $have.pagename='$qpagename'"
-                                 . " AND $want.pagename='$qlink'"
-                                 . " LIMIT 1");
-         return $row['result'] ? 1 : 0;
-     }
-};
+        if ($reversed)
+            list($have, $want) = array('linkee', 'linker');
+        else
+            list($have, $want) = array('linker', 'linkee');
+        $qpagename = $dbh->escapeSimple($pagename);
+        $qlink = $dbh->escapeSimple($link);
+        $row = $dbh->GetRow("SELECT $want.pagename as result"
+            . " FROM $link_tbl, $page_tbl linker, $page_tbl linkee, $nonempty_tbl"
+            . " WHERE linkfrom=linker.id AND linkto=linkee.id"
+            . " AND $have.pagename='$qpagename'"
+            . " AND $want.pagename='$qlink'"
+            . " LIMIT 1");
+        return $row['result'] ? 1 : 0;
+    }
+}
 
 class WikiDB_backend_PearDB_ffpgsql_search
-extends WikiDB_backend_PearDB_pgsql_search
+    extends WikiDB_backend_PearDB_pgsql_search
 {
-    function _pagename_match_clause($node) {
+    function _pagename_match_clause($node)
+    {
         $word = $node->sql();
         // @alu: use _quote maybe instead of direct pg_escape_string
         $word = pg_escape_string($word);
-        $len = strlen(PAGE_PREFIX)+1;
+        $len = strlen(PAGE_PREFIX) + 1;
         if ($node->op == 'REGEX') { // posix regex extensions
             return ($this->_case_exact
-                    ? "substring(pagename from $len) ~* '$word'"
-                    : "substring(pagename from $len) ~ '$word'");
+                ? "substring(pagename from $len) ~* '$word'"
+                : "substring(pagename from $len) ~ '$word'");
         } else {
             return ($this->_case_exact
-                    ? "substring(pagename from $len) LIKE '$word'"
-                    : "substring(pagename from $len) ILIKE '$word'");
+                ? "substring(pagename from $len) LIKE '$word'"
+                : "substring(pagename from $len) ILIKE '$word'");
         }
     }
 
@@ -689,9 +701,10 @@ extends WikiDB_backend_PearDB_pgsql_search
      The full-text index will still be used, and the regex will be used to
      prune the results afterwards.
     */
-    function _fulltext_match_clause($node) {
+    function _fulltext_match_clause($node)
+    {
         $word = strtolower($node->word);
-        $word = str_replace(" ", "&", $word); // phrase fix
+        // $word = str_replace(" ", "&", $word); // phrase fix
 
         // @alu: use _quote maybe instead of direct pg_escape_string
         $word = pg_escape_string($word);
@@ -706,5 +719,4 @@ extends WikiDB_backend_PearDB_pgsql_search
 // c-basic-offset: 4
 // c-hanging-comment-ender-p: nil
 // indent-tabs-mode: nil
-// End: 
-?>
+// End:
