@@ -1,7 +1,6 @@
-<?php // -*-php-*-
-// $Id: BackLinkIter.php 7956 2011-03-03 17:08:31Z vargenau $
+<?php
 
-require_once('lib/WikiDB/backend.php');
+require_once 'lib/WikiDB/backend.php';
 
 /**
  * This backlink iterator will work with any WikiDB_backend
@@ -10,15 +9,17 @@ require_once('lib/WikiDB/backend.php');
  * This is mostly here for testing, 'cause it's slow,slow,slow.
  */
 class WikiDB_backend_dumb_BackLinkIter
-extends WikiDB_backend_iterator
+    extends WikiDB_backend_iterator
 {
-    function WikiDB_backend_dumb_BackLinkIter(&$backend, &$all_pages, $pagename) {
+    function WikiDB_backend_dumb_BackLinkIter(&$backend, &$all_pages, $pagename)
+    {
         $this->_pages = $all_pages;
         $this->_backend = &$backend;
         $this->_target = $pagename;
     }
-  
-    function next() {
+
+    function next()
+    {
         while ($page = $this->_pages->next()) {
             $pagename = $page['pagename'];
             $links = $this->_backend->get_links($pagename, false);
@@ -30,8 +31,9 @@ extends WikiDB_backend_iterator
             }
         }
     }
-  
-    function free() {
+
+    function free()
+    {
         $this->_pages->free();
     }
 }
@@ -43,5 +45,3 @@ extends WikiDB_backend_iterator
 // c-hanging-comment-ender-p: nil
 // indent-tabs-mode: nil
 // End:
-
-?>
