@@ -1,9 +1,11 @@
-<?php //-*-php-*-
-// $Id: WikiPlugin.php 7964 2011-03-05 17:05:30Z vargenau $
+<?php
 
 class WikiPlugin
 {
-    function getDefaultArguments() {
+    public $_pi;
+
+    function getDefaultArguments()
+    {
         return array('description' => $this->getDescription());
     }
 
@@ -25,14 +27,16 @@ class WikiPlugin
      * any page which invokes the plugin uncacheable (by HTTP proxies
      * or browsers).
      */
-    function managesValidators() {
+    function managesValidators()
+    {
         return false;
     }
 
     // FIXME: args?
-    function run ($dbi, $argstr, &$request, $basepage) {
-        trigger_error("WikiPlugin::run: pure virtual function",
-                      E_USER_ERROR);
+    function run($dbi, $argstr, &$request, $basepage)
+    {
+        trigger_error("WikiPlugin::run: pure virtual function", E_USER_ERROR);
+        return false;
     }
 
     /** Get wiki-pages linked to by plugin invocation.
@@ -52,11 +56,12 @@ class WikiPlugin
      * args, not the rest of the wikidb state or any request query args)
      * will work correctly here.
      *
-     * @param string $argstr The plugin argument string.
-     * @param string $basepage The pagename the plugin is invoked from.
-     * @return array List of pagenames linked to (or false).
+     * @param  string $argstr   The plugin argument string.
+     * @param  string $basepage The pagename the plugin is invoked from.
+     * @return array  List of pagenames linked to (or false).
      */
-    function getWikiPageLinks ($argstr, $basepage) {
+    function getWikiPageLinks($argstr, $basepage)
+    {
         return false;
     }
 
@@ -67,66 +72,78 @@ class WikiPlugin
      * getDefaultFormArguments to compute the default link/form
      * targets.
      *
-     * If you want to gettextify the name (probably a good idea),
-     * override this method in your plugin class, like:
+     * If you override this method in your plugin class,
+     * you MUST NOT translate the name.
      * <pre>
-     *   function getName() { return _("MyPlugin"); }
+     *   function getName() { return "MyPlugin"; }
      * </pre>
      *
      * @return string plugin name/target.
      */
-    function getName() {
-        return preg_replace('/^.*_/', '',  get_class($this));
+    function getName()
+    {
+        return preg_replace('/^WikiPlugin_/', '', get_class($this));
     }
 
-    function getDescription() {
-        return $this->getName();
+    /**
+     * Get description of plugin.
+     *
+     * This method should be overriden in your plugin class, like:
+     * <pre>
+     *   function getDescription() { return _("MyPlugin does this..."); }
+     * </pre>
+     *
+     * @return string plugin description
+     */
+
+    function getDescription()
+    {
+        return _('This plugin has no description.');
     }
 
-    function getArgs($argstr, $request=false, $defaults=false) {
-        if ($defaults === false) {
+    function getArgs($argstr, $request = false, $defaults = array())
+    {
+        if (empty($defaults)) {
             $defaults = $this->getDefaultArguments();
         }
         //Fixme: on POST argstr is empty
         list ($argstr_args, $argstr_defaults) = $this->parseArgStr($argstr);
         $args = array();
         if (!empty($defaults))
-          foreach ($defaults as $arg => $default_val) {
-            if (isset($argstr_args[$arg])) {
-                $args[$arg] = $argstr_args[$arg];
-            } elseif ( $request and ($argval = $request->getArg($arg)) !== false ) {
-                $args[$arg] = $argval;
-            } elseif (isset($argstr_defaults[$arg])) {
-                $args[$arg] = (string) $argstr_defaults[$arg];
-            } else {
-                $args[$arg] = $default_val;
-            }
-            // expand [arg]
-            if ($request and is_string($args[$arg]) and strstr($args[$arg], "[")) {
-                $args[$arg] = $this->expandArg($args[$arg], $request);
-            }
+            foreach ($defaults as $arg => $default_val) {
+                if (isset($argstr_args[$arg])) {
+                    $args[$arg] = $argstr_args[$arg];
+                } elseif ($request and ($argval = $request->getArg($arg)) !== false) {
+                    $args[$arg] = $argval;
+                } elseif (isset($argstr_defaults[$arg])) {
+                    $args[$arg] = (string)$argstr_defaults[$arg];
+                } else {
+                    $args[$arg] = $default_val;
+                }
+                // expand [arg]
+                if ($request and is_string($args[$arg]) and strstr($args[$arg], "[")) {
+                    $args[$arg] = $this->expandArg($args[$arg], $request);
+                }
 
-            unset($argstr_args[$arg]);
-            unset($argstr_defaults[$arg]);
-        }
+                unset($argstr_args[$arg]);
+                unset($argstr_defaults[$arg]);
+            }
 
         foreach (array_merge($argstr_args, $argstr_defaults) as $arg => $val) {
-        // TODO: where the heck comes this from? Put the new method over there and peace.
-            /*if ($request and $request->getArg('pagename') == _("PhpWikiAdministration")
-                and $arg == 'overwrite') // silence this warning
-                ;*/
-            if ($this->allow_undeclared_arg($arg, $val))
+            if ($this->allow_undeclared_arg($arg, $val)) {
                 $args[$arg] = $val;
+            }
         }
 
         // Add special handling of pages and exclude args to accept <! plugin-list !>
         // and split explodePageList($args['exclude']) => array()
         // TODO : handle p[] pagehash
         foreach (array('pages', 'exclude') as $key) {
-            if (!empty($args[$key]) and array_key_exists($key, $defaults))
+            if (!empty($args[$key]) and array_key_exists($key, $defaults)) {
                 $args[$key] = is_string($args[$key])
                     ? explodePageList($args[$key])
                     : $args[$key]; // <! plugin-list !>
+            }
         }
 
         return $args;
@@ -134,20 +151,22 @@ class WikiPlugin
 
     // Patch by Dan F:
     // Expand [arg] to $request->getArg("arg") unless preceded by ~
-    function expandArg($argval, &$request) {
+    function expandArg($argval, &$request)
+    {
         // return preg_replace('/\[(\w[\w\d]*)\]/e', '$request->getArg("$1")',
         // Replace the arg unless it is preceded by a ~
         $ret = preg_replace('/([^~]|^)\[(\w[\w\d]*)\]/e',
-                            '"$1" . $request->getArg("$2")',
-                           $argval);
+            '"$1" . $request->getArg("$2")',
+            $argval);
         // Ditch the ~ so later versions can be expanded if desired
         return preg_replace('/~(\[\w[\w\d]*\])/', '$1', $ret);
     }
 
-    function parseArgStr($argstr) {
+    function parseArgStr($argstr)
+    {
         $args = array();
         $defaults = array();
-    if (empty($argstr))
+        if (empty($argstr))
             return array($args, $defaults);
 
         $arg_p = '\w+';
@@ -156,19 +175,19 @@ class WikiPlugin
         $opt_ws = '\s*';
         $qq_p = '" ( (?:[^"\\\\]|\\\\.)* ) "';
         //"<--kludge for brain-dead syntax coloring
-        $q_p  = "' ( (?:[^'\\\\]|\\\\.)* ) '";
+        $q_p = "' ( (?:[^'\\\\]|\\\\.)* ) '";
         $gt_p = "_\\( $opt_ws $qq_p $opt_ws \\)";
         $argspec_p = "($arg_p) $opt_ws ($op_p) $opt_ws (?: $qq_p|$q_p|$gt_p|($word_p))";
 
-        // handle plugin-list arguments seperately
+        // handle plugin-list arguments separately
         $plugin_p = '<!plugin-list\s+\w+.*?!>';
         while (preg_match("/^($arg_p) $opt_ws ($op_p) $opt_ws ($plugin_p) $opt_ws/x", $argstr, $m)) {
-            @ list(,$arg, $op, $plugin_val) = $m;
+            @ list(, $arg, $op, $plugin_val) = $m;
             $argstr = substr($argstr, strlen($m[0]));
             $loader = new WikiPluginLoader();
             $markup = null;
             $basepage = null;
-            $plugin_val = preg_replace(array("/^<!/","/!>$/"),array("<?","?>"),$plugin_val);
+            $plugin_val = preg_replace(array("/^<!/", "/!>$/"), array("<?", "?>"), $plugin_val);
             $val = $loader->expandPI($plugin_val, $GLOBALS['request'], $markup, $basepage);
             if ($op == '=') {
                 $args[$arg] = $val; // comma delimited pagenames or array()?
@@ -178,7 +197,12 @@ class WikiPlugin
             }
         }
         while (preg_match("/^$opt_ws $argspec_p $opt_ws/x", $argstr, $m)) {
-            //@ list(,$arg,$op,$qq_val,$q_val,$gt_val,$word_val) = $m;
+            $qq_val = '';
+            $q_val = '';
+            $gt_val = '';
+            $word_val = '';
+            $op = '';
+            $arg = '';
             $count = count($m);
             if ($count >= 7) {
                 list(, $arg, $op, $qq_val, $q_val, $gt_val, $word_val) = $m;
@@ -194,18 +218,14 @@ class WikiPlugin
             if ($qq_val)
                 $val = stripslashes($qq_val);
             elseif ($count > 4 and $q_val)
-                $val = stripslashes($q_val);
-            elseif ($count >= 6 and $gt_val)
-                $val = _(stripslashes($gt_val));
-            elseif ($count >= 7)
-                $val = $word_val;
-            else
+                $val = stripslashes($q_val); elseif ($count >= 6 and $gt_val)
+                $val = _(stripslashes($gt_val)); elseif ($count >= 7)
+                $val = $word_val; else
                 $val = '';
 
             if ($op == '=') {
                 $args[$arg] = $val;
-            }
-            else {
+            } else {
                 // NOTE: This does work for multiple args. Use the
                 // separator character defined in your webserver
                 // configuration, usually & or &amp; (See
@@ -218,82 +238,86 @@ class WikiPlugin
         }
 
         if ($argstr) {
-           $this->handle_plugin_args_cruft($argstr, $args);
+            $this->handle_plugin_args_cruft($argstr, $args);
         }
 
         return array($args, $defaults);
     }
 
     /* A plugin can override this function to define how any remaining text is handled */
-    function handle_plugin_args_cruft($argstr, $args) {
-        trigger_error(sprintf(_("trailing cruft in plugin args: '%s'"),
-                              $argstr), E_USER_NOTICE);
+    function handle_plugin_args_cruft($argstr, $args)
+    {
+        trigger_error(sprintf(_("trailing cruft in plugin args: “%s”"),
+            $argstr), E_USER_NOTICE);
     }
 
     /* A plugin can override this to allow undeclared arguments.
        Or to silence the warning.
      */
-    function allow_undeclared_arg($name, $value) {
-        trigger_error(sprintf(_("Argument '%s' not declared by plugin."),
-                              $name), E_USER_NOTICE);
-    return false;
+    function allow_undeclared_arg($name, $value)
+    {
+        trigger_error(sprintf(_("Argument “%s” not declared by plugin."),
+            $name), E_USER_NOTICE);
+        return false;
     }
 
     /* handle plugin-list argument: use run(). */
-    function makeList($plugin_args, $request, $basepage) {
+    function makeList($plugin_args, $request, $basepage)
+    {
         $dbi = $request->getDbh();
         $pagelist = $this->run($dbi, $plugin_args, $request, $basepage);
         $list = array();
         if (is_object($pagelist) and isa($pagelist, 'PageList'))
             return $pagelist->pageNames();
         elseif (is_array($pagelist))
-            return $pagelist;
-        else
+            return $pagelist; else
             return $list;
     }
 
-    function getDefaultLinkArguments() {
-        return array('targetpage'  => $this->getName(),
-                     'linktext'    => $this->getName(),
-                     'description' => $this->getDescription(),
-                     'class'       => 'wikiaction');
-    }
-
-    function getDefaultFormArguments() {
+    function getDefaultLinkArguments()
+    {
         return array('targetpage' => $this->getName(),
-                     'buttontext' => $this->getName(),
-                     'class'      => 'wikiaction',
-                     'method'     => 'get',
-                     'textinput'  => 's',
-                     'description'=> $this->getDescription(),
-                     'formsize'   => 30);
+            'linktext' => $this->getName(),
+            'description' => $this->getDescription(),
+            'class' => 'wikiaction');
     }
 
-    function makeForm($argstr, $request) {
+    function getDefaultFormArguments()
+    {
+        return array('targetpage' => $this->getName(),
+            'buttontext' => _($this->getName()),
+            'class' => 'wikiaction',
+            'method' => 'get',
+            'textinput' => 's',
+            'description' => $this->getDescription(),
+            'formsize' => 30);
+    }
+
+    function makeForm($argstr, $request)
+    {
         $form_defaults = $this->getDefaultFormArguments();
         $defaults = array_merge($form_defaults,
-                                array('start_debug' => $request->getArg('start_debug')),
-                    $this->getDefaultArguments());
+            array('start_debug' => $request->getArg('start_debug')),
+            $this->getDefaultArguments());
 
         $args = $this->getArgs($argstr, $request, $defaults);
-        $plugin = $this->getName();
         $textinput = $args['textinput'];
         assert(!empty($textinput) && isset($args['textinput']));
 
         $form = HTML::form(array('action' => WikiURL($args['targetpage']),
-                                 'method' => $args['method'],
-                                 'class'  => $args['class'],
-                                 'accept-charset' => $GLOBALS['charset']));
-        if (! USE_PATH_INFO ) {
+            'method' => $args['method'],
+            'class' => $args['class'],
+            'accept-charset' => 'UTF-8'));
+        if (!USE_PATH_INFO) {
             $pagename = $request->get('pagename');
             $form->pushContent(HTML::input(array('type' => 'hidden',
-                                                 'name' => 'pagename',
-                                                 'value' => $args['targetpage'])));
+                'name' => 'pagename',
+                'value' => $args['targetpage'])));
         }
         if ($args['targetpage'] != $this->getName()) {
             $form->pushContent(HTML::input(array('type' => 'hidden',
-                                                 'name' => 'action',
-                                                 'value' => $this->getName())));
+                'name' => 'action',
+                'value' => $this->getName())));
         }
         $contents = HTML::div();
         $contents->setAttr('class', $args['class']);
@@ -314,8 +338,7 @@ class WikiPlugin
                 $i->setAttr('size', $args['formsize']);
                 if ($args['description'])
                     $i->addTooltip($args['description']);
-            }
-            else {
+            } else {
                 $i->setAttr('type', 'hidden');
             }
             $contents->pushContent($i);
@@ -325,43 +348,47 @@ class WikiPlugin
                 $form->setAttr('enctype', 'multipart/form-data');
                 $form->setAttr('method', 'post');
                 $contents->pushContent(HTML::input(array('name' => 'MAX_FILE_SIZE',
-                                                         'value' => MAX_UPLOAD_SIZE,
-                                                         'type' => 'hidden')));
+                    'value' => MAX_UPLOAD_SIZE,
+                    'type' => 'hidden')));
             }
         }
 
         if (!empty($args['buttontext']))
             $contents->pushContent(HTML::input(array('type' => 'submit',
-                                                     'class' => 'button',
-                                                     'value' => $args['buttontext'])));
+                'class' => 'button',
+                'value' => $args['buttontext'])));
         $form->pushContent($contents);
         return $form;
     }
 
     // box is used to display a fixed-width, narrow version with common header
-    function box($args=false, $request=false, $basepage=false) {
+    function box($args = false, $request = false, $basepage = false)
+    {
         if (!$request) $request =& $GLOBALS['request'];
         $dbi = $request->getDbh();
         return $this->makeBox('', $this->run($dbi, $args, $request, $basepage));
     }
 
-    function makeBox($title, $body) {
+    function makeBox($title, $body)
+    {
         if (!$title) $title = $this->getName();
-        return HTML::div(array('class'=>'box'),
-                         HTML::div(array('class'=>'box-title'), $title),
-                         HTML::div(array('class'=>'box-data'), $body));
+        return HTML::div(array('class' => 'box'),
+            HTML::div(array('class' => 'box-title'), $title),
+            HTML::div(array('class' => 'box-data'), $body));
     }
 
-    function error ($message) {
+    function error($message)
+    {
         return HTML::span(array('class' => 'error'),
-                        HTML::strong(fmt("Plugin %s failed.", $this->getName())), ' ',
-                        $message);
+            HTML::strong(fmt("Plugin %s failed.", $this->getName())), ' ',
+            $message);
     }
 
-    function disabled ($message='') {
+    function disabled($message = '')
+    {
         $html[] = HTML::div(array('class' => 'title'),
-                            fmt("Plugin %s disabled.", $this->getName()),
-                            ' ', $message);
+            fmt("Plugin %s disabled.", $this->getName()),
+            ' ', $message);
         $html[] = HTML::pre($this->_pi);
         return HTML::div(array('class' => 'disabled-plugin'), $html);
     }
@@ -370,7 +397,8 @@ class WikiPlugin
     // PageList object, which accepts options['types'].
     // Register custom PageList types for special plugins, like
     // 'hi_content' for WikiAdminSearcheplace, 'renamed_pagename' for WikiAdminRename, ...
-    function addPageListColumn ($array) {
+    function addPageListColumn($array)
+    {
         global $customPageListColumns;
         if (empty($customPageListColumns)) $customPageListColumns = array();
         foreach ($array as $column => $obj) {
@@ -379,18 +407,20 @@ class WikiPlugin
     }
 
     // provide a sample usage text for automatic edit-toolbar insertion
-    function getUsage() {
+    function getUsage()
+    {
         $args = $this->getDefaultArguments();
-        $string = '<<'.$this->getName().' ';
+        $string = '<<' . $this->getName() . ' ';
         if ($args) {
             foreach ($args as $key => $value) {
-                $string .= ($key."||=".(string)$value." ");
+                $string .= ($key . "||=" . (string)$value . " ");
             }
         }
         return $string . '>>';
     }
 
-    function getArgumentsDescription() {
+    function getArgumentsDescription()
+    {
         $arguments = HTML();
         foreach ($this->getDefaultArguments() as $arg => $default) {
             // Work around UserPreferences plugin to avoid error
@@ -399,8 +429,7 @@ class WikiPlugin
                 // This is a bit flawed with UserPreferences object
                 //$default = sprintf("array('%s')",
                 //                   implode("', '", array_keys($default)));
-            }
-            else
+            } else
                 if (stristr($default, ' '))
                     $default = "'$default'";
             $arguments->pushcontent("$arg=$default", HTML::br());
@@ -410,18 +439,20 @@ class WikiPlugin
 
 }
 
-class WikiPluginLoader {
-    var $_errors;
+class WikiPluginLoader
+{
+    public $_errors;
 
-    function expandPI($pi, &$request, &$markup, $basepage=false) {
+    function expandPI($pi, &$request, &$markup, $basepage = false)
+    {
         if (!($ppi = $this->parsePi($pi)))
             return false;
         list($pi_name, $plugin, $plugin_args) = $ppi;
 
         if (!is_object($plugin)) {
             return new HtmlElement('div',
-                                   array('class' => 'error'),
-                                   $this->getErrorDetail());
+                array('class' => 'error'),
+                $this->getErrorDetail());
         }
         switch ($pi_name) {
             case 'plugin':
@@ -431,7 +462,7 @@ class WikiPluginLoader {
                 // to be able to know about itself, or even to change the markup XmlTree (CreateToc)
                 $dbi->_markup = &$markup;
                 // FIXME: could do better here...
-                if (! $plugin->managesValidators()) {
+                if (!$plugin->managesValidators()) {
                     // Output of plugin (potentially) depends on
                     // the state of the WikiDB (other than the current
                     // page.)
@@ -446,8 +477,8 @@ class WikiPluginLoader {
 
                     $timestamp = $dbi->getTimestamp();
                     $request->appendValidators(array('dbi_timestamp' => $timestamp,
-                                                     '%mtime' => (int)$timestamp,
-                                                     '%weak' => true));
+                        '%mtime' => (int)$timestamp,
+                        '%weak' => true));
                 }
                 return $plugin->run($dbi, $plugin_args, $request, $basepage);
             case 'plugin-list':
@@ -455,9 +486,11 @@ class WikiPluginLoader {
             case 'plugin-form':
                 return $plugin->makeForm($plugin_args, $request);
         }
+        return false;
     }
 
-    function getWikiPageLinks($pi, $basepage) {
+    function getWikiPageLinks($pi, $basepage)
+    {
         if (!($ppi = $this->parsePi($pi)))
             return false;
         list($pi_name, $plugin, $plugin_args) = $ppi;
@@ -468,7 +501,8 @@ class WikiPluginLoader {
         return $plugin->getWikiPageLinks($plugin_args, $basepage);
     }
 
-    function parsePI($pi) {
+    function parsePI($pi)
+    {
         if (!preg_match('/^\s*<\?(plugin(?:-form|-link|-list)?)\s+(\w+)\s*(.*?)\s*\?>\s*$/s', $pi, $m))
             return $this->_error(sprintf("Bad %s", 'PI'));
 
@@ -478,13 +512,14 @@ class WikiPluginLoader {
         return array($pi_name, $plugin, $plugin_args);
     }
 
-    function getPlugin($plugin_name, $pi=false) {
+    function getPlugin($plugin_name, $pi = false)
+    {
         global $ErrorManager;
         global $AllAllowedPlugins;
 
         if (in_array($plugin_name, $AllAllowedPlugins) === false) {
-            return $this->_error(sprintf(_("Plugin '%s' does not exist."),
-                                         $plugin_name));
+            return $this->_error(sprintf(_("Plugin “%s” does not exist."),
+                $plugin_name));
         }
 
         // Note that there seems to be no way to trap parse errors
@@ -495,13 +530,13 @@ class WikiPluginLoader {
         $plugin_class = "WikiPlugin_$plugin_name";
         if (!class_exists($plugin_class)) {
             // $include_failed = !@include_once("lib/plugin/$plugin_name.php");
-            $include_failed = !include_once("lib/plugin/$plugin_name.php");
+            $include_failed = !include_once($plugin_source);
             $ErrorManager->popErrorHandler();
 
             if (!class_exists($plugin_class)) {
                 if ($include_failed) {
-                    return $this->_error(sprintf(_("Plugin '%s' does not exist."),
-                                                 $plugin_name));
+                    return $this->_error(sprintf(_("Plugin “%s” does not exist."),
+                        $plugin_name));
                 }
                 return $this->_error(sprintf(_("%s: no such class"), $plugin_class));
             }
@@ -510,27 +545,30 @@ class WikiPluginLoader {
         $plugin = new $plugin_class;
         if (!is_subclass_of($plugin, "WikiPlugin"))
             return $this->_error(sprintf(_("%s: not a subclass of WikiPlugin."),
-                                         $plugin_class));
+                $plugin_class));
 
         $plugin->_pi = $pi;
         return $plugin;
     }
 
-    function _plugin_error_filter ($err) {
+    function _plugin_error_filter($err)
+    {
         if (preg_match("/Failed opening '.*' for inclusion/", $err->errstr))
-            return true;        // Ignore this error --- it's expected.
+            return true; // Ignore this error --- it's expected.
         return false;
     }
 
-    function getErrorDetail() {
+    function getErrorDetail()
+    {
         return $this->_errors;
     }
 
-    function _error($message) {
+    function _error($message)
+    {
         $this->_errors = $message;
         return false;
     }
-};
+}
 
 // Local Variables:
 // mode: php
@@ -539,4 +577,3 @@ class WikiPluginLoader {
 // c-hanging-comment-ender-p: nil
 // indent-tabs-mode: nil
 // End:
-?>
