@@ -1,5 +1,5 @@
-<?php // -*-php-*-
-// $Id: CreateBib.php 8071 2011-05-18 14:56:14Z vargenau $
+<?php
+
 /*
  * Copyright 2004 $ThePhpWikiProgrammingTeam
  *
@@ -31,36 +31,32 @@
  */
 
 class WikiPlugin_CreateBib
-extends WikiPlugin
+    extends WikiPlugin
 {
-    function getName() {
-        return _("CreateBib");
+    function getDescription()
+    {
+        return _("Automatically create a Bibtex file from linked pages.");
     }
 
-    function getDescription() {
-        return _("Automatically create a Bibtex file from linked pages");
-    }
-
-    function getDefaultArguments() {
-        return array( 'pagename'  => '[pagename]', // The page from which the BibTex file is generated
-                      );
+    function getDefaultArguments()
+    {
+        return array('pagename' => '[pagename]', // The page from which the BibTex file is generated
+        );
     }
 
     // Have to include the $starttag and $endtag to the regexps...
-    function extractBibTeX (&$content, $starttag, $endtag)
+    function extractBibTeX(&$content, $starttag, $endtag)
     {
         $bib = array();
 
         $start = false;
         $stop = false;
-        for ($i=0; $i<count($content); $i++)
-        {
+        for ($i = 0; $i < count($content); $i++) {
             // $starttag shows when to start
-            if (preg_match('/^@/',$content[$i],$match)) {
+            if (preg_match('/^@/', $content[$i], $match)) {
                 $start = true;
-            }
-            // $endtag shows when to stop
-            else if (preg_match('/^\}/',$content[$i],$match)) {
+            } // $endtag shows when to stop
+            else if (preg_match('/^\}/', $content[$i], $match)) {
                 $stop = true;
             }
             if ($start) {
@@ -73,34 +69,35 @@ extends WikiPlugin
 
     // Extract article links. Current markup is by * characters...
     // Assume straight list
-    function extractArticles (&$content) {
+    function extractArticles(&$content)
+    {
         $articles = array();
-        for ($i=0; $i<count($content); $i++) {
+        for ($i = 0; $i < count($content); $i++) {
             // Should match "* [WikiPageName] whatever"
             //if (preg_match('/^\s*\*\s+(\[.+\])/',$content[$i],$match))
-            if (preg_match('/^\s*\*\s+\[(.+)\]/',$content[$i],$match))
-            {
+            if (preg_match('/^\s*\*\s+\[(.+)\]/', $content[$i], $match)) {
                 $articles[] = $match[1];
             }
         }
         return $articles;
     }
 
+    function dumpFile(&$thispage, $filename)
+    {
+        include_once 'lib/loadsave.php';
+        $mailified = MailifyPage($thispage);
 
-    function dumpFile(&$thispage, $filename) {
-      include_once("lib/loadsave.php");
-      $mailified = MailifyPage($thispage);
+        $attrib = array('mtime' => $thispage->get('mtime'), 'is_ascii' => 1);
 
-      $attrib = array('mtime' => $thispage->get('mtime'), 'is_ascii' => 1);
-
-      $zip = new ZipWriter("Created by PhpWiki " . PHPWIKI_VERSION, $filename);
-      $zip->addRegularFile( FilenameForPage($thispage->getName()),
-                            $mailified, $attrib);
-      $zip->finish();
+        $zip = new ZipWriter("Created by PhpWiki " . PHPWIKI_VERSION, $filename);
+        $zip->addRegularFile(FilenameForPage($thispage->getName()),
+            $mailified, $attrib);
+        $zip->finish();
 
     }
 
-    function run($dbi, $argstr, $request, $basepage) {
+    function run($dbi, $argstr, $request, $basepage)
+    {
         extract($this->getArgs($argstr, $request));
         if ($pagename) {
             // Expand relative page names.
@@ -108,7 +105,7 @@ extends WikiPlugin
             $pagename = $page->name;
         }
         if (!$pagename) {
-            return $this->error(_("no page specified"));
+            return $this->error(sprintf(_("A required argument “%s” is missing."), 'pagename'));
         }
 
         // Get the links page contents
@@ -120,11 +117,11 @@ extends WikiPlugin
         $dump_url = $request->getURLtoSelf(array("file" => "tube.bib"));
         global $WikiTheme;
         $dump_button = $WikiTheme->makeButton("To File",
-                                          $dump_url , 'foo');
+            $dump_url, 'foo');
 
-        $html = HTML::div(array('class' => 'bib','align' => 'left'));
+        $html = HTML::div(array('class' => 'bib', 'align' => 'left'));
         $html->pushContent($dump_button, ' ');
-        $list = HTML::pre(array('id'=>'biblist', 'class' => 'bib'));
+        $list = HTML::pre(array('id' => 'biblist', 'class' => 'bib'));
 
         // Let's find the subpages
         if ($articles = $this->extractArticles($content)) {
@@ -149,14 +146,12 @@ extends WikiPlugin
             // Yes, we want to dump this somewhere
             // Get the contents of this page
             $p = $dbi->getPage($pagename);
-            $c = $p->getCurrentRevision();
-            $pagedata = $c->getContent();
-            $this->dumpFile($pagedata, $request->getArg('file'));
+            return $this->dumpFile($p, $request->getArg('file'));
         }
 
         return $html;
     }
-};
+}
 
 // Local Variables:
 // mode: php
@@ -165,4 +160,3 @@ extends WikiPlugin
 // c-hanging-comment-ender-p: nil
 // indent-tabs-mode: nil
 // End:
-?>
