@@ -38,8 +38,8 @@ add_config () {
 lastsection=''
 tmp=$(mktemp)
 cat > $tmp <<EOF
-# This is a generated file with values migrated from your previous configuration
-# You may want to move the values in here to the main configuration files
+; This is a generated file with values migrated from your previous configuration
+; You may want to move the values in here to the main configuration files
 EOF
 
 add_config core account_manager_type >> $tmp
@@ -64,7 +64,6 @@ add_config core ftp_upload_host >> $tmp
 add_config core groupdir_prefix >> $tmp
 add_config core homedir_prefix >> $tmp
 add_config core images_url >> $tmp
-add_config core jpgraph_path >> $tmp
 add_config core lists_host >> $tmp
 add_config core mailman_path >> $tmp
 add_config core master_path >> $tmp
@@ -95,7 +94,6 @@ add_config core use_fti >> $tmp
 add_config core use_ftp >> $tmp
 add_config core use_ftp_uploads >> $tmp
 add_config core use_gateways >> $tmp
-add_config core use_jabber >> $tmp
 add_config core use_mail >> $tmp
 add_config core use_manual_uploads >> $tmp
 add_config core use_news >> $tmp
@@ -155,8 +153,8 @@ chmod 644 $config_path/zzz-migrated-old-config
 lastsection=''
 tmp=$(mktemp)
 cat > $tmp <<EOF
-# This is a generated file with values migrated from your previous configuration
-# You may want to move the values in here to the main configuration files
+; This is a generated file with values migrated from your previous configuration
+; You may want to move the values in here to the main configuration files
 EOF
 
 add_config core database_host >> $tmp
@@ -164,10 +162,6 @@ add_config core database_name >> $tmp
 add_config core database_password >> $tmp
 add_config core database_port >> $tmp
 add_config core database_user >> $tmp
-add_config core jabber_host >> $tmp
-add_config core jabber_password >> $tmp
-add_config core jabber_port >> $tmp
-add_config core jabber_user >> $tmp
 add_config core ldap_base_dn >> $tmp
 add_config core ldap_host >> $tmp
 add_config core ldap_password >> $tmp
