@@ -19,14 +19,14 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require (dirname(__FILE__).'/../www/env.inc.php');
+require (dirname(__FILE__).'/../common/include/env.inc.php');
 require_once $gfcommon.'include/pre.php';
-			 
+
 $err='';
 
 // Plugins subsystem
-require_once('common/include/Plugin.class.php') ;
-require_once('common/include/PluginManager.class.php') ;
+require_once 'common/include/Plugin.class.php';
+require_once 'common/include/PluginManager.class.php';
 
 setup_plugin_manager () ;
 session_set_admin () ;
@@ -39,7 +39,7 @@ $rows=db_numrows($res);
 for ($i=0; $i<$rows; $i++) {
 	$role = RBACEngine::getInstance()->getRoleById (db_result($res,$i,'role_id')) ;
 	echo "Normalizing role ".$role->getDisplayableName()."\n" ;
-	
+
 	$role->normalizeData() ;
 }
 
