@@ -8,6 +8,7 @@
  * Portions Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2002-2004 (c) GForge Team
  * Copyright 2010 (c) Franck Villaume
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -26,8 +27,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 
 if (getStringFromRequest('submit')) {
@@ -54,23 +54,24 @@ if (getStringFromRequest('submit')) {
 		exit_error($u->getErrorMessage(),'my');
 	} else {
 
-		$message = sprintf(_('Someone (presumably you) on the %1$s site requested a
-password change through email verification. If this was not you,
-ignore this message and nothing will happen.
+		$message = sprintf(_('Someone (presumably you) on the %s site requested a password change through email verification.'),
+							forge_get_config ('forge_name'));
+		$message .= _('If this was not you, ignore this message and nothing will happen.');
+		$message .= "\n\n";
 
-If you requested this verification, visit the following URL
-to change your password:
+		$message .= _('If you requested this verification, visit the following URL to change your password:');
+		$message .= "\n\n";
 
-<%2$s>
+		$message .= util_make_url("/account/lostlogin.php?ch=_".$confirm_hash);
+		$message .= "\n\n";
+		$message .= sprintf(_('-- the %s staff'), forge_get_config ('forge_name'));
+		$message .= "\n";
 
- -- the %1$s staff
-'), forge_get_config ('forge_name'), util_make_url ("/account/lostlogin.php?ch=_".$confirm_hash));
+		util_send_message($u->getEmail(),sprintf(_('%s Verification'), forge_get_config ('forge_name')),$message);
 
-		util_send_message($u->getEmail(),sprintf(_('%1$s Verification'), forge_get_config ('forge_name')),$message);
+		$HTML->header(array('title'=>_('Lost Password Confirmation')));
 
-		$HTML->header(array('title'=>"Lost Password Confirmation"));
-
-		printf('<p>' . _('An email has been sent to the address you have on file. Follow the instructions in the email to change your account password.') . '</p><p><a href="%1$s">'._("Home").'</a></p>', util_make_url('/'));
+		echo '<p>'.printf(_('An email has been sent to the address you have on file. Follow the instructions in the email to change your account password.').'</p><p><a href="%s">'._("Home").'</a>', util_make_url ('/')).'</p>';
 
 		$HTML->footer(array());
 		exit();
@@ -80,16 +81,17 @@ to change your password:
 $HTML->header(array('title'=>"Lost Account Password"));
 
 echo '<p>' . _('Hey... losing your password is serious business. It compromises the security of your account, your projects, and this site.') . '</p>';
-echo '<p>' . _('Clicking "Send Lost PW Hash" below will email a URL to the email address we have on file for you. In this URL is a 128-bit confirmation hash for your account. Visiting the URL will allow you to change your password online and login.') . '</p>';
+echo '<p>' . _('Clicking “Send Lost PW Hash” below will email a URL to the email address we have on file for you. In this URL is a 128-bit confirmation hash for your account. Visiting the URL will allow you to change your password online and login.') . '</p>';
 ?>
 
 <form action="<?php echo util_make_url('/account/lostpw.php'); ?>" method="post">
 <input type="hidden" name="form_key" value="<?php echo form_generate_key(); ?>"/> <p>
-<?php echo _('Login name:'); ?>
-<br />
-<input type="text" name="loginname" />
-<br />
+<?php echo _('Login Name')._(':'); ?>
 <br />
+    <label for="loginname">
+        <input id="loginname" type="text" name="loginname"/>
+    </label>
+    <br />
 <input type="submit" name="submit" value="<?php echo _('Send Lost PW Hash'); ?>" />
 </p>
 </form>
@@ -104,5 +106,3 @@ $HTML->footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
