@@ -20,14 +20,14 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 
 $language_id=getIntFromRequest('language_id');
 setcookie('cookie_language_id',$language_id,(time()+2592000),'/','',0);
 $cookie_language_id = $language_id;
 
-echo $HTML->header(array('title'=>"Change Language"));
+$HTML->header(array('title'=>"Change Language"));
 
 ?>
 
@@ -39,6 +39,4 @@ remembered next time you visit the site.
 
 <?php
 
-echo $HTML->footer(array());
-
-?>
+$HTML->footer(array());
