@@ -4,6 +4,7 @@
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2010 (c) Franck Villaume - Capgemini
+ * Copyright 2012,2014 Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -21,13 +22,13 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
 /**
- *	admin_table_add() - present a form for adding a record to the specified table
+ * admin_table_add() - present a form for adding a record to the specified table
  *
- *	@param $table - the table to act on
- *	@param $unit - the name of the "units" described by the table's records
- *	@param $primary_key - the primary key of the table
+ * @param	$table		the table to act on
+ * @param	$unit		the name of the "units" described by the table's records
+ * @param	$primary_key	the primary key of the table
+ * @return	string
  */
 function admin_table_add($table, $unit, $primary_key) {
 	// This query may return no rows, but the field names are needed.
@@ -37,7 +38,7 @@ function admin_table_add($table, $unit, $primary_key) {
 	if ($result) {
 		$cols = db_numfields($result);
 
-		printf(_('Create a new %1$s below:'), getUnitLabel($unit));
+		printf(_('Create a new %s below:'), getUnitLabel($unit));
 
 		echo '
 			<form name="add" action="'.getStringFromServer('PHP_SELF').'?function=postadd" method="post">
@@ -46,10 +47,11 @@ function admin_table_add($table, $unit, $primary_key) {
 
 		for ($i = 0; $i < $cols; $i++) {
 			$fieldname = db_fieldname($result, $i);
-			$fields[] = $fieldname;
-
-			echo '<tr><td><strong>'.$fieldname.'</strong></td>';
-			echo '<td><input type="text" name="'.$fieldname.'" value="" /></td></tr>';
+			if ($fieldname != $primary_key) {
+				$fields[] = $fieldname;
+				echo '<tr><td><strong>'.$fieldname.'</strong></td>';
+				echo '<td><input type="text" name="'.$fieldname.'" value="" required="required" /></td></tr>';
+			}
 		}
 		echo '</table><input type="submit" value="'._('Add').'" />
 			<input type="hidden" name="__fields__" value="'.implode(',',$fields).'" />
@@ -63,22 +65,22 @@ function admin_table_add($table, $unit, $primary_key) {
 }
 
 /**
- *	admin_table_postadd() - update the database based on a submitted change
+ * admin_table_postadd() - update the database based on a submitted change
  *
- *	@param $table - the table to act on
- *	@param $unit - the name of the "units" described by the table's records
- *	@param $primary_key - the primary key of the table
+ * @param	$table	the table to act on
+ * @param	$unit	the name of the "units" described by the table's records
+ * @return	string
  */
-function admin_table_postadd($table, $unit, $primary_key) {
+function admin_table_postadd($table, $unit) {
 	if (!form_key_is_valid(getStringFromRequest('form_key'))) {
 		exit_form_double_submit('home');
 	}
-	
+
 	$field_list = getStringFromRequest('__fields__');
 	$fields = explode(",", $field_list);
 	$values = array(); $v = array ();
 	$qpa = db_construct_qpa (false, 'INSERT INTO ' . $table . ' (' . $field_list . ') VALUES (') ;
-	
+
 	$i = 1 ;
 	foreach ($fields as $field) {
 		$v[] = '$'.$i;
@@ -89,9 +91,9 @@ function admin_table_postadd($table, $unit, $primary_key) {
 	$qpa = db_construct_qpa ($qpa, implode (',', $v).')', $values) ;
 
 	if (db_query_qpa($qpa)) {
-        print('<p class="feedback">');
-		printf(_('%1$s successfully added.'), ucfirst(getUnitLabel($unit)));
-        print('</p>');
+		print('<p class="feedback">');
+		printf(_('%s successfully added.'), ucfirst(getUnitLabel($unit)));
+		print('</p>');
 	} else {
 		print('<p class="error">');
 		echo db_error();
@@ -101,20 +103,21 @@ function admin_table_postadd($table, $unit, $primary_key) {
 }
 
 /**
- *	admin_table_confirmdelete() - present a form to confirm requested record deletion
+ * admin_table_confirmdelete() - present a form to confirm requested record deletion
  *
- *	@param $table - the table to act on
- *	@param $unit - the name of the "units" described by the table's records
- *	@param $primary_key - the primary key of the table
- *	@param $id - the id of the record to act on
+ * @param	$table		the table to act on
+ * @param	$unit		the name of the "units" described by the table's records
+ * @param	$primary_key	the primary key of the table
+ * @param	$id		the id of the record to act on
+ * @return	string
  */
 function admin_table_confirmdelete($table, $unit, $primary_key, $id) {
 	if ($unit == "processor") {
 		$result = db_numrows(db_query_params ('SELECT processor_id FROM frs_file WHERE processor_id = $1',
 			array($id)));
 		if ($result > 0) {
-			echo '<div class="warning_msg">'.sprintf(_('You can\'t delete the processor %1$s since it\'s currently referenced in a file release.'), db_result(db_query_params ('select name from frs_processor where processor_id = $1',
-			array($id)), 0, 0)).'</div>';
+			echo '<p class="warning_msg">'.sprintf(_('You cannot delete the processor %s since it is currently referenced in a file release.'), db_result(db_query_params ('select name from frs_processor where processor_id = $1',
+			array($id)), 0, 0)).'</p>';
 			return;
 		}
 	}
@@ -122,7 +125,7 @@ function admin_table_confirmdelete($table, $unit, $primary_key, $id) {
 		$result = db_numrows(db_query_params ('SELECT license FROM groups WHERE license = $1',
 			array($id)));
 		if ($result > 0) {
-			echo '<div class="warning_msg">'.sprintf(_('You can\'t delete the license %1$s since it\'s currently referenced in a project.'), db_result(db_query_params ('select license_name from licenses where license_id = $1',
+			echo '<div class="warning_msg">'.sprintf(_('You can\'t delete the license %s since it is currently referenced in a project.'), db_result(db_query_params ('select license_name from licenses where license_id = $1',
 			array($id)), 0, 0)).'</div>';
 			return;
 		}
@@ -130,7 +133,16 @@ function admin_table_confirmdelete($table, $unit, $primary_key, $id) {
 	if ($unit == "supported_language") {
 		$result = db_numrows(db_query_params("SELECT language FROM users WHERE language=$1", array($id)));
 		if ($result > 0) {
-			echo '<div class="warning_msg">'.sprintf(_('You can\'t delete the language %1$s since it\'s currently referenced in a user profile.'), db_result(db_query_params ('select license_name from licenses where license_id = $1',
+			echo '<div class="warning_msg">'.sprintf(_('You cannot delete the language %s since it is currently referenced in a user profile.'), db_result(db_query_params ('select language from users where language = $1',
+			array($id)), 0, 0)).'</div>';
+			return;
+		}
+	}
+
+	if ($unit == "theme") {
+		$result = db_numrows(db_query_params("SELECT theme_id FROM users WHERE theme_id=$1", array($id)));
+		if ($result > 0) {
+			echo '<div class="warning_msg">'.sprintf(_('You cannot delete the theme %s since it is currently referenced in a user profile.'), db_result(db_query_params ('select language from users where language = $1',
 			array($id)), 0, 0)).'</div>';
 			return;
 		}
@@ -141,7 +153,7 @@ function admin_table_confirmdelete($table, $unit, $primary_key, $id) {
 	if ($result) {
 		$cols = db_numfields($result);
 		echo '<p>';
-		printf(_('Are you sure you want to delete this %1$s?'), getUnitLabel($unit));
+		printf(_('Are you sure you want to delete this %s?'), getUnitLabel($unit));
 		echo '</p>';
 		echo '<ul>';
 		for ($i = 0; $i < $cols; $i++) {
@@ -160,17 +172,18 @@ function admin_table_confirmdelete($table, $unit, $primary_key, $id) {
 }
 
 /**
- *	admin_table_delete() - delete a record from the database after confirmation
+ * admin_table_delete() - delete a record from the database after confirmation
  *
- *	@param $table - the table to act on
- *	@param $unit - the name of the "units" described by the table's records
- *	@param $primary_key - the primary key of the table
- *	@param $id - the id of the record to act on
+ * @param	$table		the table to act on
+ * @param	$unit		the name of the "units" described by the table's records
+ * @param	$primary_key	the primary key of the table
+ * @param	$id		the id of the record to act on
+ * @return	string
  */
 function admin_table_delete($table, $unit, $primary_key, $id) {
 	if (db_query_params("DELETE FROM $table WHERE $primary_key=$1", array($id))) {
                 print('<p class="feedback">');
-		printf(_('%1$s successfully deleted.'), ucfirst(getUnitLabel($unit)));
+		printf(_('%s successfully deleted.'), ucfirst(getUnitLabel($unit)));
                 print('</p>');
 	} else {
 		echo db_error();
@@ -178,12 +191,13 @@ function admin_table_delete($table, $unit, $primary_key, $id) {
 }
 
 /**
- *	admin_table_edit() - present a form for editing a record in the specified table
+ * admin_table_edit() - present a form for editing a record in the specified table
  *
- *	@param $table - the table to act on
- *	@param $unit - the name of the "units" described by the table's records
- *	@param $primary_key - the primary key of the table
- *	@param $id - the id of the record to act on
+ * @param	$table		the table to act on
+ * @param	$unit		the name of the "units" described by the table's records
+ * @param	$primary_key	the primary key of the table
+ * @param	$id		the id of the record to act on
+ * @return	string
  */
 function admin_table_edit($table, $unit, $primary_key, $id) {
 	$result = db_query_params("SELECT * FROM $table WHERE $primary_key=$1", array($id));
@@ -191,8 +205,8 @@ function admin_table_edit($table, $unit, $primary_key, $id) {
 	if ($result) {
 		$cols = db_numfields($result);
 
-		printf(_('Modify the %1$s below:'), getUnitLabel($unit));
-		
+		printf(_('Modify the %s below:'), getUnitLabel($unit));
+
 		echo '
 			<form name="edit" action="'.getStringFromServer('PHP_SELF').'?function=postedit&amp;id='.$id.'" method="post">
 			<table>';
@@ -219,18 +233,19 @@ function admin_table_edit($table, $unit, $primary_key, $id) {
 }
 
 /**
- *	admin_table_postedit() - update the database to reflect submitted modifications to a record
+ * admin_table_postedit() - update the database to reflect submitted modifications to a record
  *
- *	@param $table - the table to act on
- *	@param $unit - the name of the "units" described by the table's records
- *	@param $primary_key - the primary key of the table
- *	@param $id - the id of the record to act on
+ * @param	$table		the table to act on
+ * @param	$unit		the name of the "units" described by the table's records
+ * @param	$primary_key	the primary key of the table
+ * @param	$id		the id of the record to act on
+ * @return	string
  */
 function admin_table_postedit($table, $unit, $primary_key, $id) {
 	global $_POST;
 
 	$qpa = db_construct_qpa (false, 'UPDATE ' . $table . ' SET ') ;
-	
+
 	$i = 0 ;
 	while (list($var, $val) = each($_POST)) {
 		if ($i > 0) {
@@ -245,44 +260,46 @@ function admin_table_postedit($table, $unit, $primary_key, $id) {
 				 array ($id)) ;
 
 	if (db_query_qpa($qpa)) {
-        print('<p class="feedback">');
-		printf(_('%1$s successfully modified.'), ucfirst(getUnitLabel($unit)));
-        print('</p>');
+		print('<p class="feedback">');
+		printf(_('%s successfully modified.'), ucfirst(getUnitLabel($unit)));
+		print('</p>');
 	} else {
 		echo db_error();
 	}
 
 	$field_list = getStringFromRequest('__fields__');
-	$fields = explode(",", $field_list);
-	$values = array(); $v = array ();
-	$qpa = db_construct_qpa (false, 'INSERT INTO ' . $table . ' (' . $field_list . ') VALUES (') ;
-	
-	$i = 1 ;
-	foreach ($fields as $field) {
-		$v[] = '$'.$i;
-		$i++ ;
-		$values[] = getStringFromPost($field);
+	if (strlen($field_list)) {
+		$fields = explode(",", $field_list);
+		$values = array(); $v = array ();
+		$qpa = db_construct_qpa (false, 'INSERT INTO ' . $table . ' (' . $field_list . ') VALUES (') ;
+
+		$i = 1 ;
+		foreach ($fields as $field) {
+			$v[] = '$'.$i;
+			$i++ ;
+			$values[] = getStringFromPost($field);
+		}
+
+		$qpa = db_construct_qpa ($qpa, implode (',', $v).')', $values) ;
+
+		if (db_query_qpa($qpa)) {
+		print('<p class="feedback">');
+			printf(_('%s successfully added.'), ucfirst(getUnitLabel($unit)));
+		print('</p>');
+		} else {
+			form_release_key(getStringFromRequest('form_key'));
+			echo db_error();
+		}
 	}
-
-	$qpa = db_construct_qpa ($qpa, implode (',', $v).')', $values) ;
-
-	if (db_query_qpa($qpa)) {
-        print('<div class="feedback">');
-		printf(_('%1$s successfully added.'), ucfirst(getUnitLabel($unit)));
-        print('</div>');
-	} else {
-		form_release_key(getStringFromRequest('form_key'));
-		echo db_error();
-	}
-
 }
 
 /**
- *	admin_table_show() - display the specified table, sorted by the primary key, with links to add, edit, and delete
+ * admin_table_show() - display the specified table, sorted by the primary key, with links to add, edit, and delete
  *
- *	@param $table - the table to act on
- *	@param $unit - the name of the "units" described by the table's records
- *	@param $primary_key - the primary key of the table
+ * @param	$table		the table to act on
+ * @param	$unit		the name of the "units" described by the table's records
+ * @param	$primary_key	the primary key of the table
+ * @return	string
  */
 function admin_table_show($table, $unit, $primary_key) {
         global $HTML;
@@ -297,22 +314,22 @@ function admin_table_show($table, $unit, $primary_key) {
 		$cell_data[]=array(ucwords(getUnitLabel($unit)).' <a href="'.getStringFromServer('PHP_SELF').'?function=add">['._('add new').']</a>',
 			'colspan="'.($cols+1).'"');
 
-                echo '<table border="0" width="100%">';
+		echo '<table class="listing full">';
 		echo $HTML->multiTableRow('',$cell_data, TRUE);
 
-                echo '
-			<tr><td width="5%"></td>';
-                for ($i = 0; $i < $cols; $i++) {
+		echo '
+			<tr><td></td>';
+		for ($i = 0; $i < $cols; $i++) {
 			echo '<td><strong>'.db_fieldname($result,$i).'</strong></td>';
 		}
 		echo '</tr>';
 
-                for ($j = 0; $j < $rows; $j++) {
+		for ($j = 0; $j < $rows; $j++) {
 			echo '<tr '. $HTML->boxGetAltRowStyle($j) . '>';
 
-                        $id = db_result($result,$j,0);
-                        echo '<td><a href="'.getStringFromServer('PHP_SELF').'?function=edit&amp;id='.$id.'">['._('Edit').']</a>';
-                        echo '<a href="'.getStringFromServer('PHP_SELF').'?function=confirmdelete&amp;id='.$id.'">['._('Delete').']</a> </td>';
+			$id = db_result($result,$j,0);
+			echo '<td><a href="'.getStringFromServer('PHP_SELF').'?function=edit&amp;id='.$id.'">['._('Edit').']</a>';
+			echo '<a href="'.getStringFromServer('PHP_SELF').'?function=confirmdelete&amp;id='.$id.'">['._('Delete').']</a> </td>';
 			for ($i = 0; $i < $cols; $i++) {
 				echo '<td>'. db_result($result, $j, $i) .'</td>';
 			}
@@ -327,19 +344,19 @@ function admin_table_show($table, $unit, $primary_key) {
 /**
  * getUnitLabel - returns the localized label of a unit
  *
- * @param string unit name
- * @return name localized label
+ * @param	string	$unit	unit name
+ * @return	string		name localized label
  */
 function getUnitLabel($unit) {
 	return $unit;
 }
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 
 session_require_global_perm ('forge_admin');
 
-$HTML->header(array('title'=>sprintf(_('Edit the %1$ss Table'), ucwords(getUnitLabel($unit)))));
+$HTML->header(array('title'=>sprintf(_('Edit the %ss Table'), ucwords(getUnitLabel($unit)))));
 
 // $table, $unit and $primary_key are variables passed from the parent scripts
 $id = getStringFromRequest('id');
@@ -350,7 +367,7 @@ switch (getStringFromRequest('function')) {
 		break;
 	}
 	case 'postadd' : {
-		admin_table_postadd($table, $unit, $primary_key);
+		admin_table_postadd($table, $unit);
 		break;
 	}
 	case 'confirmdelete' : {
@@ -371,7 +388,7 @@ switch (getStringFromRequest('function')) {
 	}
 }
 
-echo admin_table_show($table, $unit, $primary_key);
+admin_table_show($table, $unit, $primary_key);
 
 $HTML->footer(array());
 
@@ -379,5 +396,3 @@ $HTML->footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
