@@ -20,12 +20,9 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
 $unit        = 'theme';
 $table       = 'themes';
 $primary_key = 'theme_id';
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 include_once $gfwww.'admin/admin_table.php';
-
-?>
