@@ -3,7 +3,8 @@
  * Site Admin group properties editing page
  *
  * Copyright 1999-2001 (c) VA Linux Systems
- * Copyright 2010 (c) Franck Villaume - Capgemini
+ * Copyright 2010-2011, Franck Villaume - Capgemini
+ * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -21,19 +22,19 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'admin/admin_utils.php';
 
-session_require_global_perm ('forge_admin');
+session_require_global_perm('forge_admin');
 
-$group_id=getIntFromGet('group_id');
+$group_id = getIntFromGet('group_id');
 
 $group = group_get_object($group_id);
 if (!$group || !is_object($group)) {
-    exit_no_group();
+	exit_no_group();
 } elseif ($group->isError()) {
-	exit_error($group->getErrorMessage(),'admin');
+	exit_error($group->getErrorMessage(), 'admin');
 }
 
 if (getStringFromPost('submit')) {
@@ -41,19 +42,18 @@ if (getStringFromPost('submit')) {
 	$reallysure = getIntFromPost('reallysure');
 	$reallyreallysure = getIntFromPost('reallyreallysure');
 	if (!$group->delete($sure, $reallysure, $reallyreallysure)) {
-		exit_error($group->getErrorMessage(),'admin');
+		exit_error($group->getErrorMessage(), 'admin');
 	} else {
-		plugin_hook('delete_link',$group_id);
-        $feedback = _('Project successfully deleted');
-        session_redirect('/admin/?feedback='.urlencode($feedback));
+		$feedback = _('Project successfully deleted');
+		session_redirect('/admin/?feedback='.urlencode($feedback));
 	}
 }
 
-$title = _('Permanently and irretrievably delete project').': '.$group->getPublicName();
+$title = _('Permanently and irretrievably delete project')._(': ').$group->getPublicName();
 site_admin_header(array('title'=>$title));
 ?>
 
-<form action="<?php echo getStringFromServer('PHP_SELF').'?group_id='.$group_id; ?>" method="post">
+<form action="<?php echo '?group_id='.$group_id; ?>" method="post">
 <input type="checkbox" value="1" name="sure" /> <?php echo _('Confirm Delete'); ?><br />
 <input type="checkbox" value="1" name="reallysure" /> <?php echo _('Confirm Delete'); ?><br />
 <input type="checkbox" value="1" name="reallyreallysure" /> <?php echo _('Confirm Delete'); ?><br />
@@ -64,5 +64,3 @@ site_admin_header(array('title'=>$title));
 <?php
 
 site_admin_footer(array());
-
-?>
