@@ -4,6 +4,9 @@
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2010 (c) Franck Villaume - Capgemini
+ * Copyright (C) 2011-2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013, French Ministry of National Education
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -21,7 +24,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'admin/admin_utils.php';
 require_once $gfwww.'project/admin/project_admin_utils.php';
@@ -37,9 +40,9 @@ if (!$group || !is_object($group)) {
 }
 
 // This function performs very update
-function do_update(&$group, $is_public, $is_template, $status, $group_type, $unix_box, $http_domain, $scm_box='') {
+function do_update(&$group, $is_template, $status, $group_type, $unix_box, $http_domain, $scm_box='') {
 	global $feedback;
-    global $error_msg;
+	global $error_msg;
 
 	db_begin();
 
@@ -49,7 +52,7 @@ function do_update(&$group, $is_public, $is_template, $status, $group_type, $uni
 		return false;
 	}
 
-	if (!$group->updateAdmin(session_get_user(), $is_public, $group_type, $unix_box, $http_domain)) {
+	if (!$group->updateAdmin(session_get_user(), $group_type, $unix_box, $http_domain)) {
 		$error_msg .= $group->getErrorMessage();
 		db_rollback();
 		return false;
@@ -73,18 +76,16 @@ function do_update(&$group, $is_public, $is_template, $status, $group_type, $uni
 	return true;
 }
 
-
 if (getStringFromRequest('submit')) {
-	$form_public = getStringFromRequest('form_public');
 	$form_template = getStringFromRequest('form_template');
 	$form_status = getStringFromRequest('form_status');
 	$form_box = getStringFromRequest('form_box');
 	$form_domain = getStringFromRequest('form_domain');
 	$form_scm_box = getStringFromRequest('form_scm_box');
 
-	do_update($group, $form_public, $form_template, $form_status, 1, $form_box, $form_domain, $form_scm_box);
+	do_update($group, $form_template, $form_status, 1, $form_box, $form_domain, $form_scm_box);
 
-} else if (getStringFromRequest('resend')) {
+} elseif (getStringFromRequest('resend')) {
 
 	$group->sendApprovalEmail();
 	$feedback .= _('Instruction email sent');
@@ -95,18 +96,18 @@ $title = _('Site Admin: Project Info for ') . $group->getPublicName();
 site_admin_header(array('title'=>$title));
 ?>
 
-<h2><?php echo util_make_link("/project/admin/?group_id=$group_id", _('[Project Admin]')); ?></h2>
+<h2><?php echo util_make_link("/project/admin/?group_id=$group_id", _('Project Admin')); ?></h2>
 <h2><?php echo util_make_link("/admin/groupdelete.php?group_id=$group_id", _('Permanently Delete Project')); ?></h2>
 
 <form action="<?php echo getStringFromServer('PHP_SELF'); ?>" method="post">
 
-<table>
+<table class="infotable">
 <tr>
 <td>
-<?php echo _('Status') ?>
+<?php echo _('Status')._(':'); ?>
 </td>
 <td>
-<?php	// PLEASE DONT TRANSLATE THIS, THIS IS DATABASE INFO THAT CANT BE DIFFERENT AMONG LANGUAGES
+<?php	// PLEASE DO NOT TRANSLATE THIS, THIS IS DATABASE INFO THAT CAN BE DIFFERENT AMONG LANGUAGES
 $status = $group->getStatus();
 if($status == 'P') {
 	// we cannot update the status of a pending project
@@ -132,28 +133,21 @@ if($status == 'P') {
 </td>
 </tr>
 <tr>
-<td>
-<?php echo _('Public?') ?>:
-</td>
-<td>
-<?php 	// PLEASE DONT TRANSLATE THIS, THIS IS DATABASE INFO THAT CANT BE DIFFERENT AMONG LANGUAGES
-	echo html_build_select_box_from_arrays(
-	array(
-		'0',
-		'1'
-	),
-	array(
-		_('No'),
-		_('Yes')
-),
-	'form_public', $group->isPublic(), false
-); ?>
-</td>
+<td colspan="2"><?php
+printf(_('With PFO-RBAC, the “is_public” property is gone. Instead, to make a project public, <%1$s>link<%2$s> the global role “Anonymous/not logged in” then <%3$s>give<%4$s> it “Project visibility” permissions.'),
+	'a href="' . util_make_url('/project/admin/users.php?group_id=' .
+	    $group_id) . '"',
+	'/a',
+	'a href="' . util_make_url('/project/admin/roleedit.php?group_id=' .
+	    $group_id . '&amp;role_id=' . RoleAnonymous::getInstance()->getID()) . '"',
+	'/a'
+);
+?></td>
 </tr>
 
 <tr>
 <td>
-<?php echo _('Template?') ?>:
+<?php echo _('Template?')._(':'); ?>
 </td>
 <td>
 <?php
@@ -165,7 +159,7 @@ if($status == 'P') {
 	array(
 		_('No'),
 		_('Yes')
-),
+	),
 	'form_template', $group->isTemplate(), false
 ); ?>
 </td>
@@ -173,7 +167,7 @@ if($status == 'P') {
 
 <tr>
 <td>
-<?php echo _('Unix Project Name:'); ?>
+<?php echo _('Project Unix Name')._(':'); ?>
 </td>
 <td>
 <?php echo $group->getUnixName(); ?>
@@ -183,7 +177,7 @@ if($status == 'P') {
 <?php
 
 	if (forge_get_config('use_shell')) {
-?> 
+?>
 <tr>
 <td>
 <?php echo _('Home Box:'); ?>
@@ -232,7 +226,7 @@ if ($group->usesSCM()) {
 
 <?php
 
-echo show_grouphistory($group->getID());
+show_grouphistory($group->getID());
 
 site_admin_footer(array());
 
@@ -240,5 +234,3 @@ site_admin_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
