@@ -5,6 +5,7 @@
  * Copyright © 2010
  *	Thorsten “mirabilos” Glaser <t.glaser@tarent.de>
  * All rights reserved.
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
  * Based on other FusionForge code.
  *
@@ -24,13 +25,13 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfwww.'include/pre.php';
 require_once $gfcommon.'include/account.php';
 require_once $gfwww.'admin/admin_utils.php';
 
 session_require_global_perm ('forge_admin');
- 
+
 $user_id = getIntFromRequest('user_id');
 $u =& user_get_object($user_id);
 if (!$u || !is_object($u)) {
@@ -51,7 +52,7 @@ if (getStringFromRequest('submit')) {
 		form_release_key(getStringFromRequest('form_key'));
 		exit_error(
 			_('Error'),
-			_('You must supply valid password (at least 6 chars)')
+			_('You must supply valid password (at least 6 chars).')
 		);
 	}
 
@@ -67,17 +68,18 @@ if (getStringFromRequest('submit')) {
 		form_release_key(getStringFromRequest('form_key'));
 		exit_error(
 			_('Error'),
-			'Could not change password: '.$u->getErrorMessage()
+			_('Could not change password: ').$u->getErrorMessage()
 		);
 	}
-	//plugin webcal change user password
-	else {
-		plugin_hook('change_cal_password',$u->getID());
-	}
 
-	site_admin_header(array('title'=>_('Site Admin: Successfully Changed User Password')));
+	site_admin_header(array('title'=>_('Site Admin: Change User Password')));
 
-	printf(_('<h2>%1$s Password Change Confirmation</h2><p>You have changed the password of %2$s (%3$s).</p>'), forge_get_config('forge_name'), $u->getUnixName(), $u->getRealName());
+	echo '<h2>';
+	printf(_('%s Password Change Confirmation'), forge_get_config('forge_name'));
+	echo '</h2>';
+	echo '<p class="feedback">';
+	printf(_('You have changed successfully the password of %1$s (%2$s).'), $u->getUnixName(), $u->getRealName());
+	echo '</p>';
 	printf('<p>'._("Go back to %s.").'</p>', '<a href="userlist.php">'._("the Full User List").'</a>');
 } else {
 	// Show change form
@@ -86,16 +88,14 @@ if (getStringFromRequest('submit')) {
 
 	<form action="<?php echo util_make_url('/admin/passedit.php?user_id='.$user_id); ?>" method="post">
 	<input type="hidden" name="form_key" value="<?php echo form_generate_key(); ?>"/>
-	<p><?php printf(_('Changing password for user #%1$s "%2$s" (%3$s)…'), $user_id, $u->getUnixName(), $u->getRealName()); ?></p>
+	<p><?php printf(_('Changing password for user #%1$s "%2$s" (%3$s).'), $user_id, $u->getUnixName(), $u->getRealName()); ?></p>
 	<p><?php echo _('New Password (at least 6 chars)') ?>:
-	<br /><input type="password" name="passwd" /></p>
+	<br /><input type="password" name="passwd" required="required" title="<?php echo _('At least 6 chars'); ?>" pattern=".{6,}"/></p>
 	<p><?php echo _('New Password (repeat)') ?>:
-	<br /><input type="password" name="passwd2" /></p>
+	<br /><input type="password" name="passwd2" required="required" title="<?php echo _('At least 6 chars'); ?>" pattern=".{6,}" /></p>
 	<p><input type="submit" name="submit" value="<?php echo _('Update password') ?>" /></p>
 	</form>
 	<?php
 }
 
 site_admin_footer(array());
-
-?>
