@@ -6,6 +6,7 @@
  * Copyright 2002-2004, GForge Team
  * Copyright 2010, Alain Peyrat - Alcatel-Lucent
  * Copyright 2011, Roland Mas
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -24,7 +25,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'include/note.php';
 require_once $gfwww.'news/admin/news_admin_utils.php';
@@ -37,60 +38,52 @@ $post_changes = getStringFromRequest('post_changes');
 $approve = getStringFromRequest('approve');
 $status = getIntFromRequest('status');
 $summary = getStringFromRequest('summary');
-$details = getStringFromRequest('details');
+$details = getHtmlTextFromRequest('details');
 $id = getIntFromRequest('id');
 $for_group = getIntFromRequest('for_group');
 
-$feedback = htmlspecialchars(getStringFromRequest('feedback'));
-
 /*
-  
+
   News uber-user admin pages
-  
+
   Show all waiting news items except those already rejected.
-  
+
   Admin members of forge_get_config('news_group') (news project) can edit/change/approve news items
-  
+
 */
 session_require_global_perm ('approve_news') ;
 
 if ($post_changes) {
 	if ($approve) {
-		
+
 		$result=db_query_params("SELECT * FROM news_bytes WHERE id=$1 AND group_id=$2", array($id, $for_group));
 		if (db_numrows($result) < 1) {
 			exit_error(_('Newsbyte not found'),'news');
 		}
-			
+
 		$forum_id = db_result($result,0,'forum_id');
 
 		if ($status==1) {
 			/*
 			  Update the db so the item shows on the home page
 			*/
-			if (getStringFromRequest('_details_content_type') == 'html') {
-				$details = TextSanitizer::purify($details);
-			} else {
-				$details = htmlspecialchars($details);
-			}
 			$result=db_query_params('UPDATE news_bytes SET is_approved=1, post_date=$1, summary=$2, details=$3 WHERE id=$4',
 						array(time(),
 						      htmlspecialchars($summary),
 						      $details,
 						      $id));
 			if (!$result || db_affected_rows($result) < 1) {
-				$error_msg .= _('Error On Update:');
+				$error_msg .= sprintf(_('Error On Update: %s'), db_error());
 			} else {
 				$feedback .= _('Newsbyte Updated.');
 			}
-		} else if ($status==2) {
+		} elseif ($status==2) {
 			/*
 			  Move msg to deleted status
 			*/
 			$result=db_query_params("UPDATE news_bytes SET is_approved='2' WHERE id=$1", array($id));
 			if (!$result || db_affected_rows($result) < 1) {
-				$error_msg .= _('Error On Update:');
-				$error_msg .= db_error();
+				$error_msg .= sprintf(_('Error On Update: %s'), db_error());
 			} else {
 				$feedback .= _('Newsbyte Deleted.');
 			}
@@ -101,75 +94,68 @@ if ($post_changes) {
 		*/
 		$approve='';
 		$list_queue='y';
-	} else if (getStringFromRequest('mass_reject')) {
+	} elseif (getStringFromRequest('mass_reject')) {
 		/*
 		  Move msg to rejected status
 		*/
 		$news_id = getArrayFromRequest('news_id');
-		$result = db_query_params("UPDATE news_bytes 
-SET is_approved='2' 
+		$result = db_query_params("UPDATE news_bytes
+SET is_approved='2'
 WHERE id = ANY($1)",array(db_int_array_to_any_clause($news_id)));
 		if (!$result || db_affected_rows($result) < 1) {
-			$error_msg .= _('Error On Update:');
-			$error_msg .= db_error();
+			$error_msg .= sprintf(_('Error On Update: %s'), db_error());
 		} else {
 			$feedback .= _('Newsbytes Rejected.');
 		}
 	}
 }
 
-news_header(array('title'=>_('News admin')));
+news_header(array('title'=>_('News Admin')));
 
 if ($approve) {
 	/*
 	  Show the submit form
 	*/
 
-	$result=db_query_params("SELECT groups.unix_group_name,groups.group_id,news_bytes.* 
-FROM news_bytes,groups WHERE id=$1 
+	$result=db_query_params("SELECT groups.unix_group_name,groups.group_id,news_bytes.*
+FROM news_bytes,groups WHERE id=$1
 AND news_bytes.group_id=groups.group_id ", array($id));
 	if (db_numrows($result) < 1) {
-		exit_error(_('Newsbyte not found'),'news');
+		exit_error(_('Newsbyte not found'), 'news');
 	}
 	if (db_result($result,0,'is_approved') == 4) {
-		exit_error(_('Newsbyte deleted'),'news');
+		exit_error(_('Newsbyte Deleted.'), 'news');
 	}
-		
+
 	$group = group_get_object(db_result($result,0,'group_id'));
-	$user =& user_get_object(db_result($result,0,'submitted_by'));
+	$user = user_get_object(db_result($result,0,'submitted_by'));
 
 	echo '
-		<p />
 		<form action="'.getStringFromServer('PHP_SELF').'" method="post">
 		<input type="hidden" name="for_group" value="'.db_result($result,0,'group_id').'" />
 		<input type="hidden" name="id" value="'.db_result($result,0,'id').'" />
-		<strong>'._('Submitted for project').':</strong> '.
+		<strong>'._('Submitted for project')._(':').'</strong> '.
 		util_make_link_g (strtolower(db_result($result,0,'unix_group_name')),db_result($result,0,'group_id'),$group->getPublicName()).'<br />
-		<strong>'._('Submitted by').':</strong> '.$user->getRealName().'<br />
+		<strong>'._('Submitted by')._(':').'</strong> '.$user->getRealName().'<br />
 		<input type="hidden" name="approve" value="y" />
 		<input type="hidden" name="post_changes" value="y" />
 		<input type="radio" name="status" value="1" /> '._('Approve For Front Page').'<br />
 		<input type="radio" name="status" value="0" /> '._('Do Nothing').'<br />
 		<input type="radio" name="status" value="2" checked="checked" /> '._('Reject').'<br />
-		<strong>'._('Subject').':</strong><br />
+		<strong>'._('Subject')._(':').'</strong><br />
 		<input type="text" name="summary" value="'.db_result($result,0,'summary').'" size="60" maxlength="60" /><br />
-		<strong>'._('Details').':</strong><br />';
-		
-	$GLOBALS['editor_was_set_up']=false;
+		<strong>'._('Details')._(':').'</strong><br />';
+
 	$params = array () ;
 	$params['name'] = 'details';
 	$params['width'] = "600";
 	$params['height'] = "300";
 	$params['group'] = db_result($result,0,'group_id');
 	$params['body'] = db_result($result,0,'details');
-	plugin_hook("text_editor",$params);
-	if (!$GLOBALS['editor_was_set_up']) {
-		//if we don't have any plugin for text editor, display a simple textarea edit box
-		echo '<textarea name="details" rows="5" cols="50">'.db_result($result,0,'details').'</textarea><br />';
-	}
-	unset($GLOBALS['editor_was_set_up']);		
-		
-		
+	$params['content'] = '<textarea name="details" rows="5" cols="50">'.$params['body'].'</textarea>';
+	plugin_hook_by_reference("text_editor",$params);
+
+	echo $params['content'].'<br/>';
 	echo '<br />
 		<input type="submit" name="submit" value="'._('Submit').'" />
 		</form>';
@@ -219,5 +205,3 @@ news_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
