@@ -1,6 +1,6 @@
 <?php
 /**
- * Site Admin page to edit canned responces for project rejection
+ * Site Admin page to edit canned responses for project rejection
  *
  * This page is linked from approve-pending.php
  *
@@ -22,7 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'include/account.php';
 require_once $gfwww.'include/canned_responses.php';
@@ -31,15 +31,15 @@ require_once $gfwww.'project/admin/project_admin_utils.php';
 
 site_admin_header(array('title'=>_('Site Admin: Edit Rejection Responses')));
 
-function check_select_value($value, $type) {
+function check_select_value($value) {
 	if( $value == "100" ) {
-		print("<span class=\"important\">".sprintf(_('You can\'t %1$s \"None\"!'), $GLOBALS['type'])."</span><br />\n");
+		print('<span class="important">'.sprintf(_('You cannot %s “None”!'), $GLOBALS['type'])."</span><br />\n");
 	}
 }
 ?>
 
 <form method="post" action="<?php echo getStringFromServer('PHP_SELF'); ?>">
-<?php echo _('Existing Responses:'); ?><?php echo get_canned_responses(); ?>
+<?php echo _('Existing Responses')._(': '); ?><?php echo get_canned_responses(); ?>
 <!-- Reinhard Spisser: commenting localization, since otherwise it will not work -->
 <!--
 <input name="action" type="submit" value="<?php echo _('Edit'); ?>" />
@@ -47,11 +47,11 @@ function check_select_value($value, $type) {
 -->
 <input name="action" type="submit" value="Edit" />
 <input name="action" type="submit" value="Delete" />
-<input type="checkbox" name="sure" value="<?php echo _('yes'); ?>" />
-<?php  echo _('Yes, I\'m sure'); ?>
+<input type="checkbox" name="sure" value="<?php echo _('Yes'); ?>" />
+<?php  echo _('I am Sure'); ?>
 </form>
 
-<br /><br />
+<br />
 
 <?php
 
@@ -64,7 +64,7 @@ if( $action == "Edit" ) {
 	$response_text = getStringFromRequest('response_text');
 
 	// Edit Response
-	check_select_value($response_id, $action);
+	check_select_value($response_id);
 	if( $action2 ) {
 		db_query_params ('UPDATE canned_responses SET response_title=$1, response_text=$2 WHERE response_id=$3',
 			array($response_title,
@@ -87,7 +87,7 @@ if( $action == "Edit" ) {
 <?php echo _('Response Text:'); ?><br />
 <textarea name="response_text" cols="50" rows="10"><?php echo $response_text; ?></textarea>
 <input type="hidden" name="response_id" value="<?php echo $response_id; ?>" />
-<input type="hidden" name="action2" value="<?php echo _('go'); ?>" />
+<input type="hidden" name="action2" value="<?php echo _('Go'); ?>" />
 <input type="hidden" name="action" value="Edit">
 <input type="submit" name="actionsubmit" value="<?php echo _('Edit'); ?>" />
 </form>
@@ -95,23 +95,23 @@ if( $action == "Edit" ) {
 <?php
 	}
 
-} else if ( $action == "Delete" ) {
+} elseif ( $action == "Delete" ) {
 	$response_id = getIntFromRequest('response_id');
 	$sure = getStringFromRequest('sure');
 
 	// Delete Response
-	check_select_value($response_id, $action);
+	check_select_value($response_id);
 	if( $sure == "yes" ) {
 		db_query_params ('DELETE FROM canned_responses WHERE response_id=$1',
 			array($response_id)) ;
 
 		print(" <strong>" ._('Deleted Response')."</strong> ");
 	} else {
-		print( _('If you\'re aren\'t sure then why did you click \'Delete\'?')."<br />");
+		print( _('If you are not sure then why did you click “Delete”?')."<br />");
 		print("<em>" ._('By the way, I didn\'t delete... just in case...')."</em><br />\n");
 	}
 
-} else if ( $action == "Create" ) {
+} elseif ( $action == "Create" ) {
 	$response_title = getStringFromRequest('response_title');
 	$response_text = getStringFromRequest('response_text');
 
@@ -141,5 +141,3 @@ site_admin_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
