@@ -21,7 +21,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'include/trove.php';
 require_once $gfwww.'admin/admin_utils.php';
@@ -34,7 +34,7 @@ if (getStringFromRequest('submit')) {
 	if (!form_key_is_valid(getStringFromRequest("form_key"))) {
 		exit_form_double_submit();
 	}
-	
+
 	$form_parent = getIntFromRequest('form_parent');
 	$form_shortname = getStringFromRequest('form_shortname');
 	$form_fullname = getStringFromRequest('form_fullname');
@@ -44,16 +44,9 @@ if (getStringFromRequest('submit')) {
 
 	if ($form_shortname && $form_fullname) {
 		$res = db_query_params ('
-			INSERT INTO trove_cat 
+			INSERT INTO trove_cat
 				(shortname,fullname,description,parent,version,root_parent)
-			VALUES (
-				$1,
-				$2,
-				$3,
-				$4,
-                                $5,
-				$6
-			)
+			VALUES ($1, $2, $3, $4, $5, $6)
 		',
 			array(htmlspecialchars($form_shortname),
 			      htmlspecialchars($form_fullname),
@@ -64,7 +57,7 @@ if (getStringFromRequest('submit')) {
 
 		if (!$res || db_affected_rows($res)<1) {
 			form_release_key(getStringFromRequest("form_key"));
-			exit_error(_('Error In Trove Operation: ').db_error(),'trove');
+			exit_error(sprintf(_('Error in Trove Operation: %s'), db_error()), 'trove');
 		}
 
 		// update full paths now
@@ -72,16 +65,16 @@ if (getStringFromRequest('submit')) {
 
 		session_redirect("/admin/trove/trove_cat_list.php");
 	} else {
-		$error_msg = 'Missing category short name or full name';
+		$error_msg = _('Missing category short name or full name');
 	}
-} 
+}
 
 site_admin_header(array('title'=>_('Add New Trove Category')));
 ?>
 
 <form action="trove_cat_add.php" method="post">
 <input type="hidden" name="form_key" value="<?php echo form_generate_key(); ?>" />
-<p><?php echo _('Parent Category'); ?>:<?php echo utils_requiredField(); ?>
+<p><?php echo _('Parent Category').utils_requiredField()._(':'); ?>
 <br /><select name="form_parent">
 
 <?php
@@ -114,11 +107,11 @@ if ($parent_trove_cat_id != -1) {
 ?>
 
 </select></p>
-<p><?php echo _('New category short name (no spaces, unix-like)'); ?>:<?php echo utils_requiredField(); ?>
-<br /><input type="text" name="form_shortname" /></p>
-<p><?php echo _('New category full name (Maximum length is 80 chars)'); ?>:<?php echo utils_requiredField(); ?>
-<br /><input type="text" name="form_fullname" /></p>
-<p><?php echo _('New category description (Maximum length is 255 chars)'); ?>:
+<p><?php echo _('New category short name (no spaces, Unix-like)').utils_requiredField()._(':'); ?>
+<br /><input type="text" required="required" name="form_shortname" /></p>
+<p><?php echo _('New category full name (maximum length is 80 chars)').utils_requiredField()._(':'); ?>
+<br /><input type="text" required="required" name="form_fullname" /></p>
+<p><?php echo _('New category description (maximum length is 255 chars)')._(':'); ?>
 <br /><input type="text" size="80" name="form_description" /></p>
 <p><input type="submit" name="submit" value="<?php echo _('Add'); ?>" /></p>
 </form>
@@ -126,5 +119,3 @@ if ($parent_trove_cat_id != -1) {
 <?php
 
 site_admin_footer(array());
-
-?>
