@@ -9,6 +9,7 @@
  *   - register existing database in system
  *
  * Copyright 1999-2001 (c) VA Linux Systems
+ * Copyright 2014, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -26,7 +27,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'include/account.php';
 require_once $gfwww.'admin/admin_utils.php';
@@ -59,9 +60,8 @@ if (getStringFromRequest('add')) {
 			$docdir = $homedir.'/htdocs/';
 			$cgidir = $homedir.'/cgi-bin/';
 
-
 			$res = db_query_params ('
-				INSERT INTO prweb_vhost(vhost_name, docdir, cgidir, group_id) 
+				INSERT INTO prweb_vhost(vhost_name, docdir, cgidir, group_id)
 				VALUES ($1,$2,$3,$4)
 			',
 			array($vhost_name,
@@ -69,18 +69,17 @@ if (getStringFromRequest('add')) {
 			$cgidir,
 			$group_id)) ;
 
-
 			if (!$res || db_affected_rows($res) < 1) {
 				$error_msg .= _('Error adding VHOST: ') .db_error();
 			} else {
-				$feedback .= _('Virtual Host: ').$vhost_name._(' scheduled for creation on group ').$group->getUnixName();
+				$feedback .= _('Virtual Host').' '.$vhost_name._(' scheduled for creation on group ').$group->getUnixName();
 			}
 		} else {
 			$error_msg .= _('Vhost not valid');
 		}
-    } else {
+	} else {
 		$warning_msg .=	_('Missing group name');
-    }
+	}
 }
 
 if (getStringFromRequest('tweakcommit')) {
@@ -89,26 +88,23 @@ if (getStringFromRequest('tweakcommit')) {
 	$cgidir = getStringFromRequest('cgidir');
 
 	$res = db_query_params ('
-		UPDATE prweb_vhost 
+		UPDATE prweb_vhost
 		SET docdir=$1,
-			cgidir=$2 
+			cgidir=$2
 		WHERE vhostid=$3
 	',
 			array($docdir,
 			$cgidir,
 			$vhostid)) ;
 
-
 	if (!$res || db_affected_rows($res) < 1) {
 		$error_msg .= _('Error updating VHOST entry: ') .db_error();
 	} else {
 		$feedback .= _('Virtual Host entry updated.');
-	}		
-
+	}
 }
 
-
-site_admin_header(array('title'=>_('Site admin')));
+site_admin_header(array('title'=>_('Site Admin')));
 ?>
 
 <h3><?php echo _('Virtual Host Administration'); ?></h3>
@@ -117,16 +113,16 @@ site_admin_header(array('title'=>_('Site admin')));
 
 <strong><?php echo _('Add Virtual Host'); ?></strong>
 
-<table border="0">
+<table>
 
 <tr>
-<td><?php echo _('Project Unix Name'); ?></td>
-<td><input type="text" name="groupname" /></td>
+<td><?php echo _('Project Unix Name').utils_requiredField(); ?></td>
+<td><input type="text" name="groupname" required="required" /></td>
 </tr>
 
 <tr>
-<td><?php echo _('Virtual Host Name'); ?></td>
-<td><input type="text" name="vhost_name" /></td>
+<td><?php echo _('Virtual Host Name').utils_requiredField(); ?></td>
+<td><input type="text" name="vhost_name" required="required" /></td>
 </tr>
 </table>
 
@@ -140,9 +136,9 @@ site_admin_header(array('title'=>_('Site admin')));
 <br />
 
 <form name="tweak" method="post" action="<?php echo getStringFromServer('PHP_SELF'); ?>">
-<table border="0">
+<table>
 <tr>
-   <td><?php echo _('Virtual Host:'); ?></td><td><input type="text" name="vhost_name" /></td>
+   <td><?php echo _('Virtual Host')._(':'); ?></td><td><input type="text" name="vhost_name" /></td>
    <td><input type="submit" value="<?php echo _('Get Info'); ?>" /></td>
 </tr>
 </table>
@@ -156,19 +152,18 @@ if (getStringFromRequest('tweak')) {
 	$vhost_name = getStringFromRequest('vhost_name');
 
 	$res_vh = db_query_params ('
-		SELECT vhostid,vhost_name,docdir,cgidir,unix_group_name,group_id
+		SELECT vhostid,vhost_name,docdir,cgidir,unix_group_name,prweb_vhost.group_id
 		FROM prweb_vhost,groups
 		WHERE vhost_name=$1
 		AND prweb_vhost.group_id=groups.group_id
 	',
 			array($vhost_name)) ;
 
-
 	if (db_numrows($res_vh) > 0) {
 
 		$row_vh = db_fetch_array($res_vh);
-	
-		print '<div class="feedback">'._('Update Record:').'</div>';
+
+		print '<p class="information">'._('Update Record:').'</p>';
 
 		$title=array();
 		$title[]=_('VHOST ID');
@@ -194,7 +189,7 @@ if (getStringFromRequest('tweak')) {
 			</form>
 		';
 	} else {
-		echo '<div class="warning">'._('No such VHOST: ') . $vhost_name.'</div>';
+		echo '<p class="warning">'._('No such VHOST: ') . $vhost_name.'</p>';
 	}
 
 }
@@ -205,5 +200,3 @@ site_admin_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
