@@ -4,6 +4,7 @@
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2010 (c) Franck Villaume
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -21,23 +22,27 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'include/vote_function.php';
 
+if (!forge_get_config('use_diary')) {
+	exit_disabled('home');
+}
+
 $diary_user = getIntFromRequest('diary_user');
 if ($diary_user) {
 	$diary_id = getIntFromRequest('diary_id');
-  
+
 	$user_obj=user_get_object($diary_user);
-	if (!$user_obj) {
+	if (!$user_obj or !$user_obj->isActive()) {
 		exit_error(_('User could not be found.'),'home');
-	} else if ($user_obj->isError()) {
+	} elseif ($user_obj->isError()) {
 		exit_error($user_obj->getErrorMessage(),'home');
 	}
 
-	$title = _('Diary And Notes For').': '. $user_obj->getRealName();
-	echo $HTML->header(array('title'=>$title));
+	$title = _('Diary and Notes for') . ' ' . $user_obj->getRealName();
+	$HTML->header(array('title'=>$title));
 
 	if ($diary_id) {
 		$res = db_query_params ('SELECT * FROM user_diary WHERE user_id=$1 AND id=$2 AND is_public=1',
@@ -54,8 +59,8 @@ if ($diary_user) {
 		}
 	}
 
-	echo $HTML->boxTop(_('Existing Diary And Note Entries'));
-	echo '<table cellspacing="2" cellpadding="0" width="100%" border="0">';
+	echo '<h2>' . _('Existing Diary and Notes Entries') . '</h2>' . "\n";
+	echo '<table class="fullwidth">' . "\n";
 	/*
 		List all diary entries
 	*/
@@ -85,12 +90,9 @@ if ($diary_user) {
 		<tr><td colspan="2" class="tablecontent">&nbsp;</td></tr>';
 	}
 	echo "</table>\n";
-	echo $HTML->boxBottom();
 
-	echo $HTML->footer(array());
+	$HTML->footer(array());
 
 } else {
 	exit_error(_('No User Selected'),'home');
 }
-
-?>
