@@ -2,6 +2,8 @@
 /**
  *
  * Copyright 2006 Daniel A. Perez <daniel@gforgegroup.com>
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2014, Franck Villaume - TrivialDev
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -39,7 +41,7 @@ if ($group_id) {
 				array($group_id),
 				1);
 	$row = db_fetch_array($res);
-	$title = $row['group_name'];
+	$title = $row['group_name']." - ";
 	$link = "?group_id=$group_id";
 	$description = " of ".$row['group_name'];
 
@@ -50,6 +52,7 @@ if ($group_id) {
 		$webmaster = forge_get_config('admin_email');
 	}
 
+	$sysdebug_enable = false;
 	// ## one time output
 	header("Content-Type: text/xml; charset=utf-8");
 	print '<?xml version="1.0" encoding="UTF-8"?>
@@ -57,7 +60,7 @@ if ($group_id) {
        ';
 	print " <channel>\n";
 	print "  <title>".forge_get_config ('forge_name')." $title Activity</title>\n";
-	print "  <link>$url/activity/$link</link>\n";
+	print "  <link>".util_make_url("/activity/$link")."</link>\n";
 	print "  <description>".forge_get_config ('forge_name')." Project Activity$description</description>\n";
 	print "  <language>en-us</language>\n";
 	print "  <copyright>Copyright ".date("Y")." ".forge_get_config ('forge_name')."</copyright>\n";
@@ -66,14 +69,35 @@ if ($group_id) {
 	print "  <docs>http://blogs.law.harvard.edu/tech/rss</docs>\n";
 	print "  <generator>".forge_get_config ('forge_name')." RSS generator</generator>\n";
 
-	$res = db_query_params ('SELECT * FROM activity_vw WHERE activity_date BETWEEN $1 AND $2 AND group_id=$3 ORDER BY activity_date DESC',
+	$res = db_query_params('SELECT * FROM activity_vw WHERE activity_date BETWEEN $1 AND $2
+		AND group_id=$3 ORDER BY activity_date DESC',
 				array(time() - 30*86400,
 				      time(),
 				      $group_id),
 				$limit);
+	$results = array();
+	while ($arr = db_fetch_array($res)) {
+		$results[] = $arr;
+	}
+
+	// If plugins wants to add activities.
+	$ids = array();
+	$texts = array();
+	$show = array();
+
+	$hookParams['group'] = $group_id ;
+	$hookParams['results'] = &$results;
+	$hookParams['show'] = &$show;
+	$hookParams['begin'] = time()-(30*86400);
+	$hookParams['end'] = time();
+	$hookParams['ids'] = &$ids;
+	$hookParams['texts'] = &$texts;
+	plugin_hook ("activity", $hookParams) ;
+
+	usort($results, 'date_compare');
 
 	// ## item outputs
-	while ($arr = db_fetch_array($res)) {
+	foreach ($results as $arr) {
 
 		switch ($arr['section']) {
 			case 'commit': {
@@ -84,6 +108,7 @@ if ($group_id) {
 				print "   <title>".htmlspecialchars('Commit for Tracker Item [#'.$arr['subref_id'].'] '.$arr['description'])."</title>\n";
 				print "   <link>$url/tracker/?func=detail&amp;atid=".$arr['ref_id'].'&amp;aid='.$arr['subref_id'].'&amp;group_id='.$arr['group_id']."</link>\n";
 				print "   <comments>$url/tracker/?func=detail&amp;atid=".$arr['ref_id'].'&amp;aid='.$arr['subref_id'].'&amp;group_id='.$arr['group_id']."</comments>\n";
+				$arr['category'] = _('Source Code');
 				break;
 			}
 			case 'trackeropen': {
@@ -94,6 +119,7 @@ if ($group_id) {
 				print "   <title>".htmlspecialchars('Tracker Item [#'.$arr['subref_id'].' '.$arr['description'].'] Opened')."</title>\n";
 				print "   <link>$url/tracker/?func=detail&amp;atid=".$arr['ref_id'].'&amp;aid='.$arr['subref_id'].'&amp;group_id='.$arr['group_id']."</link>\n";
 				print "   <comments>$url/tracker/?func=detail&amp;atid=".$arr['ref_id'].'&amp;aid='.$arr['subref_id'].'&amp;group_id='.$arr['group_id']."</comments>\n";
+				$arr['category'] = _('Trackers');
 				break;
 			}
 			case 'trackerclose': {
@@ -104,6 +130,7 @@ if ($group_id) {
 				print "   <title>".htmlspecialchars('Tracker Item [#'.$arr['subref_id'].' '.$arr['description'].'] Closed')."</title>\n";
 				print "   <link>$url/tracker/?func=detail&amp;atid=".$arr['ref_id'].'&amp;aid='.$arr['subref_id'].'&amp;group_id='.$arr['group_id']."</link>\n";
 				print "   <comments>$url/tracker/?func=detail&amp;atid=".$arr['ref_id'].'&amp;aid='.$arr['subref_id'].'&amp;group_id='.$arr['group_id']."</comments>\n";
+				$arr['category'] = _('Trackers');
 				break;
 			}
 			case 'frsrelease': {
@@ -114,6 +141,7 @@ if ($group_id) {
 				print "   <title>".htmlspecialchars('FRS Release [#'.$arr['description'].']')."</title>\n";
 				print "   <link>$url/frs/?release_id=".$arr['subref_id'].'&amp;group_id='.$arr['group_id']."</link>\n";
 				print "   <comments>$url/frs/?release_id=".$arr['subref_id'].'&amp;group_id='.$arr['group_id']."</comments>\n";
+				$arr['category'] = _('File Release System');
 				break;
 			}
 			case 'forumpost': {
@@ -124,6 +152,7 @@ if ($group_id) {
 				print "   <title>".htmlspecialchars('Forum Post [#'.$arr['subref_id'].'] '.$arr['description'])."</title>\n";
 				print "   <link>$url/forum/message.php?forum_id=".$arr['ref_id'].'&amp;msg_id='.$arr['subref_id'].'&amp;group_id='.$arr['group_id']."</link>\n";
 				print "   <comments>$url/forum/message.php?forum_id=".$arr['ref_id'].'&amp;msg_id='.$arr['subref_id'].'&amp;group_id='.$arr['group_id']."</comments>\n";
+				$arr['category'] = _('Forums');
 				break;
 			}
 			case 'news': {
@@ -134,12 +163,26 @@ if ($group_id) {
 				print "   <title>".htmlspecialchars('News Post [#'.$arr['subref_id'].'] '.$arr['description'])."</title>\n";
 				print "   <link>$url/forum/forum.php?forum_id=".$arr['subref_id']."</link>\n";
 				print "   <comments>$url/forum/forum.php?forum_id=".$arr['subref_id']."</comments>\n";
+				$arr['category'] = _('News');
 				break;
 			}
+			default: {
+				print "  <item>\n";
+				print "   <title>".htmlspecialchars($arr['title'])."</title>\n";
+				print "   <link>".$url.$arr['link']."</link>\n";
+				print "   <comment>".$url.$arr['link']."</comment>\n";
+			}
 		}
 
 		print "   <description>".rss_description($arr['description'])."</description>\n";
-		print "   <author>".$arr['user_name']."@".forge_get_config('users_host')." (".$arr['realname'].")</author>\n";
+		if (isset($arr['category']) && $arr['category']) {
+			print "   <category>".$arr['category']."</category>\n";
+		}
+		if (isset($arr['user_name']) && $arr['user_name']) {
+			print "   <author>".$arr['user_name']."@".forge_get_config('users_host')." (".$arr['realname'].")</author>\n";
+		} else {
+			print "   <author>".$arr['realname']."</author>\n";
+		}
 		print "   <pubDate>".rss_date($arr['activity_date'])."</pubDate>\n";
 		print "  </item>\n";
 	}
@@ -150,7 +193,13 @@ if ($group_id) {
 } else {
 	// Print error showing no group was selected
 
-	echo "<div class='error'>"._('Error: No group selected')."</div>";
+	echo '<br /><span class="error">'._('Error: No group selected').'</span>';
 }
 
-?>
+function date_compare($a, $b)
+{
+	if ($a['activity_date'] == $b['activity_date']) {
+		return 0;
+	}
+	return ($a['activity_date'] > $b['activity_date']) ? -1 : 1;
+}
