@@ -25,7 +25,7 @@
  * RSS feed used in connection with the Tasks Abonnement feature.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 
 require_once $gfcommon.'include/Error.class.php';
@@ -58,19 +58,19 @@ $group_id = $tinfo['group_id'];
 $group_project_id = $tinfo['group_project_id'];
 $project_task_id = $tinfo['project_task_id'];
 
-$objGroup =& group_get_object($group_id);
+$objGroup = group_get_object($group_id);
 if (!$objGroup || !is_object($objGroup)) {
 	exit_no_group();
 } elseif ($objGroup->isError()) {
 	exit_error('Error',$objGroup->getErrorMessage());
 }
 
-$objProjectGroup = &projectgroup_get_object($group_project_id);
+$objProjectGroup = projectgroup_get_object($group_project_id);
 if(!$objProjectGroup || !is_object($objProjectGroup)) {
 	exit_error('Error',_('No project group was found for this task.'));
 }
 
-$objProjectTask = &projecttask_get_object($project_task_id);
+$objProjectTask = projecttask_get_object($project_task_id);
 if(!$objProjectTask || !is_object($objProjectTask)) {
 	exit_error('Error',_('No project task was found.'));
 }
@@ -139,11 +139,11 @@ function writeRssFeedBegin($objProjectTask, $objGroup, $objProjectGroup) {
 	printf(_('Update history of the task with the name %1$s and the ID %2$d.') . ' ', $objProjectTask->getSummary(), $objProjectTask->getID());
 	print _('Current values of the task’s…').' => ';
 
-	print ' '._('Subproject:').' '.$objProjectGroup->getName().' |';
-	print ' '._('Summary:').' '.$objProjectTask->getSummary().' |';
-	print ' '._('Complete:').' '.$objProjectTask->getPercentComplete().'% |';
-	print ' '._('Status:').' '.$objProjectTask->getStatusName().' |';
-	print ' '._('Details:').' '.$objProjectTask->getDetails().' |';
+	print ' '._('Subproject')._(': ').$objProjectGroup->getName().' |';
+	print ' '._('Summary')._(': ').$objProjectTask->getSummary().' |';
+	print ' '._('Complete')._(': ').$objProjectTask->getPercentComplete().'% |';
+	print ' '._('Status')._(': ').$objProjectTask->getStatusName().' |';
+	print ' '._('Details')._(': ').$objProjectTask->getDetails().' |';
 
 	print'</description>';
 	//print'<language>en-us</language>';
@@ -160,17 +160,17 @@ function writeRssFeedItem($objProjectTask, $updates) {
 	foreach($updates as $update){
 	$update[6]==='message' ? $title = _('Comment') : $title = $update[5];
 	$update[6]==='message' ? $description = $update[5] : $description = $update[6];
-	$objGfUser = &user_get_object($update[7]);
+	$objGfUser = user_get_object($update[7]);
 		print'<item>';
 		print'<title>';
 		print $title;
 		print'</title>';
 		print'<description>';
-		print _('Updated value').': ';
+		print _('Updated value')._(': ');
 		print $description.' | ';
-		print _('Posted by').': ';
+		print _('Posted by')._(': ');
 		print $objGfUser->getUnixName().' | ';
-		print _('Update time').': ';
+		print _('Update time')._(': ');
 		print gmdate('D, d M Y G:i:s',$update[8]);
 		print'</description>';
 		print '<link>' . util_make_url("/pm/t_follow.php/" . $objProjectTask->getID()) . '</link>';
@@ -190,5 +190,3 @@ function writeRssFeedEnd() {
 	print'</channel>';
 	print'</rss>';
 }
-
-?>
