@@ -1,8 +1,9 @@
 <?php
-/*
+/**
  * Copyright 1999-2000 (c) The SourceForge Crew
  * Copyright (C) 2009-2010 Alain Peyrat, Alcatel-Lucent
  * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2012, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -75,32 +76,38 @@ $HTML->header(array('title'=>_('RSS Exports')));
 
 echo '<h2>' . _('RSS Exports') . '</h2>';
 echo '<p>';
-printf(_('%1$s data is exported in RSS 2.0 format. Many of the export URLs can also accept form/get data to customize the output. All data generated by these pages is realtime.'), forge_get_config ('forge_name'));
+printf(_('%s data is exported in RSS 2.0 format. Many of the export URLs can also accept form/get data to customize the output. All data generated by these pages is realtime.'), forge_get_config ('forge_name'));
 
-echo _('To get Project News or New Project Releases of a specific project use the Links below.'); 
+echo _('To get Project News or New Project Releases of a specific project use the Links below.');
 
 $string_rss_20 = '';
 
 // RSS for project news
 if ($project->usesNews() && forge_get_config('use_news')) {
 	$string_rss_20 .= get_rss_feed_20 ("rss20_news.php?group_id=" . $group_id,
-										$name.': ' . _('Project News'));
+										$name._(': ') . _('Project News'));
 }
 
 // RSS for project Activity
-if ( ($project->usesNews() && forge_get_config('use_news')) || 
-	($project->usesFRS() && forge_get_config('use_frs')) || 
-	($project->usesTracker() && forge_get_config('use_tracker')) || 
+if ( ($project->usesNews() && forge_get_config('use_news')) ||
+	($project->usesFRS() && forge_get_config('use_frs')) ||
+	($project->usesTracker() && forge_get_config('use_tracker')) ||
 	($project->usesForum() && forge_get_config('use_forum')) ||
 	($project->usesSCM() && forge_get_config('use_scm')) ){
 	$string_rss_20 .= get_rss_feed_20 ("rss20_activity.php?group_id=" . $group_id,
-										$name.': ' . _('Activity'));
+										$name._(': ') . _('Activity'));
 }
 
 // RSS for project Releases
 if ($project->usesFRS() && forge_get_config('use_frs')) {
 	$string_rss_20 .= get_rss_feed_20 ("rss20_newreleases.php?group_id=" . $group_id,
-										$name.': ' . _('Project Releases'));
+										$name._(': ') . _('Project Releases'));
+}
+
+// RSS for project documents
+if ($project->usesDocman() && forge_get_config('use_docman')) {
+	$string_rss_20 .= get_rss_feed_20 ("rss20_docman.php?group_id=" . $group_id,
+										$name._(': ') . _('Project Document Manager'));
 }
 
 ?>
@@ -110,4 +117,4 @@ if ($project->usesFRS() && forge_get_config('use_frs')) {
 
 <a href="javascript:history.go(-1)">[<?php echo _('Go back') ?>]</a>
 <br />
-<?php $HTML->footer(array()); ?>
+<?php $HTML->footer(array());
