@@ -5,7 +5,9 @@
  * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2002-2004 (c) GForge Team
  * Copyright 2010 (c) Franck Villaume - Capgemini
- * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright (C) 2011-2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013, French Ministry of National Education
+ * Copyright 2013, Franck Villaume - TrivialDev
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -24,7 +26,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'forum/ForumHTML.class.php';
 require_once $gfcommon.'forum/Forum.class.php';
@@ -37,7 +39,7 @@ require_once $gfcommon.'include/TextSanitizer.class.php'; // to make the HTML in
 $group_id = getIntFromRequest('group_id');
 $group_forum_id = getIntFromRequest('group_forum_id');
 $deleteforum = getStringFromRequest('deleteforum');
-$feedback = htmlspecialchars(getStringFromRequest('feedback'));
+$error_msg = htmlspecialchars(getStringFromRequest('error_msg'));
 
 global $HTML;
 
@@ -52,6 +54,10 @@ $g = group_get_object($group_id);
 if (!$g || !is_object($g) || $g->isError()) {
 	exit_no_group();
 }
+if (!$g->usesForum()) {
+	exit_error(sprintf(_('%s does not use the Forum tool.'),
+	    $g->getPublicName()), 'forums');
+}
 
 session_require_perm ('forum_admin', $group_id) ;
 
@@ -68,7 +74,7 @@ if (getStringFromRequest('post_changes')) {
 		$feedback .= $fa->ExecuteAction("delete_forum");
 		$group_forum_id=0;
 		$deleteforum=0;
-	} else if (getStringFromRequest('add_forum')) {
+	} elseif (getStringFromRequest('add_forum')) {
 		if (!form_key_is_valid(getStringFromRequest('form_key'))) {
 			exit_form_double_submit('forums');
 		}
@@ -76,11 +82,18 @@ if (getStringFromRequest('post_changes')) {
 		if (check_email_available($g, $g->getUnixName() . '-' . getStringFromRequest('forum_name'), $error_msg)) {
 			$fa = new ForumAdmin($group_id);
 			$feedback .= $fa->ExecuteAction("add_forum");
-			$g->normalizeAllRoles () ;
+			if ($fa->isError()){
+				$error_msg = $fa->getErrorMessage();
+			} else {
+				$g->normalizeAllRoles();
+			}
 		}
-	} else if (getStringFromRequest('change_status')) {
+	} elseif (getStringFromRequest('change_status')) {
 		$fa = new ForumAdmin($group_id);
 		$feedback .= $fa->ExecuteAction("change_status");
+		if ($fa->isError()){
+			$error_msg = $fa->getErrorMessage();
+		}
 	}
 }
 
@@ -88,7 +101,7 @@ if (getStringFromRequest('add_forum')) {
 	/*
 	  Show the form for adding forums
 	*/
-	forum_header(array('title'=>_('Add forum')));
+	forum_header(array('title'=>_('Add Forum')));
 
 	echo '
 			<form method="post" action="'.getStringFromServer('PHP_SELF').'">
@@ -97,39 +110,25 @@ if (getStringFromRequest('add_forum')) {
 			<input type="hidden" name="add_forum" value="y" />
 			<input type="hidden" name="group_id" value="'.$group_id.'" />
 			<input type="hidden" name="form_key" value="' . form_generate_key() . '" />
-			<strong>'._('Forum Name').':</strong><br />
-			<input type="text" name="forum_name" value="" size="20" maxlength="30" />
+			<strong>'._('Forum Name')._(':').utils_requiredField().'</strong><br />
+			<input type="text" name="forum_name" required="required" value="" size="20" maxlength="30" pattern=".{3,}" />
 			</p>
 			<p>
-			<strong>'._('Description').':</strong><br />
-			<input type="text" name="description" value="" size="40" maxlength="80" />
+			<strong>'._('Description')._(':').utils_requiredField().'</strong><br />
+			<input type="text" name="description" required="required" value="" size="40" maxlength="80" pattern=".{10,}" />
 			</p>
 			<p>
-			<strong>'._('Is Public?').'</strong><br />
-			<input type="radio" name="is_public" value="1" checked="checked" />'._('Yes').' <br />
-			<input type="radio" name="is_public" value="0" />'._('No').'
-			</p>
-			<p>
-			<strong>'._('Allow Anonymous Posts?').'</strong><br />
-			<input type="radio" name="allow_anonymous" value="1" />'._('Yes').'<br />
-			<input type="radio" name="allow_anonymous" value="0" checked="checked" />'._('No').'
-			</p>
-			<p>'.
-
-		html_build_select_box_from_assoc(array("0" => _('No Moderation') ,"1" => _('Moderated Level 1'),"2" => _('Moderated Level 2') ),"moderation_level",0) . '
-				<br />' . _('Moderated Level 1') . ': ' . _('To moderate anonymous posts (if allowed in public forum) and posts from non-member users.') . '<br />' . _('Moderated Level 2') . ': ' . _('To moderate ALL posts.') . '<p>
-				
 			<strong>'._('Email All Posts To:').'</strong><br />
-			<input type="text" name="send_all_posts_to" value="" size="60" />
+			<input type="email" name="send_all_posts_to" value="" size="60" />
 			</p>
 			<p>
 			<input type="submit" name="submit" value="'._('Add This Forum').'" />
 			</p>
 			</form>';
-
+	echo '<span>'.sprintf(_('%s Mandatory fields'), utils_requiredField()).'</span>';
 	forum_footer(array());
 
-} else if (getStringFromRequest('change_status')) {
+} elseif (getStringFromRequest('change_status')) {
 	/*
 	  Change a forum
 	*/
@@ -140,7 +139,7 @@ if (getStringFromRequest('add_forum')) {
 	echo '<p>'._('You can adjust forum features from here. Please note that private forums can still be viewed by members of your project, not the general public.').'</p>';
 	$fa = new ForumAdmin($f->Group->getID());
 	$fa->PrintAdminPendingOption($group_forum_id);
-		
+
 	echo '
 			<form action="'.getStringFromServer('PHP_SELF').'" method="post">
 				<p>
@@ -148,45 +147,32 @@ if (getStringFromRequest('add_forum')) {
 				<input type="hidden" name="change_status" value="y" />
 				<input type="hidden" name="group_forum_id" value="'. $f->getID() .'" />
 				<input type="hidden" name="group_id" value="'.$group_id.'" />
-				
-				<strong>'._('Allow Anonymous Posts?').'</strong><br />
-				<input type="radio" name="allow_anonymous" value="1"'.(($f->AllowAnonymous() == 1)?' checked="checked"':'').' /> '._('Yes').'<br />
-				<input type="radio" name="allow_anonymous" value="0"'.(($f->AllowAnonymous() == 0)?' checked="checked"':'').'/> '._('No').'
-				</p>
-				<p>
-				<strong>'._('Is Public?').'</strong><br />
-				<input type="radio" name="is_public" value="1"'.(($f->isPublic() == 1)?' checked="checked"':'').' /> '._('Yes').'<br />
-				<input type="radio" name="is_public" value="0"'.(($f->isPublic() == 0)?' checked="checked"':'').' /> '._('No').'<br />
-				<input type="radio" name="is_public" value="9"'.(($f->isPublic() == 9)?' checked="checked"':'').' />'._('Suspended').'<br />
-				<p>' .
-		html_build_select_box_from_assoc(array("0" => _('No Moderation') ,"1" => _('Moderated Level 1'),"2" => _('Moderated Level 2') ),"moderation_level",$f->getModerationLevel()) . '
-				<br />' . _('Moderated Level 1') . ': ' . _('To moderate anonymous posts (if allowed in public forum) and posts from non-member users.') . '<br />' . _('Moderated Level 2') . ': ' . _('To moderate ALL posts.') . '<p>
-				
-
-				<strong>'._('Forum Name').':</strong><br />
-				<input type="text" name="forum_name" value="'. $f->getName() .'" size="20" maxlength="30" />
+				<strong>'._('Forum Name')._(':').utils_requiredField().'</strong><br />
+				<input type="text" name="forum_name" required="required" value="'. $f->getName() .'" size="20" maxlength="30" pattern=".{3,}" />
 				</p>
 				<p>
 				<strong>'._('Email All Posts To:').'</strong><br />
-				<input type="text" name="send_all_posts_to" value="'. $f->getSendAllPostsTo() .'" size="60" />
+				<input type="email" name="send_all_posts_to" value="'. $f->getSendAllPostsTo() .'" size="60" />
 				</p>
 				<p>
-				<strong>'._('Description').':</strong><br />
-				<input type="text" name="description" value="'. $f->getDescription() .'" size="60" maxlength="80" /><br />
+				<strong>'._('Description')._(': ').utils_requiredField().'</strong><br />
+				<input type="text" name="description" required="required" value="'. $f->getDescription() .'" size="60" maxlength="80" pattern=".{10,}" /><br />
 				</p>
 				<p>
 				<input type="submit" name="submit" value="'._('Update').'" />
 				</p>
-			</form><p>';
+			</form>
+			<p>';
 	//echo '<a href="'.getStringFromServer('PHP_SELF').'?group_id='.$group_id.'&amp;group_forum_id='.$group_forum_id.'&amp;delete=1">'._('Delete Message').'</a><br />';
 	echo '<a href="'.getStringFromServer('PHP_SELF').'?group_id='.$group_id.'&amp;group_forum_id='.$group_forum_id.'&amp;deleteforum=1">'._('Delete entire forum and all content').'</a></p>';
+	echo '<span>'.sprintf(_('%s Mandatory fields'), utils_requiredField()).'</span>';
 	forum_footer(array());
 
 } elseif ($deleteforum && $group_forum_id) {
 
 	$f = new Forum ($g,$group_forum_id);
 
-	forum_header(array('title'=>_('Delete')));
+	forum_header(array('title'=>_('Permanently Delete Forum')));
 	echo '<p>
 			<strong>'._('You are about to permanently and irretrievably delete this entire forum and all its contents!').'</strong><br />
 			</p>
@@ -195,15 +181,15 @@ if (getStringFromRequest('add_forum')) {
 			<input type="hidden" name="deleteforum" value="y" />
 			<input type="hidden" name="group_id" value="'.$group_id.'" />
 			<input type="hidden" name="group_forum_id" value="'.$group_forum_id.'" />
-			<input type="checkbox" name="sure" value="1" />'._('I\'m Sure').'<br />
-			<input type="checkbox" name="really_sure" value="1" />'._('I\'m Really Sure').'<br />
+			<input type="checkbox" name="sure" value="1" />'._('I am Sure').'<br />
+			<input type="checkbox" name="really_sure" value="1" />'._('I am Really Sure').'<br />
 			<input type="submit" name="submit" value="'._('Delete').'" />
 			</form>';
 	forum_footer(array());
 
 } elseif ( getStringFromRequest("deletemsg") ) {
 	// delete message handling
-		
+
 	$forum_id = getIntFromRequest("forum_id");
 	$thread_id = getIntFromRequest("thread_id");
 	$msg_id = getIntFromRequest("deletemsg");
@@ -222,9 +208,9 @@ if (getStringFromRequest('add_forum')) {
 		// the user cancelled the request, go back to forum
 		//if thread_id is 0, then we came from message.php. else, we came from forum.php
 		if (!$thread_id) {
-            session_redirect('/forum/message.php?msg_id='.$msg_id);
+			session_redirect('/forum/message.php?msg_id='.$msg_id);
 		} else {
-            session_redirect('/forum/forum.php?thread_id='.$thread_id.'&forum_id='.$forum_id);
+			session_redirect('/forum/forum.php?thread_id='.$thread_id.'&forum_id='.$forum_id);
 		}
 		exit;
 	} else {
@@ -232,10 +218,10 @@ if (getStringFromRequest('add_forum')) {
 		forum_header(array('title'=>_('Delete a Message')));
 		echo '<center>
 							<form action="'.getStringFromServer('PHP_SELF').'" method="post">
-							<h3>' . _('WARNING! You are about to permanently delete a message and all of its followups!!') . '</h3>
+							<h3>' . _('WARNING! You are about to permanently delete a message and all of its comments!!') . '</h3>
 							<p>
 							<input type="submit" name="ok" value="' . _('Yes') . '" />
-							<input type="submit" name="cancel" value="' . _('No') . '" />    
+							<input type="submit" name="cancel" value="' . _('No') . '" />
 							<input type="hidden" name="deletemsg" value="'.$msg_id.'" />
 							<input type="hidden" name="group_id" value="'.$group_id.'" />
 							<input type="hidden" name="forum_id" value="'.$forum_id.'" />
@@ -258,11 +244,11 @@ if (getStringFromRequest('add_forum')) {
 		//actually finish editing the message and save the contents
 		$f = new Forum ($fa->GetGroupObject(),$forum_id);
 		if (!$f || !is_object($f)) {
-			exit_error(_('Error Getting Forum'),'forums');
+			exit_error(_('Error getting Forum'),'forums');
 		} elseif ($f->isError()) {
 			exit_error($f->getErrorMessage(),'forums');
 		}
-		$fm=new ForumMessage($f,$msg_id,false,false);
+		$fm=new ForumMessage($f, $msg_id, array(), false);
 		if (!$fm || !is_object($fm)) {
 			exit_error(_('Error getting new forum message'),'forums');
 		} elseif ($fm->isError()) {
@@ -270,10 +256,10 @@ if (getStringFromRequest('add_forum')) {
 		}
 		$subject = getStringFromRequest('subject');
 		$body = getStringFromRequest('body');
-			
+
 		$sanitizer = new TextSanitizer();
 		$body = $sanitizer->SanitizeHtml($body);
-			
+
 		$is_followup_to = getStringFromRequest('is_followup_to');
 		$form_key = getStringFromRequest('form_key');
 		$posted_by = getStringFromRequest('posted_by');
@@ -284,7 +270,7 @@ if (getStringFromRequest('add_forum')) {
 		if ($fm->updatemsg($forum_id,$posted_by,$subject,$body,$post_date,$is_followup_to,$thread_id,$has_followups,$most_recent_date)) {
 			$feedback .= _('Message Edited Successfully');
 		} else {
-			$error_msg .= $fm->getErrorMessage();
+			session_redirect('/forum/admin/index.php?editmsg='.$msg_id.'&group_id='.$group_id.'&thread_id='.$thread_id.'&forum_id='.$forum_id.'&error_msg='.urlencode($fm->getErrorMessage()));
 		}
 		forum_header(array('title'=>_('Edit a Message')));
 		echo '<p>'.util_make_link ('/forum/forum.php?forum_id=' . $forum_id, _("Return to the forum")) ;
@@ -292,30 +278,30 @@ if (getStringFromRequest('add_forum')) {
 	} elseif (getStringFromRequest("cancel")) {
 		// the user cancelled the request, go back to forum
 		session_redirect('/forum/message.php?msg_id='.$msg_id);
-	} else { 
+	} else {
 		//print the edit message confirmation
-			
+
 		$f = new Forum ($fa->GetGroupObject(),$forum_id);
 		if (!$f || !is_object($f)) {
-			exit_error(_('Error Getting Forum'),'forums');
+			exit_error(_('Error getting Forum'),'forums');
 		} elseif ($f->isError()) {
 			exit_error($f->getErrorMessage(),'forums');
 		}
-			
-		$fm=new ForumMessage($f,$msg_id,false,false);
+
+		$fm = new ForumMessage($f, $msg_id, array(), false);
 		if (!$fm || !is_object($fm)) {
 			exit_error(_('Error Getting ForumMessage'),'forums');
 		} elseif ($fm->isError()) {
 			exit_error($fm->getErrorMessage(),'forums');
 		}
-			
+
 		$fh = new ForumHTML($f);
 		if (!$fh || !is_object($fh)) {
 			exit_error(_('Error Getting ForumHTML'),'forums');
 		} elseif ($fh->isError()) {
 			exit_error($fh->getErrorMessage(),'forums');
 		}
-			
+
 		forum_header(array('title'=>_('Edit a Message')));
 		$fh->showEditForm($fm);
 		forum_footer(array());
@@ -361,8 +347,8 @@ if (getStringFromRequest('add_forum')) {
 		}
 
 		forum_header(array('title'=>_('Edit a Message')));
-		echo '<p><a href="/forum/forum.php?forum_id=' . $new_forum_id . '">Return to the forum</a></p>';
-		echo '<p><a href="/forum/forum.php?thread_id='.$thread_id.'&amp;forum_id=' . $new_forum_id . '">Return to the thread</a></p>';
+		echo '<p><a href="/forum/forum.php?forum_id=' . $new_forum_id . '">'._('Return to the forum').'</a></p>';
+		echo '<p><a href="/forum/forum.php?thread_id='.$thread_id.'&amp;forum_id=' . $new_forum_id . '">'._('Return to the thread').'</a></p>';
 		forum_footer(array());
 	} elseif (getStringFromRequest("cancel")) {
 		// the user cancelled the request, go back to forum
@@ -372,11 +358,11 @@ if (getStringFromRequest('add_forum')) {
 			session_redirect('/forum/forum.php?thread_id='.$thread_id.'&forum_id='.$forum_id);
 		}
 		exit;
-	} else { 
+	} else {
 		// Display select box to select new forum
 
-					forum_header(array('title'=>_('Move Thread')));
-					
+		forum_header(array('title'=>_('Move Thread')));
+
 		$ff = new ForumFactory($g);
 		if (!$ff || !is_object($ff) || $ff->isError()) {
 			exit_error($ff->getErrorMessage(),'forums');
@@ -385,7 +371,7 @@ if (getStringFromRequest('add_forum')) {
 		$farr = $ff->getForums();
 
 		if ($ff->isError()) {
-			echo '<p class="error">'.sprintf(_('No Forums Found For %s'), $g->getPublicName())
+			echo '<p class="error">'.sprintf(_('No Forums Found for %s'), $g->getPublicName())
                  . $ff->getErrorMessage().'</p>';
 			forum_footer(array());
 			exit;
@@ -405,14 +391,14 @@ if (getStringFromRequest('add_forum')) {
 				$forums[$farr[$j]->getID()] = $farr[$j]->getName();
 			}
 		}
-					
+
 		$f_from = new Forum ($fa->GetGroupObject(),$forum_id);
 		if (!$f_from || !is_object($f_from)) {
 			exit_error(_('Could Not Get Forum Object'),'forums');
 		} elseif ($f_from->isError()) {
 			exit_error($f_from->getErrorMessage(),'forums');
 		}
-					
+
 		echo '<center>
 							<form action="'.getStringFromServer('PHP_SELF').'" method="post">
 							<p><strong>' . sprintf(_('Move thread from %s forum to the following forum:'), $f_from->getName()) . '</strong></p>
@@ -423,9 +409,9 @@ if (getStringFromRequest('add_forum')) {
 							<input type="hidden" name="msg_id" value="'.$msg_id.'" />
 							<input type="hidden" name="return_to_message" value="'.$return_to_message.'" />' .
 			html_build_select_box_from_assoc($forums,'new_forum_id',$forum_id) .
-			'<br /><br />
+			'<br />
 							<input type="submit" name="ok" value="' . _("Submit") . '" />
-							<input type="submit" name="cancel" value="' . _("Cancel") . '" />    
+							<input type="submit" name="cancel" value="' . _("Cancel") . '" />
 							</p>
 							</form>
 							</center>';
@@ -438,7 +424,7 @@ if (getStringFromRequest('add_forum')) {
 	  Show main page for choosing
 	  either moderator or delete
 	*/
-		forum_header(array('title'=>_('Forums Administration')));
+	forum_header(array('title'=>_('Forums Administration')));
 
 	//
 	//	Add new forum
@@ -461,7 +447,7 @@ if (getStringFromRequest('add_forum')) {
 	$farr = $ff->getForumsAdmin();
 
 	if ($ff->isError()) {
-		echo '<p class="error">'.sprintf(_('No Forums Found For %s'), $g->getPublicName())
+		echo '<p class="error">'.sprintf(_('No Forums Found for %s'), $g->getPublicName())
 			. $ff->getErrorMessage().'</p>';
 		forum_footer(array());
 		exit;
@@ -490,5 +476,3 @@ if (getStringFromRequest('add_forum')) {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
