@@ -4,8 +4,9 @@
  *
  * Copyright 1999-2001, Tim Perdue - Sourceforge
  * Copyright 2002, Tim Perdue - GForge, LLC
- * Copyright 2010 (c) Franck Villaume - Capgemini
- * Copyright (C) 2010-2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2010-2011, Franck Villaume - Capgemini
+ * Copyright (C) 2010-2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013, French Ministry of National Education
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -24,37 +25,37 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'forum/ForumHTML.class.php';
 require_once $gfcommon.'forum/Forum.class.php';
 require_once $gfcommon.'forum/ForumFactory.class.php';
 require_once $gfcommon.'forum/ForumMessageFactory.class.php';
 require_once $gfcommon.'forum/ForumMessage.class.php';
-require_once $gfcommon.'forum/AttachManager.class.php'; //attachent manager
+require_once $gfcommon.'forum/AttachManager.class.php'; //attachment manager
 require_once $gfcommon.'include/TextSanitizer.class.php'; // to make the HTML input by the user safe to store
 
+$group_id = getIntFromRequest('group_id');
 $forum_id = getIntFromRequest('forum_id');
 $style = getStringFromRequest('style');
 $thread_id = getIntFromRequest('thread_id');
 $offset = getIntFromRequest('offset');
 $max_rows = getIntFromRequest('max_rows');
 $set = getStringFromRequest('set');
-$feedback = htmlspecialchars(getStringFromRequest('feedback'));
 
 if ($forum_id) {
 
-	/*
-		Get the group_id based on this forum_id
-	*/
-	$result=db_query_params ('SELECT group_id
-		FROM forum_group_list
-		WHERE group_forum_id=$1',
-			array($forum_id));
-	if (!$result || db_numrows($result) < 1) {
-		exit_error(_('Error forum not found: ').db_error(),'forums');
+	if (!$group_id) {
+		// Get the group_id based on this forum_id
+		$result=db_query_params ('SELECT group_id
+			FROM forum_group_list
+			WHERE group_forum_id=$1',
+				array($forum_id));
+		if (!$result || db_numrows($result) < 1) {
+			exit_error(_('Error forum not found: ').db_error(),'forums');
+		}
+		$group_id=db_result($result,0,'group_id');
 	}
-	$group_id=db_result($result,0,'group_id');
 
 	//
 	//	Set up local objects
@@ -64,11 +65,11 @@ if ($forum_id) {
 		exit_no_group();
 	}
 
-	$f=new Forum($g,$forum_id);
+	$f=new Forum($g, $forum_id);
 	if (!$f || !is_object($f)) {
-		exit_error(_('Error getting new Forum'),'forums');
+		exit_error(_('Error getting new Forum'), 'forums');
 	} elseif ($f->isError()) {
-		exit_error($f->getErrorMessage(),'forums');
+		exit_error($f->getErrorMessage(), 'forums');
 	}
 
 	/*
@@ -82,13 +83,13 @@ if ($forum_id) {
 		$body = getStringFromRequest('body');
 		$is_followup_to = getStringFromRequest('is_followup_to');
 
-		$fm=new ForumMessage($f);
+		$fm = new ForumMessage($f);
 		if (!$fm || !is_object($fm)) {
 			form_release_key(getStringFromRequest("form_key"));
-			exit_error(_('Error getting new ForumMessage'),'forums');
+			exit_error(_('Error getting new ForumMessage'), 'forums');
 		} elseif ($fm->isError()) {
 			form_release_key(getStringFromRequest("form_key"));
-			exit_error(_('Error getting new ForumMessage:'.' '.$fm->getErrorMessage()),'forums');
+			exit_error(_('Error getting new ForumMessage'._(': ').$fm->getErrorMessage()), 'forums');
 		}
 
 		if (getStringFromRequest('_body_content_type') == 'html') {
@@ -106,16 +107,16 @@ if ($forum_id) {
 
 		if (!$fm->create($subject, $body, $thread_id, $is_followup_to,$has_attach) || $fm->isError()) {
 			form_release_key(getStringFromRequest("form_key"));
-			exit_error(_('Error creating ForumMessage:').' '.$fm->getErrorMessage(),'forums');
+			session_redirect('/forum/new.php?forum_id='.$forum_id.'&group_id='.$group_id.'&error_msg='.urlencode($fm->getErrorMessage()));
 		} else {
 			if ($fm->isPending() ) {
-				$feedback=_('Message Queued for moderation -> Please wait until the admin approves/rejects it');
+				$feedback = _('Message Queued for moderation -> Please wait until the admin approves/rejects it');
 			} else {
-				$feedback=_('Message Posted Successfully');
+				$feedback = _('Message Posted Successfully');
 			}
-			$am = NEW AttachManager();//object that will handle and insert the attachment into the db
+			$am = new AttachManager();//object that will handle and insert the attachment into the db
 			$am->SetForumMsg($fm);
-			$am->attach($attach,$group_id,0,$fm->getID());
+			$am->attach($attach, $group_id, 0, $fm->getID());
 			foreach ($am->Getmessages() as $item) {
 				$feedback .= "<br />" . $item;
 			}
@@ -127,18 +128,17 @@ if ($forum_id) {
 		}
 	}
 
-
 	$fmf = new ForumMessageFactory($f);
 	if (!$fmf || !is_object($fmf)) {
 		form_release_key(getStringFromRequest("form_key"));
-		exit_error(_('Error getting new ForumMessageFactory'),'forums');
+		exit_error(_('Error getting new ForumMessageFactory'), 'forums');
 	} elseif ($fmf->isError()) {
 		form_release_key(getStringFromRequest("form_key"));
-		exit_error($fmf->getErrorMessage(),'forums');
+		exit_error($fmf->getErrorMessage(), 'forums');
 	}
 
 //echo "<br /> style: $style|max_rows: $max_rows|offset: $offset+";
-	$fmf->setUp($offset,$style,$max_rows,$set);
+	$fmf->setUp($offset, $style, $max_rows, $set);
 
 	$style=$fmf->getStyle();
 	$max_rows=$fmf->max_rows;
@@ -148,12 +148,12 @@ if ($forum_id) {
 
 	$fh = new ForumHTML($f);
 	if (!$fh || !is_object($fh)) {
-		exit_error(_('Error getting new ForumHTML'),'forums');
+		exit_error(_('Error getting new ForumHTML'), 'forums');
 	} elseif ($fh->isError()) {
-		exit_error($fh->getErrorMessage(),'forums');
+		exit_error($fh->getErrorMessage(), 'forums');
 	}
 
-	forum_header(array('title'=>_('Forum: ') . $f->getName(),'forum_id'=>$forum_id));
+	forum_header(array('title'=>_('Forum') . _(': ') . $f->getName(), 'forum_id'=>$forum_id));
 
 /**
  *
@@ -166,14 +166,6 @@ if ($forum_id) {
  *
  */
 
-	//create a pop-up select box listing the forums for this project
-	//determine if this person can see private forums or not
-	if (session_loggedin() && user_ismember($group_id)) {
-		$public_flag='0,1';
-	} else {
-		$public_flag='1';
-	}
-
 	//create a pop-up select box showing options for viewing threads
 
 	$vals=array('nested','flat','threaded','ultimate');
@@ -190,16 +182,17 @@ if ($forum_id) {
 	//now show the popup boxes in a form
 	$ret_val = '
 	<form action="'. getStringFromServer('PHP_SELF') .'" method="get">
-	<table border="0" width="33%">
+	<table>
 		<tr><td>
-	<input type="hidden" name="set" value="custom" />
-	<input type="hidden" name="forum_id" value="'.$forum_id.'" />
+			<input type="hidden" name="set" value="custom" />
+			<input type="hidden" name="forum_id" value="'.$forum_id.'" />
 			'. $options_popup .
 			'</td><td>'. $max_row_popup .
 			'</td><td><input type="submit" name="submit" value="'.
 			_('Change View').'" />
 		</td></tr>
-	</table></form>';
+	</table>
+	</form>';
 
 	$am = new AttachManager();
 	$ret_val .= $am->PrintHelperFunctions();
@@ -208,9 +201,9 @@ if ($forum_id) {
 		$msg_arr =& $fmf->nestArray($fmf->getNested());
 
 		if ($fmf->isError()) {
-			echo '<div class="error">'.$fmf->getErrorMessage().'</div>';
-	        forum_footer(array());
-            exit;
+			echo '<p class="error">'.$fmf->getErrorMessage().'</p>';
+			forum_footer(array());
+			exit;
 		}
 
 		$rows=count($msg_arr["0"]);
@@ -239,13 +232,13 @@ if ($forum_id) {
 			$i++;
 		}
 
-	} else if ($style=='threaded') {
+	} elseif ($style=='threaded') {
 
 		$msg_arr =& $fmf->nestArray($fmf->getThreaded());
 		if ($fmf->isError()) {
-			echo '<div class="error">'.$fmf->getErrorMessage().'</div>';
-	        forum_footer(array());
-            exit;
+			echo '<p class="error">'.$fmf->getErrorMessage().'</p>';
+			forum_footer(array());
+			exit;
 		}
 
 		$title_arr=array();
@@ -286,7 +279,7 @@ if ($forum_id) {
 			*/
 			$ret_val .= $bold_begin.$msg->getSubject() .$bold_end.'</a></td>'.
 				'<td>'.util_display_user($msg->getPosterName(), $msg->getPosterID(), $msg->getPosterRealName()).'</td>'.
-				'<td>'. date(_('Y-m-d H:i'),$msg->getPostDate()) .'</td></tr>';
+				'<td>'.relative_date($msg->getPostDate()).'</td></tr>';
 
 			if ($msg->hasFollowups()) {
 				$ret_val .= $fh->showSubmessages($msg_arr,$msg->getID(),1);
@@ -296,13 +289,13 @@ if ($forum_id) {
 
 		$ret_val .= $GLOBALS['HTML']->listTableBottom();
 
-	} else if (($style=='flat' && $thread_id) || ($style=='ultimate' && $thread_id)) {
+	} elseif (($style=='flat' && $thread_id) || ($style=='ultimate' && $thread_id)) {
 
 		$msg_arr =& $fmf->getFlat($thread_id);
 		if ($fmf->isError()) {
-			echo '<div class="error">'.$fmf->getErrorMessage().'</div>';
-	        forum_footer(array());
-            exit;
+			echo '<p class="error">'.$fmf->getErrorMessage().'</p>';
+			forum_footer(array());
+			exit;
 		}
 		$avail_rows=$fmf->fetched_rows;
 
@@ -338,14 +331,14 @@ ORDER BY f.most_recent_date DESC',
 			$title_arr[]=_('Topic Starter');
 			$title_arr[]=_('Replies');
 			$title_arr[]=_('Last Post');
-	
+
 			$ret_val .= $GLOBALS['HTML']->listTableTop ($title_arr);
 			$i=0;
 			while (($row=db_fetch_array($result)) && ($i < $max_rows)) {
 				$ret_val .= '
 					<tr '. $GLOBALS['HTML']->boxGetAltRowStyle($i) .'><td><a href="'.util_make_uri('/forum/forum.php?thread_id='.
 															$row['thread_id'].'&amp;forum_id='.$forum_id.'&amp;group_id='.$group_id).'">'.
-					html_image('ic/cfolder15.png') . '  &nbsp; ';
+					html_image('ic/cfolder15.png') . ' ';
 				/*
 						See if this message is new or not
 						If so, highlite it in bold
@@ -363,7 +356,7 @@ ORDER BY f.most_recent_date DESC',
 				$ret_val .= $bold_begin.$row['subject'] .$bold_end.'</a></td>'.
 				'<td>'.util_display_user($row['user_name'], $row['user_id'], $row['realname']).'</td>'.
 					'<td>'. $row['followups'] .'</td>'.
-					'<td>'.date(_('Y-m-d H:i'),$row['recent']).'</td></tr>';
+					'<td>'. relative_date($row['recent']).'</td></tr>';
 				$i++;
 			}
 
@@ -376,17 +369,17 @@ ORDER BY f.most_recent_date DESC',
 		This code puts the nice next/prev.
 	*/
 	if (($offset != 0) or ($avail_rows > $max_rows)) {
-		$ret_val .= '<table width="100%" border="0">
-			<tr class="tablecontent"><td width="50%">';
+		$ret_val .= '<table class="fullwidth">
+			<tr class="tablecontent"><td class="halfwidth">';
 		if ($offset != 0) {
 			$ret_val .= '<span class="prev">
 			<a href="javascript:history.back()"><strong>' .
 				html_image('t2.png',"15","15") ._('Newer Messages').'</strong></a></span>';
 		} else {
-			$ret_val .= '&nbsp;';
+			$ret_val .= ' ';
 		}
 
-		$ret_val .= '</td><td>&nbsp;</td><td align="right" width="50%">';
+		$ret_val .= '</td><td></td><td class="halfwidth align-right">';
 
 		if ($avail_rows > $max_rows) {
 			$ret_val .= '<span class="next">
@@ -395,23 +388,12 @@ ORDER BY f.most_recent_date DESC',
 			<strong> '._('Older Messages') .
 				html_image('t.png',"15","15") . '</strong></a></span>';
 		} else {
-			$ret_val .= '&nbsp;';
+			$ret_val .= ' ';
 		}
 		$ret_val .= '</td></tr></table>';
 	}
 
 	echo $ret_val;
-/*
-	echo '<p>&nbsp;<p>';
-
-	if (!$thread_id) {
-		//
-		//	Viewing an entire message forum in a given format
-		//
-		echo '<center><h3>'._('Start New Thread').'</h3></center>';
-		$fh->showPostForm();
-	}
-*/
 	forum_footer(array());
 
 } else {
@@ -419,5 +401,3 @@ ORDER BY f.most_recent_date DESC',
 	exit_error(_('No forum chosen'),'forums');
 
 }
-
-?>
