@@ -5,7 +5,8 @@
  * Copyright 1999-2001, Tim Perdue - Sourceforge
  * Copyright 2002, Tim Perdue - GForge, LLC
  * Copyright 2010 (c) Franck Villaume - Capgemini
- * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright (C) 2011-2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013,2014 Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -23,7 +24,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'forum/ForumHTML.class.php';
 require_once $gfcommon.'forum/ForumFactory.class.php';
@@ -36,7 +37,7 @@ if ($group_id) {
 		exit_no_group();
 	}
 
-	$ff=new ForumFactory($g);
+	$ff = new ForumFactory($g);
 	if (!$ff || !is_object($ff) || $ff->isError()) {
 		exit_error($ff->getErrorMessage(),'forums');
 	}
@@ -44,28 +45,30 @@ if ($group_id) {
 	$farr = $ff->getForums();
 
 	if ( $farr !== false && count($farr) == 1 ) {
-        session_redirect('/forum/forum.php?forum_id='.$farr[0]->getID());
+		session_redirect('/forum/forum.php?forum_id='.$farr[0]->getID());
 	}
 
-	forum_header(array('title'=>sprintf(_('Forums for %1$s'), $g->getPublicName()) ));
+	forum_header(array('title'=>sprintf(_('Forums for %s'), $g->getPublicName()) ));
 
 	if ($ff->isError()) {
-        echo '<div class="error">'. $ff->getErrorMessage().'</div>';
+		echo '<p class="error">'. $ff->getErrorMessage().'</p>';
 		forum_footer(array());
 		exit;
-    } else if ( count($farr) < 1) {
-		echo '<div class="warning_msg">'.sprintf(_('No Forums Found for %1$s'), $g->getPublicName()) .'</div>';
+	} elseif ( count($farr) < 1) {
+		echo '<p class="information">'.sprintf(_('No Forums Found for %s'), $g->getPublicName()) .'</p>';
 		forum_footer(array());
 		exit;
 	}
 
 //	echo _('<p>Choose a forum and you can browse, search, and post messages.<p>');
 
-	echo $HTML->printsubMenu(array(_("My Monitored Forums")),array("/forum/myforums.php?group_id=$group_id"));
+	if (session_loggedin()) {
+		echo $HTML->printsubMenu(array(_("My Monitored Forums")), array("/forum/myforums.php?group_id=$group_id"), false);
+	}
 
-	plugin_hook ("blocks", "forum index");
+	plugin_hook("blocks", "forum index");
 
-	$tablearr=array(_('Forum'),_('Description'),_('Threads'),_('Posts'), _('Last Post'),_('Moderation Level'));
+	$tablearr=array(_('Forum'),_('Description'),_('Threads'),_('Posts'), _('Last Post'));
 	echo $HTML->listTableTop($tablearr);
 
 	/*
@@ -78,21 +81,15 @@ if ($group_id) {
 		} elseif ($farr[$j]->isError()) {
 			echo $farr[$j]->getErrorMessage();
 		} else {
-			switch ($farr[$j]->getModerationLevel()) {
-				case 0 : $modlvl = _('No Moderation');break;
-				case 1 : $modlvl = _('Anonymous & Non Project Users');break;
-				case 2 : $modlvl = _('All Except Admins');break;
-			}
 			echo '<tr '. $HTML->boxGetAltRowStyle($j) . '><td>'.
 				'<a href="'.util_make_uri('/forum/forum.php?forum_id='.$farr[$j]->getID().'&amp;group_id='.$group_id).'">'.
 				html_image('ic/forum20w.png') .
-				'&nbsp;' .
+				' ' .
 				$farr[$j]->getName() .'</a></td>
 				<td>'.$farr[$j]->getDescription().'</td>
-				<td style="text-align:center">'.$farr[$j]->getThreadCount().'</td>
-				<td style="text-align:center">'. $farr[$j]->getMessageCount() .'</td>
-				<td>'.  date(_('Y-m-d H:i'),$farr[$j]->getMostRecentDate()) .'</td>
-				<td style="text-align:center">'. $modlvl  .'</td></tr>';
+				<td class="align-center">'.$farr[$j]->getThreadCount().'</td>
+				<td class="align-center">'. $farr[$j]->getMessageCount() .'</td>
+				<td>'.  date(_('Y-m-d H:i'),$farr[$j]->getMostRecentDate()) .'</td></tr>';
 		}
 	}
 	echo $HTML->listTableBottom();
@@ -104,5 +101,3 @@ if ($group_id) {
 	exit_no_group();
 
 }
-
-?>
