@@ -26,7 +26,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'forum/ForumHTML.class.php';
 require_once $gfcommon.'forum/Forum.class.php';
@@ -41,21 +41,21 @@ $group_id = getIntFromRequest("group_id");
 
 // If the link comes from the project, display the project header. If it comes from the user page, display the normal site header
 if ($group_id) {
-    forum_header(array('title'=>_('My Monitored Forums')));
+	forum_header(array('title'=>_('My Monitored Forums')));
 } else {
-    site_header(array('title'=>_('My Monitored Forums'), 'user_id' => $user_id));
+	site_header(array('title'=>_('My Monitored Forums'), 'user_id' => $user_id));
 }
 
 //get the user monitored forums
 $result = db_query_params ('SELECT mon.forum_id, fg.group_id FROM forum_monitored_forums mon,forum_group_list fg where mon.user_id=$1 and fg.group_forum_id=mon.forum_id',
 			   array ($user_id));
 if (!$result) {
-    echo '<div class="error">Database error :'.db_error().'</div>';
+    echo '<p class="error">Database error :'.db_error().'</p>';
     forum_footer(array());
     exit;
 }
 if ( db_numrows($result) < 1) {
-    echo '<div class="feedback">'._('You have no monitored forums').'</div>';
+    echo '<p class="information">'._('You have no monitored forums').'</p>';
     forum_footer(array());
     exit;
 }
@@ -86,22 +86,22 @@ for($i=0;$i<sizeof($monitored_forums);$i++) {
 	}
 	if (!is_object($f)) {
 		//just skip it - this object should never have been placed here
-	}	elseif ($f->isError()) {
+	} elseif ($f->isError()) {
 		echo $f->getErrorMessage();
-	}	else {
+	} else {
 		//check if the forum has new content
 
 		$fh = new ForumHTML($f);
 		if (!$fh || !is_object($fh)) {
 			exit_error(_('Error getting new ForumHTML'),'forums');
-		}	elseif ($fh->isError()) {
+		} elseif ($fh->isError()) {
 			exit_error($fh->getErrorMessage(),'forums');
 		}
 
 		$fmf = new ForumMessageFactory($f);
 		if (!$fmf || !is_object($fmf)) {
 			exit_error(_('Error getting new ForumMessageFactory'),'forums');
-		}	elseif ($fmf->isError()) {
+		} elseif ($fmf->isError()) {
 			exit_error($fmf->getErrorMessage(),'forums');
 		}
 
@@ -124,18 +124,18 @@ for($i=0;$i<sizeof($monitored_forums);$i++) {
 		//anything that's new ( new thread or followup) is considered to be a "new thing" and the forum
 		//is considered to have new contents
 		if (!empty($msg_arr)) {
-		foreach ($msg_arr as $forum_msg_arr) {
-			foreach ($forum_msg_arr as $forum_msg) {
-				if ($f->getSavedDate() < $forum_msg->getPostDate()) {
-				//we've got ourselves a new message or followup for this forum. note that, exit the search
+			foreach ($msg_arr as $forum_msg_arr) {
+				foreach ($forum_msg_arr as $forum_msg) {
+					if ($f->getSavedDate() < $forum_msg->getPostDate()) {
+						//we've got ourselves a new message or followup for this forum. note that, exit the search
 						$newcontent = "<center>" . html_image('ic/new.png','', '', array('alt' => 'new')) . "</center>";
-				break;
+						break;
+					}
+				}
+				if ($newcontent != '&nbsp;') {
+					break;
 				}
 			}
-				if ($newcontent != '&nbsp;') {
-				break;
-			}
-		}
 		}
 		/*while (($j < $rows) && ($total_rows < $max_rows)) {
 			$msg =& $msg_arr["0"][$j];
@@ -156,13 +156,12 @@ for($i=0;$i<sizeof($monitored_forums);$i++) {
 			html_image('ic/forum20w.png') .
 			'&nbsp;' .
 			$f->getName() .'</a></td>
-			<td style="text-align:center">'.$f->getThreadCount().'</td>
-			<td style="text-align:center">'. $f->getMessageCount() .'</td>
-			<td style="text-align:center">'. $date .'</td>
+			<td class="align-center">'.$f->getThreadCount().'</td>
+			<td class="align-center">'. $f->getMessageCount() .'</td>
+			<td class="align-center">'. $date .'</td>
 			<td>' . $newcontent . '</td></tr>';
 	}
 }
 
 echo $HTML->listTableBottom();
 forum_footer(array());
-?>
