@@ -22,7 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'forum/ForumHTML.class.php';
 require_once $gfcommon.'forum/Forum.class.php';
@@ -45,7 +45,7 @@ if ($forum_id && $group_id) {
 
 	$f=new Forum($g,$forum_id);
 	if (!$f || !is_object($f)) {
-		exit_error(_('Error Getting Forum'),'forums');
+		exit_error(_('Error getting Forum'),'forums');
 	} elseif ($f->isError()) {
 		exit_error($f->getErrorMessage(),'forums');
 	}
@@ -57,11 +57,11 @@ if ($forum_id && $group_id) {
 		exit_error($fh->getErrorMessage(),'forums');
 	}
 
-	if (session_loggedin() || $f->allowAnonymous()) {
-		if (!$f->allowAnonymous() && !$f->savePlace()) {
+	if (forge_check_perm('forum', $f->getID(), 'post')) {
+		if (session_loggedin() && !$f->savePlace()) {
 			exit_error($f->getErrorMessage(),'forums');
 		} else {
-			forum_header(array('title'=> _('Start New Thread for: ') . $f->getName(),'forum_id'=>$forum_id));
+			forum_header(array('title'=> _('Start New Topic for: ') . $f->getName(), 'forum_id'=>$forum_id, 'modal' => 1));
 			$fh->showPostForm();
 			forum_footer(array());
 		}
@@ -71,5 +71,3 @@ if ($forum_id && $group_id) {
 } else {
 	exit_missing_param('',array(_('Forum ID'),_('Project ID')),'forums');
 }
-
-?>
