@@ -23,9 +23,9 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
-require_once $gfwww.'frs/include/frs_utils.php';
+require_once $gfcommon.'frs/include/frs_utils.php';
 require_once $gfcommon.'frs/FRSPackage.class.php';
 
 $group_id = getIntFromRequest('group_id');
@@ -54,7 +54,8 @@ if (!$frsp || !is_object($frsp)) {
 	Relatively simple form to delete packages of releases
 */
 
-frs_admin_header(array('title'=>sprintf(_('Delete Package: %1$s'), $frsp->getName()),'group'=>$group_id));
+frs_admin_header(array('title'=>_('Delete Package')._(': ').$frsp->getName(),
+                       'group'=>$group_id));
 
 	echo '
 	<form action="/frs/admin/?group_id='.$group_id.'" method="post">
@@ -62,18 +63,16 @@ frs_admin_header(array('title'=>sprintf(_('Delete Package: %1$s'), $frsp->getNam
 	<input type="hidden" name="func" value="delete_package" />
 	<input type="hidden" name="package_id" value="'. $package_id .'" />
 	'._('You are about to permanently and irretrievably delete this package and all its releases and files!').'
-        </p> 
-        <p> 
-	<input type="checkbox" name="sure" value="1" />'._('I\'m Sure').'
-        </p> 
-        <p> 
-	<input type="checkbox" name="really_sure" value="1" />'._('I\'m Really Sure').'
+        </p>
+        <p>
+	<input type="checkbox" name="sure" value="1" />'._('I am Sure').'
+        </p>
+        <p>
+	<input type="checkbox" name="really_sure" value="1" />'._('I am Really Sure').'
         </p>
         <p>
 	<input type="submit" name="submit" value="'._('Delete').'" />
-        </p> 
+        </p>
 	</form>';
 
 frs_admin_footer();
-
-?>
