@@ -7,6 +7,7 @@
  * Copyright 2002-2004 (c) GForge Team
  * Copyright 2010-2011, Franck Villaume - Capgemini
  * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2012-2014, Franck Villaume - TrivialDev
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -25,9 +26,9 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
-require_once $gfwww.'frs/include/frs_utils.php';
+require_once $gfcommon.'frs/include/frs_utils.php';
 require_once $gfcommon.'frs/FRSPackage.class.php';
 require_once $gfcommon.'frs/FRSRelease.class.php';
 require_once $gfcommon.'frs/FRSFile.class.php';
@@ -61,7 +62,7 @@ if (getStringFromRequest('submit')) {
 	/*
 		make updates to the database
 	*/
-	if ($func=='add_package' && $package_name) {
+	if ($func == 'add_package' && $package_name) {
 
 		//create a new package
 		$frsp = new FRSPackage($project);
@@ -70,13 +71,13 @@ if (getStringFromRequest('submit')) {
 		} elseif ($frsp->isError()) {
 			exit_error($frsp->getErrorMessage(), 'frs');
 		}
-		if (!$frsp->create($package_name,$is_public)) {
+		if (!$frsp->create($package_name, $is_public)) {
 			exit_error($frsp->getErrorMessage(), 'frs');
 		} else {
 			$feedback .= _('Added Package');
 		}
 
-	} elseif ($func=='delete_package' && $package_id) {
+	} elseif ($func == 'delete_package' && $package_id) {
 
 		//delete a package
 		$frsp = new FRSPackage($project, $package_id);
@@ -94,14 +95,14 @@ if (getStringFromRequest('submit')) {
 			$feedback .= _('Deleted');
 		}
 
-	} else if ($func=='update_package' && $package_id && $package_name) {
+	} elseif ($func == 'update_package' && $package_id && $package_name) {
 		$frsp = new FRSPackage($project, $package_id);
 		if (!$frsp || !is_object($frsp)) {
 			exit_error(_('Could Not Get FRS Package'), 'frs');
 		} elseif ($frsp->isError()) {
 			exit_error($frsp->getErrorMessage(), 'frs');
 		}
-		if (!$frsp->update($package_name, $status_id)) {
+		if (!$frsp->update($package_name, $status_id, $is_public)) {
 			exit_error($frsp->getErrorMessage(), 'frs');
 		} else {
 			$feedback .= _('Updated Package');
@@ -109,16 +110,16 @@ if (getStringFromRequest('submit')) {
 	}
 }
 
-
 frs_admin_header(array('title'=>_('Release Edit/File Releases'), 'group'=>$group_id));
 
-$res=db_query_params('SELECT status_id,package_id,name AS package_name
+$res = db_query_params('SELECT status_id, package_id, name AS package_name, is_public
 			FROM frs_package WHERE group_id=$1',
 			array($group_id));
-$rows=db_numrows($res);
+$rows = db_numrows($res);
 if ($res && $rows > 0) {
 	echo '<h2>'._('QRS').'</h2>';
-	printf(_('Click here to %1$s quick-release a file %2$s'), '<a href="qrs.php?group_id=' . $group_id . '">', '</a>').'<br />';
+	printf(_('Click here to %1$s quick-release a file %2$s'), '<a href="qrs.php?group_id=' . $group_id . '">', '</a>');
+	echo '<br />';
 }
 ?>
 
@@ -147,34 +148,36 @@ if ($res && $rows > 0) {
 */
 
 if (!$res || $rows < 1) {
-	echo '<div class="warning">'._('You Have No Packages Defined').'</div>';
+	echo '<p class="information">'._('There are no packages defined.').'</p>';
 } else {
 	$title_arr = array();
 	$title_arr[] = _('Releases');
 	$title_arr[] = _('Package name');
 	$title_arr[] = _('Status');
+	$title_arr[] = _('Publicly Viewable');
 
-	echo $GLOBALS['HTML']->listTableTop($title_arr);
-
-	for ($i=0; $i<$rows; $i++) {
-		echo '
+	echo '
 		<form action="'. getStringFromServer('PHP_SELF') .'" method="post">
 		<input type="hidden" name="group_id" value="'.$group_id.'" />
-		<input type="hidden" name="func" value="update_package" />
-		<input type="hidden" name="package_id" value="'. db_result($res,$i,'package_id') .'" />
-		<tr '. $GLOBALS['HTML']->boxGetAltRowStyle($i) .'>
+		<input type="hidden" name="func" value="update_package" />';
+	echo $GLOBALS['HTML']->listTableTop($title_arr);
+
+	for ($i = 0; $i < $rows; $i++) {
+		echo '<tr '. $GLOBALS['HTML']->boxGetAltRowStyle($i) .'>
 			<td style="white-space: nowrap;" align="center">
 					<a href="qrs.php?package_id='.
-						db_result($res,$i,'package_id') .'&amp;group_id='. $group_id .'"><strong>['._('Add Release').']</strong>
-					</a>
-
-					<a href="showreleases.php?package_id='.
-						db_result($res,$i,'package_id') .'&amp;group_id='. $group_id .'"><strong>['._('Edit Releases').']</strong>
-					</a>
-
-			</td>
-			<td><input type="text" name="package_name" value="'.db_result($res,$i,'package_name') .'" size="20" maxlength="60" /></td>
-			<td>'.frs_show_status_popup ('status_id', db_result($res,$i,'status_id')).'</td>
+						db_result($res, $i, 'package_id') .'&amp;group_id='. $group_id .'"><strong>['._('Add Release').']</strong>
+					</a>';
+		$packageObject = frspackage_get_object(db_result($res, $i, 'package_id'));
+		if (count($packageObject->getReleases())) {
+			echo '		<a href="showreleases.php?package_id='.
+						db_result($res, $i, 'package_id') .'&amp;group_id='. $group_id .'"><strong>['._('Edit Releases').']</strong>
+					</a>';
+		}
+		echo '	</td>
+			<td><input type="hidden" name="package_id" value="'. db_result($res, $i, 'package_id') .'" /><input type="text" name="package_name" value="'.db_result($res, $i, 'package_name') .'" size="20" maxlength="60" required="required" pattern=".{3,}" title="'. _('At least 3 characters') .'" /></td>
+			<td>'.frs_show_status_popup('status_id', db_result($res, $i, 'status_id')).'</td>
+			<td>'.frs_show_public_popup('is_public', db_result($res, $i, 'is_public')).'</td>
 			<td><input type="submit" name="submit" value="'._('Update').'" />
 
 					<a href="deletepackage.php?package_id='.
@@ -182,11 +185,11 @@ if (!$res || $rows < 1) {
 					</a>
 
 			</td>
-			</tr></form>';
+			</tr>';
 	}
 
 	echo $GLOBALS['HTML']->listTableBottom();
-
+	echo '</form>';
 }
 
 /*
@@ -200,9 +203,9 @@ if (!$res || $rows < 1) {
 <form action="<?php echo getStringFromServer('PHP_SELF'); ?>" method="post">
 <input type="hidden" name="group_id" value="<?php echo $group_id; ?>" />
 <input type="hidden" name="func" value="add_package" />
-<p><strong><?php echo _('New Package Name') ?>:</strong>
-<input type="text" name="package_name" value="" size="20" maxlength="30" /></p>
-<p><strong><?php echo _('Publicly Viewable'); ?>:</strong>
+<p><strong><?php echo _('New Package Name')._(':'); ?></strong>
+<input type="text" name="package_name" value="" size="20" maxlength="30" required="required" pattern=".{3,}" title="<?php echo _('At least 3 characters') ?>" /></p>
+<p><strong><?php echo _('Publicly Viewable')._(':'); ?></strong>
 <input type="radio" name="is_public" value="1" checked="checked" /> <?php echo _('Public'); ?>
 <input type="radio" name="is_public" value="0" /> <?php echo _('Private'); ?></p>
 <p><input type="submit" name="submit" value="<?php echo _('Create This Package') ?>" /></p>
@@ -217,5 +220,3 @@ frs_admin_footer();
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
