@@ -23,13 +23,13 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-/* Updated rewrite of the File Release System to clean up the UI 
+/* Updated rewrite of the File Release System to clean up the UI
  * a little and incorporate FRS.class.php.		-Darrell
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
-require_once $gfwww.'frs/include/frs_utils.php';
+require_once $gfcommon.'frs/include/frs_utils.php';
 require_once $gfcommon.'frs/FRSPackage.class.php';
 require_once $gfcommon.'frs/FRSRelease.class.php';
 require_once $gfcommon.'frs/FRSFile.class.php';
@@ -85,7 +85,7 @@ if ($func=='delete_release' && $release_id) {
 /*
 	Get the releases of this package
 */
-$rs =& $frsp->getReleases();
+$rs = $frsp->getReleases();
 if (count($rs) < 1) {
 	exit_error(_('No Releases Of This Package Are Available'),'frs');
 }
@@ -97,17 +97,17 @@ frs_admin_header(array('title'=>_('Release New File Version'),'group'=>$group_id
 
 $title_arr=array();
 $title_arr[]=_('Package name');
-$title_arr[]=_('Release name');
+$title_arr[]=_('Release Name');
 $title_arr[]=_('Date');
 
-echo $GLOBALS['HTML']->listTableTop ($title_arr);
+echo $GLOBALS['HTML']->listTableTop($title_arr);
 
 for ($i=0; $i<count($rs); $i++) {
 	echo '<tr '. $HTML->boxGetAltRowStyle($i) .'>
 			<td>'.$frsp->getName().'</td>
 			<td><a href="editrelease.php?group_id='.$group_id
 				.'&amp;package_id='.$package_id
-				.'&amp;release_id='.$rs[$i]->getID().'">'. 
+				.'&amp;release_id='.$rs[$i]->getID().'">'.
 				$rs[$i]->getName().' ['._('Edit').']</a>
 				<a href="deleterelease.php?group_id='.$group_id
 				.'&amp;package_id='.$package_id
@@ -123,5 +123,3 @@ frs_admin_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
