@@ -23,18 +23,17 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'frs/FRSPackage.class.php';
-require_once $gfwww.'frs/include/frs_utils.php';
-
+require_once $gfcommon.'frs/include/frs_utils.php';
 
 if (session_loggedin()) {
 	$group_id = getIntFromRequest('group_id');
 	$filemodule_id = getIntFromRequest('filemodule_id');
 	$start = getIntFromRequest('start');
 	$stop = getIntFromRequest('stop');
-	
+
 	if ($group_id && $filemodule_id) {
 		//
 		//  Set up local objects
@@ -55,16 +54,16 @@ if (session_loggedin()) {
 			if (!$f->stopMonitor()) {
 				exit_error($f->getErrorMessage(),'frs');
 			} else {
-                $feedback = _('Monitoring Has Been Stopped');
-				frs_header(array('title'=>_('Monitoring stopped'),'group'=>$group_id));
+                $feedback = _('Monitoring Stopped');
+				frs_header(array('title'=>_('Monitoring Stopped'),'group'=>$group_id));
 				frs_footer();
 			}
 		} elseif($start) {
 			if (!$f->setMonitor()) {
 				exit_error($f->getErrorMessage(),'frs');
 			} else {
-                $feedback = _('Monitoring Has Been Started');
-				frs_header(array('title'=>_('Monitoring started'),'group'=>$group_id));
+                $feedback = _('Monitoring Started');
+				frs_header(array('title'=>_('Monitoring Started'),'group'=>$group_id));
 				frs_footer();
 			}
 		}
@@ -74,5 +73,3 @@ if (session_loggedin()) {
 } else {
 	exit_not_logged_in();
 }
-
-?>
