@@ -3,6 +3,7 @@
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2012, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -21,7 +22,6 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
 // Attempt to set up the include path, to fix problems with relative includes
 
 require_once $gfcommon.'include/FusionForge.class.php';
@@ -30,17 +30,19 @@ require_once $gfcommon.'include/Stats.class.php';
 
 function show_features_boxes() {
 	global $HTML;
-	
+
 	plugin_hook ("features_boxes_top", array());
 	$return = '<h2 class="skip">' . _('Features Boxes') . '</h2>';
 
 	if (forge_get_config('use_project_tags')) {
-		$return .= $HTML->boxTop(_('Tag Cloud'), 'Tag_Cloud');
-		$return .= tag_cloud();
-		$return .= $HTML->boxMiddle(sprintf(_('%1$s Statistics'), forge_get_config ('forge_name')), 'Forge_Statistics');
-	} else {
-		$return .= $HTML->boxTop(sprintf(_('%1$s Statistics'), forge_get_config ('forge_name')), 'Forge_Statistics');
+		$contentTag = tag_cloud();
+		if (!empty($contentTag)) {
+			$return .= $HTML->boxTop(_('Tag Cloud'), 'Tag_Cloud');
+			$return .= $contentTag;
+			$return .= $HTML->boxBottom();
+		}
 	}
+	$return .= $HTML->boxTop(sprintf(_('%s Statistics'), forge_get_config ('forge_name')), 'Forge_Statistics');
 	$return .= show_sitestats();
 	if (forge_get_config('use_frs')) {
 		$return .= $HTML->boxMiddle(_('Top Project Downloads'), 'Top_Projects_Downloads');
@@ -56,7 +58,7 @@ function show_features_boxes() {
 	$return .= show_newest_projects();
 	$return .= $HTML->boxMiddle(_('System Information'), 'System_Information');
 	$ff = new FusionForge();
-	$return .= sprintf(_('%s is running %s version %s'), 
+	$return .= sprintf(_('%s is running %s version %s'),
 			   forge_get_config ('forge_name'),
 			   $ff->software_name,
 			   $ff->software_version);
@@ -70,9 +72,6 @@ function show_top_downloads() {
 	//      to allow download list to be cached before nightly
 	//      aggregation is done. jbyers 2001.03.19
 	//
-	$month = date("Ym",time()-(2*3600*24));
-	$day = date("d",time()-(2*3600*24));
-
 	$return = '' ;
 
 	$res_topdown = db_query_params ('
@@ -96,7 +95,7 @@ function show_top_downloads() {
 		if ($row_topdown['downloads'] > 0) {
 			$t_downloads = number_format($row_topdown['downloads']);
 			$t_prj_link = util_make_link_g ($row_topdown['unix_group_name'], $row_topdown['group_id'], $row_topdown['group_name']);
-		
+
 			$return .= '<tr>';
 			$return .= '<td class="width-stat-col1">' . $t_downloads . '</td>';
 			$return .= '<td>' . $t_prj_link . '</td>';
@@ -105,17 +104,15 @@ function show_top_downloads() {
 		}
 	}
 	if ( $return == "" ) {
-		return _('No Stats Available');
+		return _('No stats available');
 	} else {
-		$t_return = $return;
-		$return = '<table summary="">' . $t_return . "</table>\n"; 
+		$return = '<table>' . $return . "</table>\n";
 	}
 	$return .= '<div class="align-center">' . util_make_link ('/top/', _('All the ranking'), array('class' => 'dot-link')) . '</div>';
-	
+
 	return $return;
 }
 
-
 function stats_getprojects_active_public() {
 	$ff = new FusionForge();
 	return $ff->getNumberOfPublicHostedProjects();
@@ -152,16 +149,17 @@ function show_sitestats() {
 
 	$gforge = new FusionForge();
 	$return = '<p>';
-	$return .= _('Hosted Projects').': ';
-	if (forge_get_config('use_trove')) {
+	$return .= _('Hosted Projects')._(': ');
+	if (forge_get_config('use_project_full_list')) {
 		$return .= '<a href="softwaremap/full_list.php">';
 	}
 	$return .= '<strong>'.number_format($gforge->getNumberOfPublicHostedProjects()).'</strong>';
-	if (forge_get_config('use_trove')) {
+	if (forge_get_config('use_project_full_list')) {
 		$return .= '</a>';
 	}
 	$return .= "</p><p>";
-	$return .= _('Registered Users').': <strong>'.number_format($gforge->getNumberOfActiveUsers()).'</strong>';
+	$return .= _('Registered Users')._(': ').'<strong>'.
+		number_format($gforge->getNumberOfActiveUsers()).'</strong>';
 	$return .= "</p>\n";
 	return $return;
 }
@@ -176,76 +174,80 @@ function show_newest_projects() {
 		if (!forge_check_perm ('project_read', $row_newproj['group_id'])) {
 			continue ;
 		}
-		
+
 		$count++ ;
 		$t_prj_date = date(_('m/d'),$row_newproj['register_time']);
 		$t_prj_link = util_make_link_g ($row_newproj['unix_group_name'],$row_newproj['group_id'],$row_newproj['group_name']);
-		
+
 		$return .= "<tr>";
 		$return .= '<td class="width-stat-col1">' . $t_prj_date . "</td>";
 		$return .= '<td>' . $t_prj_link . '</td>';
 		$return .= "</tr>\n";
 	}
-	
+
 	if ( $return == "" ) {
-		return _('No Stats Available');
+		return _('No stats available');
 	} else {
-		$t_return = $return;
-		$return = '<table summary="">' . $t_return . "</table>\n"; 
+		$return = '<table>' . $return . "</table>\n";
+	}
+
+	if (forge_get_config('use_project_full_list')) {
+		$return .= '<div class="align-center">'.util_make_link ('/softwaremap/full_list.php', _('All newest projects'), array('class' => 'dot-link')).'</div>';
 	}
-	
-	$return .= '<div class="align-center">'.util_make_link ('/softwaremap/full_list.php', _('All newest projects'), array('class' => 'dot-link')).'</div>';
 	return $return;
 }
 
 function show_highest_ranked_users() {
 	//select out the users information to show the top users on the site
-	$res = db_query_params ('SELECT users.user_name,users.user_id,users.realname,user_metric.metric	FROM user_metric,users WHERE users.user_id=user_metric.user_id AND user_metric.ranking < 11 AND users.status != $1 ORDER BY ranking ASC',
-				array ('D')) ;
-	$rows=db_numrows($res);
-	if (!$res || $rows<1) {
-		return  _('No Stats Available').db_error();
+	$res = db_query_params('SELECT users.user_name,users.user_id,users.realname,user_metric.metric	FROM user_metric,users WHERE users.user_id=user_metric.user_id AND user_metric.ranking < 11 AND users.status != $1 ORDER BY ranking ASC',
+				array ('D'));
+	if (!$res) {
+		return db_error();
 	} else {
-		$return = '';
-		for ($i=0; $i<$rows; $i++) {
-			$return .= ($i+1).' - ('. number_format(db_result($res,$i,'metric'),4) .') '
-			. util_make_link_u (db_result($res,$i,'user_name'),db_result($res,$i,'user_id'),db_result($res,$i,'realname'))
-			.'<br />';
+		$rows = db_numrows($res);
+		if ($rows < 1) {
+			return  _('No stats available');
+		} else {
+			$return = '';
+			for ($i=0; $i < $rows; $i++) {
+				$return .= ($i+1).' - ('. number_format(db_result($res,$i,'metric'),4) .') '
+				. util_make_link_u (db_result($res, $i, 'user_name'), db_result($res, $i, 'user_id'),db_result($res,$i,'realname'))
+				.'<br />';
+			}
 		}
+		$return .= '<div class="align-center">'.util_make_link('/top/topusers.php', _('All Users'), array('class' => 'dot-link')).'</div>';
+		return $return;
 	}
-	$return .= '<div class="align-center">'.util_make_link ('/top/topusers.php', _('All users'), array('class' => 'dot-link')).'</div>';
-	return $return;
 }
 
 function show_highest_ranked_projects() {
-	$statsobj = new Stats () ;
-	$result = $statsobj->getMostActiveStats ('week', 0) ;
+	$stats = new Stats();
+	$result = $stats->getMostActiveStats ('week', 0) ;
 	$return = '' ;
 
-	$count = 0 ;
-	while (($row=db_fetch_array($result)) && ($count < 20)) {
+	$count = 1 ;
+	while (($row=db_fetch_array($result)) && ($count <= 20)) {
 		if (!forge_check_perm ('project_read', $row['group_id'])) {
 			continue ;
 		}
-		$t_prj_activity = number_format(substr($row['ranking'],0,5),0);
+
 		$t_prj_link = util_make_link_g ($row['unix_group_name'],$row['group_id'],$row['group_name']);
-		
+
 		$return .= "<tr>";
-		$return .= '<td class="width-stat-col1">'. $t_prj_activity . "</td>";
+		$return .= '<td class="width-stat-col1">'. $count . "</td>";
 		$return .= '<td>' . $t_prj_link . '</td>';
 		$return .= "</tr>\n";
-		
+
 		$count++ ;
 	}
 	if ( $return == "" ) {
-		return _('No Stats Available');
+		return _('No stats available');
 	} else {
-		$t_return = $return;
-		$return = '<table summary="">' . $t_return . "</table>\n"; 
+		$return = '<table>' . $return . "</table>\n";
 	}
-	
+
 	$return .= '<div class="align-center">' . util_make_link ('/top/mostactive.php?type=week', _('All project activities'), array('class' => 'dot-link')) . '</div>';
-		
+
 	return $return;
 }
 
@@ -253,5 +255,3 @@ function show_highest_ranked_projects() {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
