@@ -1,10 +1,11 @@
-<?php 
+<?php
 /**
  * FusionForge Project Home
  *
- * Copyright 1999-2001 (c) VA Linux Systems 
+ * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2010, FusionForge Team
- * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright (C) 2011-2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -34,14 +35,8 @@ session_require_perm ('project_read', $group_id) ;
 
 $title = _('Project Home');
 
-use_javascript('/scripts/prototype/prototype.js');
-use_javascript('/scripts/scriptaculous/scriptaculous.js');
-use_javascript('/scripts/codendi/Tooltip.js');
-use_javascript('/scripts/codendi/LayoutManager.js');
-use_javascript('/scripts/codendi/ReorderColumns.js');
-
 $request =& HTTPRequest::instance();
-$request->set('group_id',$group_id);
+$request->set('group_id', $group_id);
 
 $params['submenu'] = '';
 
@@ -52,13 +47,14 @@ if (session_loggedin()) {
 	} elseif ($group->isError()) {
 		exit_error($group->getErrorMessage(), 'home');
 	}
-	
-	$perm =& $group->getPermission( session_get_user() );
+
+	// Display with the preferred layout/theme of the user (if logged-in)
+	$perm =& $group->getPermission();
 	if ($perm && is_object($perm) && $perm->isAdmin()) {
-		$sql = "SELECT l.* 
-				FROM layouts AS l INNER JOIN owner_layouts AS o ON(l.id = o.layout_id) 
-				WHERE o.owner_type = $1 
-				AND o.owner_id = $2 
+		$sql = "SELECT l.*
+				FROM layouts AS l INNER JOIN owner_layouts AS o ON(l.id = o.layout_id)
+				WHERE o.owner_type = $1
+				AND o.owner_id = $2
 				AND o.is_default = 1
 				";
 		$res = db_query_params($sql,array('g', $group_id));
@@ -70,15 +66,21 @@ if (session_loggedin()) {
 		$id = db_result($res, 0 , 'id');
 		$params['submenu'] = $HTML->subMenu(
 			array(_("Add widgets"),
-				_("Customize layout")),
+				_("Customize Layout")),
 			array('/widgets/widgets.php?owner=g'. $group_id .'&amp;layout_id='. $id,
-				'/widgets/widgets.php?owner=g'. $group_id .'&amp;layout_id='. $id.'&amp;update=layout'));
+				'/widgets/widgets.php?owner=g'. $group_id .'&amp;layout_id='. $id.'&amp;update=layout'),
+			array(array('class' => 'tabtitle-nw', 'title' => _('Select new widgets to display on the project home page.')),
+				array('class' => 'tabtitle', 'title' => _('Modify the layout: one column, multiple columns or build your own layout.'))));
 	}
 }
 
+html_use_jqueryui();
 site_project_header(array('title'=>$title, 'h1' => '', 'group'=>$group_id, 'toptab' => 'home',
 	'submenu' => $params['submenu']));
 
+$params = array('group_id' => $group_id);
+plugin_hook('project_before_widgets', $params);
+
 $lm = new WidgetLayoutManager();
 $lm->displayLayout($group_id, WidgetLayoutManager::OWNER_TYPE_GROUP);
 
@@ -88,5 +90,3 @@ site_project_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
