@@ -2,8 +2,9 @@
 /**
  * Project Summary
  *
- * Copyright 1999-2001 (c) VA Linux Systems 
+ * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2010, FusionForge Team
+ * Copyright 2014, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -27,7 +28,7 @@ $project_agg_arr=array();
 /**
  * project_setup_agg() - Set up a project aggregate array.
  *
- * @param		int		Project ID
+ * @param		int		$group_id	Project ID
  * @access		private
  */
 function project_setup_agg($group_id) {
@@ -38,7 +39,7 @@ function project_setup_agg($group_id) {
 	if ($res && $rows > 0) {
 		for ($i=0; $i<$rows; $i++) {
 			$project_agg_arr[db_result($res,$i,'type')]=db_result($res,$i,'count');
-		}	
+		}
 	}
 	$project_agg_arr_is_set=true;
 }
@@ -46,11 +47,12 @@ function project_setup_agg($group_id) {
 /**
  * project_getaggvalue() - Get a projects aggregate value for a specific type
  *
- * @param		int		The group ID
- * @param		string	The type
+ * @param		int		$group_id	The group ID
+ * @param		string	$type		The type
+ * @return		string
  * @access		private
  */
-function project_getaggvalue($group_id,$type) {
+function project_getaggvalue($group_id, $type) {
 	global $project_agg_arr,$project_agg_arr_is_set;
 	if (!$project_agg_arr_is_set) {
 		project_setup_agg($group_id);
@@ -66,49 +68,34 @@ function project_getaggvalue($group_id,$type) {
 /**
  * project_get_mail_list_count() - Get the number of mailing lists for a project.
  *
- * @param		int		The group ID
+ * @param	int $group_id The group ID
+ * @return	string
  */
 function project_get_mail_list_count($group_id) {
-	return project_getaggvalue($group_id,'mail'); 
+	return project_getaggvalue($group_id,'mail');
 }
 
 /**
  * project_get_survey_count() - Get the number of surveys for a project.
  *
- * @param		int		The group ID
+ * @param	int $group_id The group ID
+ * @return	string
  */
 function project_get_survey_count($group_id) {
-	return project_getaggvalue($group_id,'surv'); 
-}	   
-
-/**
- * project_get_public_forum_count() - Get the number of public forums for a project.
- *
- * @param		int		The group ID
- */
-function project_get_public_forum_count($group_id) {
-	return project_getaggvalue($group_id, 'fora');
-}
-
-/**
- * project_get_public_forum_message_count() - Get the number of messages within public forums for a project.
- *
- * @param		int		The group ID
- */
-function project_get_public_forum_message_count($group_id) {
-	return project_getaggvalue($group_id, 'fmsg');
+	return project_getaggvalue($group_id,'surv');
 }
 
 /**
  * project_summary() - Build a project summary box that projects can insert into their project pages
  *
- * @param		int		The group ID
- * @param		string	How to return the results.
- * @param		bool	Whether to return the results within an HTML table or not
+ * @param	int		$group_id	The group ID
+ * @param	string	$mode		How to return the results.
+ * @param	bool	$no_table	Whether to return the results within an HTML table or not
+ * @return	string
  */
-function project_summary($group_id,$mode,$no_table) {
+function project_summary($group_id, $mode, $no_table) {
 	if (!$group_id) {
-		return 'Error - No Project ID';
+		return 'Error: No Project ID';
 	}
 	if (!$mode) {
 		$mode='full';
@@ -125,35 +112,37 @@ function project_summary($group_id,$mode,$no_table) {
 	if (!$no_table) {
 		$return = '
 
-		<table border=0 width="100%"><tr><td class="tablecontent">';
+		<table border="0" width="100%"><tr><td class="tablecontent">';
 	}
 
 	// ################## ArtifactTypes
 
-	$return .= '<a href="'.util_make_url ('/tracker/?group_id='.$group_id).'">';
-	$return .= html_image("ic/tracker20g.png",'20','20',array('alt'=>'Tracker'));
-	$return .= ' Tracker</a>';
+	if ($project->usesTracker()) {
+		$return .= '<a href="'.util_make_url ('/tracker/?group_id='.$group_id).'">';
+		$return .= html_image("ic/tracker20g.png",'20','20',array('alt'=>'Tracker'));
+		$return .= ' Tracker</a>';
 
-	if ($mode != 'compact') {
-		$result=db_query_params ('SELECT agl.*,aca.count,aca.open_count
-		FROM artifact_group_list agl
-		LEFT JOIN artifact_counts_agg aca USING (group_artifact_id) 
-		WHERE agl.group_id=$1
-		AND agl.is_public=1
-		ORDER BY group_artifact_id ASC',
-			array($group_id));
+		if ($mode != 'compact') {
+			$result=db_query_params ('SELECT agl.*,aca.count,aca.open_count
+			FROM artifact_group_list agl
+			LEFT JOIN artifact_counts_agg aca USING (group_artifact_id)
+			WHERE agl.group_id=$1
+			AND agl.is_public=1
+			ORDER BY group_artifact_id ASC',
+				array($group_id));
 
-		$rows = db_numrows($result);
-	
-		if (!$result || $rows < 1) {
-			$return .= '<br /><em>'._('There are no public trackers available').'</em>';
-		} else {
-			for ($j = 0; $j < $rows; $j++) {
-				$return .= '<p>
-				&nbsp;-&nbsp;'.util_make_link ('/tracker/?atid='. db_result($result, $j, 'group_artifact_id') . '&amp;group_id='.$group_id.'&amp;func=browse',db_result($result, $j, 'name'));
-				$return .= sprintf(ngettext('(<strong>%1$s</strong> open / <strong>%2$s</strong> total)', '(<strong>%1$s</strong> open / <strong>%2$s</strong> total)', (int) db_result($result, $j, 'open_count')), (int) db_result($result, $j, 'open_count'), (int) db_result($result, $j, 'count')) ;
-				$return .= '</p>';
-			}   
+			$rows = db_numrows($result);
+
+			if (!$result || $rows < 1) {
+				$return .= '<br /><em>'._('There are no public trackers available').'</em>';
+			} else {
+				for ($j = 0; $j < $rows; $j++) {
+					$return .= '<p>
+					&nbsp;-&nbsp;'.util_make_link ('/tracker/?atid='. db_result($result, $j, 'group_artifact_id') . '&amp;group_id='.$group_id.'&amp;func=browse',db_result($result, $j, 'name'));
+					$return .= sprintf(ngettext('(<strong>%1$s</strong> open / <strong>%2$s</strong> total)', '(<strong>%1$s</strong> open / <strong>%2$s</strong> total)', (int) db_result($result, $j, 'open_count')), (int) db_result($result, $j, 'open_count'), (int) db_result($result, $j, 'count')) ;
+					$return .= '</p>';
+				}
+			}
 		}
 	}
 
@@ -162,14 +151,24 @@ function project_summary($group_id,$mode,$no_table) {
 	if ($project->usesForum()) {
 		$return .= '
 
-			<hr size="1" />';
+			<hr />';
 		$return .= '<a href="'.util_make_url ('/forum/?group_id='.$group_id).'">';
 		$return .= html_image("ic/forum20g.png","20","20",array("alt"=>"Forums"));
 		$return .= '&nbsp;Forums</a>';
 
+		$ff = new ForumFactory($project);
+		$f_arr = $ff->getForums();
+		$forums_count = count($f_arr);
+		$messages_count = 0;
+		foreach ($f_arr as $f) {
+			$messages_count += $f->getMessageCount();
+		}
+
 		if ($mode != 'compact') {
-			$return .= " ( <strong>". project_get_public_forum_message_count($group_id) ."</strong> messages in ";
-			$return .= "<strong>". project_get_public_forum_count($group_id) ."</strong> forums )\n";
+			$return .= sprintf(ngettext("<strong>%d</strong> message","<strong>%d</strong> messages",$messages_count),$messages_count);
+			$return .= ' in ';
+			$return .= sprintf(ngettext("<strong>%d</strong> forum","<strong>%d</strong> forums",$forums_count),$forums_count);
+			$return .= "\n";
 		}
 	}
 
@@ -178,7 +177,7 @@ function project_summary($group_id,$mode,$no_table) {
 	if ($project->usesDocman()) {
 		$return .= '
 
-			<hr size="1" />';
+			<hr />';
 		$return .= '<a href="'.util_make_url ('/docman/?group_id='.$group_id).'">';
 		$return .= html_image("ic/docman16b.png","20","20",array("alt"=>"Docs"));
 		$return .= '&nbsp;Doc&nbsp;Manager</a>';
@@ -189,7 +188,7 @@ function project_summary($group_id,$mode,$no_table) {
 	if ($project->usesMail()) {
 		$return .= '
 
-			<hr size="1" />';
+			<hr />';
 		$return .= '<a href="'.util_make_url ('/mail/?group_id='.$group_id).'">';
 		$return .= html_image("ic/mail16b.png","20","20",array("alt"=>"Mail Lists"));
 		$return .= '&nbsp;Mailing&nbsp;Lists</a>';
@@ -204,7 +203,7 @@ function project_summary($group_id,$mode,$no_table) {
 	if ($project->usesPm()) {
 		$return .= '
 
-			<hr size="1" />';
+			<hr />';
 		$return .= '<a href="'.util_make_url ('/pm/?group_id='.$group_id).'">';
 		$return .= html_image("ic/taskman20g.png","20","20",array("alt"=>"Tasks"));
 		$return .= '&nbsp;Task&nbsp;Manager</a>';
@@ -226,12 +225,12 @@ function project_summary($group_id,$mode,$no_table) {
 		}
 	}
 
-	// ######################### Surveys 
+	// ######################### Surveys
 
 	if ($project->usesSurvey()) {
 		$return .= '
 
-			<hr size="1" />';
+			<hr />';
 		$return .= '<a href="'.util_make_url ('/survey/?group_id='.$group_id).'">';
 		$return .= html_image("ic/survey16b.png","20","20",array("alt"=>"Surveys"));
 		$return .= "&nbsp;Surveys</a>";
@@ -240,12 +239,12 @@ function project_summary($group_id,$mode,$no_table) {
 		}
 	}
 
-	// ######################### SCM 
+	// ######################### SCM
 
 	if ($project->usesSCM()) {
 		$return .= '
 
-			<hr size="1" />';
+			<hr />';
 		$return .= '<a href="'.util_make_url ('/scm/?group_id='.$group_id).'">';
 		$return .= html_image("ic/cvs16b.png","20","20",array("alt"=>"SCM"));
 		$return .= "&nbsp;SCM&nbsp;Tree</a>";
@@ -258,11 +257,11 @@ function project_summary($group_id,$mode,$no_table) {
 	}
 
 	// ######################## Released Files
-	
-	if ($project->isActive()) {
+
+	if ($project->usesFRS()) {
 		$return .= '
 
-			<hr size="1" />';
+			<hr />';
 		$return .= '<a href="'.util_make_url ('/project/showfiles.php?group_id='.$group_id).'">';
 		$return .= html_image("ic/ftp16b.png","20","20",array("alt"=>"FTP"));
 		$return .= "&nbsp;Released&nbsp;Files</a>";
@@ -281,5 +280,3 @@ function project_summary($group_id,$mode,$no_table) {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
