@@ -33,25 +33,25 @@ $TROVE_HARDQUERYLIMIT = -1;
 /**
  * trove_genfullpaths() - Regenerates full path entries for $node and all subnodes
  *
- * @param		int		The node
- * @param		string	The full path for this node
- * @param		int		The full path IDs
+ * @param	int	$mynode		The node
+ * @param	string	$myfullpath	The full path for this node
+ * @param	int	$myfullpathids	The full path IDs
  */
-function trove_genfullpaths($mynode,$myfullpath,$myfullpathids) {
+function trove_genfullpaths($mynode, $myfullpath, $myfullpathids) {
 	// first generate own path
-	$res_update = db_query_params ('UPDATE trove_cat SET fullpath=$1,fullpath_ids=$2 WHERE trove_cat_id=$3',
-				       array ($myfullpath,
-					      $myfullpathids,
-					      $mynode));
+	db_query_params('UPDATE trove_cat SET fullpath=$1,fullpath_ids=$2 WHERE trove_cat_id=$3',
+						array ($myfullpath,
+								$myfullpathids,
+								$mynode));
 	// now generate paths for all children by recursive call
 	if($mynode!=0)
 	{
-		$res_child = db_query_params ('
+		$res_child = db_query_params('
 			SELECT trove_cat_id,fullname
 			FROM trove_cat
 			WHERE parent=$1
 			AND trove_cat_id != 0',
-					      array ($mynode));
+						  array ($mynode));
 
 		while ($row_child = db_fetch_array($res_child)) {
 			trove_genfullpaths($row_child['trove_cat_id'],
@@ -66,25 +66,25 @@ function trove_genfullpaths($mynode,$myfullpath,$myfullpathids) {
 /**
  * trove_updaterootparent() - Regenerates full path entries for $node and all subnodes
  *
- * @param		int		The node
- * @param		int		The root parent node
+ * @param	int	$mynode		The node
+ * @param	int	$rootnode	The root parent node
  */
-function trove_updaterootparent($mynode,$rootnode) {
+function trove_updaterootparent($mynode, $rootnode) {
 	// first generate own path
-	if($mynode!=$rootnode) $res_update = db_query_params ('UPDATE trove_cat SET root_parent=$1 WHERE trove_cat_id=$2',
-							      array ($rootnode,
-								     $mynode));
-	else $res_update = db_query_params ('UPDATE trove_cat SET root_parent=0 WHERE trove_cat_id=$1',
-					    array ($mynode));
+	if($mynode!=$rootnode) db_query_params('UPDATE trove_cat SET root_parent=$1 WHERE trove_cat_id=$2',
+								array ($rootnode,
+										$mynode));
+	else db_query_params('UPDATE trove_cat SET root_parent=0 WHERE trove_cat_id=$1',
+						array ($mynode));
 	// now generate paths for all children by recursive call
 	if($mynode!=0)
 	{
-		$res_child = db_query_params ('
+		$res_child = db_query_params('
 			SELECT trove_cat_id
 			FROM trove_cat
 			WHERE parent=$1
 			AND trove_cat_id!=0',
-					      array ($mynode));
+							array($mynode));
 
 		while ($row_child = db_fetch_array($res_child)) {
 			trove_updaterootparent($row_child['trove_cat_id'],$rootnode);
@@ -97,16 +97,17 @@ function trove_updaterootparent($mynode,$rootnode) {
 /**
  * trove_setnode() - Adds a group to a trove node
  *
- * @param		int		The group ID
- * @param		int		The trove category ID
- * @param		int		The root node
+ * @param	int	$group_id	The group ID
+ * @param	int	$trove_cat_id	The trove category ID
+ * @param	int	$rootnode	The root node
+ * @return	int
  */
-function trove_setnode($group_id,$trove_cat_id,$rootnode=0) {
+function trove_setnode($group_id, $trove_cat_id, $rootnode=0) {
 	// verify we were passed information
 	if ((!$group_id) || (!$trove_cat_id)) return 1;
 
 	// verify trove category exists
-	$res_verifycat = db_query_params ('
+	$res_verifycat = db_query_params('
 		SELECT trove_cat_id,fullpath_ids
 		FROM trove_cat
 		WHERE trove_cat_id=$1',
@@ -121,7 +122,7 @@ function trove_setnode($group_id,$trove_cat_id,$rootnode=0) {
 	}
 
 	// must first make sure that this is not a subnode of anything current
-	$res_topnodes = db_query_params ('
+	$res_topnodes = db_query_params('
 		SELECT trove_cat.trove_cat_id AS trove_cat_id,
 			trove_cat.fullpath_ids AS fullpath_ids
 		FROM trove_cat,trove_group_link
@@ -144,7 +145,7 @@ function trove_setnode($group_id,$trove_cat_id,$rootnode=0) {
 	// need to see if this one is more specific than another
 	// if so, delete the other and proceed with this insertion
 	$subnodeids = explode(' :: ',$row_verifycat['fullpath_ids']);
-	$res_checksubs = db_query_params ('
+	$res_checksubs = db_query_params('
 		SELECT trove_cat_id
 		FROM trove_group_link
 		WHERE group_id=$1
@@ -157,7 +158,7 @@ function trove_setnode($group_id,$trove_cat_id,$rootnode=0) {
 		for ($i=0;$i<count($subnodeids);$i++) {
 			if ($subnodeids[$i] == $row_checksubs['trove_cat_id']) {
 				// then delete subnode
-				db_query_params ('DELETE FROM trove_group_link WHERE group_id=$1 AND trove_cat_id=$2',
+				db_query_params('DELETE FROM trove_group_link WHERE group_id=$1 AND trove_cat_id=$2',
 						 array ($group_id,
 							$subnodeids[$i]));
 			}
@@ -165,7 +166,7 @@ function trove_setnode($group_id,$trove_cat_id,$rootnode=0) {
 	}
 
 	// if we got this far, must be ok
-	db_query_params ('INSERT INTO trove_group_link (trove_cat_id,trove_cat_version,group_id,trove_cat_root) VALUES ($1,$2,$3,$4)',
+	db_query_params('INSERT INTO trove_group_link (trove_cat_id,trove_cat_version,group_id,trove_cat_root) VALUES ($1,$2,$3,$4)',
 			 array ($trove_cat_id,
 				time(),
 				$group_id,
@@ -176,18 +177,19 @@ function trove_setnode($group_id,$trove_cat_id,$rootnode=0) {
 /**
  * trove_getrootcat() - Get the root categegory
  *
- * @param		int		Trove category ID
+ * @param	int $trove_cat_id Trove category ID
+ * @return	int
  */
 function trove_getrootcat($trove_cat_id) {
 	$parent = 1;
 	$current_cat = $trove_cat_id;
 
 	while ($parent > 0) {
-		$res_par = db_query_params ('
+		$res_par = db_query_params('
 			SELECT parent
 			FROM trove_cat
 			WHERE trove_cat_id=$1',
-					    array($current_cat));
+						array($current_cat));
 
 		$row_par = db_fetch_array($res_par);
 		$parent = $row_par["parent"];
@@ -202,7 +204,7 @@ function trove_getrootcat($trove_cat_id) {
  * trove_getallroots() - Returns an associative array of all project roots
  */
 function trove_getallroots() {
-	$res = db_query_params ('
+	$res = db_query_params('
 		SELECT trove_cat_id,fullname
 		FROM trove_cat
 		WHERE parent=0
@@ -219,18 +221,19 @@ function trove_getallroots() {
 /**
  * trove_catselectfull() - Returns full select output for a particular root
  *
- * @param		int		The node
- * @param		string	The category to pre-select
- * @param		string	THe select-box name
+ * @param	int	$node		The node
+ * @param	string	$selected	The category to pre-select
+ * @param	string	$name		The select-box name
+ * @param	string	$title
  */
-function trove_catselectfull($node,$selected,$name, $title='') {
+function trove_catselectfull($node, $selected, $name, $title='') {
 	print '<br /><select class="trove-nodes" name="'.$name.'" title="'.util_html_secure($title).'">';
 	print '  <option value="0">'._('None Selected')."</option>\n";
-	$res_cat = db_query_params ('
-		SELECT trove_cat_id,fullpath
-		FROM trove_cat
-		WHERE root_parent=$1
-		ORDER BY fullpath',
+	$res_cat = db_query_params('
+			SELECT trove_cat_id,fullpath
+			FROM trove_cat
+			WHERE root_parent=$1
+			ORDER BY fullpath',
 			array($node));
 
 	while ($row_cat = db_fetch_array($res_cat)) {
@@ -244,17 +247,18 @@ function trove_catselectfull($node,$selected,$name, $title='') {
 /**
  * trove_getcatlisting() - Gets discriminator listing for a group
  *
- * @param		int		The group ID
- * @param		bool	Whether filters have already been applied
- * @param		bool	Whether to print category links
- * @param		bool	???
+ * @param	int	$group_id	The group ID
+ * @param	bool	$a_filter	Whether filters have already been applied
+ * @param	bool	$a_cats		Whether to print category links
+ * @param	int	$a_complete
+ * @return	string
  */
-function trove_getcatlisting($group_id,$a_filter,$a_cats,$a_complete=0) {
+function trove_getcatlisting($group_id, $a_filter, $a_cats, $a_complete=0) {
 	global $discrim_url;
 	global $expl_discrim;
 	global $form_cat;
 
-	$res_trovecat = db_query_params ('
+	$res_trovecat = db_query_params('
 		SELECT trove_cat.fullpath AS fullpath,
 			trove_cat.fullpath_ids AS fullpath_ids,
 			trove_cat.trove_cat_id AS trove_cat_id
@@ -272,11 +276,11 @@ function trove_getcatlisting($group_id,$a_filter,$a_cats,$a_complete=0) {
 			.'<p />';
 	} else {
 		$return .= '<ul>';
-		$need_close_ul_tag = 1;
+		$need_close_ul_tag = true;
 	}
 
 	// first initialise the vars we're using here
-	$proj_discrim_used=array();
+	$proj_discrim_used = array();
 	$isfirstdiscrim = 1;
 	while ($row_trovecat = db_fetch_array($res_trovecat)) {
 		$folders = explode(" :: ",$row_trovecat['fullpath']);
@@ -288,8 +292,8 @@ function trove_getcatlisting($group_id,$a_filter,$a_cats,$a_complete=0) {
 				$return .= "</li>\n";
 			}
 			$return .= '<li>';
-			if ($a_complete==0) {
-				$return .= $folders[0].' : ';
+			if ($a_complete == 0) {
+				$return .= $folders[0];
 			}
 		}
 
@@ -302,14 +306,18 @@ function trove_getcatlisting($group_id,$a_filter,$a_cats,$a_complete=0) {
 			}
 		}
 		// then print the stuff
-		if (array_key_exists($folders_ids[0], $proj_discrim_used)) {
-			$return .= '</li><li>';
+		if (! $a_complete == 0) {
+			if (array_key_exists($folders_ids[0], $proj_discrim_used)) {
+				$return .= '</li><li>';
+			}
+		} else {
+			$return .= ' : ';
 		}
 
 		if ($a_complete) {
 			for ($i=0;$i<$folders_len;$i++) {
 				if ($a_cats) {
-					$return .= '<a href="'.util_make_url ('/softwaremap/trove_list.php?form_cat='.$folders_ids[$i].$discrim_url).'">';
+					$return .= '<a href="'.util_make_url ('/softwaremap/trove_list.php?cat=c&form_cat='.$folders_ids[$i].$discrim_url).'">';
 				}
 				$return .= ($folders[$i]);
 				if ($a_cats) {
@@ -321,22 +329,19 @@ function trove_getcatlisting($group_id,$a_filter,$a_cats,$a_complete=0) {
 			}
 		} else {
 			if ($a_cats) {
-				$return .= '<a href="'.util_make_url ('/softwaremap/trove_list.php?form_cat='.$folders_ids[$folders_len-1].$discrim_url).'">';
+				$return .= '<a href="'.util_make_url ('/softwaremap/trove_list.php?cat=c&form_cat='.$folders_ids[$folders_len-1].$discrim_url).'">';
 			}
 			$return .= ($folders[$folders_len-1]);
 			if ($a_cats) {
 				$return .= '</a>';
 			}
-			if ($i!=$folders_len-1) {
-				$return .= " : ";
-			}
 		}
 
 		if ($a_filter) {
 			if ($filterisalreadyapplied) {
 				$return .= ' <strong>'._('(Now Filtering)').'</strong> ';
 			} else {
-				$return .= ' <a href="'.util_make_url ('/softwaremap/trove_list.php?form_cat='.$form_cat);
+				$return .= ' <a href="'.util_make_url ('/softwaremap/trove_list.php?cat=c&form_cat='.$form_cat);
 				if ($discrim_url) {
 					$return .= $discrim_url.','.$folders_ids[$folders_len-1];
 				} else {
@@ -348,8 +353,7 @@ function trove_getcatlisting($group_id,$a_filter,$a_cats,$a_complete=0) {
 		$proj_discrim_used[$folders_ids[0]] = 1;
 		$isfirstdiscrim = 0;
 	}
-	if ($need_close_ul_tag)
-	{
+	if ($need_close_ul_tag) {
 		$return .= '</li></ul>';
 	}
 	return $return;
@@ -358,10 +362,10 @@ function trove_getcatlisting($group_id,$a_filter,$a_cats,$a_complete=0) {
 /**
  * trove_getfullname() - Returns cat fullname
  *
- * @param		int		The node
+ * @param	int	$node	The node
  */
 function trove_getfullname($node) {
-	$res = db_query_params ('
+	$res = db_query_params('
 		SELECT fullname
 		FROM trove_cat
 		WHERE trove_cat_id=$1',
@@ -373,7 +377,8 @@ function trove_getfullname($node) {
 /**
  * trove_getfullpath() - Returns a full path for a trove category
  *
- * @param		int		The node
+ * @param	int	$node	The node
+ * @return	string
  */
 function trove_getfullpath($node) {
 	$currentcat = $node;
@@ -381,7 +386,7 @@ function trove_getfullpath($node) {
 	$return = '';
 
 	while ($currentcat > 0) {
-		$res = db_query_params ('
+		$res = db_query_params('
 			SELECT trove_cat_id,parent,fullname
 			FROM trove_cat
 			WHERE trove_cat_id=$1',
@@ -397,44 +402,37 @@ function trove_getfullpath($node) {
 /**
  * trove_del_cat_id() - Delete the selected node (and its sub-nodes) in the trove tree
  *
- * @param		int		The node
+ * @param	int	$node	The node
  */
 function trove_del_cat_id($node) {
-        $res=db_query_params ('SELECT * FROM trove_cat WHERE parent=$1',
-			array($node));
-        if (!$res) {
-                exit_error(sprintf(_('Error In Trove Operation : %s'),db_error()),'home');
-        }
-        if (db_numrows($res)>0) {
-                for ($i=0; $i<db_numrows($res); $i++) {
-                        trove_del_cat_id(db_result($res,$i,'trove_cat_id'));
-                }
+	$res=db_query_params('SELECT * FROM trove_cat WHERE parent=$1', array($node));
+	if (!$res) {
+		exit_error(sprintf(_('Error in Trove Operation: %s'), db_error()), 'home');
+	}
+	if (db_numrows($res)>0) {
+		for ($i=0; $i<db_numrows($res); $i++) {
+			trove_del_cat_id(db_result($res,$i,'trove_cat_id'));
+		}
+	}
+	$res=db_query_params('DELETE FROM trove_treesums WHERE trove_cat_id=$1', array($node));
+	if (!$res) {
+		exit_error(sprintf(_('Error in Trove Operation: %s'), db_error()),'home');
+	}
+	$res=db_query_params('DELETE FROM trove_group_link WHERE trove_cat_id=$1', array($node));
+	if (!$res) {
+		exit_error(sprintf(_('Error in Trove Operation: %s'), db_error()), 'home');
+	}
+	$res=db_query_params('DELETE FROM trove_agg WHERE trove_cat_id=$1', array($node));
+	if (!$res) {
+		exit_error(sprintf(_('Error in Trove Operation: %s'), db_error()), 'home');
+	}
+	$res=db_query_params('DELETE FROM trove_cat WHERE trove_cat_id=$1', array($node));
+	if (!$res || db_affected_rows($res)<1) {
+		exit_error(sprintf(_('Error in Trove Operation: %s'), db_error()), 'home');
 	}
-        $res=db_query_params ('DELETE FROM trove_treesums WHERE trove_cat_id=$1',
-			array($node));
-        if (!$res) {
-                exit_error(sprintf(_('Error In Trove Operation : %s'),db_error()),'home');
-        }
-        $res=db_query_params ('DELETE FROM trove_group_link WHERE trove_cat_id=$1',
-			array($node));
-        if (!$res) {
-                exit_error(sprintf(_('Error In Trove Operation : %s'),db_error()),'home');
-        }
-        $res=db_query_params ('DELETE FROM trove_agg WHERE trove_cat_id=$1',
-			array($node));
-        if (!$res) {
-                exit_error(sprintf(_('Error In Trove Operation : %s'),db_error()),'home');
-        }
-        $res=db_query_params ('DELETE FROM trove_cat WHERE trove_cat_id=$1',
-			array($node));
-        if (!$res || db_affected_rows($res)<1) {
-                exit_error(sprintf(_('Error In Trove Operation : %s'),db_error()),'home');
-        }
 }
 
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
