@@ -5,7 +5,8 @@
  * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2003-2004 (c) Guillaume Smet - Open Wide
  * Copyright 2010 (c) Franck Villaume - Capgemini
- * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright (C) 2011-2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2012-2014, Franck Villaume - TrivialDev
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -24,8 +25,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'mail/admin/../mail_utils.php';
 
@@ -34,16 +34,14 @@ require_once $gfcommon.'mail/MailingListFactory.class.php';
 
 $group_id = getIntFromRequest('group_id');
 
-$feedback = getStringFromRequest('feedback');
-
 if ($group_id) {
 	$group = group_get_object($group_id);
 	if (!$group || !is_object($group) || $group->isError()) {
 		exit_no_group();
 	}
-	
+
 	session_require_perm ('project_admin', $group->getID()) ;
-	
+
 	//
 	//	Post Changes to database
 	//
@@ -55,7 +53,7 @@ if ($group_id) {
 
 			if (check_email_available($group, $group->getUnixName() . '-' . getStringFromPost('list_name'), $error_msg)) {
 				$mailingList = new MailingList($group);
-			
+
 				if (!form_key_is_valid(getStringFromRequest('form_key'))) {
 					exit_form_double_submit('mail');
 				}
@@ -66,7 +64,7 @@ if ($group_id) {
 					form_release_key(getStringFromRequest("form_key"));
 					exit_error($mailingList->getErrorMessage(),'mail');
 				}
-			
+
 				if(!$mailingList->create(
 					getStringFromPost('list_name'),
 					getStringFromPost('description'),
@@ -86,16 +84,17 @@ if ($group_id) {
 		//
 		} elseif (getStringFromPost('change_status') == 'y') {
 			$mailingList = new MailingList($group, getIntFromGet('group_list_id'));
-			
+
 			if(!$mailingList || !is_object($mailingList)) {
 				exit_error(_('Error getting the list'),'mail');
 			} elseif($mailingList->isError()) {
 				exit_error($mailingList->getErrorMessage(),'mail');
 			}
-			
+
 			if(!$mailingList->update(
 				unInputSpecialChars(getStringFromPost('description')),
-				getIntFromPost('is_public', MAIL__MAILING_LIST_IS_PUBLIC)
+				getIntFromPost('is_public', MAIL__MAILING_LIST_IS_PUBLIC),
+				MAIL__MAILING_LIST_IS_UPDATED
 			)) {
 				exit_error($mailingList->getErrorMessage(),'mail');
 			} else {
@@ -109,13 +108,13 @@ if ($group_id) {
 	//
 	if (getIntFromRequest('reset_pw') == 1) {
 		$mailingList = new MailingList($group, getIntFromGet('group_list_id'));
-		
+
 		if(!$mailingList || !is_object($mailingList)) {
 			exit_error(_('Error getting the list'),'mail');
 		} elseif($mailingList->isError()) {
 			exit_error($mailingList->getErrorMessage(),'mail');
 		}
-		
+
 		if($mailingList->getStatus() == MAIL__MAILING_LIST_IS_CONFIGURED) {
 			if(!$mailingList->update(
 				   $mailingList->getDescription(),
@@ -129,25 +128,24 @@ if ($group_id) {
 		}
 	}
 
-
 //
 //	Form to add list
 //
 	if(getIntFromGet('add_list')) {
 		mail_header(array('title' => _('Add a Mailing List')));
 		print '<p>';
-		printf(_('Lists are named in this manner:<br /><strong>projectname-listname@%1$s</strong>'), forge_get_config('lists_host'));
+		printf(_('Lists are named in this manner:<br /><strong>projectname-listname@%s</strong>'), forge_get_config('lists_host'));
 		print '</p>';
 
 		print '<p>';
-		print _('It will take <span class="important">6-24 Hours</span> for your list to be created.');
+		print _('It will take one hour for your list to be created.');
 		print '</p>';
-		
+
 		$mlFactory = new MailingListFactory($group);
 		if (!$mlFactory || !is_object($mlFactory) || $mlFactory->isError()) {
 			exit_error($mlFactory->getErrorMessage(),'mail');
 		}
-		
+
 		$mlArray = $mlFactory->getMailingLists();
 
 		if ($mlFactory->isError()) {
@@ -155,7 +153,7 @@ if ($group_id) {
 			mail_footer(array());
 			exit;
 		}
-		
+
 		$tableHeaders = array(
 			_('Existing mailing lists')
 		);
@@ -185,14 +183,14 @@ if ($group_id) {
 			<input type="hidden" name="post_changes" value="y" />
 			<input type="hidden" name="add_list" value="y" />
 			<input type="hidden" name="form_key" value="<?php echo form_generate_key();?>" />
-			<p><strong><?php echo _('Mailing List Name:'); ?></strong><br />
-			<strong><?php echo $group->getUnixName(); ?>-<input type="text" name="list_name" value="" size="10" maxlength="12" />@<?php echo forge_get_config('lists_host'); ?></strong><br /></p>
+			<p><strong><?php echo _('Mailing List Name')._(':'); ?></strong><br />
+			<strong><?php echo $group->getUnixName(); ?>-<input type="text" name="list_name" value="" size="10" maxlength="12" required="required" pattern="[a-zA-Z0-9]{4,}" />@<?php echo forge_get_config('lists_host'); ?></strong></p>
 			<p>
 			<strong><?php echo _('Is Public?'); ?></strong><br />
-			<input type="radio" name="is_public" value="<?php echo MAIL__MAILING_LIST_IS_PUBLIC; ?>" checked="checked" /> <?php echo _('Yes'); ?><br />
-			<input type="radio" name="is_public" value="<?php echo MAIL__MAILING_LIST_IS_PRIVATE; ?>" /> <?php echo _('No'); ?></p><p>
-			<strong><?php echo _('Description:'); ?></strong><br />
-			<input type="text" name="description" value="" size="40" maxlength="80" /><br /></p>
+			<input type="radio" name="is_public" value="<?php echo MAIL__MAILING_LIST_IS_PUBLIC; ?>" <?php echo ($group->isPublic() ? ' checked="checked"' : '') ?> /> <?php echo _('Yes'); ?><br />
+			<input type="radio" name="is_public" value="<?php echo MAIL__MAILING_LIST_IS_PRIVATE; ?>" <?php echo ($group->isPublic() ? '' : ' checked="checked"') ?> /> <?php echo _('No'); ?></p><p>
+			<strong><?php echo _('Description')._(':'); ?></strong><br />
+			<input type="text" name="description" value="" size="40" maxlength="80" /></p>
 			<p>
 			<input type="submit" name="submit" value="<?php echo _('Add This List'); ?>" /></p>
 		</form>
@@ -204,15 +202,15 @@ if ($group_id) {
 //
 	} elseif(getIntFromGet('change_status') && getIntFromGet('group_list_id')) {
 		$mailingList = new MailingList($group, getIntFromGet('group_list_id'));
-			
+
 		if(!$mailingList || !is_object($mailingList)) {
 			exit_error(_('Error getting the list'),'mail');
 		} elseif($mailingList->isError()) {
 			exit_error($mailingList->getErrorMessage(),'mail');
 		}
-   	
+
 		mail_header(array(
-			'title' => _('Mail admin')));
+			'title' => sprintf(_('Update Mailing List %s'), $mailingList->getName())));
 		?>
 		<h3><?php echo $mailingList->getName(); ?></h3>
 		<form method="post" action="<?php echo getStringFromServer('PHP_SELF'); ?>?group_id=<?php echo $group_id; ?>&amp;group_list_id=<?php echo $mailingList->getID(); ?>">
@@ -223,8 +221,9 @@ if ($group_id) {
 			<input type="radio" name="is_public" value="<?php echo MAIL__MAILING_LIST_IS_PUBLIC; ?>"<?php echo ($mailingList->isPublic() == MAIL__MAILING_LIST_IS_PUBLIC ? ' checked="checked"' : ''); ?> /> <?php echo _('Yes'); ?><br />
 			<input type="radio" name="is_public" value="<?php echo MAIL__MAILING_LIST_IS_PRIVATE; ?>"<?php echo ($mailingList->isPublic() == MAIL__MAILING_LIST_IS_PRIVATE ? ' checked="checked"' : ''); ?> /> <?php echo _('No'); ?>
 			</p>
-			<p><strong><?php echo _('Description:'); ?></strong><br />
-			<input type="text" name="description" value="<?php echo inputSpecialChars($mailingList->getDescription()); ?>" size="40" maxlength="80" /><br /></p>
+			<p>
+			<strong><?php echo _('Description')._(':'); ?></strong><br />
+			<input type="text" name="description" value="<?php echo inputSpecialChars($mailingList->getDescription()); ?>" size="40" maxlength="80" /></p>
 			<p>
 			<input type="submit" name="submit" value="<?php echo _('Update'); ?>" /></p>
 		</form>
@@ -241,7 +240,7 @@ if ($group_id) {
 		}
 
 		mail_header(array(
-			'title' => _('Mailing List Administration'))
+			'title' => _('Mailing Lists Admin'))
 		);
 
 		$mlArray = $mlFactory->getMailingLists();
@@ -252,7 +251,7 @@ if ($group_id) {
 			mail_footer(array());
 			exit;
 		}
-		echo '<p>'.sprintf(_('You can administrate lists from here. Please note that private lists can still be viewed by members of your project, but are not listed on %1$s.'), forge_get_config ('forge_name')).'</p>';
+		echo '<p>'.sprintf(_('You can administrate lists from here. Please note that private lists can still be viewed by members of your project, but are not listed on %s.'), forge_get_config ('forge_name')).'</p>';
 		echo '<ul>
 			<li>
 				<a href="'.getStringFromServer('PHP_SELF').'?group_id='.$group_id.'&amp;add_list=1">'._('Add Mailing List').'</a>
@@ -261,7 +260,7 @@ if ($group_id) {
 		$mlCount = count($mlArray);
 		if($mlCount > 0) {
 			$tableHeaders = array(
-				_('Mailing list'),
+				_('Mailing List'),
 				'',
 				'',
 				''
@@ -274,18 +273,22 @@ if ($group_id) {
 					echo $currentList->getErrorMessage();
 					echo '</td></tr>';
 				} else {
-					echo '<tr '. $HTML->boxGetAltRowStyle($i) . '><td width="60%">'.
+					echo '<tr '. $HTML->boxGetAltRowStyle($i) . '><td>'.
 					'<strong>'.$currentList->getName().'</strong><br />'.
-					htmlspecialchars($currentList->getDescription()).'</td>'.
-					'<td style="text-align:center"><a href="'.getStringFromServer('PHP_SELF').'?group_id='.$group_id.'&amp;group_list_id='.$currentList->getID().'&amp;change_status=1">'._('Update').'</a></td>' ;
-					echo '<td style="text-align:center">';
+					htmlspecialchars($currentList->getDescription()).'</td>';
+					echo '<td class="align-center">';
+					if ($currentList->getStatus() != MAIL__MAILING_LIST_PW_RESET_REQUESTED) {
+						echo '<a href="'.getStringFromServer('PHP_SELF').'?group_id='.$group_id.'&amp;group_list_id='.$currentList->getID().'&amp;change_status=1">'._('Update').'</a>';
+					}
+					echo '</td>';
+					echo '<td class="align-center">';
 					if($currentList->getStatus() == MAIL__MAILING_LIST_IS_REQUESTED) {
 						echo _('Not activated yet');
 					} else {
 						echo '<a href="'.$currentList->getExternalAdminUrl().'">'._('Administration').'</a>';
 					}
 					echo '</td>';
-					echo '<td style="text-align:center">';
+					echo '<td class="align-center">';
 					if($currentList->getStatus() == MAIL__MAILING_LIST_IS_CONFIGURED) {
 						print '<a href="'.getStringFromServer('PHP_SELF').'?group_id='.$group_id.'&amp;group_list_id='.$currentList->getID().'&amp;reset_pw=1">'._('Reset admin password').'</a></td>' ;
 
@@ -300,4 +303,3 @@ if ($group_id) {
 } else {
 	exit_no_group();
 }
-?>
