@@ -6,6 +6,7 @@
  * Copyright 2003-2004 (c) Guillaume Smet - Open Wide
  * Copyright 2010 (c) Franck Villaume - Capgemini
  * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2012, Jean-Christophe Masson - French National Education Department
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -24,7 +25,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'mail/../mail/mail_utils.php';
 
@@ -40,7 +41,7 @@ if ($group_id) {
 	} elseif ($group->isError()) {
 		exit_error($group->getErrorMessage(),'mail');
 	}
-	
+
 	$mlFactory = new MailingListFactory($group);
 	if (!$mlFactory || !is_object($mlFactory)) {
 		exit_error(_('Could Not Get MailingListFactory'),'mail');
@@ -49,7 +50,7 @@ if ($group_id) {
 	}
 
 	mail_header(array(
-		'title' => sprintf(_('Mailing Lists for %1$s'), $group->getPublicName())
+		'title' => sprintf(_('Mailing Lists for %s'), $group->getPublicName())
 	));
 
 	plugin_hook ("blocks", "mail index");
@@ -57,23 +58,24 @@ if ($group_id) {
 	$mlArray = $mlFactory->getMailingLists();
 
 	if ($mlFactory->isError()) {
-		echo '<p class="error">'.sprintf(_('Unable to get the list %s : %s'), $group->getPublicName(), $mlFactory->getErrorMessage()) .'</p>';
+		echo '<p class="error">'.sprintf(_('Unable to get the list %s: %s'), $group->getPublicName(), $mlFactory->getErrorMessage()) .'</p>';
 		mail_footer(array());
 		exit;
 	}
-	
+
 	$mlCount = count($mlArray);
 	if($mlCount == 0) {
-		echo '<p>'.sprintf(_('No Lists found for %1$s'), $group->getPublicName()) .'</p>';
+		echo '<p class="information">'.sprintf(_('No Lists found for %s'), $group->getPublicName()) .'</p>';
 		echo '<p>'._('Project administrators use the admin link to request mailing lists.').'</p>';
 		mail_footer(array());
 		exit;
 	}
-	
+
 	echo '<p>' . _('Choose a list to browse, search, and post messages.') . '</p>';
-	
+
 	$tableHeaders = array(
-		_('Mailing list'),
+		_('Mailing List'),
+		_('Address'),
 		_('Description'),
 		_('Subscription')
 	);
@@ -81,27 +83,29 @@ if ($group_id) {
 
 	for ($j = 0; $j < $mlCount; $j++) {
 		$currentList =& $mlArray[$j];
-		echo '<tr '. $HTML->boxGetAltRowStyle($j) .'>';
-		if ($currentList->isError()) {
-			echo '<td colspan="3">'.$currentList->getErrorMessage().'</td>';
-		} else if($currentList->getStatus() == MAIL__MAILING_LIST_IS_REQUESTED) {
-			echo '<td width="33%">'.
-				'<strong>'.$currentList->getName().'</strong></td>'.
-				'<td width="33%">'.htmlspecialchars($currentList->getDescription()). '</td>'.
-				'<td width="33%" style="text-align:center">'._('Not activated yet').'</td>';
-		} else {
-			echo '<td width="33%">'.
-				'<strong><a href="'.$currentList->getArchivesUrl().'">' .
-				sprintf(_('%1$s Archives'), $currentList->getName()).'</a></strong></td>'.
-				'<td>'.htmlspecialchars($currentList->getDescription()). '</td>'.
-				'<td width="33%" style="text-align:center"><a href="'.$currentList->getExternalInfoUrl().'">'._('Subscribe/Unsubscribe/Preferences').'</a>'.
-				'</td>';
+		if (!$currentList->isPermissionDeniedError()) {
+			echo '<tr '. $HTML->boxGetAltRowStyle($j) .'>';
+			if ($currentList->isError()) {
+				echo '<td colspan="4">'.$currentList->getErrorMessage().'</td>';
+			} elseif ($currentList->getStatus() == MAIL__MAILING_LIST_IS_REQUESTED) {
+				echo '<td class="halfwidth" colspan="2"><strong>'.$currentList->getName().'</strong></td>'.
+					'<td width="25%">'.htmlspecialchars($currentList->getDescription()). '</td>'.
+					'<td width="25%" class="align-center">'._('Not activated yet').'</td>';
+			} else {
+				echo '<td width="25%">'.
+					'<strong><a href="'.$currentList->getArchivesUrl().'">' .
+					sprintf(_('%s Archives'), $currentList->getName()).'</a></strong></td>'.
+					'<td width="25%" align="center"><a href="&#109;&#097;&#105;&#108;&#116;&#111;:'.$currentList->getListEmail().'">'.$currentList->getListEmail(). '</a></td>'.
+					'<td width="25%">'.htmlspecialchars($currentList->getDescription()). '</td>'.
+					'<td width="25%" class="align-center"><a href="'.$currentList->getExternalInfoUrl().'">'._('Subscribe/Unsubscribe/Preferences').'</a>'.
+					'</td>';
+			}
+			echo '</tr>';
 		}
-		echo '</tr>';
 	}
 
 	echo $HTML->listTableBottom();
-	
+
 	mail_footer(array());
 
 } else {
@@ -109,5 +113,3 @@ if ($group_id) {
 	exit_no_group();
 
 }
-
-?>
