@@ -22,7 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'include/vote_function.php';
 
@@ -34,10 +34,9 @@ if ( !$offset || $offset < 0 || !is_numeric($offset) ) {
 	$offset = 0;
 }
 
-// For expediancy, list only the filereleases in the past three days.
+// For expediency, list only the file releases in the past three days.
 $start_time = time() - (30 * 86400);
 
-
 $res_new = db_query_params ('SELECT groups.group_name,
 	groups.group_id,
 	groups.unix_group_name,
@@ -49,15 +48,15 @@ $res_new = db_query_params ('SELECT groups.group_name,
 	frs_release.name AS release_version,
 	frs_release.release_date,
 	frs_release.released_by,
-	frs_package.name AS module_name, 
-	frs_dlstats_grouptotal_vw.downloads 
-	FROM groups,users,frs_package,frs_release,frs_dlstats_grouptotal_vw 
+	frs_package.name AS module_name,
+	frs_dlstats_grouptotal_vw.downloads
+	FROM groups,users,frs_package,frs_release,frs_dlstats_grouptotal_vw
 	WHERE ( frs_release.release_date > $1
-	AND frs_release.package_id = frs_package.package_id 
-	AND frs_package.group_id = groups.group_id 
-	AND frs_release.released_by = users.user_id 
-	AND frs_package.group_id = frs_dlstats_grouptotal_vw.group_id 
-	AND frs_release.status_id=1 
+	AND frs_release.package_id = frs_package.package_id
+	AND frs_package.group_id = groups.group_id
+	AND frs_release.released_by = users.user_id
+	AND frs_package.group_id = frs_dlstats_grouptotal_vw.group_id
+	AND frs_release.status_id=1
 	AND frs_package.is_public=1 )
 	ORDER BY frs_release.release_date DESC',
 			    array($start_time),
@@ -78,11 +77,11 @@ if (!$res_new || db_numrows($res_new) < 1) {
 	}
 
 	print '
-		<table width="100%" cellpadding="0" cellspacing="0" border="0">';
+		<table class="fullwidth">';
 	$seen = array();
 	$i = 0;
 	foreach ($rows as $row_new) {
-		// avoid dupulicates of different file types
+		// avoid duplicates of different file types
 		if (!isset($seen[$row_new['group_id']])) {
 			print '
 			<tr valign="top">
@@ -90,13 +89,13 @@ if (!$res_new || db_numrows($res_new) < 1) {
 				util_make_link_g ($row_new['unix_group_name'],$row_new['group_id'],'<strong>'.$row_new['group_name'].'</strong>').'
 				</td>
 				<td nowrap="nowrap"><em>'._('Released by:').
-				util_make_link_u ($row_new['user_name'],$row_new['user_id'],'<em>'.$row_new['user_name'].'</em>').'
+				util_make_link_u ($row_new['user_name'],$row_new['user_id'],$row_new['user_name']).'</em>
 				</td>
 			</tr>
 			<tr>
 				<td>'._('Module:').' '.$row_new['module_name'].'
 				</td>
-				<td>'._('Version:').' '.$row_new['release_version'].'
+				<td>'._('Version')._(': ').$row_new['release_version'].'
 				</td>
 				<td>'.date("M d, h:iA",$row_new['release_date']).'
 				</td>
@@ -110,7 +109,7 @@ if (!$res_new || db_numrows($res_new) < 1) {
 		}
 		print '
 				</td>
-				<td style="text-align:center" nowrap="nowrap">&nbsp;</td>
+				<td></td>
 			</tr>
 			<tr>
 				<td colspan="3">';
@@ -119,7 +118,7 @@ if (!$res_new || db_numrows($res_new) < 1) {
 				util_make_link ('/frs/?group_id='.$row_new['group_id'].'&amp;release_id='.$row_new['release_id'],_('Download')).
 				' ('._('Project Total:') .$row_new['downloads'].') | ';
 				// notes for this release
-				print util_make_link ('/frs/shownotes.php?release_id='.$row_new['release_id'],_('Notes &amp; Changes')).'
+				print util_make_link ('/frs/shownotes.php?release_id='.$row_new['release_id'],_('Notes and Changes')).'
 				<hr />
 				</td>
 			</tr>';
@@ -157,5 +156,3 @@ if (!$res_new || db_numrows($res_new) < 1) {
 }
 
 $HTML->footer(array());
-
-?>
