@@ -23,7 +23,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'include/note.php';
 require_once $gfwww.'news/admin/news_admin_utils.php';
@@ -37,12 +37,10 @@ $post_changes = getStringFromRequest('post_changes');
 $approve = getStringFromRequest('approve');
 $status = getIntFromRequest('status');
 $summary = getStringFromRequest('summary');
-$details = getStringFromRequest('details');
+$details = getHtmlTextFromRequest('details');
 $id = getIntFromRequest('id');
 $for_group = getIntFromRequest('for_group');
 
-$feedback = htmlspecialchars(getStringFromRequest('feedback'));
-
 if ($group_id && $group_id != forge_get_config('news_group')) {
 	session_require_perm ('project_admin', $group_id) ;
 
@@ -65,10 +63,10 @@ if ($group_id && $group_id != forge_get_config('news_group')) {
 		if (db_numrows($result) < 1) {
 			exit_error(_('Newsbyte not found'),'news');
 		}
-		
+
 		$forum_id = db_result($result,0,'forum_id');
 		$old_group_id = db_result($result,0,'group_id');
-	
+
 		if ($approve) {
 			/*
 				Update the db so the item shows on the home page
@@ -84,19 +82,12 @@ if ($group_id && $group_id != forge_get_config('news_group')) {
 			if (!$details) {
 				$details='(none)';
 			}
-			
-			if (getStringFromRequest('_details_content_type') == 'html') {
-				$details = TextSanitizer::purify($details);
-			} else {
-				$details = htmlspecialchars($details);
-			}
 
-			$result = db_query_params("UPDATE news_bytes SET is_approved=$1, summary=$2, 
+			$result = db_query_params("UPDATE news_bytes SET is_approved=$1, summary=$2,
 details=$3 WHERE id=$4 AND group_id=$5", array($status, htmlspecialchars($summary), $details, $id, $group_id));
-			
+
 			if (!$result || db_affected_rows($result) < 1) {
-				$error_msg .= _('Error On Update:');
-				$error_msg .= db_error();
+				$error_msg .= sprintf(_('Error On Update: %s'), db_error());
 			} else {
 				$feedback .= _('Newsbyte Updated.');
 			}
@@ -119,20 +110,19 @@ details=$3 WHERE id=$4 AND group_id=$5", array($status, htmlspecialchars($summar
 		if (db_numrows($result) < 1) {
 			exit_error(_('Newsbyte not found'),'news');
 		}
-		
+
 		$group = group_get_object($group_id);
-		
+
 		echo notepad_func();
 		echo '
-		<p />
 		<form id="newsadminform" action="'.getStringFromServer('PHP_SELF').'" method="post">
 		<input type="hidden" name="group_id" value="'.db_result($result,0,'group_id').'" />
 		<input type="hidden" name="id" value="'.db_result($result,0,'id').'" />';
 
-		$user =& user_get_object(db_result($result,0,'submitted_by'));
+		$user = user_get_object(db_result($result,0,'submitted_by'));
 
 		echo '
-		<strong>'._('Submitted by').':</strong> '.$user->getRealName().'<br />
+		<strong>'._('Submitted by')._(':').'</strong> '.$user->getRealName().'<br />
 		<input type="hidden" name="approve" value="y" />
 		<input type="hidden" name="post_changes" value="y" />
 
@@ -141,25 +131,21 @@ details=$3 WHERE id=$4 AND group_id=$5", array($status, htmlspecialchars($summar
 		<input type="radio" name="status" value="4" /> '._('Delete').'<br />
 
 		<strong>'._('Subject').'</strong><br />
-		<input type="text" name="summary" value="'.db_result($result,0,'summary').'" size="60" maxlength="60" /><br />
+		<input type="text" name="summary" value="'.db_result($result,0,'summary').'" size="80" /><br />
 		<strong>'._('Details').'</strong>'.notepad_button('document.forms.newsadminform.details').'<br />';
-		
-		$GLOBALS['editor_was_set_up']=false;
+
 		$params = array () ;
 		$params['name'] = 'details';
 		$params['width'] = "600";
 		$params['height'] = "300";
 		$params['group'] = $group_id;
 		$params['body'] = db_result($result,0,'details');
-		plugin_hook("text_editor",$params);
-		if (!$GLOBALS['editor_was_set_up']) {
-			//if we don't have any plugin for text editor, display a simple textarea edit box
-			echo '<textarea name="details" rows="5" cols="50">'.db_result($result,0,'details').'</textarea><br />';
-		}
-		unset($GLOBALS['editor_was_set_up']);
-		
+		$params['content'] = '<textarea name="details" rows="5" cols="50">'.$params['body'].'</textarea>';
+		plugin_hook_by_reference("text_editor",$params);
+
+		echo $params['content'].'<br/>';
 		echo '<p>
-		<strong>'.sprintf(_('If this item is on the %1$s home page and you edit it, it will be removed from the home page.'), forge_get_config ('forge_name')).'</strong><br /></p>
+		<strong>'.sprintf(_('If this item is on the %s home page and you edit it, it will be removed from the home page.'), forge_get_config('forge_name')).'</strong></p>
 		<input type="submit" name="submit" value="'._('Submit').'" />
 		</form>';
 
@@ -171,10 +157,9 @@ details=$3 WHERE id=$4 AND group_id=$5", array($status, htmlspecialchars($summar
 		$result=db_query_params("SELECT * FROM news_bytes WHERE is_approved <> 4 AND group_id=$1", array($group_id));
 		$rows=db_numrows($result);
 		$group = group_get_object($group_id);
-		
+
 		if ($rows < 1) {
-			echo '
-				<p class="warning_msg">'._('No Queued Items Found').'</p>';
+			echo '<p class="information">'._('No Queued Items Found').'</p>';
 		} else {
 			echo '
 				<ul>';
@@ -196,5 +181,3 @@ details=$3 WHERE id=$4 AND group_id=$5", array($status, htmlspecialchars($summar
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
