@@ -22,7 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'news/news_utils.php';
 require_once $gfcommon.'forum/Forum.class.php';
@@ -30,7 +30,6 @@ require_once $gfcommon.'forum/Forum.class.php';
 $group_id = getIntFromRequest('group_id');
 $limit = getIntFromRequest('limit');
 $offset = getIntFromRequest('offset');
-$feedback = htmlspecialchars(getStringFromRequest('feedback'));
 
 news_header(array('title'=>_('News')));
 
@@ -70,9 +69,9 @@ if ($rows>$limit) {
 
 if ($rows < 1) {
 	if ($group_id) {
-		echo '<p class="warning_msg">'.sprintf(_('No News Found for %s'),group_getname($group_id)).'</p>';
+		echo '<p class="information">'.sprintf(_('No News Found for %s'),group_getname($group_id)).'</p>';
 	} else {
-		echo '<p class="warning_msg">'._('No News Found').'</p>';
+		echo '<p class="information">'._('No News Found').'</p>';
 	}
 	echo db_error();
 } else {
@@ -85,5 +84,3 @@ news_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
