@@ -24,7 +24,7 @@
  */
 
 function news_header($params) {
-	global $HTML,$group_id,$news_name,$news_id;
+	global $HTML, $group_id, $news_name,$news_id;
 
 	if (!forge_get_config('use_news')) {
 		exit_disabled();
@@ -76,8 +76,10 @@ function news_footer($params) {
  * @param bool $allow_submit (default: true)
  * @param bool $flat (default: false)
  * @param int  $tail_headlines number of additional news to display in short (-1 for all the others, default: 0)
+ * @param bool $show_forum
+ * @return string
  */
-function news_show_latest($group_id='',$limit=10,$show_summaries=true,$allow_submit=true,$flat=false,$tail_headlines=0,$show_forum=true) {
+function news_show_latest($group_id=0,$limit=10,$show_summaries=true,$allow_submit=true,$flat=false,$tail_headlines=0,$show_forum=true) {
 
 	if (!$group_id) {
 		$group_id=forge_get_config('news_group');
@@ -86,9 +88,9 @@ function news_show_latest($group_id='',$limit=10,$show_summaries=true,$allow_sub
 		Show a simple list of the latest news items with a link to the forum
 	*/
 	if ($tail_headlines == -1) {
-		$l = 0 ;
+		$l = 0;
 	} else {
-		$l = $limit + $tail_headlines ;
+		$l = $limit + $tail_headlines;
 	}
 	$result = db_query_params ('
 SELECT groups.group_name, groups.unix_group_name, groups.group_id,
@@ -112,7 +114,7 @@ ORDER BY post_date DESC',
 	$return = '';
 
 	if (!$result || $rows < 1) {
-		$return .= _('No News Items Found');
+		$return .= _('No News Found');
 		$return .= db_error();
 //		$return .= "</div>";
 	} else {
@@ -156,11 +158,11 @@ ORDER BY post_date DESC',
 				$return .= $t_thread_author;
 				$return .= '</em>';
 				$return .= ' - ';
-				$return .= date(_('Y-m-d H:i'),db_result($result,$i,'post_date'));
+				$return .= relative_date(db_result($result,$i,'post_date'));
 				$return .= ' - ';
 				$return .= $proj_name ;
 				$return .= "</div>\n";
-				
+
 				if ($summ_txt != "") {
 					$return .= '<p>'.$summ_txt.'</p>';
 				}
@@ -178,9 +180,9 @@ ORDER BY post_date DESC',
 				} else {
 					$comments_txt = _('Comments');
 				}
-				
+
 				if ($show_forum) {
-					$link_text =  _('Read&nbsp;More/Comment') ;
+					$link_text = _('Read More/Comment') ;
 					$extra_params = array( 'class'      => 'dot-link',
 					             		   'title'      => $link_text . ' ' . $t_thread_title);
 					$return .= "\n";
@@ -231,19 +233,19 @@ function news_foundry_latest($group_id=0,$limit=5,$show_summaries=true) {
 
 	$result=db_query_params("SELECT groups.group_name,groups.unix_group_name,groups.group_id,
 		users.user_name,users.realname,news_bytes.forum_id,
-		news_bytes.summary,news_bytes.post_date,news_bytes.details 
-		FROM users,news_bytes,groups,foundry_news 
-		WHERE foundry_news.foundry_id=$1 
-		AND users.user_id=news_bytes.submitted_by 
-		AND foundry_news.news_id=news_bytes.id 
-		AND news_bytes.group_id=groups.group_id 
-		AND foundry_news.is_approved=1 
+		news_bytes.summary,news_bytes.post_date,news_bytes.details
+		FROM users,news_bytes,groups,foundry_news
+		WHERE foundry_news.foundry_id=$1
+		AND users.user_id=news_bytes.submitted_by
+		AND foundry_news.news_id=news_bytes.id
+		AND news_bytes.group_id=groups.group_id
+		AND foundry_news.is_approved=1
 		ORDER BY news_bytes.post_date DESC", array($group_id),$limit);
 
 	$rows=db_numrows($result);
 
 	if (!$result || $rows < 1) {
-		$return .= '<h3>' . _('No News Items Found') . '</h3>';
+		$return .= '<h3>' . _('No News Found') . '</h3>';
 		$return .= db_error();
 	} else {
 		for ($i=0; $i<$rows; $i++) {
@@ -287,5 +289,3 @@ function get_news_name($id) {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
