@@ -5,6 +5,7 @@
  * Copyright (C) 1999-2001 VA Linux Systems
  * Copyright (C) 2002-2004 GForge Team
  * Copyright (C) 2008-2010 Alcatel-Lucent
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
  * http://fusionforge.org/
  *
@@ -46,7 +47,7 @@
  * ALONE BASIS."
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'include/note.php';
 require_once $gfwww.'news/news_utils.php';
@@ -57,24 +58,24 @@ $group_id = getIntFromRequest('group_id');
 if (!$group_id) {
 	exit_no_group();
 }
-$group=group_get_object($group_id);
+$group = group_get_object($group_id);
 if (!$group || !is_object($group)) {
 	exit_no_group();
 } elseif ($group->isError()) {
-	exit_error($group->getErrorMessage(),'news');
+	exit_error($group->getErrorMessage(), 'news');
 }
 
 $summary = getStringFromRequest('summary');
-$details = getStringFromRequest('details');
+$details = getHtmlTextFromRequest('details');
 
 if (session_loggedin()) {
 
-	if (!user_ismember($group_id,'A')) {
-		exit_permission_denied(_('You cannot submit news for a project unless you are an admin on that project'),'home');
+	if (!forge_check_perm('project_admin', $group_id)) {
+		exit_permission_denied(_('You cannot submit news for a project unless you are an admin on that project.'), 'home');
 	}
 
 	if ($group_id == forge_get_config('news_group')) {
-		exit_permission_denied(_('Submitting news from the news group is not allowed.'),'home');
+		exit_permission_denied(_('Submitting news from the news group is not allowed.'), 'home');
 	}
 
 	if (getStringFromRequest('post_changes')) {
@@ -84,44 +85,38 @@ if (session_loggedin()) {
 
 		//check to make sure both fields are there
 		if ($summary && $details) {
-			if (getStringFromRequest('_details_content_type') == 'html') {
-				$details = TextSanitizer::purify($details);
-			} else {
-				$details = htmlspecialchars($details);
-			}
-
 			/*
 			  create a new discussion forum without a default msg
 			  if one isn't already there
 			*/
-			
+
 			db_begin();
-			$f = new Forum($group);
-			if (!$f->create(preg_replace('/[^_\.0-9a-z-]/','-', strtolower($summary)),$details,1,'',0,0)) {
+			$f = new Forum($group, false, false, true);
+			if (!$f->create(preg_replace('/[^_\.0-9a-z-]/', '-', strtolower($summary)), $details, '')) {
 				db_rollback();
-				exit_error($f->getErrorMessage(),'news');
-			}
-			$group->normalizeAllRoles();
-			$new_id=$f->getID();
-			$sql='INSERT INTO news_bytes (group_id,submitted_by,is_approved,post_date,forum_id,summary,details) 
- VALUES ($1, $2, $3, $4, $5, $6, $7)';
-			$result=db_query_params($sql,
-						array($group_id, user_getid(), 0, time(), $new_id, htmlspecialchars($summary), $details));
-			if (!$result) {
-				db_rollback();
-				form_release_key(getStringFromRequest('form_key'));
-				$error_msg = _('ERROR doing insert');
+				$error_msg = $f->getErrorMessage();
 			} else {
-				db_commit();
-				$feedback = _('News Added.');
+				$group->normalizeAllRoles();
+				$new_id = $f->getID();
+				$sql = 'INSERT INTO news_bytes (group_id, submitted_by, is_approved, post_date, forum_id, summary,details)
+						VALUES ($1, $2, $3, $4, $5, $6, $7)';
+				$result = db_query_params($sql, array($group_id, user_getid(), 0, time(), $new_id, htmlspecialchars($summary), $details));
+				if (!$result) {
+					db_rollback();
+					form_release_key(getStringFromRequest('form_key'));
+					$error_msg = _('Error: insert failed.');
+				} else {
+					db_commit();
+					$feedback = _('News Added.');
+				}
 			}
 		} else {
 			form_release_key(getStringFromRequest('form_key'));
-			$error_msg = _('ERROR - both subject and body are required');
+			$error_msg = _('Error: both subject and body are required.');
 		}
 	}
 
-	//news must now be submitted from a project page - 
+	//news must now be submitted from a project page -
 
 	if (!$group_id) {
 		exit_no_group();
@@ -137,34 +132,41 @@ if (session_loggedin()) {
 
 	$jsfunc = notepad_func();
 
-	echo '
-		<p>
-		'. sprintf(_('You can post news about your project if you are an admin on your project. You may also post "help wanted" notes if your project needs help.</p><p>All posts <b>for your project</b> will appear instantly on your project summary page. Posts that are of special interest to the community will have to be approved by a member of the %1$s news team before they will appear on the %1$s home page.</p><p>You may include URLs, but not HTML in your submissions.</p><p>URLs that start with http:// are made clickable.'), forge_get_config ('forge_name')) .'</p>' . $jsfunc . 
+	echo '<p>';
+	echo _('You can post news about your project if you are an admin on your project. You may also post “help wanted” notes if your project needs help.');
+	echo '</p>';
+	echo '<p>';
+	printf(_('All posts <strong>for your project</strong> will appear instantly on your project summary page. Posts that are of special interest to the community will have to be approved by a member of the %1$s news team before they will appear on the %1$s home page.'), forge_get_config('forge_name'));
+	echo '</p>';
+	echo '<p>';
+	echo _('You may include URLs, but not HTML in your submissions.');
+	echo '</p>';
+	echo '<p>';
+	echo _('URLs that start with http:// are made clickable.');
+	echo '</p>';
+	echo $jsfunc .
 		'
 		<form id="newssubmitform" action="'.getStringFromServer('PHP_SELF').'" method="post">
 		<input type="hidden" name="group_id" value="'.$group_id.'" />
 		<input type="hidden" name="post_changes" value="y" />
 		<input type="hidden" name="form_key" value="'. form_generate_key() .'" />
-		<p><strong>'._('For project').' '.$group->getPublicName().'</strong></p>
+		<p><strong>'._('For project')._(': ').$group->getPublicName().'</strong></p>
 		<p>
-		<strong>'._('Subject').':</strong>'.utils_requiredField().'<br />
-		<input type="text" name="summary" value="'.$summary.'" size="60" maxlength="60" /></p>
+		<strong>'._('Subject')._(': ').'</strong>'.utils_requiredField().'<br />
+		<input required="required" type="text" name="summary" value="'.$summary.'" size="80" /></p>
 		<p>
-		<strong>'._('Details').':</strong>'.notepad_button('document.forms.newssubmitform.details').utils_requiredField().'</p>';
-	
-	$GLOBALS['editor_was_set_up']=false;
-	$params = array() ;
+		<strong>'._('Details')._(': ').'</strong>'.notepad_button('document.forms.newssubmitform.details').utils_requiredField().'</p>';
+
+	$params = array();
 	$params['name'] = 'details';
 	$params['width'] = "800";
 	$params['height'] = "500";
 	$params['body'] = $details;
 	$params['group'] = $group_id;
-	plugin_hook("text_editor",$params);
-	if (!$GLOBALS['editor_was_set_up']) {
-		//if we don't have any plugin for text editor, display a simple textarea edit box
-		echo '<textarea name="details" rows="5" cols="50">'.$details.'</textarea><br />';
-	}
-	unset($GLOBALS['editor_was_set_up']);
+	$params['content'] = '<textarea required="required" name="details" rows="5" cols="50">'.$details.'</textarea>';
+	plugin_hook_by_reference("text_editor",$params);
+
+	echo $params['content'].'<br />';
 	echo '<div><input type="submit" name="submit" value="'._('Submit').'" />
 		</div></form>';
 
@@ -180,5 +182,3 @@ if (session_loggedin()) {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
