@@ -1,9 +1,10 @@
 <?php
 /**
- * Help Wanted 
+ * Help Wanted
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2002-2004 (c) GForge Team
+ * Copyright 2014, Franck Villaume - TrivialDev
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -22,7 +23,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'people/people_utils.php';
 require_once $gfwww.'project/admin/project_admin_utils.php';
@@ -33,7 +34,7 @@ if (!forge_get_config('use_people')) {
 
 $group_id = getIntFromRequest('group_id');
 
-if ($group_id && (user_ismember($group_id, 'A'))) {
+if ($group_id && (forge_check_perm('project_admin', $group_id))) {
 
 	project_admin_header(array());
 
@@ -41,19 +42,19 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
 		Fill in the info to create a job
 	*/
 	echo '
-		<p>'._('Start by filling in the fields below. When you click continue, you will be shown a list of skills and experience levels that this job requires.').'	</p>
+		<p>'._('Start by filling in the fields below. When you click continue, you will be shown a list of skills and experience levels that this job requires.').'</p>
 		<p>
 		<form action="'.util_make_url ('/people/editjob.php').'" method="post">
 		<input type="hidden" name="group_id" value="'.$group_id.'" />
 		<input type="hidden" name="form_key" value="' . form_generate_key() . '">
-		<strong>'._('Category').'</strong>'.utils_requiredField().'<br /></p>
+		<strong>'._('Category').'</strong>'.utils_requiredField().'</p>
 		'. people_job_category_box('category_id') .'
 		<p>
-		<strong>'._('Short Description').':</strong>'.utils_requiredField().'<br />
-		<input type="text" name="title" value="" size="40" maxlength="60" /></p>
+		<strong>'._('Short Description')._(':').'</strong>'.utils_requiredField().'<br />
+		<input type="text" required="required" name="title" value="" size="40" maxlength="60" /></p>
 		<p>
-		<strong>'._('Long Description').':</strong>'.utils_requiredField().'<br />
-		<textarea name="description" rows="10" cols="60"></textarea></p>
+		<strong>'._('Long Description')._(':').'</strong>'.utils_requiredField().'<br />
+		<textarea required="required" name="description" rows="10" cols="60"></textarea></p>
 		<p>
 		<input type="submit" name="add_job" value="'._('Continue >>').'" />
 		</form></p>';
@@ -70,4 +71,3 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
 		exit_permission_denied('home');
 	}
 }
-?>
