@@ -1,10 +1,10 @@
 <?php
 /**
- * Help Wanted 
+ * Help Wanted
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2002-2004 (c) GForge Team
- * Copyright 2010 (c) Franck Villaume
+ * Copyright 2010-2014, Franck Villaume - TrivialDev
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -23,7 +23,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'people/people_utils.php';
 
@@ -33,7 +33,7 @@ if (!forge_get_config('use_people')) {
 
 $group_id = getIntFromRequest('group_id');
 
-if ($group_id && (user_ismember($group_id, 'A'))) {
+if ($group_id && (forge_check_perm('project_admin', $group_id))) {
 	$title = getStringFromRequest('title');
 	$description = getStringFromRequest('description');
 	$category_id = getIntFromRequest('category_id');
@@ -48,28 +48,28 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
 		/*
 			create a new job
 		*/
-		if (!$title || !$description || $category_id==100) {
+		if (!$title || !$description || $category_id == 'xzxz') {
 			exit_missing_param('',array(_('Title'),_('Description'),_('Category')),'admin');
 		}
 		if (!form_key_is_valid(getStringFromRequest('form_key'))) {
 			exit_form_double_submit('admin');
 		}
-		$result=db_query_params("INSERT INTO people_job (group_id,created_by,title,description,post_date,status_id,category_id) 
-VALUES ($1, $2, $3, $4, $5, $6, $7)", 
-array($group_id, user_getid(), htmlspecialchars($title), htmlspecialchars($description), time(), '1',$category_id));
+		$result=db_query_params("INSERT INTO people_job (group_id,created_by,title,description,post_date,status_id,category_id)
+					VALUES ($1, $2, $3, $4, $5, $6, $7)",
+					array($group_id, user_getid(), htmlspecialchars($title), htmlspecialchars($description), time(), '1',$category_id));
 		if (!$result || db_affected_rows($result) < 1) {
-			$error_msg .= sprintf(_('JOB insert FAILED: %s'),db_error());
+			$error_msg .= sprintf(_('Job insert failed: %s'),db_error());
 			form_release_key(getStringFromRequest("form_key"));
 		} else {
 			$job_id=db_insertid($result,'people_job','job_id');
-			$feedback .= _('JOB inserted successfully');
+			$feedback .= _('Job inserted successfully');
 		}
 
-	} else if (getStringFromRequest('update_job')) {
+	} elseif (getStringFromRequest('update_job')) {
 		/*
 			update the job's description, status, etc
 		*/
-		if (!$title || !$description || $category_id==100 || $status_id==100 || !$job_id) {
+		if (!$title || !$description || $category_id== 'xzxz' || $status_id== 'xzxz' || !$job_id) {
 			//required info
 			exit_missing_param('',array(_('Title'),_('Description'),_('Category'),_('Status'),_('Job')),'admin');
 		}
@@ -77,32 +77,33 @@ array($group_id, user_getid(), htmlspecialchars($title), htmlspecialchars($descr
 		$result=db_query_params("UPDATE people_job SET title=$1,description=$2,status_id=$3,category_id=$4 WHERE job_id=$5 AND group_id=$6",
 			array(htmlspecialchars($title), htmlspecialchars($description), $status_id, $category_id, $job_id, $group_id));
 		if (!$result || db_affected_rows($result) < 1) {
-			$error_msg = sprintf(_('JOB update FAILED : %s'),db_error());
+			$error_msg = sprintf(_('Job update failed: %s'),db_error());
 		} else {
-			$feedback = _('JOB updated successfully');
+			$feedback = _('Job updated successfully');
 		}
 
-} else if (getStringFromRequest('add_to_job_inventory')) {
+	} elseif (getStringFromRequest('add_to_job_inventory')) {
 		/*
 			add item to job inventory
 		*/
-		if ($skill_id == "xyxy" || $skill_level_id==100 || $skill_year_id==100  || !$job_id) {
+		if ($skill_id == 'xzxz' || $skill_level_id == 'xzxz' || $skill_year_id== 'xzxz'  || !$job_id) {
 			//required info
 			exit_missing_param('',array(_('Skill'),_('Skill Level'),_('Skill Year'),_('Job')),'admin');
 		}
 
 		if (people_verify_job_group($job_id,$group_id)) {
-			people_add_to_job_inventory($job_id,$skill_id,$skill_level_id,$skill_year_id);
-			$feedback .= _('JOB updated successfully');
+			if (people_add_to_job_inventory($job_id,$skill_id,$skill_level_id,$skill_year_id)) {;
+				$feedback .= _('Job updated successfully');
+			}
 		} else {
-			$error_msg .= _('JOB update failed - wrong project_id');
+			$error_msg .= _('Job update failed - wrong project_id');
 		}
 
-	} else if (getStringFromRequest('update_job_inventory')) {
+	} elseif (getStringFromRequest('update_job_inventory')) {
 		/*
 			Change Skill level, experience etc.
 		*/
-		if ($skill_level_id==100 || $skill_year_id==100  || !$job_id || !$job_inventory_id) {
+		if ($skill_level_id == 'xzxz' || $skill_year_id == 'xzxz'  || !$job_id || !$job_inventory_id) {
 			//required info
 			exit_missing_param('',array(_('Skill Level'),_('Skill Year'),_('Job'),_('Job Inventory')),'admin');
 		}
@@ -111,15 +112,15 @@ array($group_id, user_getid(), htmlspecialchars($title), htmlspecialchars($descr
 			$result=db_query_params("UPDATE people_job_inventory SET skill_level_id=$1,skill_year_id=$2 WHERE job_id=$3 AND job_inventory_id=$4",
 				array($skill_level_id, $skill_year_id, $job_id, $job_inventory_id));
 			if (!$result || db_affected_rows($result) < 1) {
-				$error_msg .= sprintf(_('JOB skill update FAILED: %s'), db_error());
+				$error_msg .= sprintf(_('Job skill update failed: %s'), db_error());
 			} else {
-				$feedback .= _('JOB skill updated successfully');
+				$feedback .= _('Job skill updated successfully');
 			}
 		} else {
-			$error_msg .= _('JOB skill update failed - wrong project_id');
+			$error_msg .= _('Job skill update failed - wrong project_id');
 		}
 
-	} else if (getStringFromRequest('delete_from_job_inventory')) {
+	} elseif (getStringFromRequest('delete_from_job_inventory')) {
 		/*
 			remove this skill from this job
 		*/
@@ -131,12 +132,12 @@ array($group_id, user_getid(), htmlspecialchars($title), htmlspecialchars($descr
 		if (people_verify_job_group($job_id,$group_id)) {
 			$result = db_query_params("DELETE FROM people_job_inventory WHERE job_id=$1 AND job_inventory_id=$2", array($job_id, $job_inventory_id));
 			if (!$result || db_affected_rows($result) < 1) {
-				$error_msg .= sprintf(_('JOB skill delete FAILED : %s'),db_error());
+				$error_msg .= sprintf(_('Job skill delete failed: %s'),db_error());
 			} else {
-				$feedback .= _('JOB skill deleted successfully');
+				$feedback .= _('Job skill deleted successfully');
 			}
 		} else {
-			$error_msg .= _('JOB skill delete failed - wrong project_id');
+			$error_msg .= _('Job skill delete failed - wrong project_id');
 		}
 
 	}
@@ -149,28 +150,28 @@ array($group_id, user_getid(), htmlspecialchars($title), htmlspecialchars($descr
 	//for security, include group_id
 	$result=db_query_params("SELECT * FROM people_job WHERE job_id=$1 AND group_id=$2", array($job_id, $group_id));
 	if (!$result || db_numrows($result) < 1) {
-		$error_msg .= sprintf(_('POSTING fetch FAILED: %s'),db_error());
+		$error_msg .= sprintf(_('Posting fetch failed: %s'),db_error());
 		echo '<h2>'._('No such posting for this project').'</h2>';
 	} else {
 
-		echo '<p>' 
+		echo '<p>'
         . _('Now you can edit/change the list of skills attached to this posting. Developers will be able to match their skills with your requirements.')
         .'</p><p>'
         . _('All postings are automatically closed after two weeks.').'
 		<form action="'.getStringFromServer('PHP_SELF').'" method="post">
 		<input type="hidden" name="group_id" value="'.$group_id.'" />
 		<input type="hidden" name="job_id" value="'.$job_id.'" />
-		<strong>'._('Category').'</strong><br />
+		<strong>'._('Category').'</strong>'.utils_requiredField().'<br />
 		'. people_job_category_box('category_id',db_result($result,0,'category_id')) .'
 		<p>
-		<strong>'._('Status').'</strong><br />
+		<strong>'._('Status').'</strong>'.utils_requiredField().'<br />
 		'. people_job_status_box('status_id',db_result($result,0,'status_id')) .'</p>
 		<p>
-		<strong>'._('Short Description').':</strong><br />
-		<input type="text" name="title" value="'. db_result($result,0,'title') .'" size="40" maxlength="60" /></p>
+		<strong>'._('Short Description')._(':').'</strong>'.utils_requiredField().'<br />
+		<input type="text" name="title" value="'. db_result($result,0,'title') .'" size="40" maxlength="60" required="required" /></p>
 		<p>
-		<strong>'._('Long Description').':</strong><br />
-		<textarea name="description" rows="10" cols="60">'. db_result($result,0,'description') .'</textarea></p>
+		<strong>'._('Long Description')._(':').'</strong>'.utils_requiredField().'<br />
+		<textarea name="description" rows="10" cols="60" required="required" >'. db_result($result,0,'description') .'</textarea></p>
 		<p>
 		<input type="submit" name="update_job" value="'._('Update Descriptions').'" /></p>
 		</form>';
@@ -198,5 +199,3 @@ array($group_id, user_getid(), htmlspecialchars($title), htmlspecialchars($descr
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
