@@ -1,6 +1,6 @@
 <?php
 /**
- * Help Wanted 
+ * Help Wanted
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2002-2004 (c) GForge Team
@@ -22,7 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'people/people_utils.php';
 
@@ -35,20 +35,14 @@ $job_id = getIntFromRequest('job_id');
 
 people_header(array('title'=>_('Help Wanted Latest Posts')));
 
-{
-        echo '<p>';
-
-	$result=db_query_params('SELECT people_job.group_id,people_job.job_id,groups.group_name,groups.unix_group_name,people_job.title,people_job.post_date,people_job_category.name AS category_name 
-FROM people_job,people_job_category,groups 
-WHERE people_job.group_id=groups.group_id 
-AND people_job.category_id=people_job_category.category_id 
-AND people_job.status_id=1 
-ORDER BY post_date DESC',
-array(),30);
-        echo people_show_job_list($result) . '</p>';
-
-}
+echo '<p>';
+$result=db_query_params('SELECT people_job.group_id,people_job.job_id,groups.group_name,groups.unix_group_name,people_job.title,people_job.post_date,people_job_category.name AS category_name
+			FROM people_job,people_job_category,groups
+			WHERE people_job.group_id=groups.group_id
+			AND people_job.category_id=people_job_category.category_id
+			AND people_job.status_id=1
+			ORDER BY post_date DESC',
+			array(),30);
+echo people_show_job_list($result) . '</p>';
 
 people_footer(array());
-
-?>
