@@ -1,6 +1,6 @@
 <?php
 /**
- * Help Wanted 
+ * Help Wanted
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2002-2004 (c) GForge Team
@@ -22,7 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'people/people_utils.php';
 require_once $gfwww.'project/admin/project_admin_utils.php';
@@ -35,22 +35,25 @@ $group_id = getIntFromRequest('group_id');
 $category_id = getIntFromRequest('category_id');
 
 if ($group_id) {
-	
-	project_admin_header(array());
+
+	if (forge_check_perm('project_admin', $group_id)) {
+		project_admin_header(array());
+	} else {
+		site_project_header(array('title' => _('Help Wanted System'), 'group' => $group_id, 'toptab' => 'summary'));
+	}
 
 	echo '
-	<p>'._('Here is a list of positions available for this project.').'</p>
-	<p>';
+	<p>'._('Here is a list of positions available for this project.').'</p>';
 
-	echo people_show_project_jobs($group_id) . '</p>';
+	echo people_show_project_jobs($group_id);
 
- } else if ($category_id && is_numeric($category_id)) {
+ } elseif ($category_id && is_numeric($category_id)) {
 
-	people_header(array('title'=>_('Help Wanted System')));
+	people_header(array('title'=>_('Help Wanted System')._(' as ').people_get_category_name($category_id)));
 
 	echo '
 		<p>'._('Click job titles for more detailed descriptions.').'</p>
-';
+	';
 	echo people_show_category_jobs($category_id);
 
 } else {
@@ -58,7 +61,7 @@ if ($group_id) {
 	people_header(array('title'=>_('Help Wanted System')));
 
 	print '<p>';
-	printf(_('The %1$s Project Help Wanted board is for non-commercial, project volunteer openings. Commercial use is prohibited.'), forge_get_config ('forge_name'));
+	printf(_('The %s Project Help Wanted board is for non-commercial, project volunteer openings. Commercial use is prohibited.'), forge_get_config ('forge_name'));
 	print '</p>';
 
 	print '<p>';
@@ -81,17 +84,15 @@ if ($group_id) {
 
 	echo '<h2>'._('Last posts').'</h2>';
 
-	$result=db_query_params('SELECT people_job.group_id,people_job.job_id,groups.group_name,groups.unix_group_name,people_job.title,people_job.post_date,people_job_category.name AS category_name 
-FROM people_job,people_job_category,groups 
-WHERE people_job.group_id=groups.group_id 
-AND people_job.category_id=people_job_category.category_id 
-AND people_job.status_id=1 
-ORDER BY post_date DESC', array(), 5);
+	$result=db_query_params('SELECT people_job.group_id,people_job.job_id,groups.group_name,groups.unix_group_name,people_job.title,people_job.post_date,people_job_category.name AS category_name
+				FROM people_job,people_job_category,groups
+				WHERE people_job.group_id=groups.group_id
+				AND people_job.category_id=people_job_category.category_id
+				AND people_job.status_id=1
+				ORDER BY post_date DESC', array(), 5);
         echo people_show_job_list($result);
         echo '<p><a href="helpwanted-latest.php">['._('more latest posts').']</a></p>';
 
 }
 
 people_footer(array());
-
-?>
