@@ -1,11 +1,12 @@
 <?php
 /**
- * Help Wanted 
+ * Help Wanted
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2002-2004 (c) GForge Team
  * Copyright 2010 (c) Franck Villaume
  * Copyright (C) 2010 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013-2014, Franck Villaume - TrivialDev
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -28,14 +29,14 @@ function people_header($params) {
 	global $group_id,$job_id,$HTML;
 
 	if ($group_id) {
-		$params['toptab']='people';
-		$params['group']=$group_id;
+		$params['toptab'] = 'people';
+		$params['group'] = $group_id;
 		site_project_header($params);
-	} else if (strstr($_SERVER['HTTP_REFERER'],'account')){
-		$params['toptab']='my';
+	} elseif (isset($_SERVER['HTTP_REFERER']) && strstr($_SERVER['HTTP_REFERER'], 'account')){
+		$params['toptab'] = 'my';
 		site_user_header($params);
 	} else {
-		echo $HTML->header($params);
+		$HTML->header($params);
 	}
 
 	if ($group_id && $job_id) {
@@ -48,41 +49,41 @@ function people_footer($params) {
 	$HTML->footer($params);
 }
 
-function people_skill_box($name='skill_id',$checked='xyxy') {
+function people_skill_box($name='skill_id',$checked='xzxz') {
 	global $PEOPLE_SKILL;
 	if (!$PEOPLE_SKILL) {
 		//will be used many times potentially on a single page
 		$PEOPLE_SKILL=db_query_params("SELECT * FROM people_skill ORDER BY name ASC", array());
 	}
-	return html_build_select_box($PEOPLE_SKILL,$name,'xzxz',false);
+	return html_build_select_box($PEOPLE_SKILL,$name,$checked,false);
 }
 
-function people_skill_level_box($name='skill_level_id',$checked='xyxy') {
+function people_skill_level_box($name='skill_level_id',$checked='xzxz') {
 	global $PEOPLE_SKILL_LEVEL;
 	if (!$PEOPLE_SKILL_LEVEL) {
 		//will be used many times potentially on a single page
 		$PEOPLE_SKILL_LEVEL=db_query_params("SELECT * FROM people_skill_level", array());
 	}
-	return html_build_select_box ($PEOPLE_SKILL_LEVEL,$name,$checked);
+	return html_build_select_box($PEOPLE_SKILL_LEVEL,$name,$checked, false);
 }
 
-function people_skill_year_box($name='skill_year_id',$checked='xyxy') {
+function people_skill_year_box($name='skill_year_id',$checked='xzxz') {
 	global $PEOPLE_SKILL_YEAR;
 	if (!$PEOPLE_SKILL_YEAR) {
 		//will be used many times potentially on a single page
 		$PEOPLE_SKILL_YEAR=db_query_params("SELECT * FROM people_skill_year", array());
 	}
-	return html_build_select_box ($PEOPLE_SKILL_YEAR,$name,$checked);
+	return html_build_select_box ($PEOPLE_SKILL_YEAR,$name,$checked, false);
 }
 
-function people_job_status_box($name='status_id',$checked='xyxy') {
+function people_job_status_box($name='status_id',$checked='xzxz') {
 	$result=db_query_params("SELECT * FROM people_job_status", array());
 	return html_build_select_box ($result,$name,$checked);
 }
 
-function people_job_category_box($name='category_id',$checked='xyxy') {
+function people_job_category_box($name='category_id',$checked='xzxz') {
 	$result=db_query_params("SELECT category_id,name FROM people_job_category WHERE private_flag=0", array());
-	return html_build_select_box ($result,$name,$checked);
+	return html_build_select_box($result, $name, $checked, false);
 }
 
 function people_add_to_skill_inventory($skill_id,$skill_level_id,$skill_year_id) {
@@ -90,36 +91,37 @@ function people_add_to_skill_inventory($skill_id,$skill_level_id,$skill_year_id)
 	global $error_msg;
 	if (session_loggedin()) {
 		// check required fields
-		if (!$skill_id || $skill_id == "xyxy") {
+		if (!$skill_id || $skill_id == 'xzxz') {
 			$feedback .= _('Must select a skill ID');
 		} else {
 		//check if they've already added this skill
-		$result=db_query_prams("SELECT * FROM people_skill_inventory WHERE user_id=$1 AND skill_id=$2", array(user_getid(), $skill_id));
+		$result=db_query_params("SELECT * FROM people_skill_inventory WHERE user_id=$1 AND skill_id=$2", array(user_getid(), $skill_id));
 		if (!$result || db_numrows($result) < 1) {
 			//skill not already in inventory
-			$result = db_query_params("INSERT INTO people_skill_inventory (user_id,skill_id,skill_level_id,skill_year_id) 
+			$result = db_query_params("INSERT INTO people_skill_inventory (user_id,skill_id,skill_level_id,skill_year_id)
 VALUES ($1, $2, $3, $4)", array(user_getid() ,$skill_id, $skill_level_id, $skill_year_id));
 			if (!$result || db_affected_rows($result) < 1) {
-				$error_msg .= sprintf(_('ERROR inserting into skill inventory: %s'),db_error());
+				$error_msg .= _('Error inserting into skill inventory: ');
+				$error_msg .= db_error();
 			} else {
-				$feedback .= _('Added to skill inventory ');
+				$feedback .= _('Added to skill inventory');
 			}
 		} else {
-			$error_msg .= _('ERROR - skill already in your inventory ');
+			$error_msg .= _('Error: skill already in your inventory');
 		}
 		}
 	} else {
-		echo '<p class="error">You must be logged in first</p>';
+		echo '<p class="error">'._('You must be logged in first').'</p>';
 	}
 }
 
 function people_show_skill_inventory($user_id) {
-	$result = db_query_params("SELECT people_skill.name AS skill_name, people_skill_level.name AS level_name, people_skill_year.name AS year_name 
-FROM people_skill_year,people_skill_level,people_skill,people_skill_inventory 
-WHERE people_skill_year.skill_year_id=people_skill_inventory.skill_year_id 
-AND people_skill_level.skill_level_id=people_skill_inventory.skill_level_id 
-AND people_skill.skill_id=people_skill_inventory.skill_id 
-AND people_skill_inventory.user_id=$1", array($user_id));
+	$result = db_query_params("SELECT people_skill.name AS skill_name, people_skill_level.name AS level_name, people_skill_year.name AS year_name
+				FROM people_skill_year,people_skill_level,people_skill,people_skill_inventory
+				WHERE people_skill_year.skill_year_id=people_skill_inventory.skill_year_id
+				AND people_skill_level.skill_level_id=people_skill_inventory.skill_level_id
+				AND people_skill.skill_id=people_skill_inventory.skill_id
+				AND people_skill_inventory.user_id=$1", array($user_id));
 
 	$title_arr=array();
 	$title_arr[]=_('Skill');
@@ -173,7 +175,7 @@ function people_edit_skill_inventory($user_id) {
 				<td>'. people_get_skill_name(db_result($result,$i,'skill_id')) .'</td>
 				<td>'. people_skill_level_box('skill_level_id',db_result($result,$i,'skill_level_id')). '</td>
 				<td>'. people_skill_year_box('skill_year_id',db_result($result,$i,'skill_year_id')). '</td>
-				<td nowrap="nowrap"><input type="submit" name="update_skill_inventory" value="'._('Update').'" /> &nbsp;
+				<td style="white-space:nowrap"><input type="submit" name="update_skill_inventory" value="'._('Update').'" /> &nbsp;
 					<input type="submit" name="delete_from_skill_inventory" value="'._('Delete').'" /></td>
 				</tr></form>';
 		}
@@ -198,38 +200,42 @@ function people_edit_skill_inventory($user_id) {
 
 
 function people_add_to_job_inventory($job_id,$skill_id,$skill_level_id,$skill_year_id) {
-	global $feedback;
+	global $feedback, $error_msg;
 	if (session_loggedin()) {
-		//check if they've already added this skill
+		// check if they've already added this job
 		$result=db_query_params('SELECT * FROM people_job_inventory WHERE job_id=$1 AND skill_id=$2', array($job_id, $skill_id));
 		if (!$result || db_numrows($result) < 1) {
-			//skill isn't already in this inventory
-			$result=db_query_params('INSERT INTO people_job_inventory (job_id,skill_id,skill_level_id,skill_year_id) 
-VALUES ($1, $2, $3, $4)', array($job_id, $skill_id, $skill_level_id, $skill_year_id));
+			// job is not yet in this inventory
+			$result=db_query_params('INSERT INTO people_job_inventory (job_id,skill_id,skill_level_id,skill_year_id)
+							VALUES ($1, $2, $3, $4)',
+							array($job_id, $skill_id, $skill_level_id, $skill_year_id));
 			if (!$result || db_affected_rows($result) < 1) {
-				$feedback .= _('ERROR inserting into skill inventory');
-				echo db_error();
+				$error_msg .= _('Error inserting into job inventory: ');
+				$error_msg .= db_error();
+				return false;
 			} else {
-				$feedback .= _('Added to skill inventory');
+				$feedback .= _('Added to job inventory');
+				return true;
 			}
 		} else {
-			$feedback .= _('ERROR - skill already in your inventory');
+			$error_msg .= _('Error: Skill already in your inventory.');
+			return false;
 		}
 
 	} else {
-		echo '<p class="error">You must be logged in first</p>';
+		echo '<p class="error">'._('You must be logged in first').'</p>';
+		return false;
 	}
 }
 
 function people_show_job_inventory($job_id) {
-	$result=db_query_params('SELECT people_skill.name AS skill_name, people_skill_level.name AS level_name, people_skill_year.name AS year_name 
-FROM people_skill_year,people_skill_level,people_skill,people_job_inventory 
-WHERE people_skill_year.skill_year_id=people_job_inventory.skill_year_id 
-AND people_skill_level.skill_level_id=people_job_inventory.skill_level_id 
-AND people_skill.skill_id=people_job_inventory.skill_id 
-AND people_job_inventory.job_id=$1', array($job_id));
+	$result=db_query_params('SELECT people_skill.name AS skill_name, people_skill_level.name AS level_name, people_skill_year.name AS year_name
+				FROM people_skill_year,people_skill_level,people_skill,people_job_inventory
+				WHERE people_skill_year.skill_year_id=people_job_inventory.skill_year_id
+				AND people_skill_level.skill_level_id=people_job_inventory.skill_level_id
+				AND people_skill.skill_id=people_job_inventory.skill_id
+				AND people_job_inventory.job_id=$1', array($job_id));
 
-	$title_arr=array();
 	$title_arr=array();
 	$title_arr[]=_('Skill');
 	$title_arr[]=_('Level');
@@ -278,7 +284,7 @@ function people_get_skill_name($skill_id) {
 function people_get_category_name($category_id) {
 	$result=db_query_params('SELECT name FROM people_job_category WHERE category_id=$1', array($category_id));
 	if (!$result || db_numrows($result) < 1) {
-		return 'Invalid ID';
+		return _('Invalid ID');
 	} else {
 		return db_result($result,0,'name');
 	}
@@ -293,7 +299,7 @@ function people_edit_job_inventory($job_id,$group_id) {
 	$result=db_query_params('SELECT * FROM people_job_inventory WHERE job_id=$1', array($job_id));
 
 	$title_arr=array();
-	$title_arr[]=_('Skill').utils_requiredField();
+	$title_arr[]=_('Skill');
 	$title_arr[]=_('Level').utils_requiredField();
 	$title_arr[]=_('Experience').utils_requiredField();
 	$title_arr[]=_('Action');
@@ -346,26 +352,51 @@ function people_show_category_table() {
 	//show a list of categories in a table
 	//provide links to drill into a detail page that shows these categories
 
-	$title_arr=array();
-	$title_arr[]=_('Category');;
+	$title_arr = array();
+	$title_arr[] = _('Category');
 
-	$return = $GLOBALS['HTML']->listTableTop ($title_arr);
+	$result= db_query_params('SELECT pjc.category_id, pjc.name, COUNT(pj.category_id) AS total, pj.group_id
+				FROM people_job_category pjc LEFT JOIN people_job pj
+				ON pjc.category_id=pj.category_id
+				WHERE pjc.private_flag=0
+				AND (pj.status_id=1 OR pj.status_id IS NULL)
+				GROUP BY pjc.category_id, pjc.name, pj.group_id', array());
 
-	$result= db_query_params('SELECT pjc.category_id, pjc.name, COUNT(pj.category_id) AS total 
-FROM people_job_category pjc LEFT JOIN people_job pj 
-ON pjc.category_id=pj.category_id 
-WHERE pjc.private_flag=0 
-AND (pj.status_id=1 OR pj.status_id IS NULL) 
-GROUP BY pjc.category_id, pjc.name', array());
-
-	$rows=db_numrows($result);
-	if (!$result || $rows < 1) {
-		$return .= '<tr><td><h2>'._('No Categories Found').'</h2></td></tr>';
+	$categories = array();
+	$i = 0;
+	while ($arr = db_fetch_array($result)) {
+		$added = 0;
+		if (empty($arr['group_id']) || forge_check_perm('project_read', $arr['group_id'])) {
+			$categories[$i] = $arr;
+			$added = 1;
+		}
+		if ($added && ((count($categories) - 1) > 0)) {
+			for ($j = 0; $j < (count($categories) - 1); $j++) {
+				$found = 0;
+				if ( $categories[$j]['category_id'] == $categories[$i]['category_id'] ) {
+					$categories[$j]['total'] += $categories[$i]['total'];
+					$found = 1;
+					break;
+				}
+			}
+			if ($found) {
+				array_pop($categories);
+				$added = 0;
+				$i--;
+			}
+		}
+		if ($added) {
+			$i++;
+		}
+	}
+	if (count($categories) < 1) {
+		$return = '<p class="warning" >'._('No categories found.').'</p>';
 	} else {
-		for ($i=0; $i<$rows; $i++) {
-			echo db_error();
-			$return .= '<tr '. $GLOBALS['HTML']->boxGetAltRowStyle($i) .'><td>'
-			.util_make_link ('/people/?category_id='.  db_result($result,$i,'category_id'), db_result($result,$i,'name')) .' ('. db_result($result,$i,'total') .')</td></tr>';
+		$return = $GLOBALS['HTML']->listTableTop($title_arr);
+		for ($i = 0; $i< count($categories); $i++) {
+			$return .= '<tr '. $GLOBALS['HTML']->boxGetAltRowStyle($i) .'>
+				<td>'.util_make_link('/people/?category_id='.$categories[$i]['category_id'], $categories[$i]['name']).' ('.$categories[$i]['total'].')</td>
+				</tr>';
 		}
 	}
 	$return .= $GLOBALS['HTML']->listTableBottom();
@@ -374,24 +405,24 @@ GROUP BY pjc.category_id, pjc.name', array());
 
 function people_show_project_jobs($group_id) {
 	//show open jobs for this project
-	$result = db_query_params('SELECT people_job.group_id,people_job.job_id,groups.group_name,groups.unix_group_name,people_job.title,people_job.post_date,people_job_category.name AS category_name 
-FROM people_job,people_job_category,groups 
-WHERE people_job.group_id=$1
-AND people_job.group_id=groups.group_id 
-AND people_job.category_id=people_job_category.category_id 
-AND people_job.status_id=1 ORDER BY post_date DESC', array($group_id));
+	$result = db_query_params('SELECT people_job.group_id,people_job.job_id,groups.group_name,groups.unix_group_name,people_job.title,people_job.post_date,people_job_category.name AS category_name
+				FROM people_job,people_job_category,groups
+				WHERE people_job.group_id=$1
+				AND people_job.group_id=groups.group_id
+				AND people_job.category_id=people_job_category.category_id
+				AND people_job.status_id=1 ORDER BY post_date DESC', array($group_id));
 
 	return people_show_job_list($result);
 }
 
 function people_show_category_jobs($category_id) {
 	//show open jobs for this category
-	$result=db_query_params('SELECT people_job.group_id,people_job.job_id,groups.unix_group_name,groups.group_name,people_job.title,people_job.post_date,people_job_category.name AS category_name 
-FROM people_job,people_job_category,groups 
-WHERE people_job.category_id=$1
-AND people_job.group_id=groups.group_id 
-AND people_job.category_id=people_job_category.category_id 
-AND people_job.status_id=1 ORDER BY post_date DESC', array($category_id));
+	$result=db_query_params('SELECT people_job.group_id,people_job.job_id,groups.unix_group_name,groups.group_name,people_job.title,people_job.post_date,people_job_category.name AS category_name
+				FROM people_job,people_job_category,groups
+				WHERE people_job.category_id=$1
+				AND people_job.group_id=groups.group_id
+				AND people_job.category_id=people_job_category.category_id
+				AND people_job.status_id=1 ORDER BY post_date DESC', array($category_id));
 
 	return people_show_job_list($result);
 }
@@ -401,31 +432,34 @@ function people_show_job_list($result) {
 
 	//query must contain 'group_id', 'job_id', 'title', 'category_name' and 'status_name'
 
-	$title_arr=array();
-	$title_arr[]=_('Title');
-	$title_arr[]=_('Category');
-	$title_arr[]=_('Date Opened');
-	$title_arr[]= sprintf(_('%1$s project'), forge_get_config ('forge_name'));
+	$title_arr = array();
+	$title_arr[] = _('Title');
+	$title_arr[] = _('Category');
+	$title_arr[] = _('Date Opened');
+	$title_arr[] = sprintf(_('%s project'), forge_get_config('forge_name'));
 
-	$return = $GLOBALS['HTML']->listTableTop ($title_arr);
-
-	$rows=db_numrows($result);
-	if (!isset($i)){$i=1;}
-	if ($rows < 1) {
-		$return .= '<tr '. $GLOBALS['HTML']->boxGetAltRowStyle($i) .'><td class="warning" colspan="4">'._('None Found'). db_error() .'</td></tr>';
-	} else {
-		for ($i=0; $i < $rows; $i++) {
-			$return .= '
-				<tr '. $GLOBALS['HTML']->boxGetAltRowStyle($i) .
-					'><td>'.util_make_link ('/people/viewjob.php?group_id='. db_result($result,$i,'group_id') .'&amp;job_id='.  db_result($result,$i,'job_id'), db_result($result,$i,'title')) .'</td><td>'.
-					db_result($result,$i,'category_name') .'</td><td>'.
-					date(_('Y-m-d H:i'),db_result($result,$i,'post_date')) .
-					'</td><td>'.util_make_link_g (strtolower(db_result($result,$i,'unix_group_name')),db_result($result,$i,'group_id'),db_result($result,$i,'group_name')) .'</td></tr>';
+	$projects = array();
+	while ($arr = db_fetch_array($result)) {
+		if (forge_check_perm('project_read', $arr['group_id'])) {
+			$projects[] = $arr;
 		}
 	}
 
-	$return .= $GLOBALS['HTML']->listTableBottom();
-
+	if (count($projects) < 1) {
+		$return = '<p class="warning" >'._('None Found').'</p>';
+	} else {
+		$return = $GLOBALS['HTML']->listTableTop ($title_arr);
+		for ($i = 0; $i < count($projects); $i++) {
+			$return .= '
+				<tr '. $GLOBALS['HTML']->boxGetAltRowStyle($i) . '>
+					<td>'.util_make_link('/people/viewjob.php?group_id='.$projects[$i]['group_id'].'&amp;job_id='.$projects[$i]['job_id'], $projects[$i]['title']) .'</td>
+					<td>'.$projects[$i]['category_name'].'</td>
+					<td>'.date(_('Y-m-d H:i'), $projects[$i]['post_date']).'</td>
+					<td>'.util_make_link_g(strtolower($projects[$i]['unix_group_name']), $projects[$i]['group_id'], $projects[$i]['group_name']).'</td>
+				</tr>';
+		}
+		$return .= $GLOBALS['HTML']->listTableBottom();
+	}
 	return $return;
 }
 
@@ -433,5 +467,3 @@ function people_show_job_list($result) {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
