@@ -5,7 +5,8 @@
  * Copyright 1999/2000, Sourceforge.net Tim Perdue
  * Copyright 2002 GForge, LLC, Tim Perdue
  * Copyright 2010, FusionForge Team
- * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright (C) 2011-2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013-2014, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -24,7 +25,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'pm/include/ProjectGroupHTML.class.php';
 require_once $gfcommon.'pm/ProjectGroupFactory.class.php';
@@ -67,22 +68,21 @@ if (getStringFromRequest('post_changes')) {
 	if (getStringFromRequest('addproject')) {
 		$project_name = getStringFromRequest('project_name');
 		$description = getStringFromRequest('description');
-		$is_public = getStringFromRequest('is_public');
 		$send_all_posts_to = getStringFromRequest('send_all_posts_to');
 
 		/*
 			Add new subproject
 		*/
 		session_require_perm ('pm_admin', $group_id) ;
-		if (!$pg->create($project_name,$description,$is_public,$send_all_posts_to)) {
+		if (!$pg->create($project_name,$description,$send_all_posts_to)) {
 			exit_error($pg->getErrorMessage(),'pm');
 		} else {
 			$feedback .= _('Subproject Inserted');
-			$warning_msg .= _("Please configure also the roles (by default, it's 'No Access')");
-			$g->normalizeAllRoles () ;
+			$feedback .= '<br />';
+			$feedback .= _("Please configure also the roles (by default, it's “No Access”)");
 		}
 
-	} else if ($add_cat) {
+	} elseif ($add_cat) {
 		$name = getStringFromRequest('name');
 
 		/*
@@ -95,13 +95,13 @@ if (getStringFromRequest('post_changes')) {
 			exit_error(_('Unable to create ProjectCategory Object'),'pm');
 		} else {
 			if (!$pc->create($name)) {
-				exit_error(_('Error inserting: ').$pc->getErrorMessage(),'pm');
+				$error_msg .= _('Insert Error')._(': ').$pc->getErrorMessage();
 			} else {
 				$feedback .= _('Category Inserted');
 			}
 		}
 
-	} else if ($update_cat) {
+	} elseif ($update_cat) {
 		$id = getIntFromRequest('id');
 		$name = getStringFromRequest('name');
 
@@ -117,7 +117,7 @@ if (getStringFromRequest('post_changes')) {
 			exit_error($pc->getErrorMessage(),'pm');
 		} else {
 			if (!$pc->update($name)) {
-				exit_error(_('Error updating: '.$pc->getErrorMessage()),'pm');
+				exit_error(_('Update failed')._(': ').$pc->getErrorMessage(),'pm');
 			} else {
 				$feedback .= _('Category Updated');
 				$update_cat=false;
@@ -125,7 +125,7 @@ if (getStringFromRequest('post_changes')) {
 			}
 		}
 
-	} else if (getStringFromRequest('update_pg')) {
+	} elseif (getStringFromRequest('update_pg')) {
 		$project_name = getStringFromRequest('project_name');
 		$description = getStringFromRequest('description');
 		$send_all_posts_to = getStringFromRequest('send_all_posts_to');
@@ -138,14 +138,13 @@ if (getStringFromRequest('post_changes')) {
 		if (!$pg->update($project_name,$description,$send_all_posts_to)) {
 			exit_error($pg->getErrorMessage(),'pm');
 		} else {
-			$feedback .= _('Updated successfully');
+			$feedback .= _('Subproject Updated successfully');
 		}
 
-	} else if ($delete) {
+	} elseif ($delete) {
 		$sure = getStringFromRequest('sure');
 		$really_sure = getStringFromRequest('really_sure');
 
-	
 		/*
 			Delete a subproject
 		*/
@@ -154,7 +153,7 @@ if (getStringFromRequest('post_changes')) {
 		if (!$pg->delete(getStringFromRequest('sure'),getStringFromRequest('really_sure'))) {
 			exit_error($pg->getErrorMessage(),'pm');
 		} else {
-			$feedback .= _('Successfully Deleted');
+			$feedback .= _('Subproject successfully deleted.');
 			$group_project_id=0;
 			$delete=false;
 		}
@@ -178,13 +177,12 @@ if ($add_cat && $group_project_id) {
 	session_require_perm ('pm', $pg->getID(), 'manager') ;
 
 	$title = sprintf(_('Add Categories to: %s'), $pg->getName());
-	pm_header(array ('title'=>$title));
+	pm_header(array('title'=>$title));
 
 	/*
 		List of possible categories for this ArtifactType
 	*/
 	$result=$pg->getCategories();
-	echo "<p />";
 	$rows=db_numrows($result);
 	if ($result && $rows > 0) {
 		$title_arr=array();
@@ -204,20 +202,21 @@ if ($add_cat && $group_project_id) {
 		echo $GLOBALS['HTML']->listTableBottom();
 
 	} else {
-		echo "\n<p class=\"warning_msg\">"._('No categories defined')."</p>";
+		echo "\n<p class=\"information\">"._('No categories defined')."</p>";
 	}
 
 	?>
-	<p />
 	<form action="<?php echo getStringFromServer('PHP_SELF').'?group_id='.$group_id; ?>" method="post">
+	<p>
 	<input type="hidden" name="add_cat" value="y" />
 	<input type="hidden" name="group_project_id" value="<?php echo $pg->getID(); ?>" />
-	<strong><?php echo _('Category Name') ?>:</strong><br />
-	<input type="text" name="name" value="" size="15" maxlength="30" /><br />
-	<p />
-	<span class="important"><?php echo _('Once you add a category, it cannot be deleted') ?></span>
-	<p />
-	<input type="submit" name="post_changes" value="<?php echo _('Submit') ?>" />
+	<label for="name">
+		<strong><?php echo _('Category Name') . _(':'); ?></strong>
+	</label>
+	<input id="name" required="required" type="text" name="name" value="" />
+	</p>
+	<p class="important"><?php echo _('Once you add a category, it cannot be deleted') ?></p>
+	<p><input type="submit" name="post_changes" value="<?php echo _('Submit') ?>" /></p>
 	</form>
 	<?php
 
@@ -249,20 +248,20 @@ if ($add_cat && $group_project_id) {
 	} elseif ($ac->isError()) {
 		exit_error($ac->getErrorMessage(),'pm');
 	} else {
-	    pm_header(array ('title'=>$title));
+		pm_header(array ('title'=>$title));
 		?>
-		<p />
-		<form action="<?php echo getStringFromServer('PHP_SELF').'?group_id='.$group_id; ?>" method="post" />
+		<p class="information"><?php echo _('It is not recommended that you change the category name because other things are dependent upon it. When you change the category name, all related items will be changed to the new name.')?></p>
+		<form action="<?php echo getStringFromServer('PHP_SELF').'?group_id='.$group_id; ?>" method="post">
+		<p>
 		<input type="hidden" name="update_cat" value="y" />
 		<input type="hidden" name="id" value="<?php echo $ac->getID(); ?>" />
 		<input type="hidden" name="group_project_id" value="<?php echo $pg->getID(); ?>" />
-		<p />
-		<strong><?php echo _('Category Name')?>:</strong><br />
-		<input type="text" name="name" value="<?php echo $ac->getName(); ?>" />
-		<p />
-		<div class="warning"><?php echo _('It is not recommended that you change the category name because other things are dependent upon it. When you change the category name, all related items will be changed to the new name.')?></div>
-		<p />
-		<input type="submit" name="post_changes" value="<?php echo _('Submit') ?>" />
+		<label for="name">
+			<strong><?php echo _('Category Name') . _(': '); ?></strong>
+		</label>
+		<input id="name" required="required" type="text" name="name" value="<?php echo $ac->getName(); ?>" />
+		</p>
+		<p><input type="submit" name="post_changes" value="<?php echo _('Submit') ?>" /></p>
 		</form>
 		<?php
 	}
@@ -275,36 +274,30 @@ if ($add_cat && $group_project_id) {
 	*/
 	session_require_perm ('pm_admin', $group_id) ;
 
-	pm_header(array ('title'=>_('Add a new subproject')));
+	pm_header(array('title'=>_('Add a new subproject')));
 
 	?>
 	<p><?php echo _('Add a new subproject to the Tasks. <strong>This is different than adding a task to a subproject.</strong>') ?></p>
 
-	<p />
 	<form action="<?php echo getStringFromServer('PHP_SELF')."?group_id=$group_id"; ?>" method="post">
+	<p>
 	<input type="hidden" name="addproject" value="y" />
 	<input type="hidden" name="post_changes" value="y" />
-	<p />
-	<strong><?php echo _('Is Public?')?></strong><br />
-	<input type="radio" name="is_public" value="1" checked="checked" /><?php echo _('Yes') ?><br />
-	<input type="radio" name="is_public" value="0" /><?php echo _('No') ?><p />
-	<p />
 	<strong><?php echo _('New Subproject Name').utils_requiredField()?></strong>
 	<br />
-	<input type="text" name="project_name" value="" size="15" maxlength="30" />
+	<input type="text" name="project_name" value="" size="15" maxlength="30" required="required" pattern=".{5,}" title="<?php echo _('At least 5 characters') ?>" />
 	<p />
 	<strong><?php echo _('Description').utils_requiredField() ?></strong><br />
-	<input type="text" name="description" value="" size="40" maxlength="80" />
-	<p />
-	<strong><?php echo _('Send All Updates To')?>:</strong><br />
-	<input type="text" name="send_all_posts_to" value="" size="40" maxlength="80" /><br />
+	<input type="text" name="description" value="" size="40" maxlength="80" required="required" pattern=".{10,}" title="<?php echo _('At least 10 characters') ?>" />
 	<p />
+	<strong><?php echo _('Send All Updates To')._(':'); ?></strong><br />
+	<input type="text" name="send_all_posts_to" value="" size="40" maxlength="80" /><p />
 	<input type="submit" name="submit" value="<?php echo _('Submit') ?>" />
 	</form>
 	<?php
 	pm_footer(array());
 
-} else if (getStringFromRequest('update_pg') && $group_project_id) {
+} elseif (getStringFromRequest('update_pg') && $group_project_id) {
 
 	$pg = new ProjectGroup($g,$group_project_id);
 	if (!$pg || !is_object($pg)) {
@@ -312,64 +305,60 @@ if ($add_cat && $group_project_id) {
 	} elseif ($pg->isError()) {
 		exit_error($pg->getErrorMessage(),'pm');
 	}
-
 	session_require_perm ('pm', $pg->getID(), 'manager') ;
 
 	pm_header(array('title'=>_('Change Tasks Status')));
 
 	?>
 	<p><?php echo _('You can modify an existing subproject using this form. Please note that private subprojects can still be viewed by members of your project, but not the general public.') ?></p>
-	<p />
 
 	<form action="<?php echo getStringFromServer('PHP_SELF').'?group_id='.$group_id; ?>" method="post">
 	<input type="hidden" name="post_changes" value="y" />
 	<input type="hidden" name="update_pg" value="y" />
 	<input type="hidden" name="group_project_id" value="<?php echo $pg->getID(); ?>" />
-	<table border="0">
-<!--	<tr>
-		<td>
-			<strong><?php echo _('Is Public?')?></strong><br />
-			<input type="radio" name="is_public" value="1"<?php echo (($pg->isPublic()=='1')?' checked="checked"':''); ?> /> <?php echo _('Yes') ?><br />
-			<input type="radio" name="is_public" value="0"<?php echo (($pg->isPublic()=='0')?' checked="checked"':''); ?> /> <?php echo _('No') ?><br />
-			<input type="radio" name="is_public" value="9"<?php echo (($pg->isPublic()=='9')?' checked="checked"':''); ?> /> <?php echo _('Deleted')?><br />
-		</td>
-	</tr> -->
+	<table class="infotable">
 	<tr>
-		<td><strong><?php echo _('Subproject Name').utils_requiredField() ?>:</strong><br />
-			<input type="text" name="project_name" value="<?php echo $pg->getName() ?>" />
+		<td>
+		<label for="project_name">
+			<?php echo _('Subproject Name')._(':'); ?>
+		</label>
+		</td>
+		<td>
+			<input id="project_name" type="text" name="project_name" value="<?php echo $pg->getName() ?>" required="required" pattern=".{5,}" title="<?php echo _('At least 5 characters') ?>" />
 		</td>
 	</tr>
 	<tr>
 		<td>
-			<strong><?php echo _('Description').utils_requiredField() ?>:</strong><br />
-			<input type="text" name="description" value="<?php echo $pg->getDescription(); ?>" size="40" maxlength="80" /><br />
+		<label for="description">
+			<?php echo _('Description')._(':'); ?>
+		</label>
+		</td>
+		<td>
+			<input id="description" type="text" name="description" value="<?php echo $pg->getDescription(); ?>" size="40" maxlength="80" required="required" pattern=".{10,}" title="<?php echo _('At least 10 characters') ?>" />
 		</td>
 	</tr>
 	<tr>
 		<td>
-			<strong><?php echo _('Send All Updates To')?>:</strong><br />
-			<input type="text" name="send_all_posts_to" value="<?php echo $pg->getSendAllPostsTo(); ?>" size="40" maxlength="80" /><br />
+		<label for="send_all_posts_to">
+			<?php echo _('Send All Updates To')._(':'); ?>
+		</label>
+		</td>
+		<td>
+			<input id="send_all_posts_to" type="text" name="send_all_posts_to" value="<?php echo $pg->getSendAllPostsTo(); ?>" size="40" maxlength="80" />
 		</td>
 	</tr>
 	<tr>
-		<td>
-			<strong><a href="<?php echo getStringFromServer('PHP_SELF')."?group_id=$group_id&amp;add_cat=1&amp;group_project_id=".$pg->getID(); ?>"><?php echo _('Add/Edit Categories')?></a></strong><br />
-			<strong><a href="<?php echo getStringFromServer('PHP_SELF')."?group_id=$group_id&amp;delete=1&amp;group_project_id=".$pg->getID(); ?>"><?php echo _('Permanently delete this subproject and all its data.')?></a></strong><br />
-		</td>
-	</tr>
-	<tr>
-		<td>
+		<td colspan="2">
 			<input type="submit" name="submit" value="<?php echo _('Update') ?>" />
 		</td>
 	</tr>
 	</table>
 	</form>
 	<?php
-
+	echo '<p>'.util_make_link ('/pm/admin/?group_id='.$group_id.'&amp;add_cat=1&amp;group_project_id='.$group_project_id,_('Category Administration')).'</p>';
 	pm_footer(array());
 
-} else if ($delete && $group_project_id) {
-
+} elseif ($delete && $group_project_id) {
 
 	$pg = new ProjectGroup($g,$group_project_id);
 	if (!$pg || !is_object($pg)) {
@@ -380,18 +369,29 @@ if ($add_cat && $group_project_id) {
 
 	session_require_perm ('pm', $pg->getID(), 'manager') ;
 
-	pm_header(array('title'=>_('Delete')));
+	pm_header(array('title'=>_('Permanently delete this subproject and all its data')));
 
 	?>
 	<form action="<?php echo getStringFromServer('PHP_SELF').'?group_id='.$group_id.'&amp;group_project_id='.$group_project_id; ?>" method="post">
-	<input type="hidden" name="post_changes" value="y" />
-	<input type="hidden" name="delete" value="y" /><br />
-	<?php echo _('You are about to permanently and irretrievably delete this subproject and all its related data!'); ?>
 	<p>
-	<input type="checkbox" name="sure" value="1" /><?php echo _('I\'m Sure') ?><br />
-	<input type="checkbox" name="really_sure" value="1" /><?php echo _('I\'m Really Sure'); ?>
-	</p><p>
-	<input type="submit" name="post_changes" value="<?php echo _('Delete') ?>" />
+	<input type="hidden" name="post_changes" value="y" />
+	<input type="hidden" name="delete" value="y" />
+	<?php echo _('You are about to permanently and irretrievably delete this subproject and all its related data!'); ?>
+	</p>
+	<p>
+		<input id="sure" type="checkbox" name="sure" value="1" />
+		<label for="sure">
+			<?php echo _('I am Sure') ?>
+		</label>
+	</p>
+	<p>
+		<input id="really_sure" type="checkbox" name="really_sure" value="1" />
+		<label for="really_sure">
+			<?php echo _('I am Really Sure'); ?>
+		</label>
+	</p>
+	<p>
+		<input type="submit" name="post_changes" value="<?php echo _('Permanently delete this subproject and all its data') ?>" />
 	</p>
 	</form>
 	<?php
@@ -427,8 +427,8 @@ if ($add_cat && $group_project_id) {
 	$pg_arr = $pgf->getProjectGroups();
 
 	if (count($pg_arr) < 1 || $pg_arr == false) {
-		echo '<h2>' . _('No Subprojects Found in this Project') . '</h2>';
-		echo '<p>' . _('You may add new Subprojects using the "Add a Subproject" link above.') . '</p>';
+		echo '<p class="information">' . _('No Subprojects Found in this Project') . '</p>';
+		echo '<p>' . _('You may add new Subprojects using the “Add a Subproject” link above.') . '</p>';
 		echo db_error();
 	} else {
 		for ($i=0; $i<count($pg_arr); $i++) {
@@ -439,5 +439,3 @@ if ($add_cat && $group_project_id) {
 
 	pm_footer(array());
 }
-
-?>
