@@ -30,7 +30,7 @@
  * @todo display holidays.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'pm/include/ProjectGroupHTML.class.php';
 
@@ -56,7 +56,7 @@ if ($day && ($day < 1 || $day > 31)) {
 
 if ($year && isset($month) && isset($day)) {
 	if (!checkdate($month, $day, $year)) {
-		exit_error(_('Invalid date').sprintf(_('Date not valid'), "$year-$month-$day"),'pm');
+		exit_error(_('Invalid date')._(': ')."$year-$month-$day",'pm');
 	}
 }
 
@@ -69,7 +69,6 @@ if (!$type) {
 	$type = 'threemonth';
 }
 
-
 $today = getdate(time());
 
 if (!$year) {
@@ -84,7 +83,6 @@ if (!$day) {
 	$day = $today['mday'];
 }
 
-
 $months = array(1 => _('January'), _('February'), _('March'), _('April'), _('May'), _('June'),
 		_('July'), _('August'), _('September'), _('October'), _('November'), _('December'));
 
@@ -130,15 +128,15 @@ pm_header(array('title'=>_('Calendar'),'group'=>$group_id));
  * Create link to a task.
  * This returns a string that is a link to a particular task.
  *
- * @author    Ryan T. Sammartino <ryants at shaw dot ca>
- * @param     $task  the task to make a link for.
- * @param     $type  either 'begin' for beginning of a task or 'end' for
- *                   end of a task.
- * @date      2002-01-04
+ * @author  Ryan T. Sammartino <ryants at shaw dot ca>
+ * @param   object	$task  the task to make a link for.
+ * @param   string	$type  either 'begin' for beginning of a task or 'end' for end of a task.
+ * @return	string
+ * @date    2002-01-04
  *
  */
 function make_task_link($task, $type) {
-	global $HTML, $group_id, $group_project_id;
+	global $group_id, $group_project_id;
 	return '<a title="'. util_html_secure(sprintf(_('Task summary: %s'), $task->getSummary()))
 		. '" href="'.util_make_url ('/pm/task.php?func=detailtask&amp;project_task_id=' . $task->getID() . '&amp;group_id=' . $group_id . '&amp;group_project_id=' .$group_project_id)
 		. '">' . ($type == 'begin' ?
@@ -147,23 +145,21 @@ function make_task_link($task, $type) {
 		. '</a>';
 }
 
-
 /**
  * Display one month.
  * This displays one month.  m may be less than 0 and greater than 12: display_month
  * uses mktime() to readjust it and the year in such cases.
  *
  * @author    Ryan T. Sammartino <ryants at shaw dot ca>
- * @param     m  month
- * @param     y  year
+ * @param     int	$m	month
+ * @param     int	$y	year
  * @date      2002-12-29
  *
  */
 function display_month($m, $y) {
-	global $months, $today, $month, $day, $year, $HTML,
-		$pt_arr, $group_id, $group_project_id;
+	global $today, $month, $day, $year, $pt_arr;
 	$dow = array(_('Sunday'), _('Monday'), _('Tuesday'), _('Wednesday'), _('Thursday'), _('Friday'), _('Saturday'));
-	
+
 	$tstamp = mktime(0, 0, 0, $m + 1, 0, $y) ;
 
 	$date = getdate($tstamp);
@@ -175,7 +171,7 @@ function display_month($m, $y) {
 	$m = $date['mon'];
 	$y = $date['year'];
 ?>
-	<table align="center" cellpadding="1" cellspacing="1" border="1" width="100%">
+	<table class="centered" cellpadding="1" cellspacing="1" border="1" width="100%">
 		<tr>
 		 <th colspan="7"><?php echo date (_('F Y'), $tstamp); ?></th>
 		</tr>
@@ -225,7 +221,7 @@ function display_month($m, $y) {
 					}
 				}
 				if ($cell_contents == '') {
-					$cell_contents = '<br /><br /><br />';
+					$cell_contents = '<br />';
 				}
 				print "$cell_contents</td>\n";
 			} else {
@@ -249,7 +245,7 @@ function display_month($m, $y) {
 
 ?>
 	<form action="/pm/calendar.php" method="get">
-	<table width="100%">
+	<table class="fullwidth">
 		<tr>
 			<td><?php echo _('Period'); ?><br />
 				<select name="type">
@@ -303,7 +299,7 @@ function display_month($m, $y) {
 ?>
 
 	</form>
-	<table width="100%">
+	<table class="fullwidth">
 		<tr>
 			<td width="20px" class="selected"></td>
 			<td><?php echo _('today\'s date') ?></td>
@@ -341,5 +337,3 @@ pm_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
