@@ -23,25 +23,33 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-pm_header(array('title'=>_('Delete a Task'),'group_project_id'=>$group_project_id));
-
+pm_header(array('title'=>sprintf(_("Delete Task [T%s]"), $project_task_id),
+                'group_project_id'=>$group_project_id));
 ?>
 
 <form action="<?php echo getStringFromServer('PHP_SELF')."?group_id=$group_id&amp;group_project_id=$group_project_id"; ?>" method="post">
 <input type="hidden" name="func" value="postdeletetask" />
 <input type="hidden" name="project_task_id" value="<?php echo $project_task_id; ?>" />
 
-<table border="0" align="center">
+<table class="centered">
 
 	<tr>
-		<td ><span class="veryimportant"><?php echo _('Are you sure you want to delete this task?'); ?></span>
-			<h3>&quot;<?php echo $pt->getSummary(); ?>&quot;</h3></td>
+		<td ><span class="important"><?php echo _('Are you sure you want to delete this task?'); ?></span>
+			<p><strong><?php echo $pt->getSummary(); ?></strong></p>
+		</td>
 	</tr>
-	<tr align="center">
-		<td style="text-align:center"><input type="checkbox" value="1" name="confirm_delete" /> <?php echo _('Yes, I want to delete this task'); ?></td>
+	<tr class="align-center">
+		<td class="align-center">
+			<input id="confirm_delete" type="checkbox" value="1" name="confirm_delete" />
+			<label for="confirm_delete">
+				<?php echo _('I am Sure'); ?>
+			</label>
+		</td>
 	</tr>
 	<tr>
-		<td style="text-align:center"><input type="submit" value="<?php echo _('Submit'); ?>" name="submit" /></td>
+		<td class="align-center">
+			<input type="submit" value="<?php echo _('Submit'); ?>" name="submit" />
+		</td>
 	</tr>
 
 </table>
@@ -55,5 +63,3 @@ pm_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
