@@ -45,19 +45,17 @@
 //	so a user can choose a file to upload a .csv file and store it in task mgr
 //
 
-
-pm_header(array('title'=>_('Upload data into the tasks.'),'group_project_id'=>$group_project_id));
+pm_header(array('title'=>_('Update CSV Format'),'group_project_id'=>$group_project_id));
 
 $headers = getIntFromRequest('headers', 1);
 $full = getIntFromRequest('full', 1);
 $sep = getStringFromRequest('sep', ',');
 
 ?>
-<center>
-<table>
+<table class="centered">
 	<tr>
 		<td>
-		<fieldset><legend><b>CSV Format</b></legend>
+		<fieldset><legend><strong><?php echo _('CSV Format'); ?></strong></legend>
 		<form action="/pm/task.php" method="get"><input type="hidden"
 			name="group_id" value="<?php echo $group_id ?>" /> <input
 			type="hidden" name="group_project_id"
@@ -65,21 +63,19 @@ $sep = getStringFromRequest('sep', ',');
 			name="func" value="csv" />
 		<table>
 			<tr>
-				<td valign="top"><b>Content :</b></td>
-				<td><input type="radio" name="full" value="1"<?php if ($full) echo ' checked="checked"' ?>/>Full<br />
-				<input type="radio" name="full" value="0"<?php if (!$full) echo ' checked="checked"' ?> />Normal</td>
+				<td class="top"><strong><?php echo _('Content')._(':'); ?></strong></td>
+				<td><input type="radio" name="full" value="1"<?php if ($full) echo ' checked="checked"' ?>/><?php echo _('Full'); ?><br />
+				<input type="radio" name="full" value="0"<?php if (!$full) echo ' checked="checked"' ?> /><?php echo _('Normal'); ?></td>
 			</tr>
-			<tr><td colspan="2">&nbsp;</td></tr>
 			<tr>
-				<td valign="top"><b>Separator :</b></td>
-				<td><input type="radio" name="sep" value=","<?php if ($sep==',') echo ' checked="checked"' ?>/>Comma (char: ',')<br />
-				<input type="radio" name="sep" value=";"<?php if ($sep==';') echo ' checked="checked"' ?>/>Semi-colon (char: ';')</td>
+				<td class="top"><strong><?php echo _('Separator')._(':'); ?></strong></td>
+				<td><input type="radio" name="sep" value=","<?php if ($sep==',') echo ' checked="checked"' ?>/><?php echo _('Comma (char: “,”)'); ?><br />
+				<input type="radio" name="sep" value=";"<?php if ($sep==';') echo ' checked="checked"' ?>/><?php echo _('Semi-colon (char: “;”)'); ?></td>
 			</tr>
-			<tr><td colspan="2">&nbsp;</td></tr>
 			<tr>
-				<td valign="top"><b>Header :</b></td>
-				<td><input type="radio" name="headers" value="1"<?php if ($headers) echo ' checked="checked"' ?>/>Included<br />
-				<input type="radio" name="headers" value="0"<?php if (!$headers) echo ' checked="checked"' ?>/>None</td>
+				<td class="top"><strong><?php echo _('Header')._(':'); ?></strong></td>
+				<td><input type="radio" name="headers" value="1"<?php if ($headers) echo ' checked="checked"' ?>/><?php echo _('Included'); ?><br />
+				<input type="radio" name="headers" value="0"<?php if (!$headers) echo ' checked="checked"' ?>/><?php echo _('None'); ?></td>
 			</tr>
 		</table>
 		<input type="submit" name="Submit" /></form>
@@ -87,15 +83,21 @@ $sep = getStringFromRequest('sep', ',');
 		</td>
 	</tr>
 </table>
-</center>
-<p><strong>Notes:</strong></p>
-<div>
+<h2><?php echo _('Notes'); ?></h2>
 <ul>
-<li><strong>Full/Normal :</strong> In Full, the category is also exported.</li>
-<li><strong>Comma/Semi-colon :</strong> Some international version of MS Excel uses ';' instead of ','.</li>
-<li><strong>Headers Included or not :</strong> Add a line with the name of the fields at the fist line.</li>
+<li>
+    <strong><?php echo _('Full/Normal')._(':'); ?></strong>
+    <?php echo _('In Full, the category is also exported.'); ?>
+</li>
+<li>
+    <strong><?php echo _('Comma/Semi-colon')._(':'); ?></strong>
+    <?php echo _('Some international versions of Microsoft Excel use “;” instead of “,”.'); ?>
+</li>
+<li>
+    <strong><?php echo _('Headers Included or not')._(':'); ?></strong>
+    <?php echo _('Add a line with the name of the fields at the first line.'); ?>
+</li>
 </ul>
-</div>
+
 <?php
 pm_footer(array());
-?>
