@@ -28,6 +28,12 @@ require_once $gfwww.'include/note.php';
 require_once $gfcommon.'reporting/report_utils.php';
 require_once $gfcommon.'reporting/Report.class.php';
 
+if (getStringFromRequest('commentsort') == 'anti') {
+	$sort_comments_chronologically = false;
+} else {
+	$sort_comments_chronologically = true;
+}
+
 pm_header(array('title'=>_('Modify Task'),'pagename'=>'pm_modtask','group_project_id'=>$group_project_id));
 
 echo notepad_func();
@@ -37,11 +43,13 @@ echo notepad_func();
 <form id="modtaskform" action="<?php echo getStringFromServer('PHP_SELF')."?group_id=$group_id&amp;group_project_id=$group_project_id"; ?>" method="post">
 <input type="hidden" name="func" value="postmodtask" />
 <input type="hidden" name="project_task_id" value="<?php echo $project_task_id; ?>" />
+<input type="hidden" name="duration" value="<?php echo $pt->getDuration(); ?>" />
+<input type="hidden" name="parent_id" value="<?php echo $pt->getParentID(); ?>" />
 
-<table border="0" width="100%" class="mod_task">
+<table class="fullwidth mod_task">
 
 	<tr>
-		<td><strong><?php echo _('Submitted by') ?>:</strong><br />
+		<td><strong><?php echo _('Submitted by') . _(': '); ?></strong><br />
 			<?php echo $pt->getSubmittedRealName(); ?> (<?php echo $pt->getSubmittedUnixName(); ?>)</td>
 		<td><input type="submit" value="<?php echo _('Submit') ?>" name="submit" /></td>
 		<td><strong>Task ID:</strong> <?php echo $project_task_id; ?> @ <?php
@@ -50,12 +58,12 @@ echo notepad_func();
 
 	<tr>
 		<td>
-			<strong><?php echo _('Category') ?></strong><br />
-			<?php echo $pg->categoryBox('category_id',$pt->getCategoryID()); ?> <?php util_make_link ('/pm/admin/?<?php echo "group_id=$group_id&amp;add_cat=1&amp;group_project_id='.$group_project_id,_('admin')); ?>
+			<strong><?php echo _('Category') . _(': '); ?></strong><br />
+			<?php echo $pg->categoryBox('category_id',$pt->getCategoryID()); ?> <?php util_make_link ('/pm/admin/?<?php echo "group_id=$group_id&amp;add_cat=1&amp;group_project_id='.$group_project_id,_('Admin')); ?>
 		</td>
 
 		<td>
-			<strong><?php echo _('Subproject'); ?>:</strong><br />
+			<strong><?php echo _('Subproject') . _(': '); ?></strong><br />
 			<?php echo $pg->groupProjectBox('new_group_project_id',$group_project_id,false); ?>
 		</td>
 
@@ -67,13 +75,13 @@ echo notepad_func();
 
 	<tr>
 		<td>
-		<strong><?php echo _('Percent Complete') ?>:</strong><br />
-		<?php echo $pg->percentCompleteBox('percent_complete',$pt->getPercentComplete()); ?>
+		<strong><?php echo _('Percent Complete') . _(': '); ?></strong><br />
+		<?php $pg->percentCompleteBox('percent_complete',$pt->getPercentComplete()); ?>
 		</td>
 
 		<td>
-		<strong><?php echo _('Priority') ?>:</strong><br />
-		<?php echo build_priority_select_box('priority',$pt->getPriority()); ?>
+		<strong><?php echo _('Priority') . _(': '); ?></strong><br />
+		<?php build_priority_select_box('priority',$pt->getPriority()); ?>
 		</td>
 
 		<td>
@@ -84,9 +92,9 @@ echo notepad_func();
 		</td>
 	</tr>
 
-  	<tr>
+	<tr>
 		<td>
-		<strong><?php echo _('Task Summary') ?>:</strong><br />
+		<strong><?php echo _('Task Summary') . _(': '); ?></strong><br />
 		<input type="text" name="summary" size="65" maxlength="65" value="<?php echo $pt->getSummary(); ?>" />
 		</td>
 		<td colspan="2">
@@ -103,10 +111,10 @@ echo notepad_func();
 
 	<tr>
 		<td colspan="3">
-		<strong><?php echo _('Original Comment') ?>:</strong><br />
-		<?php 
+		<strong><?php echo _('Original Comment') . _(': '); ?></strong><br />
+		<?php
 			$sanitizer = new TextSanitizer();
-        	$body = $sanitizer->SanitizeHtml($pt->getDetails());
+			$body = $sanitizer->SanitizeHtml($pt->getDetails());
 
 			if (strpos($body,'<') === false) {
 				echo nl2br($pt->getDetails());
@@ -115,7 +123,7 @@ echo notepad_func();
 			}
 		?>
 		<p />
-		<strong><?php echo _('Add A Comment') ?>:</strong><?php echo notepad_button('document.forms.modtaskform.details') ?><br />
+		<strong><?php echo _('Add A Comment') . _(': '); ?></strong><?php echo notepad_button('document.forms.modtaskform.details') ?><br />
 <?php
 $GLOBALS['editor_was_set_up']=false;
 $params = array() ;
@@ -126,7 +134,7 @@ $params['body'] = "";
 $params['group'] = $group_id;
 plugin_hook("text_editor",$params);
 if (!$GLOBALS['editor_was_set_up']) {
-    echo '<textarea name="details" rows="5" cols="80"></textarea>';
+	echo '<textarea name="details" rows="5" cols="80"></textarea>';
 }
 unset($GLOBALS['editor_was_set_up']);
 ?>
@@ -135,13 +143,13 @@ unset($GLOBALS['editor_was_set_up']);
 
 	<tr>
 		<td colspan="3">
-		<strong><?php echo _('Start Date') ?>:</strong><br />
+		<strong><?php echo _('Start Date') . _(': '); ?></strong><br />
 		<?php
-		echo $pg->showMonthBox ('start_month',date('m', $pt->getStartDate()));
-		echo $pg->showDayBox ('start_day',date('d', $pt->getStartDate()));
-		echo $pg->showYearBox ('start_year',date('Y', $pt->getStartDate()));
-		echo $pg->showHourBox ('start_hour',date('G', $pt->getStartDate()));
-		echo $pg->showMinuteBox ('start_minute',date('i',$pt->getStartDate()));
+		$pg->showMonthBox ('start_month',date('m', $pt->getStartDate()));
+		$pg->showDayBox ('start_day',date('d', $pt->getStartDate()));
+		$pg->showYearBox ('start_year',date('Y', $pt->getStartDate()));
+		$pg->showHourBox ('start_hour',date('G', $pt->getStartDate()));
+		$pg->showMinuteBox ('start_minute',date('i',$pt->getStartDate()));
 		?><br /><?php echo _('The system will modify your start/end dates if you attempt to create a start date earlier than the end date of any tasks you depend on.') ?>
 		<br /><a href="calendar.php?group_id=<?php echo $group_id; ?>&amp;group_project_id=<?php echo $group_project_id; ?>" target="_blank"><?php echo _('View Calendar') ?></a>
 		</td>
@@ -149,20 +157,20 @@ unset($GLOBALS['editor_was_set_up']);
 
 	<tr>
 		<td colspan="3">
-		<strong><?php echo _('End Date') ?>:</strong><br />
+		<strong><?php echo _('End Date') . _(': '); ?></strong><br />
 		<?php
-		echo $pg->showMonthBox ('end_month',date('m', $pt->getEndDate()));
-		echo $pg->showDayBox ('end_day',date('d', $pt->getEndDate()));
-		echo $pg->showYearBox ('end_year',date('Y', $pt->getEndDate()));
-		echo $pg->showHourBox ('end_hour',date('G', $pt->getEndDate()));
-		echo $pg->showMinuteBox ('end_minute',date('i', $pt->getEndDate()));
+		$pg->showMonthBox ('end_month',date('m', $pt->getEndDate()));
+		$pg->showDayBox ('end_day',date('d', $pt->getEndDate()));
+		$pg->showYearBox ('end_year',date('Y', $pt->getEndDate()));
+		$pg->showHourBox ('end_hour',date('G', $pt->getEndDate()));
+		$pg->showMinuteBox ('end_minute',date('i', $pt->getEndDate()));
 		?>
 		</td>
 	</tr>
 
 	<tr>
-		<td valign="top">
-		<strong><?php echo _('Assigned to') ?>:</strong><br />
+		<td class="top">
+		<strong><?php echo _('Assigned to') . _(': '); ?></strong><br />
 		<?php
 		/*
 			List of possible users that this one could be assigned to
@@ -171,8 +179,8 @@ unset($GLOBALS['editor_was_set_up']);
 		?>
 		</td>
 
-		<td valign="top" colspan="2">
-		<strong><?php echo _('Dependent on task') ?>:</strong><br />
+		<td class="top" colspan="2">
+		<strong><?php echo _('Dependent on task') . _(': '); ?></strong><br />
 		<?php
 		/*
 			List of possible tasks that this one could depend on
@@ -186,24 +194,22 @@ unset($GLOBALS['editor_was_set_up']);
 
 	<tr>
 		<td>
-		<strong><?php echo _('Estimated Hours') ?>:</strong><br />
+		<strong><?php echo _('Estimated Hours') . _(': '); ?></strong><br />
 		<input type="text" name="hours" size="5" value="<?php echo $pt->getHours(); ?>" />
 		</td>
 
 		<td colspan="2">
-		<strong><?php echo _('Status') ?>:</strong><br />
+		<strong><?php echo _('Status') . _(': '); ?></strong><br />
 		<?php
 		echo $pg->statusBox('status_id', $pt->getStatusID(), false );
 		?>
-		<input type="hidden" name="duration" value="<?php echo $pt->getDuration(); ?>" />
-		<input type="hidden" name="parent_id" value="<?php echo $pt->getParentID(); ?>" />
 		</td>
 	</tr>
 <!--
 //will add duration and parent selection boxes
 	<tr>
 		<td>
-		<strong><?php echo _('Estimated Hours') ?>:</strong><br />
+		<strong><?php echo _('Estimated Hours') . _(': '); ?></strong><br />
 		<input type="text" name="hours" size="5" value="<?php echo $pt->getHours(); ?>" />
 		</td>
 
@@ -217,28 +223,29 @@ unset($GLOBALS['editor_was_set_up']);
 -->
 	<tr>
 		<td colspan="3">
-			<?php echo $pt->showDependentTasks(); ?>
+			<?php $pt->showDependentTasks(); ?>
 		</td>
 	</tr>
 
 	<tr>
 		<td colspan="3">
-			<?php echo $pt->showRelatedArtifacts(); ?>
+			<?php $pt->showRelatedArtifacts(); ?>
 		</td>
 	</tr>
 
 	<tr>
 		<td colspan="3">
-			<?php echo $pt->showMessages(); ?>
+			<?php $pt->showMessages($sort_comments_chronologically, "/pm/task.php?func=detailtask&amp;project_task_id=$project_task_id&amp;group_id=$group_id&amp;group_project_id=$group_project_id"); ?>
 		</td>
 	</tr>
 	<?php
-		$hookParams['task_id']=$project_task_id;
-		plugin_hook("task_extra_detail",$hookParams);
+		$hookParams['task_id'] = $project_task_id;
+		$hookParams['group_id'] = $group_id;
+		plugin_hook("task_extra_detail", $hookParams);
 	?>
 	<tr>
 		<td colspan="3">
-			<?php echo $pt->showHistory(); ?>
+			<?php $pt->showHistory(); ?>
 		</td>
 	</tr>
 
@@ -251,7 +258,7 @@ unset($GLOBALS['editor_was_set_up']);
 </table>
 </form>
 
-<h3><?php echo _('Time tracking'); ?></h3>
+<h2><?php echo _('Time tracking'); ?></h2>
 
 <?php
 $title_arr = array();
@@ -268,22 +275,23 @@ $report=new Report();
 if ($report->isError()) {
 	exit_error($report->getErrorMessage(),'pm');
 }
+$report->setStartDate($pt->ProjectGroup->Group->getStartDate());
 
-echo '<form action="/reporting/timeadd.php" method="post">
+echo '<form id="time-tracking" action="/reporting/timeadd.php" method="post">
 	<input type="hidden" name="project_task_id" value="'.$project_task_id.'" />
 	<input type="hidden" name="submit" value="1" />';
 echo $HTML->listTableTop ($title_arr);
 echo '<tr '.$HTML->boxGetAltRowStyle($xi++).'>
-		<td style="text-align:center">'. report_weeks_box($report, 'week') .'</td>
-		<td style="text-align:center">'. report_day_adjust_box($report, 'days_adjust') .'</td>
-		<td style="text-align:center"><input type="text" name="hours" value="" size="3" maxlength="3" /></td>
-		<td style="text-align:center">'.report_time_category_box('time_code',false).'</td>
+		<td class="align-center">'. report_weeks_box($report, 'week') .'</td>
+		<td class="align-center">'. report_day_adjust_box() .'</td>
+		<td class="align-center"><input id="time-tracking-hours" type="text" required="required" name="hours" value="" size="3" maxlength="3" /></td>
+		<td class="align-center">'.report_time_category_box('time_code',false).'</td>
 		<td>&nbsp;</td>
-		<td style="text-align:center"><input type="submit" name="add" value="'._('Add').'" /><input type="submit" name="cancel" value="'._('Cancel').'" /></td>
+		<td class="align-center"><input type="submit" name="add" value="'._('Add').'" /><input type="submit" name="cancel" value="'._('Cancel').'" /></td>
 	</tr>';
-	
+
 //setenv("TZ=" . $user_timezone); //restore the user's timezone
-	
+
 //
 //	Display Time Recorded for this task
 //
@@ -291,7 +299,7 @@ echo '<tr '.$HTML->boxGetAltRowStyle($xi++).'>
 
 $res=db_query_params ('SELECT users.realname, rep_time_tracking.report_date, rep_time_tracking.hours, rep_time_category.category_name
 	FROM users,rep_time_tracking,rep_time_category
-	WHERE 
+	WHERE
 	users.user_id=rep_time_tracking.user_id
 	AND rep_time_tracking.time_code=rep_time_category.time_code
 	AND rep_time_tracking.project_task_id=$1',
@@ -301,24 +309,25 @@ for ($i=0; $i<db_numrows($res); $i++) {
 
 	echo '
 	<tr '.$HTML->boxGetAltRowStyle($xi++).'>
-	<td>&nbsp;</td>
+	<td></td>
 	<td>'.date(_('Y-m-d H:i'),db_result($res,$i,'report_date')).'</td>
 	<td>'.db_result($res,$i,'hours').'</td>
 	<td>'.db_result($res,$i,'category_name').'</td>
 	<td>'.db_result($res,$i,'realname').'</td>
-	<td>&nbsp;</td></tr>';
+	<td></td></tr>';
 	$total_hours += db_result($res,$i,'hours');
-	
+
 }
 
 echo '
 <tr '.$HTML->boxGetAltRowStyle($xi++).'>
-<td><strong>'._('Total').':</strong></td>
-<td>&nbsp;</td>
+<td><strong>'._('Total')._(': ').'</strong></td>
+<td></td>
 <td>'.$total_hours.'</td>
-<td>&nbsp;</td>
-<td>&nbsp;</td>
-<td>&nbsp;</td></tr>';
+<td></td>
+<td></td>
+<td></td>
+</tr>';
 
 echo $HTML->listTableBottom();
 echo "</form>\n";
@@ -329,5 +338,3 @@ pm_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
