@@ -36,7 +36,7 @@ return data:
 	$array[success]=true;
 	$array[session_hash]=jkjkjkjkjkjkjkj;
 	$array[subprojects]=array(
-						55=>'Subproject 1', 
+						55=>'Subproject 1',
 						77=>'Subproject2'
 						);
 
@@ -53,10 +53,9 @@ function &MSPLogin($username,$password) {
 		$array['success']=true;
 		$array['session_hash']=$session_ser;
 
-
 		$result = db_query_params ('SELECT group_project_id FROM project_group_list',
 					   array ()) ;
-		
+
 		$gids = array () ;
 		while ($arr = db_fetch_array($result)) {
 			if (forge_check_perm ('pm', $arr['group_project_id'], 'read')) {
@@ -83,7 +82,6 @@ function &MSPLogin($username,$password) {
 		$array['success']=false;
 		$array['errormessage']=$feedback;
 	}
-	printr($array,'MSPLogin::return-array');
 	return $array;
 }
 
@@ -105,7 +103,7 @@ function &MSPDownload($session_hash,$group_project_id) {
 		$array['success']=false;
 		$array['errormessage']='Could Not Continue Session';
 	}
-	$pg =& projectgroup_get_object($group_project_id);
+	$pg = projectgroup_get_object($group_project_id);
 	if (!$pg || !is_object($pg)) {
 		$array['success']=false;
 		$array['errormessage']='Could Not Get ProjectGroup';
@@ -113,7 +111,7 @@ function &MSPDownload($session_hash,$group_project_id) {
 		$array['success']=false;
 		$array['errormessage']='Could Not Get ProjectGroup: '.$pg->getErrorMessage();
 	} else {
-		$ptf =& new ProjectTaskFactory($pg);
+		$ptf = new ProjectTaskFactory($pg);
 		if (!$ptf || !is_object($ptf)) {
 			$array['success']=false;
 			$array['errormessage']='Could Not Get ProjectTaskFactory';
@@ -130,7 +128,6 @@ function &MSPDownload($session_hash,$group_project_id) {
 			}
 		}
 	}
-	printr($array,'MSPDownload::return-array');
 	return $array;
 }
 
@@ -142,16 +139,15 @@ function &MSPDownload($session_hash,$group_project_id) {
 
 LINK TYPES -
 				SS . Start to Start
-				SF . Start to Finish  
+				SF . Start to Finish
 				FS . Finish to Start
 				FF . Finish to Finish
 
-
 	params:
 
 	$session_hash
 	$group_project_id (subproject_id)
-	$tasks = 
+	$tasks =
 		array(
 			id=>1,
 			msproj_id=>p1,
@@ -196,8 +192,6 @@ Return:
 
 */
 function &MSPCheckin($session_hash,$group_project_id,$tasks) {
-	global $primap;
-	printr($tasks,'MSPCheckin::in-tasks');
 	if (!session_continue($session_hash)) {
 		$array['success']=false;
 		$array['errormessage']='Could Not Continue Session';
@@ -210,8 +204,8 @@ function &MSPCheckin($session_hash,$group_project_id,$tasks) {
 * Return the projects by user.
 *
 * @author	Luis Hurtado	luis@gforgegroup.com
-* @param	session_hash	User session
-* @return	Groups		User groups
+* @param	object	$session_hash	User session
+* @return	array	Groups		User groups
 * @date		2005-01-19
 *
 */
@@ -234,21 +228,21 @@ function &MSPGetProjects($session_hash) {
 * Create SubProjects
 *
 * @author	Luis Hurtado	luis@gforgegroup.com
-* @param	groupid		ID Group
-* @param	session_hash	User Session
-* @param	name		Project name
-* @param	ispublic	1 Public  0 Private
-* @param	description	Project Description
-* @return	ProjectGroup	Object ProjectGroup
+* @param	int		$group_id		ID Group
+* @param	object	$session_hash	User Session
+* @param	string	$name		Project name
+* @param	bool	$is_public	1 Public  0 Private
+* @param	string	$description	Project Description
+* @return	object	ProjectGroup	Object ProjectGroup
 * @date		2005-01-19
 *
 */
-function &MSPCreateProject($groupid,$session_hash,$name,$ispublic,$description) {
+function &MSPCreateProject($group_id, $session_hash, $name, $is_public, $description) {
 	if (!session_continue($session_hash)) {
 		$array['success']=false;
 		$array['errormessage']='Could Not Continue Session';
 	}
-	$group = group_get_object($groupid);
+	$group = group_get_object($group_id);
 	if (!$group || !is_object($group)) {
 		$res['code']="error";
 		$res['description']="No Such Project";
@@ -265,15 +259,14 @@ function &MSPCreateProject($groupid,$session_hash,$name,$ispublic,$description)
 				$res['description']="Could Not Get ProjectGroup";
 				return $res;
 			} else {
-				if (!$pg->create($name,$description,$ispublic)) {
+				if (!$pg->create($name, $description, $is_public)) {
 					$res['code']="error";
 					$res['description']='Error Creating Subproject '.$pg->getErrorMessage();
 					return $res;
 				} else {
-					return $pg;	
+					return $pg;
 				}
 			}
 		}
 	}
 }
-?>
