@@ -22,11 +22,10 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
 // Quota in bytes
 $QUOTA = 1048576;
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'project/admin/project_admin_utils.php';
 
@@ -44,7 +43,7 @@ function check_file_size($size) {
 		return true;
 	} else {
 		//too big or small
-		$error_msg .= _('ERROR - file must be > 20 bytes and < 256000 bytes in length').' <br />';
+		$error_msg .= _('Error: file must be > 20 bytes and < 256000 bytes in length').' <br />';
 		return false;
 	}
 }
@@ -56,7 +55,7 @@ function store_file($id, $input_file) {
 	global $error_msg;
 
 	if (!util_check_fileupload($input_file)) {
-		exit_error(_('Invalid filename'),'admin');
+		exit_error(_('Invalid file name.'),'admin');
 	}
 
 	$filename = $input_file['tmp_name'];
@@ -96,9 +95,8 @@ function store_file($id, $input_file) {
 		                          $input_file['type'], $width, $height, $curtime, $group_id, $id));
 		}
 
-
 		if (!$res || db_affected_rows($res) < 1) {
-			$error_msg .= _('ERROR: DB: Cannot store multimedia file : ').db_error();
+			$error_msg .= _('Error: Cannot store multimedia file: ').db_error();
 		} else {
 			$feedback .= _('Multimedia File Uploaded');
 		}
@@ -129,19 +127,19 @@ if (getStringFromRequest('submit')) {
 			}
 		}
 
-	} else if (getStringFromRequest('remove')) {
+	} elseif (getStringFromRequest('remove')) {
 
 		$res=db_query_params ('DELETE FROM db_images WHERE id=$1 AND group_id=$2',
 			array($id,
 				$group_id));
 
 		if (!$res || db_affected_rows($res) < 1) {
-			$error_msg .= _('ERROR: DB: Cannot delete multimedia file: ').db_error();
+			$error_msg .= _('Error: Cannot delete multimedia file: ').db_error();
 		} else {
 			$feedback .= _('Multimedia File Deleted');
 		}
 
-	} else if (getStringFromRequest("edit")) {
+	} elseif (getStringFromRequest("edit")) {
 		if ($description == "") {
 			$error_msg .= _('File description is required');
 		} else {
@@ -160,7 +158,7 @@ if (getStringFromRequest('submit')) {
 				$id));
 
 				if (!$res || db_affected_rows($res) < 1) {
-					$error_msg .= _('ERROR: DB: Cannot update multimedia file').db_error();
+					$error_msg .= _('Error: Cannot update multimedia file').db_error();
 				} else {
 					$feedback .= _('Multimedia File Properties Updated');
 				}
@@ -196,7 +194,7 @@ if (getStringFromRequest('submit')) {
 project_admin_header(array('title'=>_('Edit Multimedia Data')));
 
 echo '
-	<p>'.sprintf(_('You can store up to %1$s MB of multimedia data (bitmap and vector graphics, sound clips, 3D models) in the database. Use this page to add/delete your project multimedia data.'), sprintf("%.2f", $QUOTA/(1024*1024))).'</p>
+	<p>'.sprintf(_('You can store up to %s MB of multimedia data (bitmap and vector graphics, sound clips, 3D models) in the database. Use this page to add/delete your project multimedia data.'), sprintf("%.2f", $QUOTA/(1024*1024))).'</p>
 	<p>
 ';
 
@@ -221,15 +219,15 @@ if ($mode == "edit") {
 	<input type="hidden" name="group_id" value="'.$group_id.'" />
 	<input type="hidden" name="id" value="'.$id.'" />
 
-	<strong>'._('Replace with new file (optional)').':</strong><br />
-	<input type="file" name="input_file" size="30" />
+	<strong>'._('Replace with new file (optional)')._(':').'</strong><br />
+	<input type="file" name="input_file" />
 	<p>
 
-	<strong>'._('Description').':</strong><br />
+	<strong>'._('Description')._(':').'</strong><br />
 	<input type="text" name="description" size="40" maxlength="255" value="'.db_result($result,$i,'description').'" />
 	</p>
 	<p>
-	<strong>'._('MIME Type').':</strong><br />
+	<strong>'._('MIME Type')._(':').'</strong><br />
 	<input type="text" name="filetype" size="40" maxlength="255" value="'.db_result($result,$i,'filetype').'" />
 
 	<input type="hidden" name="edit" value="1" />
@@ -249,20 +247,20 @@ if ($mode == "edit") {
 	<p>
 	<form action="'. getStringFromServer('PHP_SELF') .'" method="post" enctype="multipart/form-data">
 	<input type="hidden" name="group_id" value="'.$group_id.'" />
-	<strong>'._('Local filename').':</strong>'.utils_requiredField().'<br />
-	<input type="file" name="input_file" size="30" />
+	<strong>'._('Local filename')._(':').'</strong>'.utils_requiredField().'<br />
+	<input type="file" required="required" name="input_file" size="30" />
 	<p>
-	<strong>'._('Description').':</strong>'.utils_requiredField().'<br />
-	<input type="text" name="description" size="40" maxlength="255" /></p><p>
+	<strong>'._('Description')._(':').'</strong>'.utils_requiredField().'<br />
+	<input type="text" required="required" name="description" size="40" maxlength="255" /></p><p>
 	<input type="hidden" name="add" value="1" />
-	<input type="submit" value="'._('Add File').'" name="submit" /><br /></p>
+	<input type="submit" value="'._('Add File').'" name="submit" /></p>
 	</form></p>
 	';
 }
 
 $arr=array();
 $arr[]=_('Edit');
-$arr[]=_('ID');
+$arr[]=_('Id');
 $arr[]=_('Uploaded');
 $arr[]=_('Name');
 $arr[]=_('MIME Type');
@@ -286,7 +284,7 @@ for ($i=0; $i<$rows; $i++) {
 
 	echo '
 	<tr '. $GLOBALS['HTML']->boxGetAltRowStyle($i) .'>'
-	.'<td style="text-align:center">'
+	.'<td class="align-center">'
 	 .'<a href="'. getStringFromServer('PHP_SELF') .'?submit=1&amp;group_id='.$group_id.'&amp;remove=1&amp;id='
 	 .db_result($result,$i,'id').'">'
 	 .'['._('Del').']'.'</a>'
@@ -301,8 +299,8 @@ for ($i=0; $i<$rows; $i++) {
 
 	.'<td>'.util_make_link ('/dbimage.php?id='.db_result($result,$i,'id'), db_result($result,$i,'filename')).'</td>'
 	.'<td>'.db_result($result,$i,'filetype').'</td>'
-	.'<td style="text-align:right">'.db_result($result,$i,'filesize').'</td>'
-	.'<td style="text-align:right">'.$dims.'</td>'
+	.'<td class="align-right">'.db_result($result,$i,'filesize').'</td>'
+	.'<td class="align-right">'.$dims.'</td>'
 	.'<td>'.db_result($result,$i,'description').'</td>'
 	.'</tr>';
 }
@@ -315,5 +313,3 @@ project_admin_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
