@@ -7,8 +7,8 @@
  * members, but only admins may perform most functions.
  *
  * Copyright 2004 GForge, LLC - Tim Perdue
- * Copyright 2010 (c), Franck Villaume
- * Copyright (C) 2010-2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2010, Franck Villaume - Capgemini
+ * Copyright 2010-2011, Alain Peyrat - Alcatel-Lucent
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -27,21 +27,20 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'include/role_utils.php';
 require_once $gfwww.'project/admin/project_admin_utils.php';
 require_once $gfcommon.'include/GroupJoinRequest.class.php';
 
 $group_id = getIntFromRequest('group_id');
-$feedback = htmlspecialchars(getStringFromRequest('feedback'));
 
 session_require_perm ('project_admin', $group_id) ;
 
 // get current information
 $group = group_get_object($group_id);
 if (!$group || !is_object($group)) {
-    exit_no_group();
+	exit_no_group();
 } elseif ($group->isError()) {
 	exit_error($group->getErrorMessage(),'admin');
 }
@@ -65,11 +64,12 @@ if (getStringFromRequest('submit')) {
 	$use_tracker = getStringFromRequest('use_tracker');
 	$use_frs = getStringFromRequest('use_frs');
 	$use_stats = getStringFromRequest('use_stats');
+	$use_activity = getStringFromRequest('use_activity');
 	$tags = getStringFromRequest('form_tags');
 	$addTags = getArrayFromRequest('addTags');
 	$new_doc_address = getStringFromRequest('new_doc_address');
 	$send_all_docs = getStringFromRequest('send_all_docs');
-	
+
 	if (trim($tags) != "") {
 		$tags .= ",";
 	}
@@ -96,9 +96,10 @@ if (getStringFromRequest('submit')) {
 		$use_frs,
 		$use_stats,
 		$tags,
+		$use_activity,
 		0
 	);
-	
+
 	//100 $logo_image_id
 
 	if (!$res) {
@@ -108,7 +109,7 @@ if (getStringFromRequest('submit')) {
 	}
 }
 
-project_admin_header(array('title'=>_('Project Information'), 'group'=>$group->getID()));
+project_admin_header(array('title'=>sprintf(_('Project Information for %s'), $group->getPublicName()),'group'=>$group->getID()));
 ?>
 
 <table class="my-layout-table">
@@ -118,13 +119,13 @@ project_admin_header(array('title'=>_('Project Information'), 'group'=>$group->g
 <?php echo $HTML->boxTop(_('Misc. Project Information'));
 
 if (forge_get_config('use_shell')) {
-?> 
-<p><?php echo _('Group shell (SSH) server:&nbsp;') ?><strong><?php echo $group->getUnixName().'.'.forge_get_config('web_host'); ?></strong></p>
-<p><?php echo _('Group directory on shell server:&nbsp;') ?><br/><strong><?php echo account_group_homedir($group->getUnixName()); ?></strong></p>
-<p><?php echo _('Project WWW directory on shell server:&nbsp;') ?><br /><strong><?php echo account_group_homedir($group->getUnixName()).'/htdocs'; ?></strong></p>
+?>
+<p><?php echo _('Group shell (SSH) server:') ?> <strong><?php echo forge_get_config('shell_host'); ?></strong></p>
+<p><?php echo _('Group directory on shell server:') ?><br/><strong><?php echo account_group_homedir($group->getUnixName()); ?></strong></p>
+<p><?php echo _('Project WWW directory on shell server:') ?><br /><strong><?php echo account_group_homedir($group->getUnixName()).'/htdocs'; ?></strong></p>
 <?php
 	} //end of use_shell condition
-?> 
+?>
 
 <form action="<?php echo getStringFromServer('PHP_SELF'); ?>" method="post">
 
@@ -151,7 +152,7 @@ if (forge_get_config('use_shell')) {
 <?php echo _('Add tags (use comma as separator): ') ?><br />
 <input type="text" name="form_tags" size="100" value="<?php echo $group->getTags(); ?>" />
 </p>
-<?php 
+<?php
 	$infos = getAllProjectTags();
 	if ($infos) {
 		echo '<br />';
@@ -201,11 +202,11 @@ if (forge_get_config('use_shell')) {
 <?php
 // This function is used to render checkboxes below
 function c($v) {
-        if ($v) {
-                return 'checked="checked"';
-        } else {
-                return '';
-        }
+	if ($v) {
+		return 'checked="checked"';
+	} else {
+		return '';
+	}
 }
 ?>
 
@@ -214,7 +215,7 @@ if(forge_get_config('use_mail')) {
 ?>
 <input type="hidden" name="use_mail" value="<?php echo ($group->usesMail() ? '1' : '0'); ?>" />
 <?php
-} 
+}
 
 if(forge_get_config('use_survey')) {
 ?>
@@ -222,6 +223,12 @@ if(forge_get_config('use_survey')) {
 <?php
 }
 
+if(forge_get_config('use_activity')) {
+?>
+<input type="hidden" name="use_activity" value="<?php echo ($group->usesActivity() ? '1' : '0'); ?>" />
+<?php
+}
+
 if(forge_get_config('use_forum')) {
 ?>
 <input type="hidden" name="use_forum" value="<?php echo ($group->usesForum() ? '1' : '0'); ?>" />
@@ -249,6 +256,13 @@ if(forge_get_config('use_news')) {
 if(forge_get_config('use_docman')) {
 ?>
 <input type="hidden" name="use_docman" value="<?php echo ($group->usesDocman() ? '1' : '0'); ?>" />
+<p>
+<?php echo _('If you wish, you can provide default email addresses to which new submissions will be sent') ?>.<br />
+<strong><?php echo _('New Document Submissions')._(':'); ?></strong><br />
+<input type="email" name="new_doc_address" value="<?php echo $group->getDocEmailAddress(); ?>" size="40" maxlength="250" />
+<?php echo _('(send on all updates)') ?>
+<input type="checkbox" name="send_all_docs" value="1" <?php echo c($group->docEmailAll()); ?> />
+</p>
 <?php
 }
 
@@ -271,14 +285,6 @@ if(forge_get_config('use_frs')) {
 
 <input type="hidden" name="use_stats" value="<?php echo ($group->usesStats() ? '1' : '0'); ?>" />
 
-<p>
-<?php echo _('If you wish, you can provide default email addresses to which new submissions will be sent') ?>.<br />
-<strong><?php echo _('New Document Submissions') ?>:</strong><br />
-<input type="text" name="new_doc_address" value="<?php echo $group->getDocEmailAddress(); ?>" size="40" maxlength="250" />
-<?php echo _('(send on all updates)') ?>
-<input type="checkbox" name="send_all_docs" value="1" <?php echo c($group->docEmailAll()); ?> />
-</p>
-
 <p>
 <input type="submit" name="submit" value="<?php echo _('Update') ?>" />
 </p>
@@ -286,7 +292,7 @@ if(forge_get_config('use_frs')) {
 </form>
 
 <?php
-plugin_hook('admin_project_link',$group_id) ;
+plugin_hook('hierarchy_views', array($group_id, 'admin'));
 
 echo $HTML->boxBottom();?>
 
@@ -302,5 +308,3 @@ project_admin_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
