@@ -22,7 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'project/admin/project_admin_utils.php';
 require_once $gfwww.'include/role_utils.php';
@@ -61,14 +61,14 @@ if (count($newids) > 0) {
 $accumulated_ids = array_unique($accumulated_ids);
 
 if (getStringFromRequest('finished')) {
-    session_redirect('/project/admin/massfinish.php?group_id='.$group_id.'&accumulated_ids='.implode(',',$accumulated_ids));
+	session_redirect('/project/admin/massfinish.php?group_id='.$group_id.'&accumulated_ids='.implode(',',$accumulated_ids));
 }
 
 project_admin_header(array('title'=>_('Add Users From List'),'group'=>$group_id));
 
 echo '
 <p>
-'._('Check the box next to the name of the user(s) you want to add. Your choices will be preserved if you click any of the letters below. When done, click "Finish" to choose the roles for the users you are adding.').'
+'._('Check the box next to the name of the user(s) you want to add. Your choices will be preserved if you click any of the letters below. When done, click “Finish” to choose the roles for the users you are adding.').'
 </p>
 <form action="'.getStringFromServer('PHP_SELF').'?group_id='.$group_id.'" method="post">
 <input type="hidden" name="accumulated_ids" value="'. implode(',',$accumulated_ids) .'" />';
@@ -87,9 +87,9 @@ if (!$res || db_numrows($res) < 1) {
 	echo '<p>' . _('No Matching Users Found') . '</p>';
 } else {
 
-	$titles[]=_('Real name');
-	$titles[]=_('Unix name');
-	$titles[]=_('Add user');
+	$titles[]=_('Real Name');
+	$titles[]=_('Unix Name');
+	$titles[]=_('Add User');
 
 	echo $HTML->listTableTop($titles);
 
@@ -122,5 +122,3 @@ project_admin_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
