@@ -4,6 +4,7 @@
  *
  * Copyright 2010 (c) Alcatel-Lucent
  * Copyright 2011, Roland Mas
+ * Copyright 2014, Franck Villaume - TrivialDev
  *
  * @author Alain Peyrat
  * @date 2010-05-18
@@ -24,7 +25,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'project/admin/project_admin_utils.php';
 require_once $gfcommon.'include/Role.class.php';
@@ -58,14 +59,16 @@ if ($role->getHomeProject()->getID() != $group_id) {
 
 if (getStringFromRequest('submit')) {
 	if (getIntFromRequest('sure')) {
+		$role_name = $role->getName();
 		if (!$role->delete()) {
-			$error_msg = _('ERROR: ').$role->getErrorMessage();
+			$error_msg = _('Error')._(': ').$role->getErrorMessage();
 		} else {
 			$feedback = _('Successfully Deleted Role');
+			$group->addHistory(_('Deleted Role'), $role_name);
 			session_redirect('/project/admin/users.php?group_id='.$group_id.'&feedback='.urlencode($feedback));
 		}
 	} else {
-		$error_msg = _('Error: Please check "I\'m Sure" to confirm or return to previous page to cancel.');
+		$error_msg = _('Error: Please check “I am Sure” to confirm or return to previous page to cancel.');
 	}
 
 	session_redirect('/project/admin/users.php?group_id='.$group_id.'&error_msg='.urlencode($error_msg));
@@ -76,14 +79,27 @@ project_admin_header(array('title'=>$title,'group'=>$group_id));
 
 printf(_('You are about to permanently delete role %s'), $role->getName()); ?>
 
+<table class="centered">
+<tr>
+<td>
+<fieldset>
+<legend><?php echo _('Confirm Delete') ?></legend>
 <form action="<?php echo getStringFromServer('PHP_SELF') ?>?group_id=<?php echo $group_id ?>&amp;role_id=<?php echo $role_id ?>" method="post">
 <p>
-<input name="sure" value="1" type="checkbox" /><?php echo _("I'm Sure") ?><br />
+<input id="sure" type="checkbox" value="1" name="sure" />
+<label for="sure">
+<?php echo _('I am Sure'); ?>
+</label>
 </p>
 
 <p>
 <input type="submit" name="submit" value="<?php echo _('Submit') ?>" />
 </p>
 </form>
+</fieldset>
+</td>
+</tr>
+</table>
 
-<?php project_admin_footer(array()) ?>
+<?php
+project_admin_footer(array());
