@@ -7,6 +7,8 @@
  * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
  * Copyright © 2011
  *	Thorsten Glaser <t.glaser@tarent.de>
+ * Copyright 2014, Stéphane-Eymeric Bredthauer
+ * Copyright 2014, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -24,11 +26,10 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'project/admin/project_admin_utils.php';
 require_once $gfcommon.'include/Role.class.php';
-require_once $gfcommon.'include/RoleObserver.class.php';
 require_once $gfcommon.'include/rbac_texts.php';
 
 $group_id = getIntFromRequest('group_id');
@@ -43,148 +44,102 @@ if (getStringFromRequest('delete')) {
 	session_redirect('/project/admin/roledelete.php?group_id='.$group_id.'&role_id='.$role_id);
 }
 
-//
-//	The observer is a special role, which is actually
-//	just controlling the is_public/allow anon flags
-//
-//	Get observer role instead of regular role
-//
-if ($role_id=='observer') {
-	$role = new RoleObserver($group);
-	if (!$role || !is_object($role)) {
-		exit_error(_('Could Not Get RoleObserver'),'admin');
-	} elseif ($role->isError()) {
-		exit_error($role->getErrorMessage(),'admin');
-	}
-
-	if (getStringFromRequest('submit')) {
-		if (!$role->update($data)) {
-			$error_msg = $role->getErrorMessage();
-		} else {
-			$feedback = _('Successfully Updated Role');
-		}
-	}
+if (getStringFromRequest('add')) {
+	$role_name = trim(getStringFromRequest('role_name')) ;
+	$role = new Role ($group) ;
+	$role_id=$role->createDefault($role_name) ;
 } else {
-	if (USE_PFO_RBAC) {
-		if (getStringFromRequest('add')) {
-			$role_name = trim(getStringFromRequest('role_name')) ;
-			$role = new Role ($group) ;
-			$role_id=$role->createDefault($role_name) ;
-		} else {
-			$role = RBACEngine::getInstance()->getRoleById($role_id) ;
-		}
-	} else {
-		$role = new Role($group,$role_id);
-	}
-	if (!$role || !is_object($role)) {
-		exit_error(_('Could Not Get Role'),'admin');
-	} elseif ($role->isError()) {
-		exit_error($role->getErrorMessage(),'admin');
-	}
+	$role = RBACEngine::getInstance()->getRoleById($role_id) ;
+}
+if (!$role || !is_object($role)) {
+	exit_error(_('Could Not Get Role'),'admin');
+} elseif ($role->isError()) {
+	exit_error($role->getErrorMessage(),'admin');
+}
 
-	$old_data = $role->getSettingsForProject ($group) ;
-	$new_data = array () ;
+$old_data = $role->getSettingsForProject ($group) ;
+$new_data = array () ;
 
-	if (!is_array ($data)) {
-		$data = array () ;
+if (!is_array ($data)) {
+	$data = array () ;
+}
+foreach ($old_data as $section => $values) {
+	if (!array_key_exists ($section, $data)) {
+		continue ;
 	}
-	foreach ($old_data as $section => $values) {
-		if (!array_key_exists ($section, $data)) {
+	foreach ($values as $ref_id => $val) {
+		if (!array_key_exists ($ref_id, $data[$section])) {
 			continue ;
 		}
-		foreach ($values as $ref_id => $val) {
-			if (!array_key_exists ($ref_id, $data[$section])) {
-				continue ;
-			}
-			$new_data[$section][$ref_id] = $data[$section][$ref_id] ;
-		}
+		$new_data[$section][$ref_id] = $data[$section][$ref_id] ;
 	}
-	$data = $new_data ;
-	if (getStringFromRequest('submit')) {
-		if (($role->getHomeProject() != NULL)
-		    && ($role->getHomeProject()->getID() == $group_id)) {
-			$role_name = trim(getStringFromRequest('role_name'));
-			$public = getIntFromRequest('public') ? true : false ;
-		} else {
-			$role_name = $role->getName() ;
-			$public = $role->isPublic() ;
-		}
-		if (!$role_name) {
-			$error_msg .= ' Missing Role Name ';
-		} else {
+}
+$data = $new_data ;
+if (getStringFromRequest('submit')) {
+	if (($role->getHomeProject() != NULL)
+		&& ($role->getHomeProject()->getID() == $group_id)) {
+		$role_name = trim(getStringFromRequest('role_name'));
+		$public = getIntFromRequest('public') ? true : false ;
+	} else {
+		$role_name = $role->getName() ;
+		$public = $role->isPublic() ;
+	}
+	if (!$role_name) {
+		$error_msg .= _('Missing Role Name');
+	} else {
+		if (!$role_id) {
+			$role_id = $role->create($role_name, $data);
 			if (!$role_id) {
-				$role_id=$role->create($role_name,$data);
-				if (!$role_id) {
-					$error_msg .= $role->getErrorMessage();
-				} else {
-					$feedback = _('Successfully Created New Role');
-				}
+				$error_msg .= $role->getErrorMessage();
 			} else {
-				if ($role instanceof RoleExplicit) {
-					$role->setPublic($public) ;
-				}
-				if (!$role->update($role_name,$data,false)) {
-					$error_msg .= $role->getErrorMessage();
-				} else {
-					$feedback = _('Successfully Updated Role');
-				}
+				$feedback = _('Successfully Created New Role');
+				$group->addHistory(_('Added Role'), $role_name);
+			}
+		} else {
+			if ($role instanceof RoleExplicit) {
+				$role->setPublic($public) ;
+			}
+			if (!$role->update($role_name, $data, false)) {
+				$error_msg .= $role->getErrorMessage();
+			} else {
+				$feedback = _('Successfully Updated Role');
+				$group->addHistory(_('Updated Role'), $role_name);
 			}
-			//plugin webcal
-			//change assistant for webcal
-			$params = getIntFromRequest('group_id');
-			plugin_hook('change_cal_permission_auto',$params);
 		}
 	}
 }
 
-if ($role_id=='observer') {
-	$title= _('Edit Observer');
-	$msg = _('Use this page to edit the permissions and access levels of non-members of your project. Non-members includes users who are not logged in.');
+if (!$role_id) {
+	$title= _('New Role');
 } else {
-	if (!$role_id) {
-		$title= _('New Role');
-	} else {
-		$title= _('Edit Role');
-	}
-	if (USE_PFO_RBAC) {
-		$msg = _('Use this page to edit the permissions attached to each role.  Note that each role has at least as much access as the Anonymous and LoggedIn roles.  For example, if the Anonymous role has read access to a forum, all other roles will have it too.');
-	} else {
-		$msg = _('Use this page to edit your project\'s Roles. Note that each member has at least as much access as the Observer. For example, if the Observer can read CVS, so can any other role in the project.');
-	}
+	$title= _('Edit Role');
 }
+$msg = _('Use this page to edit the permissions attached to each role.  Note that each role has at least as much access as the Anonymous and LoggedIn roles.  For example, if the Anonymous role has read access to a forum, all other roles will have it too.');
 
-project_admin_header(array('title'=> $title,'group'=>$group_id));
+project_admin_header(array('title'=> $title, 'group'=>$group_id));
 
 echo '<p>'.$msg.'</p>';
 echo '
 <form action="'.getStringFromServer('PHP_SELF').'?group_id='.$group_id.'&amp;role_id='. $role_id .'" method="post">';
 
-if (USE_PFO_RBAC) {
-	if ($role->getHomeProject() == NULL
-	    || $role->getHomeProject()->getID() != $group_id) {
-		echo '<p><strong>'._('Role Name').'</strong></p>' ;
-		echo $role->getDisplayableName ($group) ;
-	} else {
-		echo '<p><strong>'._('Role Name').'</strong><br /><input type="text" name="role_name" value="'.$role->getName().'" /><br />' ;
-		echo '<input type="checkbox" name="public" value="1"' ;
-		if ($role->isPublic()) {
-			echo ' checked="checked"' ;
-		}
-		echo ' /> '._('Shared role (can be referenced by other projects)').'</p>' ;
-	}
+if ($role->getHomeProject() == NULL
+    || $role->getHomeProject()->getID() != $group_id) {
+	echo '<p><strong>'._('Role Name').'</strong></p>' ;
+	echo $role->getDisplayableName ($group) ;
 } else {
-	if ($role_id != 'observer') {
-		echo '<p><strong>'._('Role Name').'</strong><br />
-	<input type="text" name="role_name" value="'.$role->getName().'" />
-	</p>';
+	echo '<p><strong>'._('Role Name').'</strong><br /><input type="text" name="role_name" value="'.$role->getName().'" required="required" /><br />' ;
+	echo '<input type="checkbox" name="public" value="1"' ;
+	if ($role->isPublic()) {
+		echo ' checked="checked"' ;
 	}
+	echo ' /> '._('Shared role (can be referenced by other projects)').'</p>' ;
 }
 
 $titles[]=_('Section');
 $titles[]=_('Subsection');
 $titles[]=_('Setting');
 
-setup_rbac_strings () ;
+setup_rbac_strings();
 
 echo $HTML->listTableTop($titles);
 
@@ -194,18 +149,14 @@ echo $HTML->listTableTop($titles);
 //	Everything is built on the multi-dimensial arrays in the Role object
 //
 $j = 0;
-if (USE_PFO_RBAC) {
-	$keys = array_keys($role->getSettingsForProject ($group)) ;
-	$keys2 = array () ;
-	foreach ($keys as $key) {
-		if (!in_array ($key, $role->global_settings)) {
-			$keys2[] = $key ;
-		}
+$keys = array_keys($role->getSettingsForProject ($group)) ;
+$keys2 = array () ;
+foreach ($keys as $key) {
+	if (!in_array ($key, $role->global_settings)) {
+		$keys2[] = $key ;
 	}
-	$keys = $keys2 ;
-} else {
-	$keys = array_keys($role->role_values);
 }
+$keys = $keys2 ;
 for ($i=0; $i<count($keys); $i++) {
         if ((!$group->usesForum() && preg_match("/forum/", $keys[$i])) ||
                 (!$group->usesTracker() && preg_match("/tracker/", $keys[$i])) ||
@@ -233,7 +184,7 @@ for ($i=0; $i<count($keys); $i++) {
 		if ($keys[$i] == 'forumanon') {
 			//skip as we have special case below
 		} else {
-			$res=db_query_params ('SELECT group_forum_id,forum_name,is_public,allow_anonymous 
+			$res=db_query_params ('SELECT group_forum_id,forum_name
 				FROM forum_group_list WHERE group_id=$1',
 			array($group_id));
 			for ($q=0; $q<db_numrows($res); $q++) {
@@ -254,9 +205,9 @@ for ($i=0; $i<count($keys); $i++) {
 				<td style="padding-left: 4em;">'.$rbac_edit_section_names[$keys[$i]].'</td>
 				<td>'.db_result($res,$q,'forum_name').'</td>
 				<td>'.html_build_select_box_from_assoc(
-					$role->getRoleVals($keys[$i]), 
-					"data[".$keys[$i]."][".db_result($res,$q,'group_forum_id')."]", 
-					$role->getVal($keys[$i],db_result($res,$q,'group_forum_id')), 
+					$role->getRoleVals($keys[$i]),
+					"data[".$keys[$i]."][".db_result($res,$q,'group_forum_id')."]",
+					$role->getVal($keys[$i],db_result($res,$q,'group_forum_id')),
 					false, false ). $txt .'</td></tr>';
 			}
 		}
@@ -265,7 +216,7 @@ for ($i=0; $i<count($keys); $i++) {
 //
 	} elseif ($keys[$i] == 'pm' || $keys[$i] == 'pmpublic') {
 
-		$res=db_query_params ('SELECT group_project_id,project_name,is_public 
+		$res=db_query_params ('SELECT group_project_id,project_name
 			FROM project_group_list WHERE group_id=$1',
 			array($group_id));
 		for ($q=0; $q<db_numrows($res); $q++) {
@@ -273,9 +224,9 @@ for ($i=0; $i<count($keys); $i++) {
 			<td style="padding-left: 4em;">'.$rbac_edit_section_names[$keys[$i]].'</td>
 			<td>'.db_result($res,$q,'project_name').'</td>
 			<td>'.html_build_select_box_from_assoc(
-				$role->getRoleVals($keys[$i]), 
-				"data[".$keys[$i]."][".db_result($res,$q,'group_project_id')."]", 
-				$role->getVal($keys[$i],db_result($res,$q,'group_project_id')), 
+				$role->getRoleVals($keys[$i]),
+				"data[".$keys[$i]."][".db_result($res,$q,'group_project_id')."]",
+				$role->getVal($keys[$i],db_result($res,$q,'group_project_id')),
 				false, false ).'</td></tr>';
 		}
 
@@ -287,7 +238,7 @@ for ($i=0; $i<count($keys); $i++) {
 		if ($keys[$i] == 'trackeranon') {
 			//skip as we have special case below
 		} else {
-			$res=db_query_params ('SELECT group_artifact_id,name,is_public,allow_anon
+			$res=db_query_params ('SELECT group_artifact_id,name
 				FROM artifact_group_list WHERE group_id=$1',
 			array($group_id));
 			for ($q=0; $q<db_numrows($res); $q++) {
@@ -308,9 +259,9 @@ for ($i=0; $i<count($keys); $i++) {
 				<td style="padding-left: 4em;">'.$rbac_edit_section_names[$keys[$i]].'</td>
 				<td>'.db_result($res,$q,'name').'</td>
 				<td>'.html_build_select_box_from_assoc(
-					$role->getRoleVals($keys[$i]), 
-					"data[".$keys[$i]."][".db_result($res,$q,'group_artifact_id')."]", 
-					$role->getVal($keys[$i],db_result($res,$q,'group_artifact_id')), 
+					$role->getRoleVals($keys[$i]),
+					"data[".$keys[$i]."][".db_result($res,$q,'group_artifact_id')."]",
+					$role->getVal($keys[$i],db_result($res,$q,'group_artifact_id')),
 					false, false ). $txt .'</td></tr>';
 			}
 		}
@@ -320,7 +271,7 @@ for ($i=0; $i<count($keys); $i++) {
 //
 	} elseif ($keys[$i] == 'frspackage') {
 
-		$res=db_query_params ('SELECT package_id,name,is_public 
+		$res=db_query_params ('SELECT package_id,name,is_public
 			FROM frs_package WHERE group_id=$1',
 			array($group_id));
 		for ($q=0; $q<db_numrows($res); $q++) {
@@ -328,9 +279,9 @@ for ($i=0; $i<count($keys); $i++) {
 			<td>'.$rbac_edit_section_names[$keys[$i]].'</td>
 			<td>'.db_result($res,$q,'name').'</td>
 			<td>'.html_build_select_box_from_assoc(
-				$role->getRoleVals($keys[$i]), 
-				"data[".$keys[$i]."][".db_result($res,$q,'package_id')."]", 
-				$role->getVal($keys[$i],db_result($res,$q,'package_id')), 
+				$role->getRoleVals($keys[$i]),
+				"data[".$keys[$i]."][".db_result($res,$q,'package_id')."]",
+				$role->getVal($keys[$i],db_result($res,$q,'package_id')),
 				false, false ).'</td></tr>';
 		}
 
@@ -342,11 +293,7 @@ for ($i=0; $i<count($keys); $i++) {
 		echo '<tr '. $HTML->boxGetAltRowStyle($j++) . '>
 		<td colspan="2"><strong>'.$rbac_edit_section_names[$keys[$i]].'</strong></td>
 		<td>';
-        	if (USE_PFO_RBAC) {
-			echo html_build_select_box_from_assoc($role->getRoleVals($keys[$i]), "data[".$keys[$i]."][$group_id]", $role->getVal($keys[$i],$group_id), false, false ) ;
-                } else {
-			echo html_build_select_box_from_assoc($role->getRoleVals($keys[$i]), "data[".$keys[$i]."][0]", $role->getVal($keys[$i],0), false, false ) ;
-                }
+		echo html_build_select_box_from_assoc($role->getRoleVals($keys[$i]), "data[".$keys[$i]."][$group_id]", $role->getVal($keys[$i],$group_id), false, false ) ;
 		echo '</td>
 		</tr>';
 
@@ -365,5 +312,3 @@ project_admin_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
