@@ -1,13 +1,16 @@
 <?php
-/*-
- * Project Admin Main Page
+/**
+ * Project Admin Users Page
  *
  * Copyright 2004 GForge, LLC
  * Copyright 2006 federicot
  * Copyright © 2011
  *	Thorsten Glaser <t.glaser@tarent.de>
  * Copyright 2011, Roland Mas
+ * Copyright 2014, Stéphane-Eymeric Bredthauer
+ * Copyright 2014, Franck Villaume - TrivialDev
  * All rights reserved.
+ * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -29,7 +32,7 @@
  * members, but only admins may perform most functions.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'project/admin/project_admin_utils.php';
 require_once $gfwww.'include/role_utils.php';
@@ -37,16 +40,13 @@ require_once $gfcommon.'include/account.php';
 require_once $gfcommon.'include/GroupJoinRequest.class.php';
 
 $group_id = getIntFromRequest('group_id');
-$feedback = htmlspecialchars(getStringFromRequest('feedback'));
-$warnig_msg = htmlspecialchars(getStringFromRequest('warnig_msg'));
-$error_msg = htmlspecialchars(getStringFromRequest('error_msg'));
 
 session_require_perm ('project_admin', $group_id) ;
 
 // get current information
 $group = group_get_object($group_id);
 if (!$group || !is_object($group)) {
-    exit_no_group();
+	exit_no_group();
 } elseif ($group->isError()) {
 	exit_error($group->getErrorMessage(),'admin');
 }
@@ -62,44 +62,40 @@ if (plugin_hook_listeners("project_admin_users") > 0) {
 function cache_external_roles () {
 	global $used_external_roles, $unused_external_roles, $group, $group_id;
 
-	if (USE_PFO_RBAC) {
-		$unused_external_roles = array () ;
-		foreach (RBACEngine::getInstance()->getPublicRoles() as $r) {
-			$grs = $r->getLinkedProjects () ;
-			$seen = false ;
-			foreach ($grs as $g) {
-				if ($g->getID() == $group_id) {
-					$seen = true ;
-					break ;
-				}
-			}
-			if (!$seen) {
-				$unused_external_roles[] = $r ;
+	$unused_external_roles = array () ;
+	foreach (RBACEngine::getInstance()->getPublicRoles() as $r) {
+		$grs = $r->getLinkedProjects () ;
+		$seen = false ;
+		foreach ($grs as $g) {
+			if ($g->getID() == $group_id) {
+				$seen = true ;
+				break ;
 			}
 		}
-		$used_external_roles = array () ;
-		foreach ($group->getRoles() as $r) {
-			if ($r->getHomeProject() == NULL
-			    || $r->getHomeProject()->getID() != $group_id) {
-				$used_external_roles[] = $r ;
-			}
+		if (!$seen) {
+			$unused_external_roles[] = $r ;
 		}
-
-		sortRoleList ($used_external_roles, $group, 'composite') ;
-		sortRoleList ($unused_external_roles, $group, 'composite') ;
-
 	}
+	$used_external_roles = array () ;
+	foreach ($group->getRoles() as $r) {
+		if ($r->getHomeProject() == NULL
+		    || $r->getHomeProject()->getID() != $group_id) {
+			$used_external_roles[] = $r ;
+		}
+	}
+
+	sortRoleList ($used_external_roles, $group, 'composite') ;
+	sortRoleList ($unused_external_roles, $group, 'composite') ;
+
 }
 
 cache_external_roles () ;
 
 if (getStringFromRequest('submit')) {
 	if (getStringFromRequest('adduser')) {
-		/*
-			add user to this project
-			*/
+		/* Add user to this project */
 		$form_unix_name = getStringFromRequest('form_unix_name');
-		$user_object = &user_get_object_by_name($form_unix_name);
+		$user_object = user_get_object_by_name($form_unix_name);
 		if ($user_object === false) {
 			$warning_msg .= _('No Matching Users Found');
 		} else {
@@ -122,8 +118,8 @@ if (getStringFromRequest('submit')) {
 				}
 			}
 		}
-	} else if (getStringFromRequest('rmuser')) {
-		/* remove a member from this project */
+	} elseif (getStringFromRequest('rmuser')) {
+		/* Remove a member from this project */
 		$user_id = getIntFromRequest('user_id');
 		$role_id = getIntFromRequest('role_id');
 		$role = RBACEngine::getInstance()->getRoleById($role_id) ;
@@ -137,7 +133,7 @@ if (getStringFromRequest('submit')) {
 		} else {
 			$feedback = _("Member Removed Successfully");
 		}
-	} else if (getStringFromRequest('updateuser')) {
+	} elseif (getStringFromRequest('updateuser')) {
 		/* Adjust Member Role */
 		$user_id = getIntFromRequest('user_id');
 		$role_id = getIntFromRequest('role_id');
@@ -152,9 +148,7 @@ if (getStringFromRequest('submit')) {
 			}
 		}
 	} elseif (getStringFromRequest('acceptpending')) {
-		/*
-			add user to this project
-			*/
+		/* Add user to this project */
 		$role_id = getIntFromRequest('role_id');
 		if (!$role_id) {
 			$warning_msg .= _("Role not selected");
@@ -174,9 +168,7 @@ if (getStringFromRequest('submit')) {
 			}
 		}
 	} elseif (getStringFromRequest('rejectpending')) {
-		/*
-			reject adding user to this project
-			*/
+		/* Reject adding user to this project */
 		$form_userid = getIntFromRequest('form_userid');
 		$gjr=new GroupJoinRequest($group,$form_userid);
 		if (!$gjr || !is_object($gjr) || $gjr->isError()) {
@@ -185,36 +177,34 @@ if (getStringFromRequest('submit')) {
 			if (!$gjr->reject()) {
 				$error_msg = $gjr->getErrorMessage();
 			} else {
-				$feedback .= 'Rejected';
+				$feedback .= _('Rejected');
 			}
 		}
-	} else if (getStringFromRequest('linkrole')) {
+	} elseif (getStringFromRequest('linkrole')) {
 		/* link a role to this project */
-		if (USE_PFO_RBAC) {
-			$role_id = getIntFromRequest('role_id');
-			foreach ($unused_external_roles as $r) {
-				if ($r->getID() == $role_id) {
-					if (!$r->linkProject($group)) {
-						$error_msg = $r->getErrorMessage();
-					} else {
-						$feedback = _("Role linked successfully");
-						cache_external_roles () ;
-					}
+		$role_id = getIntFromRequest('role_id');
+		foreach ($unused_external_roles as $r) {
+			if ($r->getID() == $role_id) {
+				if (!$r->linkProject($group)) {
+					$error_msg = $r->getErrorMessage();
+				} else {
+					$feedback = _("Role linked successfully");
+					$group->addHistory(_('Linked Role'), $r->getName());
+					cache_external_roles () ;
 				}
 			}
 		}
-	} else if (getStringFromRequest('unlinkrole')) {
+	} elseif (getStringFromRequest('unlinkrole')) {
 		/* unlink a role from this project */
-		if (USE_PFO_RBAC) {
-			$role_id = getIntFromRequest('role_id');
-			foreach ($used_external_roles as $r) {
-				if ($r->getID() == $role_id) {
-					if (!$r->unLinkProject($group)) {
-						$error_msg = $r->getErrorMessage();
-					} else {
-						$feedback = _("Role unlinked successfully");
-						cache_external_roles () ;
-					}
+		$role_id = getIntFromRequest('role_id');
+		foreach ($used_external_roles as $r) {
+			if ($r->getID() == $role_id) {
+				if (!$r->unLinkProject($group)) {
+					$error_msg = $r->getErrorMessage();
+				} else {
+					$feedback = _("Role unlinked successfully");
+					$group->addHistory(_('Unlinked Role'), $r->getName());
+					cache_external_roles () ;
 				}
 			}
 		}
@@ -286,7 +276,7 @@ project_admin_header(array('title'=>sprintf(_('Members of %s'), $group->getPubli
 			method="post">
 		<input type="hidden" name="submit" value="y" />
 		<div style="float:left;">
-			<input type="text" name="form_unix_name" size="16" value="" />
+			<input type="text" name="form_unix_name" size="16" value="" required="required" />
 		</div><div style="float:right;">
 			<?php echo role_box($group_id,'role_id'); ?>
 			<input type="submit" name="adduser" value="<?php echo _("Add Member") ?>" />
@@ -311,7 +301,7 @@ project_admin_header(array('title'=>sprintf(_('Members of %s'), $group->getPubli
 $members = $group->getUsers() ;
 
 echo '<table width="100%"><thead><tr>';
-echo '<th>'._('User name').'</th>';
+echo '<th>'._('User Name').'</th>';
 echo '<th>'._('Role').'</th>';
 echo '<th style="text-align:right">'._('Action').'</th>';
 echo '</tr></thead><tbody>';
@@ -319,7 +309,7 @@ echo '</tr></thead><tbody>';
 $i = 0;
 foreach ($members as $user) {
 	$i++;
-	
+
 	$roles = array () ;
 	foreach (RBACEngine::getInstance()->getAvailableRolesForUser ($user) as $role) {
 		if ($role->getHomeProject() && $role->getHomeProject()->getID() == $group->getID()) {
@@ -380,19 +370,13 @@ echo '</tbody></table>';
 		?></td>
 		<td><?php
 
-
-
-
-
-
-
 		//
 		//      RBAC Editing Functions
 		//
 		echo $HTML->boxTop(_("Edit Roles"));
 
 echo '<table width="100%"><thead><tr>';
-echo '<th>'._('Role name').'</th>';
+echo '<th>'._('Role Name').'</th>';
 echo '<th style="text-align:right">'._('Action').'</th>';
 echo '</tr></thead><tbody>';
 
@@ -418,7 +402,7 @@ foreach ($roles as $r) {
 		<input type="submit" name="edit" value="'._("Edit Permissions").'" />
 	</div>
 	</form>';
-	
+
 	if ($r->getHomeProject() != NULL && $r->getHomeProject()->getId() == $group_id) {
 		echo '<form action="roledelete.php?group_id='. $group_id .'" method="post">
         <div style="float:right;">
@@ -435,7 +419,7 @@ foreach ($roles as $r) {
 echo '<tr><td colspan="2">
 	<form action="roleedit.php?group_id='. $group_id .'" method="post">
 	<div style="float:left;">
-		<input type="text" name="role_name" size="10" value="" />
+		<input type="text" name="role_name" size="10" value="" required="required" />
 	</div><div style="float:right;">
 		<input type="submit" name="add" value="'._("Create Role").'" />
 	</div>
@@ -444,18 +428,18 @@ echo '<tr><td colspan="2">
 
 echo '</tbody></table>' ;
 
-if (!USE_PFO_RBAC) {
-		echo '
-        <form action="roleedit.php?group_id='. $group_id .'&amp;role_id=observer" method="post">
-        <p><input type="submit" name="edit" value="'._("Edit Observer").'" /></p>
-        </form>';
-}
+//TODO: What is the observer ? role_id is a numeric.
+//      Something is missing here.
+//      Code commented by nerville : 20140314.
+// echo '
+//         <form action="roleedit.php?group_id='. $group_id .'&amp;role_id=observer" method="post">
+//         <p><input type="submit" name="edit" value="'._("Edit Observer").'" /></p>
+//         </form>';
 
-if (USE_PFO_RBAC) {
-	if (count ($used_external_roles)) {
-		echo $HTML->boxMiddle(_("Currently used external roles"));
+if (count ($used_external_roles)) {
+	echo $HTML->boxMiddle(_("Currently used external roles"));
 echo '<table width="100%"><thead><tr>';
-echo '<th>'._('Role name').'</th>';
+echo '<th>'._('Role Name').'</th>';
 echo '<th style="text-align:right">'._('Action').'</th>';
 echo '</tr></thead><tbody>';
 
@@ -479,7 +463,7 @@ echo '</tbody></table>' ;
 	if (count ($unused_external_roles)) {
 		echo $HTML->boxMiddle(_("Available external roles"));
 echo '<table width="100%"><thead><tr>';
-echo '<th>'._('Role name').'</th>';
+echo '<th>'._('Role Name').'</th>';
 echo '<th style="text-align:right">'._('Action').'</th>';
 echo '</tr></thead><tbody>';
 
@@ -504,7 +488,6 @@ echo '
 </td></tr>';
 echo '</tbody></table>' ;
 	}
-}
 
 echo $HTML->boxBottom();
 ?></td>
@@ -520,5 +503,3 @@ project_admin_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
