@@ -4,6 +4,7 @@
  *
  * Portions Copyright 1999-2001 (c) VA Linux Systems
  * The rest Copyright 2002-2004 (c) GForge Team
+ * Copyright 2014, Franck Villaume - TrivialDev
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -22,7 +23,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'project/admin/project_admin_utils.php';
 
@@ -37,7 +38,7 @@ $group = group_get_object($group_id);
 
 if (!$group || !is_object($group)) {
         exit_error('Error','Error creating group object');
-} else if ($group->isError()) {
+} elseif ($group->isError()) {
         exit_error('ERROR',$group->getErrorMessage());
 }
 
@@ -62,7 +63,7 @@ if (getStringFromRequest('createvhost')) {
 
 	} else {
 
-		$feedback .= sprintf(_('Not a valid hostname - %1$s'), $vhost_name);
+		$feedback .= sprintf(_('Not a valid hostname - %s'), $vhost_name);
 
 	}
 }
@@ -74,8 +75,8 @@ if (getStringFromRequest('deletevhost')) {
 	//schedule for deletion
 
 	$res =	db_query_params ('
-		SELECT * 
-		FROM prweb_vhost 
+		SELECT *
+		FROM prweb_vhost
 		WHERE vhostid=$1
 	',
 			array($vhostid));
@@ -83,8 +84,8 @@ if (getStringFromRequest('deletevhost')) {
 	$row_vh = db_fetch_array($res);
 
 	$res = db_query_params ('
-		DELETE FROM prweb_vhost 
-		WHERE vhostid=$1 
+		DELETE FROM prweb_vhost
+		WHERE vhostid=$1
 		AND group_id=$2
 	',
 			array($vhostid,
@@ -109,16 +110,16 @@ printf(_('To add a new virtual host - simply point a <strong>CNAME</strong> for
 print '</p>';
 
 print '<p>';
-printf(_('Clicking on "create" will schedule the creation of the Virtual Host.  This will be synced to the project webservers - such that <em>yourhost.org</em> will display the material at <em>%1$s.%2$s</em>.'), $group->getUnixName(), forge_get_config ('web_host'));
+printf(_('Clicking on “Create” will schedule the creation of the Virtual Host.  This will be synced to the project webservers - such that <em>yourhost.org</em> will display the material at <em>%1$s.%2$s</em>.'), $group->getUnixName(), forge_get_config ('web_host'));
 print '</p>';
 
 ?>
 
-<form name="new_vhost" action="<?php echo getStringFromServer('PHP_SELF').'?group_id='.$group->getID().'&amp;createvhost=1'; ?>" method="post"> 
-<table border="0">
+<form name="new_vhost" action="<?php echo getStringFromServer('PHP_SELF').'?group_id='.$group->getID().'&amp;createvhost=1'; ?>" method="post">
+<table>
 <tr>
 	<td> <?php echo _('New Virtual Host <em>(e.g. vhost.org)</em>') ?> </td>
-	<td> <input type="text" size="15" maxlength="255" name="vhost_name" /> </td>
+	<td> <input type="text" size="15" maxlength="255" name="vhost_name" required="required" /> </td>
 	<td> <input type="submit" value="<?php echo _('Create') ?>" /> </td>
 </tr>
 </table>
@@ -130,7 +131,7 @@ $res_db = db_query_params('
 	SELECT *
 	FROM prweb_vhost
 	WHERE group_id=$1', array($group->getID()));
-	
+
 if (db_numrows($res_db) > 0) {
 
 	$title=array();
@@ -143,7 +144,7 @@ if (db_numrows($res_db) > 0) {
 		print '	<tr>
 			<td>'.$row_db['vhost_name'].'</td>
 			<td>[ <strong><a href="'.getStringFromServer('PHP_SELF').'?group_id='.$group->getID().'&amp;vhostid='.$row_db['vhostid'].'&amp;deletevhost=1">'._('Delete').'</a></strong>]
-			</tr>	
+			</tr>
 		';
 
 	}
@@ -155,5 +156,3 @@ if (db_numrows($res_db) > 0) {
 }
 
 project_admin_footer(array());
-
-?>
