@@ -4,6 +4,7 @@
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2002-2004 (c) GForge Team
+ * Copyright 2014, Franck Villaume - TrivialDev
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -22,7 +23,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 
 $group_id = getIntFromGet("group_id");
@@ -32,12 +33,14 @@ if (!$group_id && $form_grp) {
 	$group_id = $form_grp;
 }
 
+session_require_perm('project_read', $group_id);
+
 site_project_header(array('title'=>_('Project Member List'),'group'=>$group_id,'toptab'=>'memberlist'));
 
-echo '<p>' . _('If you would like to contribute to this project by becoming a developer, contact one of the project admins, designated in bold text below.') . '</p>';
+echo '<p>' . _('If you would like to contribute to this project by becoming a member, contact one of the project admins, designated in bold text below.') . '</p>';
 
 // beginning of the user descripion block
-$project =& group_get_object($group_id);
+$project = group_get_object($group_id);
 $project_stdzd_uri = util_make_url_g ($project->getUnixName(), $group_id);
 $usergroup_stdzd_uri = $project_stdzd_uri.'members/';
 print '<div about="'. $usergroup_stdzd_uri .'" typeof="sioc:UserGroup">';
@@ -47,7 +50,7 @@ print '</div>';
 
 $title_arr=array();
 $title_arr[]=_('Member');
-$title_arr[]=_('Username');
+$title_arr[]=_('User Name');
 $title_arr[]=_('Role(s)/Position(s)');
 if(forge_get_config('use_people')) {
 	$title_arr[]=_('Skills');
@@ -78,8 +81,7 @@ foreach ($members as $user) {
 	}
 	echo "</div>\n";
 	echo '</td>';
-	
-	
+
 	/*
         print '<span property ="dc:Identifier" content="'.$user->getID().'">';
         echo '</span>';
@@ -88,19 +90,15 @@ foreach ($members as $user) {
         print '<span property="fusionforge:has_job" content="'.$role_string.'">';
         echo '</span>';*/
 
-	if (USE_PFO_RBAC) {
-		$roles = RBACEngine::getInstance()->getAvailableRolesForUser ($user) ;
-		sortRoleList ($roles) ;
-		$role_names = array () ;
-		foreach ($roles as $role) {
-			if ($role->getHomeProject() && $role->getHomeProject()->getID() == $project->getID()) {
-				$role_names[] = $role->getName() ;
-			}
+	$roles = RBACEngine::getInstance()->getAvailableRolesForUser ($user) ;
+	sortRoleList ($roles) ;
+	$role_names = array () ;
+	foreach ($roles as $role) {
+		if ($role->getHomeProject() && $role->getHomeProject()->getID() == $project->getID()) {
+			$role_names[] = $role->getName() ;
 		}
-		$role_string = implode (', ', $role_names) ;
-	} else {
-		$role_string = $user->getRole ($project)->getName() ;
 	}
+	$role_string = implode (', ', $role_names) ;
 
 	echo '<td>';
 	echo util_display_user($user->getUnixName(),$user->getID(),$user->getUnixName(), 's');
@@ -111,9 +109,7 @@ foreach ($members as $user) {
 	}
    	echo '</tr>';
 }
-// end of community member description block 
+// end of community member description block
 echo $GLOBALS['HTML']->listTableBottom();
 
 site_project_footer(array());
-
-?>
