@@ -22,8 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 #require_once('common/tracker/ArtifactGroup.class.php');
 
@@ -128,7 +127,7 @@ $title = _('Project Member List');
 site_project_header(array('title'=>$title,'group'=>$group_id,'toptab'=>'memberlist'));
 
 echo '<p>';
-echo _('If you would like to contribute to this project by becoming a developer, contact one of the project admins, designated in bold text below.');
+echo _('If you would like to contribute to this project by becoming a member, contact one of the project admins, designated in bold text below.');
 echo '</p>';
 
         $title_arr=array();
@@ -153,19 +152,15 @@ foreach ($group->getUsers() as $member) {
 		util_make_link ('/sendmessage.php?touser='.$member->getId(),
 				sprintf (_('Contact %s'),$member->getRealName())).'
 			</td>';
-	if (USE_PFO_RBAC) {
-		$roles = RBACEngine::getInstance()->getAvailableRolesForUser ($member) ;
-		sortRoleList ($roles) ;
-		$role_names = array () ;
-		foreach ($roles as $role) {
-			if ($role->getHomeProject() && $role->getHomeProject()->getID() == $group->getID()) {
-				$role_names[] = $role->getName() ;
-			}
+	$roles = RBACEngine::getInstance()->getAvailableRolesForUser ($member) ;
+	sortRoleList ($roles) ;
+	$role_names = array () ;
+	foreach ($roles as $role) {
+		if ($role->getHomeProject() && $role->getHomeProject()->getID() == $group->getID()) {
+			$role_names[] = $role->getName() ;
 		}
-		$role_string = implode (', ', $role_names) ;
-	} else {
-		$role_string = $user->getRole ($group)->getName() ;
 	}
+	$role_string = implode (', ', $role_names) ;
 
 				echo '
 			<td align="center">'.$role_string.'
@@ -178,7 +173,7 @@ foreach ($group->getUsers() as $member) {
 	echo '
 		</tr>';
 
-	// print out all the artifacts assigned to this person 
+	// print out all the artifacts assigned to this person
         $artifact_group=db_query_params("SELECT group_artifact_id, name
                                   FROM artifact_group_list
                                   WHERE group_id=$1
@@ -254,5 +249,3 @@ foreach ($group->getUsers() as $member) {
 echo $GLOBALS['HTML']->listTableBottom();
 
 site_project_footer(array());
-
-?>
