@@ -3,6 +3,7 @@
  * Project Membership Request
  *
  * Copyright 2005 (c) GForge, L.L.C.
+ * Copyright 2012, Franck Villaume - TrivialDev
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -21,7 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'include/GroupJoinRequest.class.php';
 
@@ -40,13 +41,13 @@ if (!session_loggedin()) {
 $group = group_get_object($group_id);
 
 if ($submit) {
-
 	$gjr=new GroupJoinRequest($group);
 	$usr=&session_get_user();
 	if (!$gjr->create($usr->getId(),$comments)) {
-		exit_error($gjr->getErrorMessage(),'summary');
+		session_redirect('/projects/'.$group->getUnixName().'/?error_msg='.urlencode($gjr->getErrorMessage()));
 	} else {
 		$feedback = _('Your request has been submitted.');
+		session_redirect('/projects/'.$group->getUnixName().'/?feedback='.urlencode($feedback));
 	}
 }
 
@@ -57,14 +58,14 @@ site_project_header(array('title'=>$title,'group'=>$group_id,'toptab'=>'summary'
 plugin_hook ("blocks", "request_join");
 
 ?>
-<p><?php 
+<p><?php
 $nbadmins = count($group->getAdmins());
 echo ngettext('You can request to join a project by clicking the submit button. The administrator will be emailed to approve or deny your request.', 'You can request to join a project by clicking the submit button. The administrators will be emailed to approve or deny your request.', $nbadmins); ?></p>
 <form action="<?php echo getStringFromServer('PHP_SELF')."?group_id=$group_id"; ?>" method="post">
 <p>
 <?php echo ngettext('You must send a comment to the administrator:', 'You must send a comment to the administrators:',$nbadmins); echo utils_requiredField(); ?>
 </p>
-<textarea name="comments" rows="15" cols="60"><?php echo $comments ?></textarea>
+<textarea name="comments" required="required" rows="15" cols="60"><?php echo $comments ?></textarea>
 <p>
 	<input type="submit" name="submit" value="<?php echo _('Submit'); ?>" />
 </p>
@@ -72,5 +73,3 @@ echo ngettext('You can request to join a project by clicking the submit button.
 <?php
 
 site_project_footer(array());
-
-?>
