@@ -5,6 +5,7 @@
  * Copyright 2003 GForge, LLC
  * Copyright 2010 (c) Franck Villaume - Capgemini
  * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2012-2013, Franck Villaume - TrivialDev
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -23,27 +24,30 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'reporting/report_utils.php';
 require_once $gfcommon.'reporting/Report.class.php';
+require_once $gfcommon.'reporting/ReportProjectAct.class.php';
 require_once $gfwww.'project/admin/project_admin_utils.php';
 
 $group_id = getIntFromRequest('group_id');
-if ( !$group_id ) {
+if (!$group_id) {
 	exit_no_group();
 }
 
+session_require_perm('project_admin', $group_id);
+
 $group = group_get_object($group_id);
 if (!$group || !is_object($group)) {
-    exit_no_group();
+	exit_no_group();
 } elseif ($group->isError()) {
 	exit_error($group->getErrorMessage(),'admin');
 }
 
 $report=new Report();
 if ($report->isError()) {
-    exit_error($report->getErrorMessage(),'admin');
+	exit_error($report->getErrorMessage(),'admin');
 }
 
 $area = getStringFromRequest('area');
@@ -54,8 +58,8 @@ $end = getIntFromRequest('end');
 /*
  * Set the start date to birth of the project.
  */
-$res=db_query_params('SELECT register_time FROM groups WHERE group_id=$1', array($group_id));
-$report->site_start_date=db_result($res,0,'register_time');
+$res = db_query_params('SELECT register_time FROM groups WHERE group_id=$1', array($group_id));
+$report->site_start_date = db_result($res,0,'register_time');
 
 if (!$start || !$end) $z =& $report->getMonthStartArr();
 
@@ -75,40 +79,51 @@ if (!$SPAN) {
 	if ($delta > 365) $SPAN=3;
 }
 
-$area = util_ensure_value_in_set ($area, array ('tracker','forum','docman','taskman','downloads')) ;
 if ($SPAN && !is_numeric($SPAN)) { $SPAN = 1; }
 if ($start && !is_numeric($start)) { $start = false; }
 if ($end && !is_numeric($end)) { $end = false; }
 
-$params['title'] = _('Project Statistics');
-$params['group'] = $group_id;
-$params['toptab'] = 'activity';
-$params['submenu'] = $HTML->subMenu(array(_('Statistics')), array('/project/stats/?group_id='.$group_id));
+if (!$group->usesStats()) {
+	exit_disabled('activity');
+}
 
-site_project_header($params);
+html_use_jqueryjqplotpluginCanvas();
+html_use_jqueryjqplotpluginhighlighter();
+html_use_jqueryjqplotplugindateAxisRenderer();
+html_use_jqueryjqplotpluginBar();
+
+project_admin_header(array('title'=>sprintf(_('Project Statistics for %s'), $group->getPublicName()),
+							'group'=>$group_id));
 
 //
 // BEGIN PAGE CONTENT CODE
 //
 ?>
-<div align="center">
-
 <form action="<?php echo getStringFromServer('PHP_SELF'); ?>" method="get">
-<input type="hidden" name="group_id" value="<?php echo $group_id; ?>" />
-<table><tr>
-<td><strong><?php echo _('Areas'); ?>:</strong><br /><?php echo report_area_box('area',$area,$group); ?></td>
-<td><strong><?php echo _('Type'); ?>:</strong><br /><?php echo report_span_box('SPAN',$SPAN); ?></td>
-<td><strong><?php echo _('Start'); ?>:</strong><br /><?php echo report_months_box($report, 'start', $start); ?></td>
-<td><strong><?php echo _('End'); ?>:</strong><br /><?php echo report_months_box($report, 'end', $end); ?></td>
-<td><input type="submit" name="submit" value="<?php echo _('Refresh'); ?>" /></td>
-</tr></table>
+<table class="centered">
+<tr>
+<td><strong><?php echo _('Area')._(':'); ?></strong><br /><?php echo report_area_box('area',$area,$group); ?></td>
+<td><strong><?php echo _('Type')._(':'); ?></strong><br /><?php echo report_span_box('SPAN',$SPAN); ?></td>
+<td><strong><?php echo _('Start Date')._(':'); ?></strong><br /><?php echo report_months_box($report, 'start', $start); ?></td>
+<td><strong><?php echo _('End Date')._(':'); ?></strong><br /><?php echo report_months_box($report, 'end', $end); ?></td>
+<td>
+	<input type="hidden" name="group_id" value="<?php echo $group_id; ?>" />
+	<input type="submit" name="submit" value="<?php echo _('Refresh'); ?>" />
+</td>
+</tr>
+</table>
 </form>
 <p>
-<img src="/reporting/projectact_graph.php?<?php echo "SPAN=$SPAN&amp;start=$start&amp;end=$end&amp;g_id=$group_id&amp;area=$area"; ?>" width="640" height="480" alt="stats graph" />
+<?php
+if ($start == $end) {
+	echo '<p class="error">'._('Start and end dates must be different').'</p>';
+} else {
+	if (!report_actgraph('project', $SPAN, $start, $end, $group_id, $area)) {
+		echo '<p class="error">'._('Error during graphic computation.');
+	}
+}
+?>
 </p>
-</div>
 <?php
 
-site_project_footer( array() );
-
-?>
+site_project_footer(array());
