@@ -3,6 +3,7 @@
  * SCM Frontend
  *
  * Copyright 2004 (c) Roland Mas, Tim Perdue -GForge LLC
+ * Copyright 2013, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -20,23 +21,36 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
-require_once $gfwww.'scm/include/scm_utils.php';    
+require_once $gfwww.'scm/include/scm_utils.php';
 
 $group_id = getIntFromRequest("group_id");
 $group = group_get_object($group_id);
 if (!$group || !is_object($group)) {
 	exit_no_group();
 }
-scm_header(array('title'=>_('SCM Repository'),'group'=>$group_id));
 
-plugin_hook ("blocks", "scm index");
+session_require_perm('scm', $group_id, 'read');
 
-$hook_params = array () ;
-$hook_params['group_id'] = $group_id ;
-plugin_hook ("scm_page", $hook_params) ;
+// Check if there is an associated scm plugin and issue a warning if none.
+$scm_plugin = '';
+foreach (PluginManager::instance()->GetPlugins() as $p) {
+	$plugin = PluginManager::instance()->GetPluginObject($p);
+	if (isset($plugin->provides['scm']) && $plugin->provides['scm'] && $group->usesPlugin($p)) {
+		$scm_plugin = $p;
+	}
+}
+if (!$scm_plugin) {
+	$warning_msg = _("This project has no associated Source Code Management tool defined, please configure one using the Administration submenu.");
+}
 
-scm_footer(); 
+scm_header(array('title'=> sprintf(_('Source Code Repository for %s'), $group->getPublicName()),'group'=>$group_id));
 
-?>
+plugin_hook("blocks", "scm index");
+
+$hook_params = array();
+$hook_params['group_id'] = $group_id;
+plugin_hook("scm_page", $hook_params);
+
+scm_footer();
