@@ -3,6 +3,7 @@
  * SCM Reporting
  *
  * Copyright 2004-2005 (c) Tim Perdue - GForge LLC
+ * Copyright 2012-2013, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -21,41 +22,29 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
-require_once $gfwww.'scm/include/scm_utils.php';    
+require_once $gfwww.'scm/include/scm_utils.php';
+
+html_use_jqueryjqplotpluginCanvas();
+html_use_jqueryjqplotpluginPie();
+html_use_jqueryjqplotpluginhighlighter();
+html_use_jqueryjqplotplugindateAxisRenderer();
 
 $group_id = getIntFromRequest("group_id");
-scm_header(array('title'=>_('SCM Repository Reporting'),'group'=>$group_id));
+scm_header(array('title'=>_('SCM Repository Reporting'), 'group'=>$group_id));
 
-?>
+echo '<h2>'._('Commits Over Time')."</h2>\n";
+commitstime_graph($group_id, 1);
 
-<h2>Commits Over Time</h2>
-<p>
-<img src="commitstime_graph.php?group_id=<?php echo $group_id; ?>" 
-     alt="Commits Over Time" />
-</p>
 
-<h2>Commits Last 30 Days</h2>
-<p>
-<img src="commits_graph.php?group_id=<?php echo $group_id; ?>&amp;days=30" 
-     alt="Commits Last 30 Days" />
-</p>
+echo '<h2>'._('Commits Last 30 Days')."</h2>\n";
+commits_graph($group_id, 30, 2);
 
-<h2>Commits Last 90 Days</h2>
-<p>
-<img src="commits_graph.php?group_id=<?php echo $group_id; ?>&amp;days=90" 
-     alt="Commits Last 90 Days" />
-</p>
+echo '<h2>'._('Commits Last 90 Days')."</h2>\n";
+commits_graph($group_id, 90, 3);
 
-<h2>Commits Last 365 Days</h2>
-<p>
-<img src="commits_graph.php?group_id=<?php echo $group_id; ?>&amp;days=365" 
-     alt="Commits Last 365 Days" />
-</p>
+echo '<h2>'._('Commits Last 365 Days')."</h2>\n";
+commits_graph($group_id, 365, 4);
 
-<?php
-
-scm_footer(); 
-
-?>
+scm_footer();
