@@ -9,7 +9,8 @@
  * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
  * http://codex.xerox.com
  *
- * Copyright 2010 (c), Franck Villaume
+ * Copyright 2010, Franck Villaume - Capgemini
+ * Copyright 2012, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -33,7 +34,7 @@ if (isset($_GET['view']) && $_GET['view'] == 'tar') {
 	$no_gz_buffer=true;
 }
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'scm/include/scm_utils.php';
 require_once $gfwww.'scm/include/viewvc_utils.php';
@@ -65,7 +66,7 @@ if (!$projectName) {
 $Group = group_get_object_by_name($projectName);
 if (!$Group || !is_object($Group)) {
 	exit_no_group();
-} else if ( $Group->isError()) {
+} elseif ( $Group->isError()) {
 	exit_error($Group->getErrorMessage(),'summary');
 }
 if (!$Group->usesSCM()) {
@@ -74,10 +75,10 @@ if (!$Group->usesSCM()) {
 
 // check if the scm_box is located in another server
 $scm_box = $Group->getSCMBox();
-//$external_scm = (gethostbyname(forge_get_config('web_host')) != gethostbyname($scm_box)); 
-$external_scm = !$sys_scm_single_host;
+//$external_scm = (gethostbyname(forge_get_config('web_host')) != gethostbyname($scm_box));
+$external_scm = !forge_get_config('scm_single_host');
 
-if (!forge_check_perm ('scm', $Group->getID(), 'read')) {
+if (!forge_check_perm('scm', $Group->getID(), 'read')) {
 	exit_permission_denied('scm');
 }
 
@@ -85,21 +86,21 @@ if ($external_scm) {
 	//$server_script = "/cgi-bin/viewcvs.cgi";
 	$server_script = $GLOBALS["sys_path_to_scmweb"]."/viewcvs.cgi";
 	// remove leading / (if any)
-	$server_script = preg_replace("/^\\//", "", $server_script); 
-	
+	$server_script = preg_replace("/^\\//", "", $server_script);
+
 	// pass the parameters passed to this script to the remote script in the same fashion
 	$script_url = "http://".$scm_box."/".$server_script.$_SERVER["PATH_INFO"]."?".$_SERVER["QUERY_STRING"];
 	$fh = @fopen($script_url, "r");
 	if (!$fh) {
 		exit_error(sprintf(_('Could not open script %s.'),$script_url),'home');
 	}
-	
+
 	// start reading the output of the script (in 8k chunks)
 	$content = "";
 	while (!feof($fh)) {
 		$content .= fread($fh, 8192);
 	}
-	
+
 	if (viewcvs_is_html()) {
 		// Now, we must replace the occurencies of $server_script with this script
 		// (do this only of outputting HTML)
@@ -111,14 +112,18 @@ if ($external_scm) {
 	$unix_name = $Group->getUnixName();
 
 	// Call to ViewCVS CGI locally (see viewcvs_utils.php)
-	
+
 	// see what type of plugin this project if using
 	if ($Group->usesPlugin('scmcvs')) {
 		$repos_type = 'cvs';
-	} else if ($Group->usesPlugin('scmsvn')) {
+	} elseif ($Group->usesPlugin('scmsvn')) {
 		$repos_type = 'svn';
 	}
-	
+
+	// HACK : getSiteMenu in Navigation.class.php use GLOBAL['group_id']
+	// to fix missing projet name tab
+	$group_id = $Group->getID();
+
 	$content = viewcvs_execute($unix_name, $repos_type);
 }
 
@@ -127,12 +132,21 @@ if ($external_scm) {
 // is set to 0 in the ViewCVS config file
 $found = false;
 $line = strtok($content,SEPARATOR);
+
+if ($line == 'Status: 301 Moved') {
+	while ($line) {
+		header($line);
+		$line = strtok(SEPARATOR);
+	}
+	exit;
+}
+
 while ($line && !$found) {
 	if (preg_match('/^Content-Type:(.*)$/',$line,$matches)) {
 		header('Content-Type:' . $matches[1]);
- 		$found = true;
- 	}
-	$line = strtok(SEPARATOR);	
+		$found = true;
+	}
+	$line = strtok(SEPARATOR);
 }
 $content = substr($content, strpos($content,$line));
 
@@ -161,5 +175,3 @@ if (viewcvs_is_html()) {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
