@@ -3,6 +3,7 @@
  * Search Engine
  *
  * Copyright 2004 (c) Dominik Haas, GForge Team
+ * Copyright 2013, French Ministry of National Education
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -25,7 +26,7 @@ require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'search/include/renderers/HtmlGroupSearchRenderer.class.php';
 
 class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
-	
+
 	/**
 	 * group id
 	 *
@@ -37,7 +38,7 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 	 * the words to search for
 	 *
 	 * @var string $words
-	 */	
+	 */
 	var $words;
 
 	/**
@@ -46,7 +47,7 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 	 * @var boolean $isExact
 	 */
 	var $isExact;
-	
+
 	/**
 	 * selected parents sections
 	 *
@@ -68,10 +69,10 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 		$this->words = $words;
 		$this->isExact = $isExact;
 		$searchQuery =& $this->searchQuery;
-		
+
 		$this->HtmlGroupSearchRenderer(SEARCH__TYPE_IS_ADVANCED, $words, $isExact, $searchQuery, $groupId);
 	}
-	
+
 	/**
 	 * flush - overwrites the flush method from htmlrenderer
 	 */
@@ -83,44 +84,44 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 
 	/**
 	 * writeHeader - write the header of the output
-	 */		
+	 */
 	function writeHeader() {
-		site_project_header(array('title' => _('Advanced search'), 'group' => $this->groupId, 'toptab'=>'none'));
+		site_project_header(array('title' => _('Advanced search'), 'group' => $this->groupId, 'toptab' => 'none'));
 		$sectionarray = $this->getSectionArray();
 		$this->handleTransferInformation($sectionarray);
 
 		echo $this->getAdvancedSearchBox($sectionarray, $this->groupId, $this->words, $this->isExact);
 	}
-	
+
 	/**
 	 * writeBody - write the Body of the output
 	 */
 	function writeBody() {
 		if (strlen($this->words) < 3) {
-			echo '<div class="error">'._('Error: Under min length search').'</div>';
+			echo '<p class="error">'._('Error') . _(': ') . _('Search must be at least three characters').'</p>';
 		} else {
 			echo $this->getResult();
 		}
 	}
-	
+
 	/**
 	 * getResult - returns the Body of the output
-	 * 
+	 *
   	 * @return string result of all selected searches
 	 */
 	function getResult() {
 		$html = '';
-		
+
 		if (in_array('short_forum', $this->selectedParentSections)) {
 			$renderer = new ForumsHtmlSearchRenderer($this->words, $this->offset, $this->isExact, $this->groupId, $this->getSelectedChildSections('short_forum'));
 			$html .= $this->getPartResult($renderer, 'short_forum', _('Forum Search Results'));
 		}
-		
+
 		if (in_array('short_tracker', $this->selectedParentSections)) {
 			$renderer = new TrackersHtmlSearchRenderer($this->words, $this->offset, $this->isExact, $this->groupId,  $this->getSelectedChildSections('short_tracker'));
 			$html .= $this->getPartResult($renderer,  'short_tracker', _('Tracker Search Results'));
 		}
-		
+
 		if (in_array('short_pm', $this->selectedParentSections)) {
 			$renderer = new TasksHtmlSearchRenderer($this->words, $this->offset, $this->isExact, $this->groupId, $this->getSelectedChildSections('short_pm'));
 			$html .= $this->getPartResult($renderer, 'short_pm', _('Task Search Results'));
@@ -132,22 +133,22 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 		}
 
 		if (in_array('short_files', $this->selectedParentSections)) {
-			$renderer = new FilesHtmlSearchRenderer($this->words, $this->offset, $this->isExact, $this->groupId, $this->getSelectedChildSections('short_files'));
+			$renderer = new FrsHtmlSearchRenderer($this->words, $this->offset, $this->isExact, $this->groupId, $this->getSelectedChildSections('short_files'));
 			$html .= $this->getPartResult($renderer, 'short_files', _('Files Search Results'));
 		}
-		
+
 		if (in_array('short_news', $this->selectedParentSections)) {
 			$renderer = new NewsHtmlSearchRenderer($this->words, $this->offset, $this->isExact, $this->groupId);
 			$html .= $this->getPartResult($renderer, 'short_news', _('News Search Results'));
 		}
 
-		// This is quite complex but the goal is to extract all the 
+		// This is quite complex but the goal is to extract all the
 		// registered plugins to the hook 'search_engines' and call
 		// them.
 		$pluginManager = plugin_manager_get_object();
 		$searchManager = getSearchManager();
 		$engines = $searchManager->getAvailableSearchEngines();
-		
+
 		if (isset($pluginManager->hooks_to_plugins['search_engines'])) {
 			$p_list = $pluginManager->hooks_to_plugins['search_engines'];
 			foreach ($p_list as $p_name) {
@@ -156,8 +157,8 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 				if (in_array($p_name, $this->selectedParentSections)) {
 					reset($engines);
 					foreach($engines as $e) {
-						if ($e->type == $p_name) {		
-							$renderer = $e->getSearchRenderer($this->words, 
+						if ($e->type == $p_name) {
+							$renderer = $e->getSearchRenderer($this->words,
 								$this->offset, $this->isExact, $this->groupId);
 							$html .= $this->getPartResult($renderer, 'short_'.$p_name, $name);
 						}
@@ -166,49 +167,54 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 			}
 		}
 
-		return $html.'<br />'; 
+		return $html.'<br />';
 	}
 
 	/**
-	* getPartResult - returns the result of the given renderer 
-	* 
-  	* @return string result of the renderer
-	*/			
+	 * getPartResult - returns the result of the given renderer
+	 *
+	 * @param object $renderer
+	 * @param string $section
+	 * @param string $title
+	 * @return string result of the renderer
+	 */
 	function getPartResult($renderer, $section, $title='') {
 		$result = '';
 		$renderer->searchQuery->executeQuery();
 		$query = NULL;
-		
+
 		if ($title === '')
 			$title = $section;
-		
+
 		$result .= '<h2><a name="'.$section.'"></a>'.$title.'</h2>';
-		
+
 		if ($renderer->searchQuery->getRowsCount() > 0) {
 			if ($renderer->searchQuery->getRowsTotalCount() >= $renderer->searchQuery->getRowsPerPage())
 				$result .= '<i>' . sprintf(_('Note: only the first %d results for this category are displayed.'), $renderer->searchQuery->getRowsPerPage()) . '</i>';
 			$result .= $GLOBALS['HTML']->listTabletop($renderer->tableHeaders);
-			$result .= $renderer->getRows();			
-			$result .= $GLOBALS['HTML']->listTableBottom();			
+			$result .= $renderer->getRows();
+			$result .= $GLOBALS['HTML']->listTableBottom();
 		} elseif(method_exists($renderer, 'getSections') && (count($renderer->getSections($this->groupId)) == 0)) {
-			$result .= '<p>'.sprintf(_('No matches found for <em>%s</em> - No sections available (check your permissions)'), $query['words']).'</p>';
+			$result .= '<p>'.sprintf(_('No matches found for “%s”'), $this->words);
+			$result .= _(' - ');
+			$result .= _('No sections available (check your permissions)').'</p>';
 		} else {
-			$result .= '<p>'.sprintf(_('No matches found for <em>%s</em>'), $query['words']).'</p>';
+			$result .= '<p>'.sprintf(_('No matches found for “%s”'), $this->words).'</p>';
 		}
 		return $result;
 	}
-	
+
 	/**
 	* getSectionArray - creates an array of sections in which the user can search
-	* 
-  	* @return array sections 
-	*/		
+	*
+  	* @return array sections
+	*/
 	function getSectionArray() {
 		global $gfwww, $gfcommon;
-		
+
 		$sections = array();
 		$group = group_get_object($this->groupId);
-		
+
 		if ($group->usesForum()) {
 			require_once $gfwww.'search/include/renderers/ForumsHtmlSearchRenderer.class.php';
 			$undersections = ForumsHtmlSearchRenderer::getSections($this->groupId);
@@ -216,7 +222,7 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 				$sections['short_forum'] = $undersections;
 			}
 		}
-		
+
 		if ($group->usesTracker()) {
 			require_once $gfwww.'search/include/renderers/TrackersHtmlSearchRenderer.class.php';
 			$undersections = TrackersHtmlSearchRenderer::getSections($this->groupId);
@@ -236,17 +242,22 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 
 		if ($group->usesDocman()) {
 			require_once $gfwww.'search/include/renderers/DocsHtmlSearchRenderer.class.php';
-			$undersections = DocsHtmlSearchRenderer::getSections($this->groupId);	
+			$undersections = DocsHtmlSearchRenderer::getSections($this->groupId);
 			if (count($undersections) > 0) {
 				$sections['short_docman'] = $undersections;
 			}
 		}
-		
+
 		if ($group->usesNews()) {
 			require_once $gfwww.'search/include/renderers/NewsHtmlSearchRenderer.class.php';
-			$sections['short_news'] = true;
+			$undersections = NewsHtmlSearchRenderer::getSections($this->groupId);
+			if(count($undersections) > 0){
+				$sections['short_news'] = $undersections;
+			} else {
+				$sections['short_news'] = true;
+			}
 		}
-			
+
 		if ($group->usesFRS()) {
 			require_once $gfwww.'search/include/renderers/FrsHtmlSearchRenderer.class.php';
 			$undersections = FrsHtmlSearchRenderer::getSections($this->groupId);
@@ -268,17 +279,17 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 
 		return $sections;
 	}
-	
+
 	/**
 	* handleTransferInformation - marks parentsections if child is marked and processes cookie information
-	* 
-	*/		
+	*
+	*/
 	function handleTransferInformation(&$sectionarray) {
 		//get through all sections
 		//if a childsection is marked to search in, mark the parent too
-		
+
 		$postArray = _getPostArray();
-		
+
 		foreach($sectionarray as $key => $section) {
 			if(is_array($section)) {
 				foreach ($postArray as $postkey => $postvalue) {
@@ -293,18 +304,18 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 		}
 
 	}
-	
+
 	/**
 	* getSelectedChildSections - gets all selected child sections from the given parentsection
-	* 
+	*
 	* @param string	$parentsection the parentsection
-	* 
+	*
   	* @return array all child sections from the parent section the user wants to search in
-	*/		
+	*/
 	function getSelectedChildSections($parentsection) {
 		$sections = array();
 		$postArray = _getPostArray();
-		
+
 		foreach($postArray as $key => $value) {
 			if (substr($key, 0, strlen($parentsection)) == $parentsection) {
 				if (strlen(substr($key, strlen($parentsection) , strlen($key))) > 0) {
@@ -323,7 +334,7 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
         <input class="ff" type="hidden" name="search" value="1"/>
         <input class="ff" type="hidden" name="group_id" value="'.$group_id.'"/>
         <div align="center"><br />
-            <table border="0">
+            <table>
                 <tr class="ff">
                     <td class="ff" colspan ="2">
                         <input class="ff" type="text" size="60" name="words" value="'.stripslashes(htmlspecialchars($words)).'" />
@@ -331,37 +342,37 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
                     </td>
                 </tr>
                 <tr class="ff">
-                    <td class="ff" valign="top">
+                    <td class="ff top">
                         <input class="ff" type="radio" name="mode" value="'.SEARCH__MODE_AND.'" '.($isExact ? 'checked="checked"' : '').' />'._('with all words').'
                     </td>
                     <td class="ff">
                         <input class="ff" type="radio" name="mode" value="'.SEARCH__MODE_OR.'" '.(!$isExact ? 'checked="checked"' : '').' />'._('with one word').'
                     </td>
                 </tr>
-            </table><br /></div>'
+            </table><br />'
 			. $this->createSubSections($sectionsArray) .'
-        </form>';
+        </div>
+		</form>
+';
 
-
-		//create javascript methods for select none/all
-		$res .= '
-            <!-- method for disable/enable checkboxes -->
-	<script language="JavaScript" type="text/javascript">/* <![CDATA[ */
-            function setCheckBoxes(parent, checked) {
-
-
-                for (var i = 0; i < document.advancedsearch.elements.length; i++)
-                    if (document.advancedsearch.elements[i].type == "checkbox") 
-                            if (document.advancedsearch.elements[i].name.substr(0, parent.length) == parent)
-                                document.advancedsearch.elements[i].checked = checked;
-                }
-	/* ]]> */</script>
-        ';
+		// Add jquery javascript method for select none/all
+		$res .= <<< EOS
+<script type="text/javascript">
+jQuery(function () {
+	jQuery('.checkall').click(function () {
+		jQuery(this).parents('fieldset:eq(0)').find(':checkbox').attr('checked', this.checked);
+	});
+	jQuery('.checkthemall').click(function () {
+		jQuery('#advsearch').find(':checkbox').attr('checked', this.checked);
+	});
+});
+</script>
+EOS;
 		return $res;
 	}
 
 	function createSubSections($sectionsArray) {
-		global $group_subsection_names;
+		$group_subsection_names = getSubSectionNames();
 
 		$countLines = 0;
 		foreach ($sectionsArray as $section) {
@@ -378,20 +389,15 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 		$break = $breakLimit;
 		$countLines = 0;
  		$countCol = 1;
- 
+
 		$return = '
-			<table width="100%" border="0" cellspacing="0" cellpadding="1">
-				<tr class="tableheader">
-					<td>
-						<table width="100%" cellspacing="0" border="0">
+			<table cellspacing="10" cellpadding="1" id="advsearch">
 							<tr class="tablecontent">
-								<!--<td colspan="2">'._('Search in').':</td-->
-								<td align="right">'._('Select').' <a href="javascript:setCheckBoxes(\'\', true)">'._('all').'</a> / <a href="javascript:setCheckBoxes(\'\', false)">'._('none').'</a></td>
+								<td colspan="3" class="align-center">
+									<input type="checkbox" class="checkthemall" />'._('Search All').'
+								</td>
 							</tr>
-							<tr class="tablecontent">
-								<td colspan="3">&nbsp;</td>
-							</tr>
-							<tr valign="top" class="tablecontent align-center">
+							<tr class="top tablecontent">
 								<td>';
 		foreach($sectionsArray as $key => $section) {
 			$oldcountlines = $countLines;
@@ -400,7 +406,7 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 			} else {
 				$countLines += 3;
 			}
-				
+
 			if ($countLines >= $break) {
  				// if we are closer to the limit with this one included, then
  				// it's better to include it.
@@ -410,39 +416,29 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 					$break += $breakLimit;
 				}
 			}
-		
-			$return .= '<table width="90%" border="0" cellpadding="1" cellspacing="0">
-							<tr><td><table width="100%" border="0" cellspacing="0" cellpadding="3">
-							<tr>
-								<td cellspacing="0">
-									<a href="#'.$key.'">'.$group_subsection_names[$key].'</a>'
-				.'	</td>
-								<td align="right">'
-				._('Select').' <a href="javascript:setCheckBoxes(\''.$key.'\', true)">'._('all').'</a> / <a href="javascript:setCheckBoxes(\''.$key.'\', false)">'._('none').'</a>
-								</td>
-							</tr>
-							<tr class="tablecontent">
-								<td colspan="2">';
-								
+
+			$return .= '<fieldset>'."\n";
+			$return .= '<legend>';
+			$return .= '<input type="checkbox" name="'.$key.'_checkall"';
+			if (getStringFromRequest($key.'_checkall')) $return .= ' checked="checked"';
+			$return .= ' class="checkall" /><a href="#'.$key.'">'.$group_subsection_names[$key].'</a>';
+			$return .= "\n";
+			$return .= '</legend>';
+
 			if (!is_array($section)) {
-				$return .= '		<input type="checkbox" name="'.urlencode($key).'"';
-				if (isset($GLOBALS[urlencode($key)]))
-					$return .= ' checked="checked" ';
-				$return .= ' /></input>'.$group_subsection_names[$key].'<br />';
-			}
-			else
+				$return .= '		<input type="checkbox" name="'.$key.'"';
+				if (getStringFromRequest($key))	$return .= ' checked="checked"';
+				$return .= ' class="childCheckBox" />'.$group_subsection_names[$key].'<br />'."\n";
+			} else {
 				foreach($section as $underkey => $undersection) {
-					$return .= '	<input type="checkbox" name="'.urlencode($key.$underkey).'"';
-					if (isset($GLOBALS[urlencode($key.$underkey)]))
-						$return .= ' checked="checked" ';
-					$return .= ' />'.$undersection.'<br />';				
-					
+					$return .= '	<input type="checkbox" name="'.$key.$underkey.'"';
+					if (getStringFromRequest($key.$underkey)) $return .= ' checked="checked"';
+					$return .= ' />'.$undersection.'<br />'."\n";
 				}
-				
-			$return .=		'	</td>
-							</tr>
-						</table></td></tr></table><br />';
-						
+			}
+
+			$return .= '</fieldset>';
+
 			if ($countLines >= $break) {
 				if (($countLines - $break) < ($break - $countLines)) {
 					$return .= '</td><td width="33%">';
@@ -450,10 +446,10 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 				}
 			}
 		}
-		
+
 		return $return.'		</td>
 							</tr>
-						</table></td></tr></table>';
+						</table>';
 
 	}
 
@@ -463,5 +459,3 @@ class AdvancedSearchHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
