@@ -3,6 +3,9 @@
  * Search Engine
  *
  * Copyright 2004 (c) Dominik Haas, GForge Team
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013, Franck Villaume - TrivialDev
+ * Copyright 2013, French Ministry of National Education
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -23,9 +26,10 @@
 
 require_once $gfwww.'search/include/renderers/HtmlGroupSearchRenderer.class.php';
 require_once $gfcommon.'search/DocsSearchQuery.class.php';
-			  
+require_once $gfcommon.'docman/Document.class.php';
+
 class DocsHtmlSearchRenderer extends HtmlGroupSearchRenderer {
-	
+
 	/**
 	 * Constructor
 	 *
@@ -33,22 +37,22 @@ class DocsHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 	 * @param int $offset offset
 	 * @param boolean $isExact if we want to search for all the words or if only one matching the query is sufficient
 	 * @param int $groupId group id
-	 * @param array $sections array of all sections to search in (array of strings)
+	 * @param array|string $sections array of all sections to search in (array of strings)
 	 *
 	 */
 	function DocsHtmlSearchRenderer($words, $offset, $isExact, $groupId, $sections=SEARCH__ALL_SECTIONS) {
-	
+
 		$userIsGroupMember = $this->isGroupMember($groupId);
-					
+
 		$searchQuery = new DocsSearchQuery($words, $offset, $isExact, $groupId, $sections, $userIsGroupMember);
-		
+
 		$this->HtmlGroupSearchRenderer(SEARCH__TYPE_IS_DOCS, $words, $isExact, $searchQuery, $groupId, 'docman');
-		
+
 		$this->tableHeaders = array(
-			'&nbsp;',
+			_('Directory'),
 			_('#'),
 			_('Title'),
-			_('Description'),
+			_('Description')
 		);
 	}
 
@@ -60,26 +64,31 @@ class DocsHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 	function getRows() {
 		$rowsCount = $this->searchQuery->getRowsCount();
 		$result =& $this->searchQuery->getResult();
-		$dateFormat = _('Y-m-d H:i');
-		
+
+		if (!forge_check_perm('docman', $this->groupId, 'read')) {
+			return '';
+		}
+
 		$return = '';
-		
+
 		$lastDocGroup = null;
-		
+
 		$rowColor = 0;
 		for($i = 0; $i < $rowsCount; $i++) {
 			//section changed
 			$currentDocGroup = db_result($result, $i, 'groupname');
+			$groupObject = group_get_object($this->groupId);
+			$document = new Document($groupObject, db_result($result, $i, 'docid'));
 			if ($lastDocGroup != $currentDocGroup) {
-				$return .= '<tr><td colspan="4">'.$currentDocGroup.'</td></tr>';
+				$return .= '<tr><td>'.html_image('ic/cfolder15.png', '10', '12', array('border' => '0')).util_make_link('/docman/?group_id='.$this->groupId.'&amp;view=listfile&amp;dirid='.$document->getDocGroupID(),$currentDocGroup).'</td><td colspan="3">&nbsp;</td></tr>';
 				$lastDocGroup = $currentDocGroup;
 				$rowColor = 0;
 			}
 			$return .= '<tr '. $GLOBALS['HTML']->boxGetAltRowStyle($rowColor) .'>'
-				. '<td width="5%">&nbsp;</td>'
+				. '<td>&nbsp;</td>'
 				. '<td>'.db_result($result, $i, 'docid').'</td>'
 				. '<td><a href="'.util_make_url ('/docman/view.php/'.$this->groupId . '/'.db_result($result, $i, 'docid').'/'.db_result($result, $i, 'filename')).'">'
-				. html_image('ic/msg.png', '10', '12', array('border' => '0'))
+				. html_image('ic/msg.png', '10', '12')
 				. ' '.db_result($result, $i, 'title').'</a></td>'
 				. '<td>'.db_result($result, $i, 'description').'</td></tr>';
 			$rowColor++;
@@ -89,14 +98,13 @@ class DocsHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 
 	/**
 	 * getSections - get the array of possible sections to search in
-	 * 
+	 *
+	 * @param int $groupId
   	 * @return array sections
-	 */		
+	 */
 	static function getSections($groupId) {
 		$userIsGroupMember = DocsHtmlSearchRenderer::isGroupMember($groupId);
-		
+
 		return DocsSearchQuery::getSections($groupId, $userIsGroupMember);
 	}
 }
-
-?>
