@@ -3,6 +3,7 @@
  * Search Engine
  *
  * Copyright 2004 (c) Dominik Haas, GForge Team
+ * Copyright 2012, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -31,7 +32,7 @@ require_once $gfwww.'search/include/renderers/FrsHtmlSearchRenderer.class.php';
 require_once $gfwww.'search/include/renderers/NewsHtmlSearchRenderer.class.php';
 
 class FullProjectHtmlSearchRenderer extends HtmlGroupSearchRenderer {
-	
+
 	/**
 	 * group id
 	 *
@@ -43,7 +44,7 @@ class FullProjectHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 	 * the words to search for
 	 *
 	 * @var string $words
-	 */	
+	 */
 	var $words;
 
 	/**
@@ -52,7 +53,7 @@ class FullProjectHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 	 * @var boolean $isExact
 	 */
 	var $isExact;
-	
+
 	/**
 	 * Constructor
 	 *
@@ -66,14 +67,15 @@ class FullProjectHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 		$this->groupId = $groupId;
 		$this->words = $words;
 		$this->isExact = $isExact;
-		
+
 		$this->HtmlGroupSearchRenderer(SEARCH__TYPE_IS_ADVANCED, $words, $isExact, '', $groupId);
 	}
-	
+
 	/**
 	 * flush - overwrites the flush method from htmlrenderer
 	 */
 	function flush() {
+		$this->writeHeader();
 		$this->writeBody();
 		$this->writeFooter();
 	}
@@ -82,14 +84,18 @@ class FullProjectHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 	 * writeBody - write the Body of the output
 	 */
 	function writeBody() {
-		$title = _('Entire project search');
-		site_project_header(array('title' => $title, 'group' => $this->groupId, 'toptab' => ''));
-		echo $this->getResult();
+		if (!$this->words) {
+			echo '<p class="error">'._('Error') . _(': ') . _('Please enter a term to search for').'</p>';
+		} elseif (!forge_get_config('use_fti') && (strlen($this->words) < 3)) {
+			echo '<p class="error">'._('Error') . _(': ') . _('Search must be at least three characters').'</p>';
+		} else {
+			echo $this->getResult();
+		}
 	}
-	
+
 	/**
 	 * getResult - returns the Body of the output
-	 * 
+	 *
   	 * @return string result of all selected searches
 	 */
 	function getResult() {
@@ -143,20 +149,40 @@ class FullProjectHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 		}
 
 		if (! $html && ! $validLength) {
-			$html .= '<div class="error">'._('Error: search query too short').'</div>';
+			$html .= '<p class="error">'._('Error: search query too short').'</p>';
 		}
 
-		plugin_hook('full_search_engines', $this);
-		$plugin = plugin_manager_get_object();
-		$html .= $plugin->getReturnedValue('full_search_engines');
+		// This is quite complex but the goal is to extract all the
+		// registered plugins to the hook 'search_engines' and call
+		// them.
+		$pluginManager = plugin_manager_get_object();
+		$searchManager = getSearchManager();
+		$engines = $searchManager->getAvailableSearchEngines();
 
-/*		
+		if (isset($pluginManager->hooks_to_plugins['full_search_engines'])) {
+			$p_list = $pluginManager->hooks_to_plugins['full_search_engines'];
+			foreach ($p_list as $p_name) {
+				$p_obj = $pluginManager->GetPluginObject($p_name);
+				$name = $p_obj->text;
+				reset($engines);
+				foreach($engines as $e) {
+					if ($e->type == $p_name) {
+						$renderer = $e->getSearchRenderer($this->words,
+							$this->offset, $this->isExact, $this->groupId);
+						$html .= $this->getPartResult($renderer, 'short_'.$p_name,
+													  sprintf(_("%s Search Results"), $name));
+					}
+				}
+			}
+		}
+
+/*
 		$renderer = new ForumsHtmlSearchRenderer($this->words, $this->offset, $this->isExact, $this->groupId);
 		$html .= $this->getPartResult($renderer, 'short_forum', _('Forum Search Results'));
-		
+
 		$renderer = new TrackersHtmlSearchRenderer($this->words, $this->offset, $this->isExact, $this->groupId);
 		$html .= $this->getPartResult($renderer,  'short_tracker', _('Tracker Search Results'));
-		
+
 		$renderer = new TasksHtmlSearchRenderer($this->words, $this->offset, $this->isExact, $this->groupId);
 		$html .= $this->getPartResult($renderer, 'short_pm', _('Task Search Results'));
 
@@ -165,45 +191,47 @@ class FullProjectHtmlSearchRenderer extends HtmlGroupSearchRenderer {
 
 		$renderer = new FrsHtmlSearchRenderer($this->words, $this->offset, $this->isExact, $this->groupId);
 		$html .= $this->getPartResult($renderer, 'short_files', _('Files Search Results'));
-		
+
 		$renderer = new NewsHtmlSearchRenderer($this->words, $this->offset, $this->isExact, $this->groupId);
 		$html .= $this->getPartResult($renderer, 'short_news', _('News Search Results'));
 */
 
-		return $html.'<br />'; 
+		return $html.'<br />';
 	}
 
 	/**
-	* getPartResult - returns the result of the given renderer 
-	* 
+	* getPartResult - returns the result of the given renderer
+	*
+	* @param object $renderer
+	* @param int $section
+	* @param string $title
   	* @return string result of the renderer
-	*/			
+	*/
 	function getPartResult($renderer, $section, $title='') {
 		$result = '';
 		$renderer->searchQuery->executeQuery();
-		
+
 		if ($title === '')
 			$title = $section;
-		
+
 		$result .= '<h2><a name="'.$section.'"></a>'.$title.'</h2>';
-		
+
 		if ($renderer->searchQuery->getRowsCount() > 0) {
 			$result .= $GLOBALS['HTML']->listTabletop($renderer->tableHeaders);
-			$result .= $renderer->getRows();			
-			$result .= $GLOBALS['HTML']->listTableBottom();			
+			$result .= $renderer->getRows();
+			$result .= $GLOBALS['HTML']->listTableBottom();
 		} elseif(method_exists($renderer, 'getSections') && (count($renderer->getSections($this->groupId)) == 0)) {
-			$result .= '<p>'.sprintf(_('No matches found for <em>%s</em> - No sections available (check your permissions)'), $this->words).'</p>';
+            $result .= '<p>'.sprintf(_('No matches found for “%s”'), $this->words);
+            $result .= _(' - ');
+            $result .= _('No sections available (check your permissions)').'</p>';
 		} else {
-			$result .= '<p>'.sprintf(_('No matches found for <em>%s</em>'), $this->words).'</p>';
+			$result .= '<p>'.sprintf(_('No matches found for “%s”'), htmlspecialchars($this->words)).'</p>';
 		}
 		return $result;
 	}
-
 }
 
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
