@@ -24,9 +24,12 @@
 
 require_once $gfwww.'search/include/renderers/HtmlSearchRenderer.class.php';
 
+/**
+ *
+ */
 class HtmlGroupSearchRenderer extends HtmlSearchRenderer {
-	
-	/** TODO: Find what for is $offset, looks like it's not used, added to remove warning 
+
+	/** TODO: Find what for is $offset, looks like it's not used, added to remove warning
 	*/
 	var $offset;
 	/**
@@ -35,7 +38,7 @@ class HtmlGroupSearchRenderer extends HtmlSearchRenderer {
 	 * @var int $groupId
 	 */
 	var $groupId;
-	
+
 	/**
 	 * selected top tab
 	 * @var string $topTab
@@ -45,27 +48,33 @@ class HtmlGroupSearchRenderer extends HtmlSearchRenderer {
 	/**
 	 * Constructor
 	 *
-	 * @param string $typeOfSearch type of the search (Software, Forum, People and so on)
-	 * @param string $words words we are searching for
-	 * @param int $offset offset
-	 * @param boolean $isExact if we want to search for all the words or if only one matching the query is sufficient
-	 * @param object $searchQuery SearchQuery instance
-	 * @param int $groupId group id
+	 * @param string  $typeOfSearch type of the search (Software, Forum, People and so on)
+	 * @param string  $words        words we are searching for
+	 * @param boolean $isExact      if we want to search for all the words or if only one matching the query is sufficient
+	 * @param object  $searchQuery  SearchQuery instance
+	 * @param int     $groupId      group id
+	 * @param string  $topTab
+	 * @return void
 	 */
 	function HtmlGroupSearchRenderer($typeOfSearch, $words, $isExact, $searchQuery, $groupId, $topTab = '') {
 		$this->HtmlSearchRenderer($typeOfSearch, $words, $isExact, $searchQuery);
 		$this->groupId = $groupId;
 		$this->topTab = $topTab;
 	}
-	
+
 	/**
 	 * writeHeader - write the header of the output
 	 */
 	function writeHeader() {
-		site_project_header(array('title' => _('Search'), 'group' => $this->groupId, 'toptab' => $this->topTab));
-		parent::writeHeader();
+		$title = sprintf(_('Search results for “%s”'), $this->query['words']);
+		site_project_header(array('title' => $title, 'group' => $this->groupId, 'toptab' => $this->topTab));
+
+		printf (_('Tip: Use %s to get more precise results.'),
+			util_make_link('/search/advanced_search.php?group_id='.$this->groupId.'&amp;words='.
+				htmlspecialchars_decode($this->query['words']),
+				_('Advanced search')));
 	}
-	
+
 	/**
 	 * getPreviousResultsUrl - get the url to go to see the previous results
 	 *
@@ -74,7 +83,7 @@ class HtmlGroupSearchRenderer extends HtmlSearchRenderer {
 	function getPreviousResultsUrl() {
 		return parent::getPreviousResultsUrl().'&amp;group_id='.$this->groupId;
 	}
-	
+
 	/**
 	 * getNextResultsUrl - get the url to go to see the next results
 	 *
@@ -88,6 +97,7 @@ class HtmlGroupSearchRenderer extends HtmlSearchRenderer {
 	 * isGroupMember - returns if the logged in user is member of the current group
 	 *
 	 * @param int $groupId group id
+	 * @return bool
 	 */
 	static function isGroupMember($groupId) {
 		$Group = group_get_object($groupId);
@@ -97,7 +107,6 @@ class HtmlGroupSearchRenderer extends HtmlSearchRenderer {
 				return true;
 			}
 		}
-		return false;		
+		return false;
 	}
 }
-?>
