@@ -37,11 +37,10 @@ class HtmlSearchRenderer extends SearchRenderer {
 	/**
 	 * Constructor
 	 *
-	 * @param string $typeOfSearch type of the search (Software, Forum, People and so on)
-	 * @param string $words words we are searching for
-	 * @param int $offset offset
-	 * @param boolean $isExact if we want to search for all the words or if only one matching the query is sufficient
-	 * @param object $searchQuery SearchQuery instance
+	 * @param string  $typeOfSearch type of the search (Software, Forum, People and so on)
+	 * @param string  $words        words we are searching for
+	 * @param boolean $isExact      if we want to search for all the words or if only one matching the query is sufficient
+	 * @param object  $searchQuery  SearchQuery instance
 	 */
 	function HtmlSearchRenderer($typeOfSearch, $words, $isExact, $searchQuery) {
 		$this->SearchRenderer($typeOfSearch, $words, $isExact, $searchQuery);
@@ -54,7 +53,7 @@ class HtmlSearchRenderer extends SearchRenderer {
 		$searchQuery =& $this->searchQuery;
 		if($searchQuery->isError()) {
 			$this->writeHeader();
-			echo '<div class="error">'.$searchQuery->getErrorMessage().'</div>';
+			echo '<p class="error">'.$searchQuery->getErrorMessage().'</p>';
 			$this->writeFooter();
 		} else {
 			$searchQuery->executeQuery();
@@ -87,7 +86,7 @@ class HtmlSearchRenderer extends SearchRenderer {
 	function writeFooter() {
 		$GLOBALS['HTML']->footer(array());
 	}
-	
+
 	/**
 	 * getResults - get the html output which will display the search results
 	 *
@@ -96,21 +95,20 @@ class HtmlSearchRenderer extends SearchRenderer {
 	function writeResults() {
 		$searchQuery =& $this->searchQuery;
 		$query =& $this->query;
-		
-		$html = '<h2>'.sprintf(_('Search results for <em>%1$s</em>'), $query['words']).'</h2>';
+
 		if(!$searchQuery->getResult() || $searchQuery->getRowsCount() < 1) {
-			$html .= '<p><strong>'.sprintf(_('No matches found for <em>%1$s</em>'), $query['words']).'</strong></p>';
+			$html = '<p><strong>'.sprintf(_('No matches found for “%s”'), $query['words']).'</strong></p>';
 			$html .= db_error();
 		} else {
-			$html .= $GLOBALS['HTML']->listTableTop($this->tableHeaders);
+			$html = $GLOBALS['HTML']->listTableTop($this->tableHeaders);
 			$html .= $this->getRows();
 			$html .= $GLOBALS['HTML']->listTableBottom();
 		}
-		
+
 		if($searchQuery->getRowsCount() > 0 && ($searchQuery->getRowsTotalCount() > $searchQuery->getRowsCount() || $searchQuery->getOffset() != 0 )) {
 			$html .= $this->getNavigationPanel();
 		}
-		
+
 		return $html;
 	}
 
@@ -118,12 +116,12 @@ class HtmlSearchRenderer extends SearchRenderer {
 	 * getNavigationPanel - get the html output for the navigation panel
 	 *
 	 * @return string html output
-	 */ 
+	 */
 	function getNavigationPanel() {
 		$searchQuery =& $this->searchQuery;
-		
+
 		$html = '<br />';
-		$html .= '<table class="tablecontent" width="100%" cellpadding="5" cellspacing="0">';
+		$html .= '<table class="tablecontent" width="100%" cellpadding="5">';
 		$html .= '<tr>';
 		$html .= '<td>';
 		if ($searchQuery->getOffset() != 0) {
@@ -133,7 +131,7 @@ class HtmlSearchRenderer extends SearchRenderer {
 		} else {
 			$html .= '&nbsp;';
 		}
-		$html .= '</td><td align="right">';
+		$html .= '</td><td class="align-right">';
 		if ($searchQuery->getRowsTotalCount() > $searchQuery->getRowsCount()) {
 			$html .= '<a href="'.$this->getNextResultsUrl().'" class="next">'
 				._('Next Results').' '
@@ -145,7 +143,7 @@ class HtmlSearchRenderer extends SearchRenderer {
 		$html .= '</table>';
 		return $html;
 	}
-	
+
 	/**
 	 * getPreviousResultsUrl - get the url to go to see the previous results
 	 *
@@ -154,14 +152,14 @@ class HtmlSearchRenderer extends SearchRenderer {
 	function getPreviousResultsUrl() {
 		$offset = $this->searchQuery->getOffset() - $this->searchQuery->getRowsPerPage();
 		$query =& $this->query;
-		
+
 		$url = '/search/?type='.$query['typeOfSearch'].'&amp;exact='.$query['isExact'].'&amp;q='.urlencode($query['words']);
 		if($offset > 0) {
 			$url .= '&amp;offset='.$offset;
 		}
 		return $url;
 	}
-	
+
 	/**
 	 * getNextResultsUrl - get the url to go to see the next results
 	 *
@@ -182,7 +180,13 @@ class HtmlSearchRenderer extends SearchRenderer {
 		if (empty($text)) {
 			return '&nbsp;';
 		}
-		$regexp = implode($this->searchQuery->getWords(), '|');
+		$words = $this->searchQuery->getWords();
+		foreach ($this->searchQuery->getPhrases() as $p) {
+			foreach (explode(' ',$p) as $w) {
+				$words[] = $w;
+			}
+		}
+		$regexp = implode('|',$words);
 		return preg_replace('/('.str_replace('/', '\/', $regexp).')/i','<span class="selected">\1</span>', $text);
 	}
 
@@ -205,5 +209,3 @@ class HtmlSearchRenderer extends SearchRenderer {
 		return db_result($this->searchQuery->getResult(), 0, $fieldName);
 	}
 }
-
-?>
