@@ -24,9 +24,9 @@
 
 $no_gz_buffer = true;
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
-require_once $gfwww.'tracker/include/ArtifactTypeHtml.class.php';
+require_once $gfcommon.'tracker/include/ArtifactTypeHtml.class.php';
 require_once $gfwww.'search/include/SearchManager.class.php';
 
 $group_id = getIntFromRequest('group_id');
@@ -79,7 +79,5 @@ $renderer = $searchManager->getSearchRenderer($type_of_search, $words, $offset,
 if ($renderer) {
 	$renderer->flush();
 } else {
-	exit_error(_('Error - Invalid search'));
+	exit_error(_('Error: Invalid search'));
 }
-
-?>
