@@ -3,6 +3,7 @@
  * Code Snippets Repository
  *
  * Copyright 1999-2001 (c) VA Linux Systems
+ * Copyright 2014, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -21,7 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'snippet/snippet_utils.php';
 
@@ -36,7 +37,7 @@ if (session_loggedin()) {
 		$result=db_query_params ('SELECT * FROM snippet WHERE snippet_id=$1',
 			array($id));
 		if (!$result || db_numrows($result) < 1) {
-			exit_error(_('Error - snippet doesn\'t exist'));
+			exit_error(_('Error: snippet does not exist'));
 		}
 
 		/*
@@ -68,13 +69,13 @@ if (session_loggedin()) {
 								  time(),
 								  htmlspecialchars($code)));
 				if (!$result) {
-					$error_msg .= _('ERROR DOING SNIPPET VERSION INSERT! ').db_error();
+					$error_msg .= _('Error doing snippet version insert').' '.db_error();
 				} else {
 					form_release_key(getStringFromRequest("form_key"));
 					$feedback .= _('Snippet Version Added Successfully.');
 				}
 			} else {
-				exit_error(_('Error - Go back and fill in all the information'));
+				exit_error(_('Error: Go back and fill in all the information'));
 			}
 
 		}
@@ -91,29 +92,29 @@ if (session_loggedin()) {
 		<input type="hidden" name="id" value="<?php echo $id; ?>" />
 
 		<table>
-		<tr><td colspan="2"><strong><?php echo _('Version:'); ?></strong><br />
-			<input type="text" name="version" size="10" maxlength="15" />
+		<tr><td colspan="2"><strong><?php echo _('Version')._(':'). utils_requiredField(); ?></strong><br />
+			<input type="text" name="version" size="10" maxlength="15" required="required" />
 		</td></tr>
 
-		<tr><td colspan="2"><strong><?php echo _('Changes:'); ?></strong><br />
-			<textarea name="changes" rows="5" cols="45"></textarea>
+		<tr><td colspan="2"><strong><?php echo _('Changes')._(':'). utils_requiredField(); ?></strong><br />
+			<textarea name="changes" rows="5" cols="45" required="required" s></textarea>
 		</td></tr>
-  
-		<tr><td colspan="2"><strong><?php echo _('Paste the Code Here:'); ?></strong><br />
-			<textarea name="code" rows="30" cols="85"></textarea>
+
+		<tr><td colspan="2"><strong><?php echo _('Paste the Code Here')._(':'). utils_requiredField(); ?></strong><br />
+			<textarea name="code" rows="30" cols="85" required="required" ></textarea>
 		</td></tr>
- 
-		<tr><td colspan="2" style="text-align:center">
+
+		<tr><td colspan="2" class="align-center">
 			<strong><?php echo _('Make sure all info is complete and accurate'); ?></strong>
 			<br />
-			<input type="submit" name="submit" value="<?php echo _('SUBMIT'); ?>" />
+			<input type="submit" name="submit" value="<?php echo _('Submit'); ?>" />
 		</td></tr>
 		</table></form></p>
 		<?php
 
 		snippet_footer(array());
 
-	} else if ($type=='package') {
+	} elseif ($type=='package') {
 		/*
 			Handle insertion of a new package version
 		*/
@@ -122,9 +123,9 @@ if (session_loggedin()) {
 			See if the package exists first
 		*/
 		$result=db_query_params ('SELECT * FROM snippet_package WHERE snippet_package_id=$1',
-			array($id));
+					array($id));
 		if (!$result || db_numrows($result) < 1) {
-			exit_error(_('Error - snippet_package doesn\'t exist'));
+			exit_error(_('Error: snippet_package does not exist'));
 		}
 
 		if (getStringFromRequest('post_changes')) {
@@ -151,7 +152,7 @@ if (session_loggedin()) {
 								  time()));
 				if (!$result) {
 					//error in database
-					$error_msg .= _('ERROR DOING SNIPPET PACKAGE VERSION INSERT! ').db_error();
+					$error_msg .= _('Error doing snippet package version insert').' '.db_error();
 					snippet_header(array('title'=>_('New snippet package')));
 					snippet_footer(array());
 					exit;
@@ -169,9 +170,9 @@ if (session_loggedin()) {
 */
 					?>
 
-<script language="JavaScript" type="text/javascript">/* <![CDATA[ */
+<script type="text/javascript">/* <![CDATA[ */
 function show_add_snippet_box() {
-	newWindow = open("","occursDialog","height=500,width=300,scrollbars=yes,resizable=yes");
+	var newWindow = open('','occursDialog','height=500,width=300,scrollbars=yes,resizable=yes');
 	newWindow.location=('/snippet/add_snippet_to_package.php?snippet_package_version_id=<?php
 			echo $snippet_package_version_id; ?>');
 }
@@ -195,7 +196,7 @@ function show_add_snippet_box() {
 
 			} else {
 				form_release_key(getStringFromRequest("form_key"));
-				exit_error( _('Error - Go back and fill in all the information'));
+				exit_error( _('Error: Go back and fill in all the information'));
 			}
 
 		}
@@ -214,38 +215,33 @@ function show_add_snippet_box() {
 		<input type="hidden" name="id" value="<?php echo $id; ?>" />
 
 		<table>
-		<tr><td colspan="2"><strong><?php echo _('Version:'); ?></strong><br />
+		<tr><td colspan="2"><strong><?php echo _('Version')._(':'); ?></strong><br />
 			<input type="text" name="version" size="10" maxlength="15" />
 		</td></tr>
 
-		<tr><td colspan="2"><strong><?php echo _('Changes:'); ?></strong><br />
+		<tr><td colspan="2"><strong><?php echo _('Changes')._(':'); ?></strong><br />
 			<textarea name="changes" rows="5" cols="45"></textarea>
 		</td></tr>
 
-		<tr><td colspan="2" style="text-align:center">
+		<tr><td colspan="2" class="align-center">
 			<strong><?php echo _('Make sure all info is complete and accurate'); ?></strong>
 			<br />
-			<input type="submit" name="submit" value="<?php echo _('SUBMIT'); ?>" />
+			<input type="submit" name="submit" value="<?php echo _('Submit'); ?>" />
 		</td></tr>
 		</table></form></p>
 		<?php
 
 		snippet_footer(array());
 
-
 	} else {
-		exit_error(_('Error - was the URL or form mangled??'));
+		exit_error(_('Error: was the URL or form mangled??'));
 	}
 
 } else {
-
 	exit_not_logged_in();
-
 }
 
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
