@@ -3,6 +3,7 @@
  * Code Snippets Repository
  *
  * Copyright 1999-2001 (c) VA Linux Systems
+ * Copyright 2013, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -21,14 +22,15 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'snippet/snippet_utils.php';
 
 /**
  * createSnippetQuery - Creates the SQL query for loading data about snippets
  *
- * @param	string	clause - the last part of the where clause
+ * @param	string	$clause - the last part of the where clause
+ * @return string
  */
 function createSnippetQuery($clause) {
 	return "SELECT users.realname,users.user_name,snippet.description,snippet.snippet_id,snippet.name FROM snippet,users WHERE users.user_id=snippet.created_by AND ".$clause;
@@ -37,13 +39,14 @@ function createSnippetQuery($clause) {
 /**
  * createPackageQuery - Creates the SQL query for loading data about packages
  *
- * @param	string	clause - the last part of the where clause
+ * @param	string	$clause - the last part of the where clause
+ * @return	string
  */
 function createPackageQuery($clause) {
 	return "SELECT users.realname,users.user_name,users.user_id,snippet_package.description,snippet_package.snippet_package_id,snippet_package.name FROM snippet_package,users WHERE users.user_id=snippet_package.created_by AND ".$clause;
 }
 
-snippet_header(array('title'=>_('Snippet Library'), 'header'=>''));
+snippet_header(array('title'=>_('Snippet Library')));
 
 $by = getStringFromRequest('by');
 
@@ -56,16 +59,16 @@ if ($by=='lang') {
 	$qpa = db_construct_qpa ($qpa, ' AND snippet.language=$1', array ($lang)) ;
 	$qpa2 = db_construct_qpa ($qpa2, ' AND snippet_package.language=$1', array ($lang)) ;
 
-	echo '<h2>' .sprintf(_('Snippets by language: %1$s'), $SCRIPT_LANGUAGE[$lang]).'</h2>';
-} else if ($by=='cat') {
+	echo '<h2>' .sprintf(_('Snippets by language: %s'), $SCRIPT_LANGUAGE[$lang]).'</h2>';
+} elseif ($by=='cat') {
 	$cat = getStringFromRequest('cat');
 
 	$qpa = db_construct_qpa ($qpa, ' AND snippet.category=$1', array ($cat)) ;
 	$qpa2 = db_construct_qpa ($qpa2, ' AND snippet_package.category=$1', array ($cat)) ;
 
-	echo '<h2>' .sprintf(_('Snippets by category: %1$s'), $SCRIPT_CATEGORY[$cat]).'</h2>';
+	echo '<h2>' .sprintf(_('Snippets by category: %s'), $SCRIPT_CATEGORY[$cat]).'</h2>';
 } else {
-	exit_error(_('Error - bad url?'));
+	exit_error(_('Error: bad url?'));
 }
 
 $result = db_query_qpa ($qpa) ;
@@ -74,7 +77,7 @@ $result2 = db_query_qpa ($qpa2) ;
 $rows2=db_numrows($result2);
 
 if ((!$result || $rows < 1) && (!$result2 || $rows2 < 1)) {
-	echo '<h2>' ._('No snippets found').'</h2>';
+	echo '<p class="information">' ._('No snippets found.').'</p>';
 } else {
 
 	$title_arr=array();
@@ -118,4 +121,3 @@ if ((!$result || $rows < 1) && (!$result2 || $rows2 < 1)) {
 	echo $GLOBALS['HTML']->listTableBottom();
 }
 snippet_footer(array());
-?>
