@@ -22,7 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'snippet/snippet_utils.php';
 /*
@@ -30,7 +30,7 @@ require_once $gfwww.'snippet/snippet_utils.php';
 */
 
 if (session_loggedin()) {
-	snippet_header(array('title'=>'Delete Snippets'));
+	snippet_header(array('title' => _('Delete Snippets')));
 	$type = getStringFromRequest('type');
 	$snippet_version_id = getIntFromRequest('snippet_version_id');
 	$snippet_package_version_id = getIntFromRequest('snippet_package_version_id');
@@ -42,26 +42,27 @@ if (session_loggedin()) {
 
 		//Check to see if they are the creator of this package_version
 		$result=db_query_params("SELECT * FROM snippet_package_version ".
-			"WHERE submitted_by=$1 AND ".
-			"snippet_package_version_id=$2", array(user_getid(), $snippet_package_version_id));
+					"WHERE submitted_by=$1 AND ".
+					"snippet_package_version_id=$2",
+					array(user_getid(), $snippet_package_version_id));
 		if (!$result || db_numrows($result) < 1) {
-			echo '<p class="error">Error - Only the creator of a package version can delete snippets from it.</p>';
+			echo '<p class="error">'._('Error: Only the creator of a package version can delete snippets from it.').'</p>';
 			snippet_footer(array());
 			exit;
 		} else {
 
 			//Remove the item from the package
-			$result=db_query_params ('DELETE FROM snippet_package_item 
-WHERE snippet_version_id=$1 
-AND snippet_package_version_id=$2',
-			array($snippet_version_id,
-				$snippet_package_version_id));
+			$result=db_query_params ('DELETE FROM snippet_package_item
+						WHERE snippet_version_id=$1
+						AND snippet_package_version_id=$2',
+						array($snippet_version_id,
+							$snippet_package_version_id));
 			if (!$result || db_affected_rows($result) < 1) {
-				echo '<p class="error">Error - That snippet doesn\'t exist in this package.</p>';
+				echo '<p class="error">'._('Error: That snippet does not exist in this package.').'</p>';
 				snippet_footer(array());
 				exit;
 			} else {
-				echo '<p class="feedback">Item Removed From Package</p>';
+				echo '<p class="feedback">'._('Item Removed From Package').'</p>';
 				snippet_footer(array());
 				exit;
 			}
@@ -74,9 +75,10 @@ AND snippet_package_version_id=$2',
 
 		//find this snippet id and make sure the current user created it
 		$result=db_query_params("SELECT * FROM snippet_version ".
-			"WHERE snippet_version_id=$1 AND submitted_by=$2", array($snippet_version_id, user_getid()));
+					"WHERE snippet_version_id=$1 AND submitted_by=$2",
+					array($snippet_version_id, user_getid()));
 		if (!$result || db_numrows($result) < 1) {
-			echo '<p class="error">Error - That snippet doesn\'t exist.</p>';
+			echo '<p class="error">'._('Error: That snippet does not exist.').'</p>';
 			snippet_footer(array());
 			exit;
 		} else {
@@ -84,7 +86,8 @@ AND snippet_package_version_id=$2',
 
 			//do the delete
 			$result=db_query_params("DELETE FROM snippet_version ".
-				"WHERE snippet_version_id=$1 AND submitted_by=$2", array($snippet_version_id, user_getid()));
+						"WHERE snippet_version_id=$1 AND submitted_by=$2",
+						array($snippet_version_id, user_getid()));
 
 			//see if any versions of this snippet are left
 			$result=db_query_params("SELECT * FROM snippet_version WHERE snippet_id=$1", array($snippet_id));
@@ -94,7 +97,7 @@ AND snippet_package_version_id=$2',
 				$result=db_query_params("DELETE FROM snippet WHERE snippet_id=$1",array($snippet_id));
 			}
 
-			echo '<class="feedback">Snippet Removed</p>';
+			echo '<p class="feedback">'._('Snippet Removed').'</p>';
 			snippet_footer(array());
 			exit;
 		}
@@ -107,11 +110,12 @@ AND snippet_package_version_id=$2',
 
 		//make sure they own this version of the package
 		$result=db_query_params("SELECT * FROM snippet_package_version ".
-			"WHERE submitted_by=$1 AND ".
-			"snippet_package_version_id=$2", array(user_getid(), $snippet_package_version_id));
+					"WHERE submitted_by=$1 AND ".
+					"snippet_package_version_id=$2",
+					array(user_getid(), $snippet_package_version_id));
 		if (!$result || db_numrows($result) < 1) {
 			//they don't own it or it's not found
-			echo '<p class="error">Error - Only the creator of a package version can delete it.</p>';
+			echo '<p class="error">'._('Error: Only the creator of a package version can delete it.').'</p>';
 			snippet_footer(array());
 			exit;
 		} else {
@@ -119,27 +123,30 @@ AND snippet_package_version_id=$2',
 
 			//do the version delete
 			$result=db_query_params("DELETE FROM snippet_package_version ".
-		       		"WHERE submitted_by=$1 AND ".
-				"snippet_package_version_id=$2", array(user_getid(), $snippet_package_version_id));
+						"WHERE submitted_by=$1 AND ".
+						"snippet_package_version_id=$2",
+						array(user_getid(), $snippet_package_version_id));
 
 			//delete snippet_package_items
 			$result=db_query_params("DELETE FROM snippet_package_item ".
-				"WHERE snippet_package_version_id=$1", array($snippet_package_version_id));
+						"WHERE snippet_package_version_id=$1",
+						array($snippet_package_version_id));
 
 			//see if any versions of this package remain
 			$result=db_query_params("SELECT * FROM snippet_package_version ".
-				"WHERE snippet_package_id=$1", array($snippet_package_id));
+						"WHERE snippet_package_id=$1",
+						array($snippet_package_id));
 			if (!$result || db_numrows($result) < 1) {
 				//since no versions of this package remain,
 				//delete the main package even if the user didn't create it
 				$result=db_query_params("DELETE FROM snippet_package WHERE snippet_package_id=$1", array($snippet_package_id));
 			}
-			echo '<p class="feedback">Package Removed</p>';
+			echo '<p class="feedback">'._('Package Removed').'</p>';
 			snippet_footer(array());
 			exit;
 		}
 	} else {
-		exit_error(_('Error - mangled URL?'));
+		exit_error(_('Error: mangled URL?'));
 	}
 
 } else {
@@ -147,5 +154,3 @@ AND snippet_package_version_id=$2',
 	exit_not_logged_in();
 
 }
-
-?>
