@@ -21,7 +21,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'snippet/snippet_utils.php';
 
@@ -54,9 +54,8 @@ if (session_loggedin()) {
 			if (!$result) {
 				//error in database
 				form_release_key(getStringFromRequest("form_key"));
-				$error_msg .= _('ERROR DOING SNIPPET PACKAGE INSERT!');
+				$error_msg .= _('Error doing snippet package insert').' '.db_error();
 				snippet_header(array('title'=>_('Submit A New Snippet Package')));
-				echo db_error();
 				snippet_footer(array());
 				exit;
 			} else {
@@ -73,14 +72,14 @@ if (session_loggedin()) {
 								  time()));
 				if (!$result) {
 					//error in database
-					$error_msg .= _('ERROR DOING SNIPPET PACKAGE VERSION INSERT!');
+					$error_msg .= _('Error doing snippet package version insert');
 					snippet_header(array('title'=>_('Submit A New Snippet Package')));
 					echo db_error();
 					snippet_footer(array());
 					exit;
 				} else {
 					//so far so good - now add snippets to the package
-					$feedback .= _('Snippet Pacakge Version Added Successfully.');
+					$feedback .= _('Snippet Package Version Added Successfully.');
 
 					//id for this snippet_package_version
 					$snippet_package_version_id=
@@ -93,10 +92,10 @@ if (session_loggedin()) {
 
 					?>
 
-<script language="JavaScript" type="text/javascript">/* <![CDATA[ */
+<script type="text/javascript">/* <![CDATA[ */
 function show_add_snippet_box() {
-	newWindow = open("","occursDialog","height=500,width=300,scrollbars=yes,resizable=yes");
-	newWindow.location=('/snippet/add_snippet_to_package.php?suppress_nav=1&snippet_package_version_id=<?php 
+	var newWindow = open('','occursDialog','height=500,width=300,scrollbars=yes,resizable=yes');
+	newWindow.location=('/snippet/add_snippet_to_package.php?suppress_nav=1&snippet_package_version_id=<?php
 			echo $snippet_package_version_id; ?>');
 }
 /* ]]> */</script>
@@ -107,7 +106,7 @@ function show_add_snippet_box() {
 <p>
 <?php echo _('If a new window opened, use it to add snippets to your package. If a new window did not open, use the following link to add to your package BEFORE you leave this page.'); ?></p>
 
-<p><?php echo util_make_link ('/snippet/add_snippet_to_package.php?snippet_package_version_id='.$snippet_package_version_id,_('Add snippets to package'),array('target'=>'_blank')); ?></p>
+<p><?php echo util_make_link ('/snippet/add_snippet_to_package.php?snippet_package_version_id='.$snippet_package_version_id,_('Add snippets to package')); ?></p>
 
 <p>
 <?php echo _('<strong>Browse the library</strong> to find the snippets you want to add, then add them using the new window link shown above.'); ?>
@@ -121,7 +120,7 @@ function show_add_snippet_box() {
 			}
 		} else {
 			form_release_key(getStringFromRequest("form_key"));
-			exit_error(_('Error - Go back and fill in all the information'));
+			exit_error(_('Error: Go back and fill in all the information'));
 		}
 
 	}
@@ -134,27 +133,27 @@ function show_add_snippet_box() {
     </p>
 	<ol>
       <li><?php echo _('Create the package using this form.'); ?></li>
-	  <li><?php echo _('<strong>Then</strong> use the "Add Snippets to Package" link to add files to your package.'); ?></li>
+	  <li><?php echo _('<strong>Then</strong> use the “Add Snippets to Package” link to add files to your package.'); ?></li>
 	</ol>
 	<p><?php echo _('<span class="important">Note:</span> You can submit a new version of an existing package by browsing the library and using the link on the existing package. You should only use this page if you are submitting an entirely new package.'); ?>
     </p>
 	<form action="<?php echo getStringFromServer('PHP_SELF'); ?>" method="post">
 	<input type="hidden" name="form_key" value="<?php echo form_generate_key(); ?>"/>
 	<input type="hidden" name="post_changes" value="y" />
-	<input type="hidden" name="changes" value="First Posted Version" />
+	<input type="hidden" name="changes" value="<?php echo _('First Posted Version') ?>" />
 
 	<table>
 
-	<tr><td colspan="2"><strong><?php echo _('Title:'); ?></strong><?php echo utils_requiredField(); ?><br />
-		<input type="text" name="name" size="45" maxlength="60" />
+	<tr><td colspan="2"><strong><?php echo _('Title')._(':'); ?></strong><?php echo utils_requiredField(); ?><br />
+		<input type="text" required="required" name="name" size="45" maxlength="60" />
 	</td></tr>
 
-	<tr><td colspan="2"><strong><?php echo _('Description:'); ?></strong><?php echo utils_requiredField(); ?><br />
-		<textarea name="description" rows="5" cols="45"></textarea>
+	<tr><td colspan="2"><strong><?php echo _('Description')._(':'); ?></strong><?php echo utils_requiredField(); ?><br />
+		<textarea name="description" required="required" rows="5" cols="45"></textarea>
 	</td></tr>
 
 	<tr>
-	<td><strong><?php echo _('Language') ?>:</strong><?php echo utils_requiredField(); ?><br />
+	<td><strong><?php echo _('Language')._(':'); ?></strong><?php echo utils_requiredField(); ?><br />
 		<?php echo html_build_select_box_from_array ($SCRIPT_LANGUAGE,'language'); ?>
 		<br />
 		<!--<?php echo util_make_link ('/support/?func=addsupport&amp;group_id=1',_('Suggest a Language')); ?>-->
@@ -166,15 +165,15 @@ function show_add_snippet_box() {
 		<!--<?php echo util_make_link ('/support/?func=addsupport&amp;group_id=1',_('Suggest a Category')); ?>-->
 	</td>
 	</tr>
- 
-	<tr><td colspan="2"><strong><?php echo _('Version') ?>:</strong><?php echo utils_requiredField(); ?><br />
-		<input type="text" name="version" size="10" maxlength="15" />
+
+	<tr><td colspan="2"><strong><?php echo _('Version')._(':'); ?></strong><?php echo utils_requiredField(); ?><br />
+		<input type="text" required="required" name="version" size="10" maxlength="15" />
 	</td></tr>
 
-	<tr><td colspan="2" style="text-align:center">
+	<tr><td colspan="2" class="align-center">
 		<strong><?php echo _('Make sure all info is complete and accurate'); ?></strong>
 		<br />
-		<input type="submit" name="submit" value="<?php echo _('SUBMIT'); ?>" />
+		<input type="submit" name="submit" value="<?php echo _('Submit'); ?>" />
 	</td></tr>
 
 	</table></form>
@@ -191,5 +190,3 @@ function show_add_snippet_box() {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
