@@ -3,6 +3,8 @@
  * Code Snippets Repository
  *
  * Copyright 1999-2001 (c) VA Linux Systems - Tim Perdue
+ * Copyright 2012, Jean-Christophe Masson - French National Education Department
+ * Copyright 2012-2014, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -22,7 +24,7 @@
  */
 
 $SCRIPT_CATEGORY[0]= _('Choose One');
-$SCRIPT_CATEGORY[1]= _('UNIX Admin');
+$SCRIPT_CATEGORY[1]= _('Unix Admin');
 $SCRIPT_CATEGORY[2]= _('HTML Manipulation');
 $SCRIPT_CATEGORY[3]= _('BBS Systems');
 $SCRIPT_CATEGORY[4]= _('Auctions');
@@ -101,29 +103,17 @@ $SCRIPT_EXTENSION[16] = '.cs';
 
 function snippet_header($params) {
 	global $HTML;
-	global $feedback;
-	global $warning_msg;
-	global $error_msg;
 
 	if (!forge_get_config('use_snippet')) {
 		exit_disabled();
 	}
 
 	$HTML->header($params);
-	if (!empty($error_msg)) {
-		html_feedback_top($error_msg);
-	}
-	if (!empty($warning_msg)) {
-		html_feedback_top($warning_msg);
-	}
-	if (!empty($feedback)) {
-		html_feedback_top($feedback);
-	}
 
 	/*
 		Show horizontal links
 	*/
-	
+
 	echo '<p><strong>';
 	echo util_make_link ('/snippet/',_('Browse')).'
 		 | '.util_make_link ('/snippet/submit.php',_('Submit A New Snippet')).'
@@ -132,24 +122,21 @@ function snippet_header($params) {
 }
 
 function snippet_footer($params) {
-	GLOBAL $HTML;
+	global $HTML;
 	$HTML->footer($params);
 }
 
 function snippet_show_package_snippets($version) {
 	//show the latest version
-	$result=db_query_params("SELECT snippet_package_item.snippet_version_id, snippet_version.version,snippet.name,users.user_name 
-FROM snippet,snippet_version,snippet_package_item,users 
-WHERE snippet.snippet_id=snippet_version.snippet_id 
-AND users.user_id=snippet_version.submitted_by 
-AND snippet_version.snippet_version_id=snippet_package_item.snippet_version_id 
-AND snippet_package_item.snippet_package_version_id=$1", array($version));
+	$result=db_query_params("SELECT users.realname,users.user_id,snippet_package_item.snippet_version_id, snippet_version.version,snippet.name,users.user_name
+				FROM snippet,snippet_version,snippet_package_item,users
+				WHERE snippet.snippet_id=snippet_version.snippet_id
+				AND users.user_id=snippet_version.submitted_by
+				AND snippet_version.snippet_version_id=snippet_package_item.snippet_version_id
+				AND snippet_package_item.snippet_package_version_id=$1", array($version));
 
 	$rows=db_numrows($result);
-	echo '
-	<p>&nbsp;</p>
-	<h3>' ._('Snippets In This Package:').':</h3>
-	<p>&nbsp;</p>';
+	echo '<h3>' ._('Snippets In This Package').'</h3>';
 
 	$title_arr=array();
 	$title_arr[]= _('Snippet ID');
@@ -157,14 +144,12 @@ AND snippet_package_item.snippet_package_version_id=$1", array($version));
 	$title_arr[]= _('Title');
 	$title_arr[]= _('Author');
 
-	echo $GLOBALS['HTML']->listTableTop ($title_arr,$links_arr);
-
 	if (!$result || $rows < 1) {
 		echo db_error();
 		echo '
-			<tr><td colspan="4"><h3>' ._('No Snippets Are In This Package Yet').'</h3></td></tr>';
+			<div class="warning_msg">'._('No Snippets Are In This Package Yet').'</div>';
 	} else {
-
+		echo $GLOBALS['HTML']->listTableTop($title_arr);
 		//get the newest version, so we can display it's code
 		$newest_version=db_result($result,0,'snippet_version_id');
 
@@ -172,15 +157,13 @@ AND snippet_package_item.snippet_package_version_id=$1", array($version));
 			echo '
 			<tr '. $GLOBALS['HTML']->boxGetAltRowStyle($i) .'><td>'.db_result($result,$i,'snippet_version_id').
 				'</td><td>'.
-				util_make_link ('/snippet/download.php?type=snippet&amp;id='.db_result($result,$i,'snippet_version_id'),db_result($result,$i,'version')).
+				util_make_link('/snippet/download.php?type=snippet&amp;id='.db_result($result,$i,'snippet_version_id'),db_result($result,$i,'version')).
 				'</td><td>'.
 				db_result($result,$i,'name').'</td><td>'.
-				db_result($result,$i,'user_name').'</td></tr>';
+				util_make_link_u(db_result($result, $i, 'user_name'), db_result($result, $i, 'user_id'),db_result($result, $i, 'realname')).'</td></tr>';
 		}
+		echo $GLOBALS['HTML']->listTableBottom();
 	}
-
-	echo $GLOBALS['HTML']->listTableBottom();
-
 }
 
 function snippet_show_package_details($id) {
@@ -190,23 +173,23 @@ function snippet_show_package_details($id) {
 
 	echo '
 	<p>
-	<table width="100%" border="0" cellspacing="1" cellpadding="2">
+	<table class="fullwidth" cellspacing="1" cellpadding="2">
 
 	<tr><td colspan="2">
 	<h2>'. db_result($result,0,'name').'</h2>
 	</td></tr>
 
 	<tr>
-		<td><strong>Category:</strong><br />
+		<td><strong>'._('Category')._(':').'</strong><br />
 		'.$SCRIPT_CATEGORY[db_result($result,0,'category')].'
 		</td>
 
-		<td><strong>Language:</strong><br />
+		<td><strong>'._('Language')._(':').'</strong><br />
 		'.$SCRIPT_LANGUAGE[db_result($result,0,'language')].'
 		</td>
 	</tr>
 
-	<tr><td colspan="2">&nbsp;<br /><strong>Description:</strong><br />
+	<tr><td colspan="2"><br /><strong>'._('Description')._(':').'</strong><br />
 	'. util_make_links(nl2br(db_result($result,0,'description'))).'
 	</td></tr>
 
@@ -221,26 +204,26 @@ function snippet_show_snippet_details($id) {
 
 	echo '
 	<p>
-	<table width="100%" border="0" cellspacing="1" cellpadding="2">
+	<table class="fullwidth" cellspacing="1" cellpadding="2">
 
 	<tr><td colspan="2">
 	<h2>'. db_result($result,0,'name').'</h2>
 	</td></tr>
 
-	<tr><td><strong>Type:</strong><br />
+	<tr><td><strong>'._('Type')._(':').'</strong><br />
 		'.$SCRIPT_TYPE[db_result($result,0,'type')].'</td>
-	<td><strong>Category:</strong><br />
+	<td><strong>'._('Category')._(':').'</strong><br />
 		'.$SCRIPT_CATEGORY[db_result($result,0,'category')].'
 	</td></tr>
 
-	<tr><td><strong>License:</strong><br />
+	<tr><td><strong>'._('License')._(':').'</strong><br />
 		'.$SCRIPT_LICENSE[db_result($result,0,'license')].'</td>
-	<td><strong>Language:</strong><br />
+	<td><strong>'._('Language')._(':').'</strong><br />
 		'.$SCRIPT_LANGUAGE[db_result($result,0,'language')].'
 	</td></tr>
 
-	<tr><td colspan="2">&nbsp;<br />
-	<strong>Description:</strong><br />
+	<tr><td colspan="2"><br />
+	<strong>'._('Description')._(':').'</strong><br />
 	'. util_make_links(nl2br(db_result($result,0,'description'))).'
 	</td></tr>
 
@@ -251,5 +234,3 @@ function snippet_show_snippet_details($id) {
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
