@@ -1,6 +1,6 @@
 <?php
 
-$no_gz_buffer=true;
+$no_gz_buffer = true;
 $no_debug     = true;
 
 // 0. Include GForge files for access to GForge system
@@ -10,6 +10,10 @@ require_once $gfcommon.'include/gettext.php';
 require_once $gfcommon.'include/FusionForge.class.php';
 
 ini_set('memory_limit','32M');
+sysdebug_off();
+
+// Disable error_reporting as it breaks XML generated output.
+error_reporting(0);
 
 $uri = 'http://'.forge_get_config('web_host');
 // 1. include client and server
@@ -125,7 +129,6 @@ require_once $gfwww.'soap/frs/frs.php';
 //
 require_once $gfwww.'soap/scm/scm.php';
 
-
 $wsdl_data = $server->wsdl->serialize();
 
 if (isset($wsdl)) {
@@ -136,7 +139,7 @@ if (isset($wsdl)) {
 /**
  * continueSession - A utility method to carry on with an already established session
  *
- * @param 	string		The session key
+ * @param 	string		$sessionKey	The session key
  */
 function continue_session($sessionKey) {
 	session_continue($sessionKey);
@@ -145,30 +148,30 @@ function continue_session($sessionKey) {
 // session/authentication
 /**
  * login - Logs in a SOAP client
- * 
- * @param	string	userid	The user's unix id
- * @param	string	passwd	The user's passwd in clear text
+ *
+ * @param	string	$userid	userid	The user's unix id
+ * @param	string	$passwd	passwd	The user's passwd in clear text
  *
  * @return	string	the session key
  */
 function login($userid, $passwd) {
 	global $feedback, $session_ser;
-		
+
 	setlocale (LC_TIME, _('en_US'));
 
-	$res = session_login_valid($userid, $passwd);
-	
+	$res = session_check_credentials_in_database($userid, $passwd);
+
 	if (!$res) {
 		return new soap_fault('1001', 'user', "Unable to log in with userid of ".$userid, $feedback);
  	}
-	
-	return $session_ser;
+
+	return session_build_session_token(user_getid());
 }
 
 /**
  * logout - Logs out a SOAP client
  *
- * @param 	string	sessionkey	The session key
+ * @param 	string	$session_ser	sessionkey	The session key
  */
 function logout($session_ser) {
 	continue_session($session_ser);
@@ -178,7 +181,7 @@ function logout($session_ser) {
 
 /**
  * version - get the running version of FusionForge
- * 
+ *
  * @return	string 	the version of FusionForge running on the server
  */
 function version() {
@@ -193,5 +196,3 @@ $server->service($HTTP_RAW_POST_DATA);
 if(isset($log) and $log != ''){
 	harness('nusoap_r2_base_server',$server->headers['User-Agent'],$server->methodname,$server->request,$server->response,$server->result);
 }
-
-?>
