@@ -3,6 +3,7 @@
  * SOAP Tasks Include - this file contains wrapper functions for the SOAP interface
  *
  * Copyright 2004 (c) GForge, LLC
+ * Copyright (C) 2012 Alain Peyrat - Alcatel-Lucent
  * http://gforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -90,7 +91,6 @@ $server->wsdl->addComplexType(
 	'tns:TaskDependency'
 );
 
-
 $server->wsdl->addComplexType(
 	'TaskAssignee',
 	'complexType',
@@ -114,8 +114,6 @@ $server->wsdl->addComplexType(
 	'tns:TaskAssignee'
 );
 
-
-
 //
 //	ProjectTasks
 //
@@ -327,6 +325,42 @@ $server->register(
 	$uri,$uri.'#getProjectTechnicians','rpc','encoded'
 );
 
+//addSubproject
+$server->register(
+	'addSubproject',
+	array('session_ser'=>'xsd:string',
+		'group_id'=>'xsd:int',
+		'group_project_id'=>'xsd:int',
+		'project_name'=>'xsd:string',
+		'description'=>'xsd:string',
+		'_public'=>'xsd:int',
+		'send_all_posts_to'=>'xsd:string'),
+	array('addSubproject'=>'xsd:int'),
+	$uri,$uri.'#addSubproject','rpc','encoded'
+);
+
+//updateSubproject
+$server->register(
+	'updateSubproject',
+	array('session_ser'=>'xsd:string',
+		'group_id'=>'xsd:int',
+		'group_project_id'=>'xsd:int',
+		'project_name'=>'xsd:string',
+		'description'=>'xsd:string',
+		'send_all_posts_to'=>'xsd:string'),
+	array('updateSubproject'=>'xsd:boolean'),
+	$uri,$uri.'#updateSubproject','rpc','encoded'
+);
+
+//deleteSubproject
+$server->register(
+	'deleteSubproject',
+	array('session_ser'=>'xsd:string',
+		'group_id'=>'xsd:int',
+		'group_project_id'=>'xsd:int'),
+	array('deleteSubproject'=>'xsd:boolean'),
+	$uri,$uri.'#deleteSubproject','rpc','encoded'
+);
 
 //
 //	getProjectGroups
@@ -397,13 +431,13 @@ function &addProjectTask($session_ser,$group_id,$group_project_id,$summary,$deta
 	} elseif ($a->isError()) {
 		return new soap_fault ('','addProjectTask','$a->getErrorMessage()',$a->getErrorMessage());
 	}
-	
+
 	// transform the $depend_arr (which is an array of ints) to include the link type
 	$depend_map = array();
 	foreach ($depend_arr as $depend_id) {
 		$depend_map[$depend_id] = PM_LINK_DEFAULT;
 	}
-	
+
 	if (!$a->create($summary,$details,$priority,$hours,$start_date,$end_date,
             $category_id,$percent_complete,$assigned_arr,$depend_map,$duration,$parent_id)) {
 		return new soap_fault ('','addProjectTask',$a->getErrorMessage(),$a->getErrorMessage());
@@ -439,13 +473,13 @@ function &updateProjectTask($session_ser,$group_id,$group_project_id,$project_ta
     } elseif ($a->isError()) {
         return new soap_fault ('','updateProjectTask',$a->getErrorMessage(),$a->getErrorMessage());
     }
-    
+
     // transform the $depend_arr (which is an array of ints) to include the link type
 	$depend_map = array();
 	foreach ($depend_arr as $depend_id) {
 		$depend_map[$depend_id] = PM_LINK_DEFAULT;
 	}
-	
+
     if (!$a->update($summary,$details,$priority,$hours,$start_date,$end_date,$status_id,$category_id,
 		$percent_complete,$assigned_arr,$depend_map,$new_group_project_id,$duration,$parent_id)) {
         return new soap_fault ('','updateProjectTask',$a->getErrorMessage(),$a->getErrorMessage());
@@ -472,7 +506,7 @@ function &getProjectTaskCategories($session_ser,$group_id,$group_project_id) {
 	} elseif ($at->isError()) {
 		return new soap_fault ('','getProjectTaskCategories',$at->getErrorMessage(),$at->getErrorMessage());
 	}
-	
+
 	$cat_arr = $at->getCategoryObjects();
 
 	return projectcategories_to_soap($cat_arr);
@@ -518,7 +552,7 @@ function &getProjectTechnicians($session_ser,$group_id,$group_project_id) {
 	$engine = RBACEngine::getInstance () ;
 	$techs = $engine->getUsersByAllowedAction ('pm', $pg->getID(), 'tech') ;
 
-	return users_to_soap ($techs);
+	return users_to_soap($techs);
 }
 
 function &getProjectTasks($session_ser,$group_id,$group_project_id,$assigned_to,$status,$category,$group) {
@@ -566,19 +600,19 @@ function projecttasks_to_soap($pt_arr) {
 				$dependent_on[] = array("task_id" => $dependent_on_id,
 										"link_type" => $link_type);
 			}
-			
+
 			//build the assigned_to array
 			$assigned_to = array();
 			$assigned_ids = $pt_arr[$i]->getAssignedTo();
 			foreach ($assigned_ids as $assigned_id) {
-				$assigned_to[] = array("user_id" => $assigned_id, 
+				$assigned_to[] = array("user_id" => $assigned_id,
 										"percent_effort" => 0		// TODO: This should be implemented
 									);
 			}
-			
+
 			$sort_id = $pt_arr[$i]->getExternalID();
 			if (!$sort_id) $sort_id=0;
-			
+
 			$return[]=array(
 				'project_task_id'=>$pt_arr[$i]->data_array['project_task_id'],
 				'group_project_id'=>$pt_arr[$i]->data_array['group_project_id'],
@@ -690,4 +724,50 @@ function &addProjectMessage($session_ser,$group_id,$group_project_id,$project_ta
 	}
 }
 
-?>
+//
+//	addSubproject
+//
+function addSubproject($session_ser,$group_id,$group_project_id,$project_name,$description,$_public,$send_all_posts_to) {
+	continue_session($session_ser);
+
+	$g = group_get_object($group_id);
+	$pg = new ProjectGroup($g,$group_project_id);
+
+	if (!$pg->create($project_name,$description,$send_all_posts_to)) {
+		return new soap_fault ('','addSubproject','Could Not Create Subproject','Could Not Create Subproject');
+	} else {
+		return $pg->getID();
+	}
+}
+
+//
+//	updateSubproject
+//
+function updateSubproject($session_ser,$group_id,$group_project_id,$project_name,$description,$send_all_posts_to) {
+	continue_session($session_ser);
+
+	$g = group_get_object($group_id);
+	$pg = new ProjectGroup($g,$group_project_id);
+
+	if (!$pg->update($project_name,$description,$send_all_posts_to)) {
+		return new soap_fault ('','updateSubproject','Could Not Update Subproject','Could Not Update Subproject');
+	} else {
+		return true;
+	}
+}
+
+//
+//	deleteSubproject
+//
+function deleteSubproject($session_ser,$group_id,$group_project_id) {
+	continue_session($session_ser);
+
+	$g = group_get_object($group_id);
+	$pg = new ProjectGroup($g,$group_project_id);
+
+	if (!$pg->delete(true,true)) {
+		return new soap_fault ('','deleteSubproject','Could Not Delete Subproject','Could Not Delete Subproject');
+	} else {
+		return true;
+	}
+}
