@@ -132,8 +132,8 @@ $server->register(
 	$uri,
 	$uri.'#getArtifactTypes','rpc','encoded'
 );
-// 
-// Artifact Extra Fields 
+//
+// Artifact Extra Fields
 // By remo on 08-Mar-2005
 
 $server->wsdl->addComplexType(
@@ -159,7 +159,6 @@ $server->wsdl->addComplexType(
 	'tns:ArtifactExtraFieldsData'
 );
 
-
 //
 //	Artifacts
 //
@@ -207,7 +206,6 @@ $server->register(
 	array('getArtifactsResponse'=>'tns:ArrayOfArtifact'),
 	$uri,$uri.'#getArtifacts','rpc','encoded');
 
-
 //addArtifact
 $server->register(
 	'addArtifact',
@@ -226,7 +224,6 @@ $server->register(
 	$uri,$uri.'#addArtifact','rpc','encoded'
 );
 
-
 //updateArtifact
 $server->register(
 	'updateArtifact',
@@ -330,14 +327,13 @@ function artifactFileDelete($session_ser,$group_id,$group_artifact_id,$artifact_
 	} elseif ($a->isError()) {
 		return new soap_fault ('','artifactFileDelete','$a->getErrorMessage()',$a->getErrorMessage());
 	}
-	if (!$a->delete()) {
+	if (!$a->delete(true)) {
 		return new soap_fault ('','artifactFileDelete','$a->getErrorMessage()',$a->getErrorMessage());
 	} else {
 		return true;
 	}
 }
 
-
 //
 //	ArtifactMessage
 //
@@ -578,17 +574,17 @@ function arrangeExtraFields($extra_fields, $extra_field_info) {
 			$efields=$extra_fields[$eky];
 			$efid = $efields['extra_field_id'];
 			$data = $efields['field_data'];
-			
+
 			// if the extra field is of type CHECKBOX or MULTISELECT we must
 			// convert the value passed by the user from a comma separated list
 			// of ids to an array
 			if (array_key_exists($efid, $extra_field_info)) {
 				if ($extra_field_info[$efid]['field_type'] == ARTIFACT_EXTRAFIELDTYPE_CHECKBOX ||
 						$extra_field_info[$efid]['field_type'] == ARTIFACT_EXTRAFIELDTYPE_MULTISELECT) {
-					$data = split(",", $data);
+					$data = explode(',', $data);
 				}
 			}
-			
+
 			$fieldsdata[$efid]=$data;
 		}
 	}
@@ -623,7 +619,7 @@ function &addArtifact($session_ser,$group_id,$group_artifact_id,$status_id,
 	} elseif ($a->isError()) {
 		return new soap_fault ('','addArtifact',$a->getErrorMessage(),$a->getErrorMessage());
 	}
-	
+
 	$aef = $a->ArtifactType->getExtraFields();
 	$extra_flds=arrangeExtraFields($extra_fields,$aef);
 	if (!$a->create($summary,$details,$assigned_to,$priority,$extra_flds)) {
@@ -728,13 +724,13 @@ function &getArtifacts($session_ser,$group_id,$group_artifact_id,$assigned_to,$s
 	} else {
 		$set = false;
 	}
-	
+
 	$af->setup(0,'','',0,$set,$assigned_to,$status);
 	$artifacts = $af->getArtifacts();
 	if ($artifacts === false) {
 		return new soap_fault ('','getArtifacts',$af->getErrorMessage(),$af->getErrorMessage());
 	}
-	return artifacts_to_soap($artifacts);
+	return util_strip_unprintable(artifacts_to_soap($artifacts));
 
 }
 
@@ -828,7 +824,7 @@ function &getArtifactFiles($session_ser,$group_id,$group_artifact_id,$artifact_i
 	} elseif ($a->isError()) {
 		return new soap_fault ('','getArtifactFiles',$a->getErrorMessage(),$a->getErrorMessage());
 	}
-	
+
 	$files_arr = $a->getFiles();
 	$return = artifactfiles_to_soap($files_arr);
 
@@ -882,23 +878,22 @@ function getArtifactFileData($session_ser,$group_id,$group_artifact_id,$artifact
 	} elseif ($a->isError()) {
 		return new soap_fault ('','getArtifactFileData',$a->getErrorMessage(),$a->getErrorMessage());
 	}
-	
+
 	$af=new ArtifactFile($a,$file_id);
 	if (!$af || !is_object($af)) {
 		return new soap_fault ('','getArtifactFileData','ArtifactFile Could Not Be Created','ArtifactFile Could Not Be Created');
-	} else if ($af->isError()) {
+	} elseif ($af->isError()) {
 		return new soap_fault ('','getArtifactFileData',$af->getErrorMessage(),$af->getErrorMessage());
-	} 
-	
+	}
+
 	//send file encoded in base64
 	return base64_encode($af->getData());
 }
 
-
 //
 //
 //	addArtifactFile
-// 
+//
 
 /*
  'session_ser'=>'xsd:string',
@@ -912,7 +907,7 @@ function getArtifactFileData($session_ser,$group_id,$group_artifact_id,$artifact
  */
 function addArtifactFile($session_ser,$group_id,$group_artifact_id,$artifact_id,$base64_contents,$description,$filename,$filetype) {
 	continue_session($session_ser);
-	
+
 	$grp = group_get_object($group_id);
 	if (!$grp || !is_object($grp)) {
 		return new soap_fault ('','addArtifactFile','Could Not Get Project','Could Not Get Project');
@@ -933,23 +928,23 @@ function addArtifactFile($session_ser,$group_id,$group_artifact_id,$artifact_id,
 	} elseif ($a->isError()) {
 		return new soap_fault ('','addArtifactFile',$a->getErrorMessage(),$a->getErrorMessage());
 	}
-	
+
 	$af = new ArtifactFile($a);
 	if (!$af || !is_object($af)) {
 		return new soap_fault ('','addArtifactFile','Could Not Create ArtifactFile object','Could Not Create ArtifactFile object');
-	} else if ($af->isError()) {
+	} elseif ($af->isError()) {
 		return new soap_fault ('','addArtifactFile',$af->getErrorMessage(),$af->getErrorMessage());
 	}
 
 	$bin_data = base64_decode($base64_contents);
 	$filesize = strlen($bin_data);
-	
+
 	$res = $af->create($filename,$filetype,$filesize,$bin_data,$description);
-	
+
 	if (!$res) {
 		return new soap_fault ('','addArtifactFile',$af->getErrorMessage(),$af->getErrorMessage());
 	}
-	
+
 	return $res;
 }
 
@@ -1095,7 +1090,7 @@ function artifactGetChangeLog($session_ser, $group_id, $group_artifact_id, $arti
 	} elseif ($grp->isError()) {
 		return new soap_fault ('','artifactGetChangeLog',$grp->getErrorMessage(),$grp->getErrorMessage());
 	}
-	
+
 	$at = new ArtifactType($grp,$group_artifact_id);
 	if (!$at || !is_object($at)) {
 		return new soap_fault ('','artifactGetChangeLog','Could Not Get ArtifactType','Could Not Get ArtifactType');
@@ -1109,7 +1104,7 @@ function artifactGetChangeLog($session_ser, $group_id, $group_artifact_id, $arti
 	} elseif ($artifact->isError()) {
 		return new soap_fault ('','artifactGetChangeLog',$artifact->getErrorMessage(),$artifact->getErrorMessage());
 	}
-	
+
 	// note that Artifact::getHistory returns a DB result handler
 	$result = $artifact->getHistory();
 	return artifact_history_to_soap($result, $at);
@@ -1122,17 +1117,17 @@ function artifact_history_to_soap($db_result, &$artifactType) {
 		$old_value = $entry["old_value"];
 		$date = $entry["entrydate"];
 		$user_name = $entry["user_name"];
-		
+
 		if ($field_name == 'status_id') {
 			$old_value = $artifactType->getStatusName($old_value);
-		} else if ($field_name == 'assigned_to') {
+		} elseif ($field_name == 'assigned_to') {
 			$old_value =  user_getname($old_value);
-		} else if ($field == 'close_date') {
+		} elseif ($field_name == 'close_date') {
 			$old_value =  date(_('Y-m-d H:i'), $old_value);
 		}
-		
+
 		//$date = date(_('Y-m-d H:i'), $date);
-		
+
 		$result[] = array(
 					"field_name"	=> $field_name,
 					"old_value"		=> $old_value,
@@ -1140,7 +1135,6 @@ function artifact_history_to_soap($db_result, &$artifactType) {
 					"user_name"		=> $user_name
 					);
 	}
-	
+
 	return $result;
 }
-?>
