@@ -1,7 +1,8 @@
 <?php
-/*
+/**
  * Copyright (C) 2008-2009 Alcatel-Lucent
  * Copyright (C) 2010 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2012, Franck Villaume - TrivialDev
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -19,7 +20,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-/*
+/**
  * Standard Alcatel-Lucent disclaimer for contributing to open source
  *
  * "The Full List ("Contribution") has not been tested and/or
@@ -41,8 +42,7 @@
  * ALONE BASIS."
  */
 
-
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'include/trove.php';
 
@@ -50,65 +50,37 @@ if (!forge_get_config('use_project_full_list')) {
 	exit_disabled();
 }
 
-$HTML->header(array('title'=>_('Software Map'),'pagename'=>'softwaremap'));
+$HTML->header(array('title'=>_('Project List'),'pagename'=>'softwaremap'));
 $HTML->printSoftwareMapLinks();
 
-$res_grp = db_query_params ('
-	SELECT group_id, group_name, unix_group_name, short_description, register_time
-	FROM groups
-	WHERE status = $1 AND type_id=1 AND group_id>4 AND register_time > 0 
-	ORDER BY group_name ASC
-',
-			    array ('A'),
-			    $TROVE_HARDQUERYLIMIT);
-$projects = array();
-while ($row_grp = db_fetch_array($res_grp)) {
-	if (!forge_check_perm ('project_read', $row_grp['group_id'])) {
-		continue ;
-	}
-	$projects[] = $row_grp;
-}
+$projects = get_public_active_projects_asc($TROVE_HARDQUERYLIMIT);
+
 $querytotalcount = count($projects);
-	
+
 // #################################################################
 // limit/offset display
 
 $page = getIntFromRequest('page',1);
 
 // store this as a var so it can be printed later as well
-$html_limit = '<span style="text-align:center;font-size:smaller">';
-if ($querytotalcount == $TROVE_HARDQUERYLIMIT){
-	$html_limit .= sprintf(_('More than <strong>%1$s</strong> projects in result set.'), $querytotalcount);
+$html_limit = '';
+if ($querytotalcount == $TROVE_HARDQUERYLIMIT) {
+	$html_limit .= sprintf(_('More than <strong>%d</strong> projects in result set.'), $querytotalcount);
 }
-$html_limit .= sprintf(_('<strong>%1$s</strong> projects in result set.'), $querytotalcount);
+$html_limit .= sprintf(_('<strong>%d</strong> projects in result set.'), $querytotalcount);
+
+$html_limit .= ' ';
 
 // only display pages stuff if there is more to display
 if ($querytotalcount > $TROVE_BROWSELIMIT) {
-	$html_limit .= sprintf(_(' Displaying %1$s per page. Projects sorted by alphabetical order.'), $TROVE_BROWSELIMIT).'<br/>';
-
-	// display all the numbers
-	for ($i=1;$i<=ceil($querytotalcount/$TROVE_BROWSELIMIT);$i++) {
-		$html_limit .= ' ';
-		if ($page != $i) {
-			$html_limit .= '<a href="'.$_SERVER['PHP_SELF'];
-			$html_limit .= '?page='.$i;
-			$html_limit .= '">';
-		} else $html_limit .= '<strong>';
-		$html_limit .= '&lt;'.$i.'&gt;';
-		if ($page != $i) {
-			$html_limit .= '</a>';
-		} else $html_limit .= '</strong>';
-		$html_limit .= ' ';
-	}
+	$html_limit .= html_trove_limit_navigation_box($_SERVER['PHP_SELF'], $querytotalcount, $TROVE_BROWSELIMIT, $page);
 }
 
-$html_limit .= '</span>';
-
 print $html_limit."<hr />\n";
 
 // #################################################################
 // print actual project listings
-for ($i_proj=0;$i_proj<$querytotalcount;$i_proj++) { 
+for ($i_proj=0;$i_proj<$querytotalcount;$i_proj++) {
 	$row_grp = $projects[$i_proj];
 
 	// check to see if row is in page range
@@ -116,17 +88,17 @@ for ($i_proj=0;$i_proj<$querytotalcount;$i_proj++) {
 		$viewthisrow = 1;
 	} else {
 		$viewthisrow = 0;
-	}	
+	}
 
 	if ($viewthisrow) {
-		
-		// Embed RDFa description for /projects/PROJ_NAME 
+
+		// Embed RDFa description for /projects/PROJ_NAME
 		$proj_uri = util_make_url_g(strtolower($row_grp['unix_group_name']),$row_grp['group_id']);
 		print '<div typeof="doap:Project sioc:Space" about="'.$proj_uri.'">'."\n";
 		print '<span rel="planetforge:hosted_by" resource="'. util_make_url ('/') .'"></span>'."\n";
-		
-		print '<table border="0" cellpadding="0" width="100%">';
-		print '<tr valign="top"><td colspan="2">';
+
+		print '<table class="fullwidth">';
+		print '<tr class="top"><td colspan="2">';
 		print util_make_link_g(strtolower($row_grp['unix_group_name']),$row_grp['group_id'],'<strong>'
 			.'<span property="doap:name">'
 			.$row_grp['group_name']
@@ -135,22 +107,24 @@ for ($i_proj=0;$i_proj<$querytotalcount;$i_proj++) {
 
 		if ($row_grp['short_description']) {
 			print "- "
-			. '<span property="doap:short_desc">' 
+			. '<span property="doap:short_desc">'
 			. $row_grp['short_description']
 			. '</span>';
 		}
 
 		// extra description
-		print '</td></tr><tr valign="top"><td>';
+		print '</td></tr><tr class="top"><td>';
 		// list all trove categories
-		print trove_getcatlisting($row_grp['group_id'],0,1,1);
+		if (forge_get_config('use_trove')) {
+			print trove_getcatlisting($row_grp['group_id'],0,1,1);
+		}
 		print '</td>';
-		print '<td valign="bottom" style="text-align:right;"><br />'._('Register Date:').' <strong>'.date(_('Y-m-d H:i'),$row_grp['register_time']).'</strong></td>';
+		print '<td class="bottom align-right"><br />'._('Register Date:').' <strong>'.date(_('Y-m-d H:i'),$row_grp['register_time']).'</strong></td>';
 		print '</tr>';
-        print '</table>';
+		print '</table>';
         print '</div>'; // /doap:Project
 		print '<hr />';
-	} // end if for row and range chacking   
+	} // end if for row and range chacking
 }
 
 // print bottom navigation if there are more projects to display
@@ -159,5 +133,3 @@ if ($querytotalcount > $TROVE_BROWSELIMIT) {
 }
 
 $HTML->footer(array());
-
-?>
