@@ -40,7 +40,7 @@
  * ALONE BASIS."
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'include/trove.php';
 require_once $gfcommon.'include/tag_cloud.php';
@@ -49,13 +49,13 @@ if (!forge_get_config('use_project_tags')) {
 	exit_disabled();
 }
 
-$HTML->header(array('title'=>_('Software Map'),'pagename'=>'softwaremap'));
+$HTML->header(array('title'=>_('Tag Cloud'),'pagename'=>'softwaremap'));
 $HTML->printSoftwareMapLinks();
 
 $selected_tag = getStringFromRequest('tag');
 $page = getIntFromRequest('page', 1);
 
-echo '<br />' . tag_cloud(array('selected' => $selected_tag, 'nb_max' => 100)) . '<br /><br />';
+echo '<br />' . tag_cloud(array('selected' => $selected_tag, 'nb_max' => 100)) . '<br />';
 
 if ($selected_tag) {
 	$res_grp = db_query_params('
@@ -64,13 +64,13 @@ if ($selected_tag) {
 		WHERE name = $1
 		AND project_tags.group_id = groups.group_id
 		AND status = $2 AND type_id=1 AND register_time > 0
-		ORDER BY group_name ASC', 
+		ORDER BY group_name ASC',
 		array($selected_tag, 'A'), $TROVE_HARDQUERYLIMIT);
 	$projects = array();
 	$project_ids = array();
 	while ($row_grp = db_fetch_array($res_grp)) {
-		if (!forge_check_perm ('project_read', $row_grp['group_id'])) {
-			continue ;
+		if (!forge_check_perm('project_read', $row_grp['group_id'])) {
+			continue;
 		}
 		$projects[] = $row_grp;
 		$project_ids[] = $row_grp['group_id'];
@@ -89,26 +89,27 @@ if ($selected_tag) {
 		$html_limit .= sprintf(ngettext('<strong>%d</strong> project in result set.',
 						'<strong>%d</strong> projects in result set.',
 						$querytotalcount),
-				       $querytotalcount) ;
+						$querytotalcount);
 	}
 
 	// only display pages stuff if there is more to display
 	if ($querytotalcount > $TROVE_BROWSELIMIT) {
-		$html_limit .= ' ' ;
-		$html_limit .= sprintf (ngettext ('Displaying %d project per page. Projects sorted by alphabetical order.<br />',
-						  'Displaying %d projects per page. Projects sorted by alphabetical order.<br />',
+		$html_limit .= ' ';
+		$html_limit .= sprintf(ngettext('Displaying %d project per page. Projects sorted by alphabetical order.',
+						  'Displaying %d projects per page. Projects sorted by alphabetical order.',
 						  $TROVE_BROWSELIMIT),
-					$TROVE_BROWSELIMIT) ;
+						$TROVE_BROWSELIMIT);
+		$html_limit .= '.<br />';
 
 		// display all the numbers
-		for ($i=1;$i<=ceil($querytotalcount/$TROVE_BROWSELIMIT);$i++) {
+		for ($i=1 ;$i <= ceil($querytotalcount/$TROVE_BROWSELIMIT); $i++) {
 			$html_limit .= ' ';
 			if ($page != $i) {
-				$html_limit .= util_make_link ('/softwaremap/tag_cloud.php?tag='.$selected_tag.'&page='.$i,
+				$html_limit .= util_make_link ('/softwaremap/tag_cloud.php?tag='.$selected_tag.'&amp;page='.$i,
 							       '&lt;'.$i.'&gt;');
 			} else {
 				$html_limit .= '<strong>&lt;'.$i.'&gt;</strong>';
-			}				
+			}
 			$html_limit .= ' ';
 		}
 	}
@@ -117,7 +118,7 @@ if ($selected_tag) {
 
 	// #################################################################
 	// print actual project listings
-	for ($i_proj=0;$i_proj<$querytotalcount;$i_proj++) {
+	for ($i_proj = 0; $i_proj < $querytotalcount; $i_proj++) {
 		$row_grp = $projects[$i_proj];
 
 		// check to see if row is in page range
@@ -128,8 +129,8 @@ if ($selected_tag) {
 		}
 
 		if ($row_grp && $viewthisrow) {
-			print '<table border="0" cellpadding="0" width="100%">';
-			print '<tr valign="top"><td colspan="2">';
+			print '<table class="fullwidth">';
+			print '<tr class="top"><td colspan="2">';
 			print util_make_link ('/projects/'. strtolower($row_grp['unix_group_name']).'/',
 					      '<strong>'.$row_grp['group_name'].'</strong> ');
 
@@ -139,13 +140,13 @@ if ($selected_tag) {
 
 			// extra description
 			print '</td></tr>';
-			print '<tr valign="top"><td colspan="2">';
-			print _('Tags'). ':&nbsp;' . list_project_tag($row_grp['group_id']);
+			print '<tr class="top"><td colspan="2">';
+			print _('Tags') . _(': ') . list_project_tag($row_grp['group_id']);
 			print '</td></tr>';
-			print '<tr valign="top"><td>';
+			print '<tr class="top"><td>';
 			// list all trove categories
 			print trove_getcatlisting($row_grp['group_id'],0,1,0);
-			print '</td>'."\n".'<td align="right">'; // now the right side of the display
+			print '</td>'."\n".'<td class="align-right">'; // now the right side of the display
 			$res = db_query_params('SELECT percentile, ranking
 					FROM project_weekly_metric
 					WHERE group_id=$1', array($row_grp['group_id']));
@@ -160,12 +161,12 @@ if ($selected_tag) {
 			}
 			printf ('<br />'._('Activity Percentile: <strong>%3.0f</strong>'), $percentile);
 			printf ('<br />'._('Activity Ranking: <strong>%d</strong>'), $ranking);
-			printf ('<br />'._('Registered: <strong>%s</strong>'), 
-				date(_('Y-m-d H:i'),$row_grp['register_time']));
+			printf ('<br />'._('Registered') . _(': '));
+            printf ('<strong>%s</strong>', date(_('Y-m-d H:i'),$row_grp['register_time']));
 			print '</td></tr>';
 			/*
 			 if ($row_grp['jobs_count']) {
-			 print '<tr><td colspan="2" align="center">'
+			 print '<tr><td colspan="2" class="align-center">'
 			 .util_make_link ('/people/?group_id='.$row_grp['group_id'],_("[This project needs help]")).'</td></td>';
 			 }
 			*/
@@ -181,4 +182,3 @@ if ($selected_tag) {
 }
 
 $HTML->footer(array());
-?>
