@@ -23,13 +23,13 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'stats/site_stats_utils.php';
 
 session_require_global_perm ('forge_stats', 'read') ;
 
-$HTML->header(array('title'=>sprintf(_('%1$s Sitewide Aggregate Statistics'), forge_get_config ('forge_name'))));
+$HTML->header(array('title'=>sprintf(_('%s Sitewide Aggregate Statistics'), forge_get_config ('forge_name'))));
 
 //
 // BEGIN PAGE CONTENT CODE
@@ -39,8 +39,8 @@ $HTML->header(array('title'=>sprintf(_('%1$s Sitewide Aggregate Statistics'), fo
 
 <hr />
 
-<table width="100%" cellpadding="0" cellspacing="0" border="0">
-<tr align="center">
+<table class="fullwidth">
+<tr class="align-center">
 <td><strong><?php echo _('OVERVIEW STATS'); ?></strong></td>
 <td><a href="projects.php"><?php echo _('PROJECT STATS'); ?></a></td>
 <td><a href="graphs.php"><?php echo _('SITE GRAPHS'); ?></a></td>
@@ -65,4 +65,3 @@ echo '<ul><li><a href="i18n.php">'.("I18n Statistics").'</a></li></ul>';
 //
 
 $HTML->footer( array() );
-?>
