@@ -4,6 +4,7 @@
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  * Copyright 2010 (c) FusionForge Team
+ * Copyright 2013, Franck Villaume - TrivialDev
  * http://fusionforge.org
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -38,26 +39,6 @@ $allowed_orderby_vals = array('downloads',
 			      'cvs_commits',
 			      'cvs_adds');
 
-// week_to_dates
-function week_to_dates( $week, $year = 0 ) {
-
-	if ( $year == 0 ) {
-		$year = gmstrftime("%Y", time() );
-	}
-
-	   // One second into the New Year!
-	$beginning = gmmktime(0,0,0,1,1,$year);
-	while ( gmstrftime("%U", $beginning) < 1 ) {
-		   // 86,400 seconds? That's almost exactly one day!
-		$beginning += 86400;
-	}
-	$beginning += (86400 * 7 * ($week - 1));
-	$end = $beginning + (86400 * 6);
-
-	return array( $beginning, $end );
-}
-
-
 function stats_util_sum_array( $sum, $add ) {
 	if (!is_array($sum)) {
 		$sum = array();
@@ -82,7 +63,7 @@ function stats_generate_trove_pulldown( $selected_id = 0 ) {
 		FROM trove_cat
 		ORDER BY fullpath',
 			array());
-	
+
 	print '
 		<select name="trovecatid">';
 
@@ -101,7 +82,6 @@ function stats_generate_trove_pulldown( $selected_id = 0 ) {
 		</select>';
 }
 
-
 function stats_trove_cat_to_name( $trovecatid ) {
 
 	$res = db_query_params ('
@@ -112,14 +92,13 @@ function stats_trove_cat_to_name( $trovecatid ) {
 
 	if ( $row = db_fetch_array($res) ) {
 		return $row["fullpath"];
-	} else { 
+	} else {
 		return sprintf(_(" (no category found with ID %d)"), $trovecatid) ;
 	}
 }
 
-
 function stats_generate_trove_grouplist( $trovecatid ) {
-	
+
 	$results = array();
 
 	$res = db_query_params ('
@@ -138,12 +117,11 @@ function stats_generate_trove_grouplist( $trovecatid ) {
 	return $results;
 }
 
-
 function stats_site_projects_form( $report='last_30', $orderby = 'downloads', $projects = 0, $trovecat = 0 ) {
 	global $allowed_orderby_vals ;
 
 	print '<form action="projects.php" method="get">' . "\n";
-	print '<table width="100%" cellpadding="0" cellspacing="0" class="tableheading">' . "\n";
+	print '<table class="tableheading fullwidth">' . "\n";
 
 	print '<tr><td><strong>'._('Projects in trove category:').'</strong></td><td>';
 	stats_generate_trove_pulldown( $trovecat );
@@ -161,7 +139,7 @@ function stats_site_projects_form( $report='last_30', $orderby = 'downloads', $p
 
 	$reports_names=array();
 	$reports_names[]=_('last_30');
-	$reports_names[]=_('all');
+	$reports_names[]=_('All');
 
 	echo html_build_select_box_from_arrays($reports_ids, $reports_names, 'report', $report, false);
 
@@ -172,7 +150,7 @@ function stats_site_projects_form( $report='last_30', $orderby = 'downloads', $p
 	print html_build_select_box_from_arrays ( $allowed_orderby_vals, $allowed_orderby_vals, "orderby", $orderby, false );
 	print '</td></tr>';
 
-	print '<tr><td colspan="2" style="text-align:center"> <input type="submit" value="'._('Generate Report').'" /> </td></tr>';
+	print '<tr><td colspan="2" class="align-center"> <input type="submit" value="'._('Generate Report').'" /> </td></tr>';
 
 	print '</table>' . "\n";
 	print '</form>' . "\n";
@@ -210,6 +188,8 @@ SELECT g.group_id, g.group_name,
        SUM(s.patches_closed) AS patches_closed,
        SUM(s.tasks_opened) AS tasks_opened,
        SUM(s.tasks_closed) AS tasks_closed,
+       SUM(s.artifacts_opened) AS artifacts_opened,
+       SUM(s.artifacts_closed) AS artifacts_closed,
        SUM(s.cvs_checkouts) AS cvs_checkouts,
        SUM(s.cvs_commits) AS cvs_commits,
        SUM(s.cvs_adds) AS cvs_adds
@@ -223,7 +203,7 @@ ORDER BY ' . $order_clause,
 SELECT g.group_id, g.group_name, s.downloads, s.site_views,
        s.subdomain_views, s.msg_posted, s.bugs_opened, s.bugs_closed,
        s.support_opened, s.support_closed, s.patches_opened,
-       s.patches_closed, s.tasks_opened, s.tasks_closed,
+       s.patches_closed, s.artifacts_opened, artifacts_closed, s.tasks_opened, s.tasks_closed,
        s.cvs_checkouts, s.cvs_commits, s.cvs_adds
 FROM stats_project_all_vw s, groups g
 WHERE s.group_id = g.group_id
@@ -233,7 +213,7 @@ ORDER BY ' . $order_clause,
 }
 
 function stats_site_projects( $report, $orderby, $projects, $trove ) {
-	$i=0;
+
 	$offset=0;
 	$trove_cat=0;
 	$res=stats_site_project_result( $report, $orderby, $projects, $trove );
@@ -241,9 +221,9 @@ function stats_site_projects( $report, $orderby, $projects, $trove ) {
 	if ( db_numrows( $res ) > 1 ) {
 
 		?>
-		<table width="100%" cellpadding="0" cellspacing="0" border="0">
+		<table class="fullwidth">
 
-		<tr valign="top" align="right" class="tableheading">
+		<tr class="align-right top tableheading">
 			<td><strong><?php echo _('Project Name'); ?></strong></td>
 			<td colspan="2"><strong><?php echo _('Page Views'); ?></strong></td>
 			<?php if (forge_get_config('use_frs')) { ?>
@@ -271,13 +251,13 @@ function stats_site_projects( $report, $orderby, $projects, $trove ) {
 		if ( $trove_cat > 0 ) {
 			$uri_string .= "&amp;trovecatid=" . $trove_cat;
 		}
-		if ( $trove_cat == -1 ) { 
+		if ( $trove_cat == -1 ) {
 			$uri_string .= "&amp;projects=" . urlencode( implode( " ", $projects) );
 		}
 		$uri_string .= "&amp;orderby=";
 
 		?>
-		<tr valign="top" align="right" class="tableheading">
+		<tr class="align-right top tableheading">
 			<td>&nbsp;</td>
 			<td><a href="<?php echo $uri_string; ?>site_views"><?php echo _('Site'); ?></a></td>
 			<td><a href="<?php echo $uri_string; ?>subdomain_views"><?php echo _('Subdomain'); ?></a></td>
@@ -306,10 +286,10 @@ function stats_site_projects( $report, $orderby, $projects, $trove ) {
 			<?php plugin_hook('stats_detail_header_table'); ?>
 			</tr>
 		<?php
-	
-		$i = $offset;	
+
+		$i = $offset;
 		while ( $row = db_fetch_array($res) ) {
-			print	'<tr ' . $GLOBALS['HTML']->boxGetAltRowStyle($i) . ' align="right">'
+			print	'<tr ' . $GLOBALS['HTML']->boxGetAltRowStyle($i) . ' style="text-align:right">'
 				. '<td>' . ($i + 1)." " . util_make_link ('/project/stats/?group_id='.$row["group_id"], $row["group_name"]) . '</td>'
 				. '<td>&nbsp;&nbsp;' . number_format( $row["site_views"],0 ) . '</td>'
 				. '<td>&nbsp;&nbsp;' . number_format( $row["subdomain_views"],0 ) . '</td>';
@@ -340,11 +320,10 @@ function stats_site_projects( $report, $orderby, $projects, $trove ) {
 			plugin_hook('stats_data',$hook_params);
 			print '</tr>' . "\n";
 			$i++;
-			$sum = stats_util_sum_array( $sum, $row );
 		}
 
 		?>
-		</table></p>
+		</table>
 		<?php
 
 	} else {
@@ -368,13 +347,13 @@ function stats_site_projects_daily( $span ) {
 				$span);
 	echo db_error();
 
-	   // if there are any weeks, we have valid data.
-	if ( ($valid_days = db_numrows( $res )) > 1 ) {
+	// if there are any weeks, we have valid data.
+	if ( ($valid_days = db_numrows( $res )) >= 1 ) {
 
 		?>
-		<h2><?php printf(_('Statistics for the past %1$s days'), $valid_days); ?></h2>
-		<table width="100%" cellpadding="0" cellspacing="0" border="0">
-			<tr valign="top" align="right">
+		<h2><?php printf(_('Statistics for the past %d days'), $valid_days); ?></h2>
+		<table class="fullwidth">
+			<tr class="top align-right">
 			<td><strong><?php echo _('Day'); ?></strong></td>
 			<td><strong><?php echo _('Site Views'); ?></strong></td>
 			<td><strong><?php echo _('Subdomain Views'); ?></strong></td>
@@ -386,11 +365,11 @@ function stats_site_projects_daily( $span ) {
 			<td><strong><?php echo _('SCM'); ?></strong></td>
 			</tr>
 		<?php
-	
+
 		while ( $row = db_fetch_array($res) ) {
 			 $i++;
 
-			print	'<tr ' . $GLOBALS['HTML']->boxGetAltRowStyle($i) . ' align="right">'
+			print	'<tr ' . $GLOBALS['HTML']->boxGetAltRowStyle($i) . ' style="text-align:right">'
 				. '<td>' . gmstrftime("%d %b %Y", mktime(0,0,1,substr($row["month"],4,2),$row["day"],substr($row["month"],0,4)) ) . '</td>'
 				. '<td>' . number_format( $row["site_page_views"],0 ) . '</td>'
 				. '<td>' . number_format( $row["subdomain_views"],0 ) . '</td>'
@@ -422,14 +401,14 @@ function stats_site_projects_monthly() {
 	echo db_error();
 
 	// if there are any weeks, we have valid data.
-	if ( ($valid_months = db_numrows( $res )) > 1 ) {
+	if (($valid_months = db_numrows($res)) >= 1 ) {
 
 		?>
 
-		<h2><?php printf(_('Statistics for the past %1$s months'), $valid_months); ?></h2>
-		<table width="100%" cellpadding="0" cellspacing="0" border="0">
-			<tr valign="top" align="right">
-			<td><strong><?php echo _('Month'); ?>Month</strong></td>
+		<h2><?php printf(_('Statistics for the past %d months'), $valid_months); ?></h2>
+		<table class="fullwidth">
+			<tr class="top align-right">
+			<td><strong><?php echo _('Month'); ?></strong></td>
 			<td><strong><?php echo _('Site Views'); ?></strong></td>
 			<td><strong><?php echo _('Subdomain Views'); ?></strong></td>
 			<td><strong><?php echo _('Downloads'); ?></strong></td>
@@ -445,7 +424,7 @@ function stats_site_projects_monthly() {
 		while ( $row = db_fetch_array($res) ) {
 			$i++;
 
-			print	'<tr ' . $GLOBALS['HTML']->boxGetAltRowStyle($i) . ' align="right">'
+			print	'<tr ' . $GLOBALS['HTML']->boxGetAltRowStyle($i) . 'style="text-align:right">'
 				. '<td>' . $row['month'] . '</td>'
 				. '<td>' . number_format( $row["site_page_views"],0 ) . '</td>'
 				. '<td>' . number_format( $row["subdomain_views"],0 ) . '</td>'
@@ -473,22 +452,19 @@ function stats_site_aggregate( ) {
 			array ());
 	$site_totals = db_fetch_array($res);
 
-
 	$res = db_query_params ('SELECT COUNT(*) AS count FROM groups WHERE status=$1',
 			array ('A'));
 	$groups = db_fetch_array($res);
 
-
 	$res = db_query_params ('SELECT COUNT(*) AS count FROM users WHERE status=$1',
 			array ('A'));
 	$users = db_fetch_array($res);
-	
 
 	?>
 	<h2><?php echo _('Current Aggregate Statistics for All Time'); ?></h2>
 
-	<table width="100%" cellpadding="0" cellspacing="0" border="0">
-	<tr valign="top">
+	<table class="fullwidth">
+	<tr class="top">
 		<td><strong><?php echo _('Site Views'); ?></strong></td>
 		<td><strong><?php echo _('Subdomain Views'); ?></strong></td>
 		<td><strong><?php echo _('Downloads'); ?></strong></td>
@@ -508,9 +484,189 @@ function stats_site_aggregate( ) {
 	<?php
 }
 
+function views_graph($monthly = 0) {
+	global $gfcommon;
+	require_once $gfcommon.'reporting/Report.class.php';
+	$report = new Report();
+	if ($monthly) {
+		$res = db_query_params('SELECT month,site_page_views AS site_views,subdomain_views
+					FROM stats_site_months ORDER BY month ASC',
+					array());
+	} else {
+		$beg_year = date('Y',mktime(0,0,0,(date('m')-1),date('d'),date('Y')));
+		$beg_month = date('m',mktime(0,0,0,(date('m')-1),date('d'),date('Y')));
+		$beg_day = date('d',mktime(0,0,0,(date('m')-1),date('d'),date('Y')));
+		$res = db_query_params ('SELECT month,day,site_page_views AS site_views,subdomain_views
+			FROM stats_site_vw
+			( month = $1 AND day >= $2 ) OR ( month > $3 )
+			ORDER BY month ASC, day ASC',
+			array ("$beg_year$beg_month",
+				$beg_day,
+				"$beg_year$beg_month"));
+	}
+
+	$i = 0;
+	$xlabel = array();
+	$ydata = array();
+	while ( $row = db_fetch_array($res) ) {
+		$xlabel[$i] = $row['month'] . ((isset($row['day'])) ? "/" . $row['day'] : '');
+		$ydata[$i] = $row['site_views'] + $row['subdomain_views'];
+		++$i;
+	}
+
+	$monthStartArr = $report->getMonthStartArr();
+	$monthStartArrFormat = $report->getMonthStartArrFormat();
+	if (count($ydata)) {
+		$chartid = '_views_graph';
+		echo '<script type="text/javascript">//<![CDATA['."\n";
+		echo 'var '.$chartid.'values = new Array();';
+		echo 'var plot'.$chartid.';';
+		for ($j = 0; $j < count($monthStartArrFormat); $j++) {
+			$key = array_search($monthStartArrFormat[$j], $xlabel);
+			if ($key !== FALSE) {
+				echo 'var '.$chartid.'datevalues = '.$ydata[$key].';';
+			} else {
+				echo 'var '.$chartid.'datevalues = 0;';
+			}
+			echo 'var '.$chartid.'date = '.$monthStartArrFormat[$j].';';
+			echo $chartid.'values.push(['.$chartid.'date, '.$chartid.'datevalues]);';
+		}
+		echo 'jQuery(document).ready(function(){
+				plot'.$chartid.' = jQuery.jqplot (\'chart'.$chartid.'\', ['.$chartid.'values], {
+					axesDefaults: {
+						tickRenderer: jQuery.jqplot.CanvasAxisTickRenderer,
+						tickOptions: {
+							angle: 30,
+							showGridline: false,
+						},
+						pad: 0,
+					},
+					axes: {
+						xaxis: {
+							renderer: jQuery.jqplot.CategoryAxisRenderer,
+							label: \''.('Pages view per month').'\',
+						},
+						yaxis: {
+							min: 0,
+							tickOptions: {
+								angle: 0,
+							}
+						}
+					},
+					highlighter: {
+						show: true,
+						sizeAdjust: 2.5,
+						showTooltip: true,
+						tooltipAxes: \'y\',
+					},
+				});
+			});';
+		echo 'jQuery(window).resize(function() {
+			plot'.$chartid.'.replot();
+			});'."\n";
+		echo '//]]></script>';
+		echo '<div id="chart'.$chartid.'"></div>';
+	} else {
+		echo '<p class="information">'._('Page view: no graph to display.').'</p>';
+	}
+}
+
+function users_graph() {
+	global $gfcommon;
+	require_once $gfcommon.'reporting/Report.class.php';
+	$report = new Report();
+	$res = db_query_params ('SELECT month,day,new_users,new_projects FROM stats_site ORDER BY month ASC, day ASC',
+			array ());
+
+	$i = 0;
+	$yMax = 0;
+	$xlabel = array();
+	$ydata = array();
+	$ydata[0] = array();
+	$ydata[1] = array();
+	$label[0] = _('New users');
+	$label[1] = _('New projects');
+	$monthStartArr = $report->getMonthStartArr();
+	$monthStartArrFormat = $report->getMonthStartArrFormat();
+	while ( $row = db_fetch_array($res) ) {
+		$xlabel[$i] = $row['month'] . ((isset($row['day'])) ? "/" . $row['day'] : '');
+		$ydata[0][$i] = $row['new_users'];
+		$ydata[1][$i] = $row['new_projects'];
+		++$i;
+	}
+	if (count($ydata[0])) {
+		$chartid = '_newprojectuser';
+		echo '<script type="text/javascript">//<![CDATA['."\n";
+		echo 'var '.$chartid.'values = new Array();';
+		echo 'var '.$chartid.'labels = new Array();';
+		echo 'var '.$chartid.'series = new Array();';
+		echo 'var plot'.$chartid.';';
+		for ($z = 0; $z < count($ydata); $z++) {
+			echo $chartid.'values['.$z.'] = new Array();';
+			echo $chartid.'labels.push({label:\''.$label[$z].'\'});';
+			for ($j = 0; $j < count($monthStartArrFormat); $j++) {
+				$key = array_search($monthStartArrFormat[$j], $xlabel);
+				if ($key !== FALSE) {
+					echo 'var '.$chartid.'datevalues = '.$ydata[$z][$key].';';
+					if ($ydata[$z][$thekey] > $yMax) {
+						$yMax = $ydata[$z][$thekey];
+					}
+				} else {
+					echo 'var '.$chartid.'datevalues = 0;';
+				}
+				echo 'var '.$chartid.'date = '.$monthStartArrFormat[$j].';';
+				echo $chartid.'values['.$z.'].push(['.$chartid.'date, '.$chartid.'datevalues]);';
+			}
+		}
+		for ($z = 0; $z < count($ydata); $z++) {
+			echo $chartid.'series.push('.$chartid.'values['.$z.']);';
+		}
+		echo 'jQuery(document).ready(function(){
+				plot'.$chartid.' = jQuery.jqplot (\'chart'.$chartid.'\', '.$chartid.'series, {
+					axesDefaults: {
+						tickRenderer: jQuery.jqplot.CanvasAxisTickRenderer,
+						tickOptions: {
+							angle: 30,
+							showGridline: false,
+						},
+						pad: 0,
+					},
+					legend: {
+						show:true, location: \'ne\',
+					},
+					series:
+						'.$chartid.'labels
+					,
+					axes: {
+						xaxis: {
+							renderer: jQuery.jqplot.CategoryAxisRenderer,
+							label: \''.('New Users and new projects per month').'\',
+						},
+						yaxis: {
+							max: '.++$yMax.',
+							min: 0,
+							tickOptions: {
+								angle: 0,
+							}
+						}
+					},
+					highlighter: {
+						show: true,
+						sizeAdjust: 2.5,
+					},
+				});
+			});';
+		echo 'jQuery(window).resize(function() {
+			plot'.$chartid.'.replot();
+			});'."\n";
+		echo '//]]></script>';
+		echo '<div id="chart'.$chartid.'"></div>';
+	} else {
+		echo '<p class="information">'._('New users, new projects: no graph to display.').'</p>';
+	}
+}
+
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
