@@ -24,7 +24,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfwww.'survey/include/SurveyHTML.class.php';
 
@@ -32,23 +32,23 @@ $is_admin_page='y';
 $group_id = getIntFromRequest('group_id');
 $survey_id = getIntFromRequest('survey_id');
 $sh = new  SurveyHtml();
-$sh->header(array('title'=>_('Survey Administration')));
+$sh->header(array('title'=>_('Surveys Administration')));
 
 if (!$group_id) {
-    exit_no_group();
+	exit_no_group();
 }
-$group=group_get_object($group_id);
+$group = group_get_object($group_id);
 if (!$group || !is_object($group)) {
-    exit_no_group();
+	exit_no_group();
 } elseif ($group->isError()) {
-    exit_error($group->getErrorMessage(),'surveys');
+	exit_error($group->getErrorMessage(),'surveys');
 }
 
 if (!session_loggedin()) {
 	exit_not_logged_in();
 }
 
-if ( !user_ismember($group_id,'A')) {
+if ( !forge_check_perm('project_admin', $group_id)) {
 	exit_permission_denied(_('You are not a Project admin'),'surveys');
 }
 
@@ -65,7 +65,7 @@ if ( !user_ismember($group_id,'A')) {
     <?php print(_('Create a survey, listing the questions in order (choose from <strong>your</strong> list of questions).')); ?>
     </li>
     <li>
-    <?php printf(_('Link to the survey using this format: %1$s where XX is the survey number'),
+    <?php printf(_('Link to the survey using this format: %s where XX is the survey number'),
                  '<br /><strong>'.util_make_url('/survey/survey.php?group_id='.$group_id.'&amp;survey_id=XX').'</strong>'); ?>
     </li>
 </ol>
@@ -84,5 +84,3 @@ $sh->footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
