@@ -22,8 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 
 $is_admin_page='y';
@@ -32,15 +31,15 @@ $survey_id = getIntFromRequest('survey_id');
 $customer_id = getIntFromRequest('customer_id');
 survey_header(array('title'=>_('Results')));
 
-if (!session_loggedin() || !user_ismember($group_id,'A')) {
-        echo '<div class="error">'._('Permission denied').'</div>';
+if (!session_loggedin() || !forge_check_perm('project_admin', $group_id)) {
+        echo '<div class="error">'._('Permission denied.').'</div>';
         survey_footer(array());
 	exit;
 }
 
 ?>
 
-<form action="none">
+<form action="">
 <?php
 
 /*
@@ -94,11 +93,11 @@ for ($i=0; $i<$count; $i++) {
 			Don't show question number if it's just a comment
 		*/
 
-		echo "\n<tr><td valign=\"top\">&nbsp;</td>\n<td>"; 
+		echo "\n<tr><td class=\"top\">&nbsp;</td>\n<td>";
 
 	} else {
 
-		echo "\n<tr><td valign=\"top\"><strong>";
+		echo "\n<tr><td class=\"top\"><strong>";
 
 		/*
 			If it's a 1-5 question box and first in series, move Quest
@@ -113,11 +112,11 @@ for ($i=0; $i<$count; $i++) {
 		$q_num++;
 
 	}
-	
+
 	if ($question_type == "1") {
 
 		/*
-			This is a radio-button question. Values 1-5.	
+			This is a radio-button question. Values 1-5.
 		*/
 
 
@@ -140,7 +139,7 @@ for ($i=0; $i<$count; $i++) {
 
 		echo "&nbsp; ".db_result($result, 0, "question")."\n";
 
-	} else if ($question_type == "2") {
+	} elseif ($question_type == "2") {
 
 		/*
 			This is a text-area question.
@@ -156,9 +155,9 @@ for ($i=0; $i<$count; $i++) {
 		if ($not_found==0) {
 			echo db_result($result, 0, "response");
 		}
-		echo "</textarea>\n";	
+		echo "</textarea>\n";
 
-	} else if ($question_type == "3") {
+	} elseif ($question_type == "3") {
 
                 /*
                         This is a Yes/No question.
@@ -188,10 +187,10 @@ for ($i=0; $i<$count; $i++) {
                 if (($not_found==0) && db_result($result, 0, "response")=="5") { echo " checked=\"checked\""; }
 
                 echo " />";
- 
+
 		echo "&nbsp; ".db_result($result, 0, "question")."\n";
 
-        } else if ($question_type == "4") {
+        } elseif ($question_type == "4") {
 
 		/*
 			This is a comment only.
@@ -200,7 +199,7 @@ for ($i=0; $i<$count; $i++) {
 		echo "\n&nbsp;<p><strong>".db_result($result, 0, "question")."</strong></p>\n";
 		echo "\n<input type=\"hidden\" name=\"_".$quest_array[$i]."\" value=\"-666\" />";
 
-        } else if ($question_type == "5") {
+        } elseif ($question_type == "5") {
 
                 /*
                         This is a text-field question.
@@ -238,5 +237,3 @@ survey_footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
