@@ -23,7 +23,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../../env.inc.php');
+require_once '../../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'survey/Survey.class.php';
 require_once $gfcommon.'survey/SurveyFactory.class.php';
@@ -34,7 +34,7 @@ require_once $gfwww.'survey/include/SurveyHTML.class.php';
 $group_id = getIntFromRequest('group_id');
 $survey_id = getIntFromRequest('survey_id');
 
-/* We need a group_id */ 
+/* We need a group_id */
 if (!$group_id) {
     exit_no_group();
 }
@@ -48,48 +48,47 @@ $is_admin_page='y';
 $sh = new  SurveyHtml();
 $s = new Survey($g, $survey_id);
 
-if (!session_loggedin() || !user_ismember($group_id,'A')) {
+if (!session_loggedin() || !forge_check_perm('project_admin', $group_id)) {
 	$sh->header(array());
-	echo '<div class="error">' . _('Permission denied') . '</div>';
+	echo '<div class="error">' . _('Permission denied.') . '</div>';
 	$sh->footer(array());
 	exit;
 }
 
 if (getStringFromRequest('post')=="Y") {
-    if (!form_key_is_valid(getStringFromRequest('form_key'))) {
+	if (!form_key_is_valid(getStringFromRequest('form_key'))) {
 		exit_form_double_submit('surveys');
 	}
 	$survey_title = getStringFromRequest('survey_title');
-    $to_add = getStringFromRequest('to_add');
-    $to_del = getStringFromRequest('to_del');
-    $is_active = getStringFromRequest('is_active');
+	$to_add = getStringFromRequest('to_add');
+	$to_del = getStringFromRequest('to_del');
+	$is_active = getStringFromRequest('is_active');
 
-    if ($survey_id) { /* Modify */
+	if ($survey_id) { /* Modify */
 		$s->update($survey_title, $to_add, $to_del, $is_active);
 		$feedback = _('Update Successful');
-    }  else {  /* Add */
+	}  else {  /* Add */
 		$s->create($survey_title, $to_add, $is_active);
 		$feedback = _('Survey Added');
-    }
+	}
 }
 
 /* Order changes */
 if (getStringFromRequest('updown')=="Y") {
-    $question_id = getIntFromRequest('question_id');
-    $is_up = getStringFromRequest('is_up');
-
-    $s->updateOrder($question_id, $is_up);
-    $feedback = _('Update Successful');
+	$question_id = getIntFromRequest('question_id');
+	$is_up = getStringFromRequest('is_up');
+	$s->updateOrder($question_id, $is_up);
+	$feedback = _('Update Successful');
 }
 
 /* Error on previous transactions? */
 if ($s->isError()) {
-    $error_msg = $s->getErrorMessage();
-    form_release_key(getStringFromRequest("form_key"));
-} 
+	$error_msg = $s->getErrorMessage();
+	form_release_key(getStringFromRequest("form_key"));
+}
 
 $title = $survey_id ? _('Edit a Survey') : _('Add a Survey');
-$sh->header(array('title'=>$title));
+$sh->header(array('title'=>$title, 'modal'=>1));
 
 echo ($sh->ShowAddSurveyForm($s));
 
@@ -97,10 +96,9 @@ echo ($sh->ShowAddSurveyForm($s));
 $sf = new SurveyFactory($g);
 $ss = & $sf->getSurveys();
 if (!$ss) {
-    echo '<p class="warning_msg">' . _('No Survey Question is found') . '</p>';
+	echo '<p class="information">' . _('No Survey is found') . '</p>';
 } else {
-    echo($sh->showSurveys($ss, 1, 1, 1, 1, 1, 1, 0, 0, 0, 1));
+	echo($sh->showSurveys($ss, 1, 1, 1, 1, 1, 1, 0, 0, 0, 1, 1));
 }
 
 $sh->footer(array());
-?>
