@@ -22,7 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'survey/SurveyFactory.class.php';
 require_once $gfwww.'survey/include/SurveyHTML.class.php';
@@ -30,7 +30,7 @@ require_once $gfwww.'survey/include/SurveyHTML.class.php';
 $group_id = getIntFromRequest('group_id');
 $survey_id = getIntFromRequest('survey_id');
 
- /* We need a group_id */ 
+ /* We need a group_id */
 if (!$group_id) {
     exit_no_group();
 }
@@ -43,21 +43,20 @@ if (!$g || !is_object($g) || $g->isError()) {
 $user_id = user_getid();
 
 /* Show header */
-$title = sprintf(_('Surveys for %1$s'), $g->getPublicName());
+$title = sprintf(_('Surveys for %s'), $g->getPublicName());
 $sh = new SurveyHtml();
 $sh->header(array('title'=>$title));
 
 plugin_hook ("blocks", "survey index");
 
-/* Show list of Servey */
+/* Show list of Survey */
 $sf = new SurveyFactory($g);
 $ss = & $sf->getSurveys();
 if (!$ss) {
-    echo '<p class="warning_msg">' . (_('No Survey is found')) . '</p>';
+    echo '<p class="information">' . (_('No Survey is found')) . '</p>';
 } else {
 	echo '<p>' . _('Select a survey to vote') . '</p>';
     echo($sh->showSurveys($ss, 0, 0, 1, 1, 1, 0));
 }
 
 $sh->footer(array());
-?>
