@@ -22,11 +22,16 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'survey/SurveyFactory.class.php';
 require_once $gfwww.'survey/include/SurveyHTML.class.php';
 
+$group_id = getIntFromRequest('group_id');
+if (!$group_id) {
+	exit_no_group();
+}
+
 /* Show header */
 $title = _('Survey Privacy');
 $sh = new SurveyHtml();
@@ -45,11 +50,11 @@ echo '<p>';
 echo _("The information gathered is used only in aggregate form, not to single out specific users or developers.");
 echo '</p>';
 echo '<p>';
-echo _("If any changes are made to this policy, it will affect only future data that is collected and the user will of course have the ability to 'opt-out'."); 
+echo _("If any changes are made to this policy, it will affect only future data that is collected and the user will of course have the ability to 'opt-out'.");
 echo '</p>';
 
 ?>
 
-<p><strong><?php printf(_('The %1$s Team'), forge_get_config ('forge_name')); ?></strong></p>
+<p><strong><?php printf(_('-- the %s staff'), forge_get_config ('forge_name')); ?></strong></p>
 
-<?php echo $HTML->footer(array()); ?>
+<?php $sh->footer(array());
