@@ -22,7 +22,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'survey/Survey.class.php';
 require_once $gfwww.'survey/include/SurveyHTML.class.php';
@@ -30,7 +30,7 @@ require_once $gfwww.'survey/include/SurveyHTML.class.php';
 $group_id = getIntFromRequest('group_id');
 $survey_id = getIntFromRequest('survey_id');
 
-/* We need a group_id */ 
+/* We need a group_id */
 if (!$group_id) {
     exit_no_group();
 }
@@ -45,19 +45,17 @@ if (!session_loggedin()) {
 	exit_not_logged_in();
 }
 
-$sh = new  SurveyHtml();
+$sh = new SurveyHtml();
 $s = new Survey($g, $survey_id);
 
-$title = sprintf(_('Vote for Survey: %1$s'), $s->getTitle());
+$title = _('Vote for Survey') . _(': ') . $s->getTitle();
 $sh->header(array('title'=>$title));
 
 if (!$survey_id) {
-    echo '<div class="error">'._('For some reason, the Project ID or Survey ID did not make it to this page').'</div>';
+	echo '<p class="error">'._('For some reason, the Project ID or Survey ID did not make it to this page').'</p>';
 } else {
-	plugin_hook ("blocks", "survey_".$s->getTitle());
-    echo($sh->showSurveyForm($s));
+	plugin_hook("blocks", "survey_".$s->getTitle());
+	echo($sh->showSurveyForm($s));
 }
 
 $sh->footer(array());
-
-?>
