@@ -23,8 +23,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'survey/Survey.class.php';
 require_once $gfcommon.'survey/SurveyResponse.class.php';
@@ -46,7 +45,7 @@ if (!$survey_id) {
 	/*
 		Quit if params are not provided
 	*/
-	echo '<div class="error">'._('For some reason, the Project ID or Survey ID did not make it to this page').'</div>';
+	echo '<p class="error">'._('For some reason, the Project ID or Survey ID did not make it to this page').'</p>';
 	$sh->footer(array());
 	exit;
 }
@@ -58,7 +57,7 @@ if (!session_loggedin()) {
 echo '<p>' . _('Thank you for taking time to complete this survey.') . '</p>';
 echo '<p>' . _('Regards,') . '</p>';
 echo '<p><strong>';
-printf(_('The %1$s Crew'), forge_get_config ('forge_name'));
+printf(_('-- the %s staff'), forge_get_config ('forge_name'));
 echo '</strong></p>';
 
 /*
@@ -82,7 +81,7 @@ $sr = new SurveyResponse($g);
 
 for ($i=0; $i<$count; $i++) {
     /*	Insert each form value into the responses table */
-    
+
     $val="_" . $quest_array[$i];
     $response = getStringFromRequest($val);;
 
@@ -93,5 +92,3 @@ for ($i=0; $i<$count; $i++) {
 }
 
 $sh->footer(array());
-
-?>
