@@ -27,7 +27,7 @@
 
 $no_gz_buffer=true;
 
-require_once('env.inc.php');
+require_once 'env.inc.php';
 require_once $gfcommon.'include/pre.php';
 
 // get current information
@@ -38,7 +38,7 @@ if (!$group_id) {
 $group = group_get_object($group_id);
 if (!$group || !is_object($group)) {
 	exit_error(_('Error creating group'),'home');
-} else if ($group->isError()) {
+} elseif ($group->isError()) {
 	exit_error($group->getErrorMessage(),'home');
 }
 
@@ -59,7 +59,5 @@ if (file_exists(forge_get_config('scm_tarballs_path').'/'.$filename)) {
 
 	readfile_chunked(forge_get_config('scm_tarballs_path').'/'.$filename);
 } else {
-	session_redirect('/404.php');
+	session_redirect404();
 }
-
-?>
