@@ -6,6 +6,7 @@
  * Copyright 1999-2000 (c) The SourceForge Crew
  * Copyright 2002-2004 (c) GForge Team
  * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright 2013, Franck Villaume - TrivialDev
  * http://fusionforge.org/
  *
  * This file is part of FusionForge. FusionForge is free software;
@@ -24,9 +25,9 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require ('../env.inc.php');    
+require '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
-require_once $gfcommon.'include/Stats.class.php';    
+require_once $gfcommon.'include/Stats.class.php';
 
 $offset = getIntFromRequest('offset');
 $type = getStringFromRequest('type');
@@ -48,7 +49,7 @@ print '<p><em>('._('Updated Daily').')</em></p>
 
 <p>'.util_make_link ('/top/','['._('View Other Top Categories').']').'</p>';
 
-$arr=array(_('Rank'),_('Project name'),_('Percentile'));
+$arr=array(_('Rank'),_('Project Name'),_('Percentile'));
 
 echo $HTML->listTableTop($arr);
 
@@ -76,14 +77,14 @@ if ($i<$rows) {
 	if ($offset>0) {
 		print '
 	<tr class="tablegetmore">
-		<td>'.util_make_link ('/top/mostactive.php?type='.$type.'&offset='.($offset-$LIMIT),'<strong><-- '._('More').'</strong>');
+		<td>'.util_make_link ('/top/mostactive.php?type='.$type.'&offset='.($offset-$limit),'<strong><-- '._('More').'</strong>');
 	} else {
 		print '&nbsp;';
 	}
 	print '
 		</td>
 		<td>&nbsp;</td>
-		<td align="RIGHT">'.util_make_link ('/top/mostactive.php?type='.$type.'&offset='.($offset+$LIMIT),'<strong>'._('More').' --></strong>').'
+		<td align="RIGHT">'.util_make_link ('/top/mostactive.php?type='.$type.'&offset='.($offset+$limit),'<strong>'._('More').' --></strong>').'
 		</td>
 	</tr>';
 }
@@ -96,5 +97,3 @@ $HTML->footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
