@@ -24,9 +24,9 @@
  */
 
 // Results per page
-$LIMIT = 50; 
+$LIMIT = 50;
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 
 $offset = getStringFromRequest('offset');
@@ -60,8 +60,8 @@ print '<br /><em>('._('Updated Daily').')</em>
 
 $tableHeaders = array(
 	_('Rank'),
-	_('User name'),
-	_('Real name'),
+	_('User Name'),
+	_('Real Name'),
 	_('Rating'),
 	_('Last Rank'),
 	_('Change')
@@ -75,10 +75,10 @@ while ($row_top = db_fetch_array($res_top)) {
 	print '<tr '. $HTML->boxGetAltRowStyle($i) .'><td>&nbsp;&nbsp;'.$row_top['ranking']
 		.'</td><td>'.util_make_link_u ($row_top['user_name'],$row_top['user_id'],$row_top['user_name']).'</td>'
 		.'<td>'.$row_top['realname'].'</td>'
-		.'</td><td align="right">'.sprintf('%.2f', $row_top['metric'])
-		.'&nbsp;&nbsp;&nbsp;</td><td align="right">'.$row_top['old_ranking']
+		.'</td><td class="align-right">'.sprintf('%.2f', $row_top['metric'])
+		.'&nbsp;&nbsp;&nbsp;</td><td class="align-right">'.$row_top['old_ranking']
 		.'&nbsp;&nbsp;&nbsp;</td>'
-		.'<td align="right">';
+		.'<td class="align-right">';
 
 	// calculate change
 	$diff = $row_top["old_ranking"] - $row_top["ranking"];
@@ -89,10 +89,10 @@ while ($row_top = db_fetch_array($res_top)) {
 		print _('Same');
 	}
 	else if ($diff > 0) {
-		print "<span class=\"up\"".sprintf(_('Up %1$s'), $diff)."</span>";
+		print "<span class=\"up\"".sprintf(_('Up %s'), $diff)."</span>";
 	}
 	else if ($diff < 0) {
-		print "<span class=\"down\">".sprintf(_('Down %1$s'), (0-$diff))."</span>";
+		print "<span class=\"down\">".sprintf(_('Down %s'), (0-$diff))."</span>";
 	}
 
 	print '&nbsp;&nbsp;&nbsp;</td></tr>
@@ -113,5 +113,3 @@ $HTML->footer(array());
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
