@@ -11,13 +11,12 @@
 
 $no_gz_buffer=true;
 
-require_once('../env.inc.php');
+require_once '../env.inc.php';
 require_once $gfcommon.'include/pre.php';
 require_once $gfcommon.'tracker/Artifact.class.php';
 require_once $gfcommon.'tracker/ArtifactFile.class.php';
 require_once $gfcommon.'tracker/ArtifactType.class.php';
 
-
 $arr=explode('/',getStringFromServer('REQUEST_URI'));
 $group_id=(int)$arr[3];
 $atid=(int)$arr[4];
@@ -49,19 +48,21 @@ if ($ath->isError()) {
 $ah=new Artifact($ath,$aid);
 if (!$ah || !is_object($ah)) {
 	exit_error(_('Artifact Could Not Be Created'),'tracker');
-} else if ($ah->isError()) {
+} elseif ($ah->isError()) {
 	exit_error($ah->getErrorMessage(), 'tracker');
 } else {
 	$afh=new ArtifactFile($ah,$file_id);
 	if (!$afh || !is_object($afh)) {
 		exit_error(_('ArtifactFile Could Not Be Created'),'tracker');
-	} else if ($afh->isError()) {
+	} elseif ($afh->isError()) {
 		exit_error($afh->getErrorMessage(),'tracker');
 	} else {
-		Header ('Content-disposition: filename="'.str_replace('"', '', $afh->getName()).'"');
-		Header ("Content-type: ".$afh->getType());
-		echo $afh->getData();
+		Header('Content-disposition: filename="'.str_replace('"', '', $afh->getName()).'"');
+		/* SECURITY: do not serve as $afh->getType() but application/octet-stream */
+		header('X-Content-Type-Options: nosniff');
+		header('Content-Type: application/octet-stream');
+		header("Content-length: ".$afh->getSize());
+
+		readfile_chunked($afh->getFile());
 	}
 }
-
-?>
