@@ -22,38 +22,38 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('TroveCategoryLabel.class.php');
+require_once 'TroveCategoryLabel.class.php';
 
 // should extend observable
 class TroveCategory extends Error {
-	
+
 	/**
 	 * Associative array of data from db.
 	 *
 	 * @var	 array   $dataArray.
 	 */
 	var $dataArray;
-	
+
 	/**
 	 * Selected Trove category id
 	 *
 	 * @var int $categoryId
 	 */
 	var $categoryId;
-	
+
 	var $labels;
 	var $children;
 	var $parents;
 	var $parent;
-	
+
 	var $filter;
-	
+
 	/**
 	 *  Constructor.
 	 *
-	 * @param	int		The trove_cat_id.
-	 * @param	array		The associative array of data.
-	 * @return	boolean	success.
+	 * @param	bool|int			$categoryId		The trove_cat_id.
+	 * @param	bool|array	$dataArray		The associative array of data.
+	 * @return	bool	success.
 	 */
 	function TroveCategory($categoryId = false, $dataArray = false) {
 		if ($categoryId) {
@@ -61,22 +61,22 @@ class TroveCategory extends Error {
 			if (!$dataArray || !is_array($dataArray)) {
 				if (!$this->fetchData($categoryId)) {
 					$this->setError(_('Invalid Trove Category'),
-							_('That Trove category does not exist.').' '.db_error()
+							_('That Trove category does not exist').' '.db_error('SYS_DB_TROVE')
 					);
 				}
 			} else {
 				$this->dataArray =& $dataArray;
 			}
 		} else {
-			$this->setError(_('ERROR'), _('That Trove category does not exist.'));
+			$this->setError(_('Error'), _('That Trove category does not exist'));
 		}
 	}
-	
+
 	/**
 	 *  fetchData - re-fetch the data for this category from the database.
 	 *
-	 *  @param  int	 The category_id.
-	 *	@return	boolean	success.
+	 *  @param  int		$categoryId	The category_id.
+	 *	@return	bool	success.
 	 */
 	function fetchData($categoryId) {
 		$res = db_query_params('SELECT * FROM trove_cat	WHERE trove_cat_id=$1',
@@ -88,13 +88,13 @@ class TroveCategory extends Error {
 		db_free_result($res);
 		return true;
 	}
-	
+
 	function update($shortName, $fullName, $description) {
 		$shortName = trim($shortName);
 		$fullName = trim($fullName);
 		$description = trim($description);
 		if(empty($shortName) || empty($fullName)) {
-			$this->setError(_('ERROR'), _('Empty strings'));
+			$this->setError(_('Error'), _('Empty strings'));
 			return false;
 		} else {
 			db_begin();
@@ -103,10 +103,10 @@ class TroveCategory extends Error {
 					fullname=$2,
 					description=$3,
 					version=$4
-				WHERE trove_cat_id=$5", 
+				WHERE trove_cat_id=$5",
 				array(htmlspecialchars($shortName), htmlspecialchars($fullName), htmlspecialchars($description), date('Ymd',time())."01", $this->categoryId));
 			if(!$result || db_affected_rows($result) != 1) {
-				$this->setError(_('ERROR'), _('Cannot update'));
+				$this->setError(_('Error'), _('Cannot update'));
 				db_rollback();
 				return false;
 			} else {
@@ -116,11 +116,11 @@ class TroveCategory extends Error {
 			}
 		}
 	}
-	
+
 	function getId() {
 		return $this->categoryId;
 	}
-	
+
 	// returns a localized label if available
 	function & getLabel($languageId) {
 		if(!isset($this->labels)) {
@@ -133,7 +133,7 @@ class TroveCategory extends Error {
 			return $this->labels;
 		}
 	}
-	
+
 	function getLocalizedLabel() {
 		$languageId = choose_language_from_context();
 		$label = $this->getLabel($languageId);
@@ -143,14 +143,14 @@ class TroveCategory extends Error {
 			return $this->getFullName();
 		}
 	}
-	
+
 	function &getLabels() {
 		if(!isset($this->labels)) {
 			$this->labels = array();
-			$res = db_query_params("SELECT  trove_category_labels.*, supported_languages.name AS language_name FROM trove_category_labels, supported_languages  
-																WHERE category_id=$1 AND supported_languages.language_id=trove_category_labels.language_id", 
-																array($this->cathergoryId));
-			
+			$res = db_query_params("SELECT  trove_category_labels.*, supported_languages.name AS language_name FROM trove_category_labels, supported_languages
+																WHERE category_id=$1 AND supported_languages.language_id=trove_category_labels.language_id",
+																array($this->categoryId));
+
 			if (!$res) {
 				return $this->labels;
 			}
@@ -161,27 +161,27 @@ class TroveCategory extends Error {
 		}
 		return $this->labels;
 	}
-	
+
 	function &getParents() {
 		return $this->parents;
 	}
-	
+
 	function &getChildren() {
 		if(!isset($this->children)) {
 			$this->children = array();
-			
+
 			$result = db_query_params("
 				SELECT trove_cat.*,
 				trove_treesums.subprojects AS subprojects
-				FROM trove_cat LEFT JOIN trove_treesums USING (trove_cat_id) 
+				FROM trove_cat LEFT JOIN trove_treesums USING (trove_cat_id)
 				WHERE (
-					trove_treesums.limit_1=0 
+					trove_treesums.limit_1=0
 					OR trove_treesums.limit_1 IS NULL
 				)
 				AND trove_cat.parent=$1
 				ORDER BY fullname",
-				array($this->categoryId), -1, 0, SYS_DB_TROVE);
-			
+				array($this->categoryId), -1, 0, 'SYS_DB_TROVE');
+
 			if(!$result) {
 				$this->setError();
 				return false;
@@ -193,7 +193,7 @@ class TroveCategory extends Error {
 		}
 		return $this->children;
 	}
-	
+
 	function getRootParentId() {
 		return $this->dataArray['root_parent'];
 	}
@@ -201,19 +201,19 @@ class TroveCategory extends Error {
 	function getFullName() {
 		return $this->dataArray['fullname'];
 	}
-	
+
 	function getShortName() {
 		return $this->dataArray['shortname'];
 	}
-	
+
 	function getDescription() {
 		return $this->dataArray['description'];
 	}
-	
+
 	function getSubProjectsCount() {
 		return ($this->dataArray['subprojects'] ? $this->dataArray['subprojects'] : 0);
 	}
-	
+
 	function setFilter($filterArray) {
 		$this->filter = $filterArray;
 	}
@@ -221,7 +221,7 @@ class TroveCategory extends Error {
 	function getProjects($offset) {
 		$qpa = db_constract_qpa () ;
 		$qpa = db_construct_qpa ($qpa, 'SELECT * FROM trove_agg') ;
-		
+
 		for($i = 0, $count = sizeof($this->filter); $i < $count; $i++) {
 			$qpa = db_construct_qpa ($qpa,
 						 ", trove_agg trove_agg_$i") ;
@@ -239,16 +239,14 @@ class TroveCategory extends Error {
 
 		$qpa = db_construct_qpa ($qpa,
 					 'ORDER BY trove_agg.trove_cat_id ASC, trove_agg.ranking ASC') ;
-		
+
 		$result = db_query_qpa ($qpa, TROVE__PROJECTS_PER_PAGE, $offset);
 		return $result;
 	}
-	
+
 }
 
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"
 // End:
-
-?>
