@@ -71,7 +71,7 @@ class TroveCategoryLabel extends Error {
 			// set error
 			return false;
 		}
-		
+
 		db_begin();
 		$result = db_query_params("INSERT INTO trove_category_labels
 			(category_id, label, language_id) VALUES ($1, $2, $3)",
@@ -84,11 +84,12 @@ class TroveCategoryLabel extends Error {
 		$this->labelId = db_insertid($result, 'trove_category_labels', 'label_id');
 		$this->fetchData($this->labelId);
 		db_commit();
+		return true;
 	}
 
 	function update() {
 	}
-	
+
 	function fetchData($labelId) {
 		$res=db_query_params("SELECT trove_category_labels.*, supported_languages.name AS language_name FROM trove_category_labels, supported_languages "
 			. "WHERE trove_category_labels.label_id=$1 "
@@ -107,7 +108,7 @@ class TroveCategoryLabel extends Error {
 	function remove() {
 		db_begin();
 		$res = db_query_params("DELETE FROM trove_category_labels WHERE label_id=$1", array($this->labelId));
-		if(!res || db_affected_rows($res) != 1) {
+		if(!$res || db_affected_rows($res) != 1) {
 			// $this->setError();
 			db_rollback();
 			return false;
@@ -124,15 +125,13 @@ class TroveCategoryLabel extends Error {
 	function getLabel() {
 		return $this->dataArray['label'];
 	}
-	
+
 	function getLanguageId() {
 		return $this->dataArray['language_id'];
 	}
-	
+
 	function getLanguageName() {
 		return $this->dataArray['language_name'];
 	}
 
 }
-
-?>
