@@ -21,14 +21,14 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-require_once('../env.inc.php');
-require_once('pre.php');
-require_once('trove.php');
+require_once '../env.inc.php';
+require_once 'pre.php';
+require_once 'trove.php';
 
-require_once('common/include/escapingUtils.php');
-require_once('TroveCategory.class.php');
-require_once('TroveCategoryFactory.class.php');
-require_once('include/utils.php');
+require_once 'common/include/escapingUtils.php';
+require_once 'TroveCategory.class.php';
+require_once 'TroveCategoryFactory.class.php';
+require_once 'include/utils.php';
 
 if (!forge_get_config('use_trove')) {
 	exit_disabled();
@@ -55,7 +55,7 @@ if($filter) {
 
 	// check and clean the array
 	$filterArray = explode(',', $filter);
-	$cleanArray = array();	
+	$cleanArray = array();
 	$count = max(6, sizeof($filterArray));
 	for ($i = 0; $i < $count; $i++) {
 		if(is_numeric($filterArray[$i]) && $filterArray[$i] != 0) {
@@ -65,9 +65,9 @@ if($filter) {
 	$filterArray = array_unique($cleanArray);
 	if(!empty($filterArray)) {
 		$filterCategories = TroveCategoryFactory::getCategories($filterArray);
-	
+
 		echo '<p><span style="color:red;">'._('Limiting View').'</span>';
-		
+
 		for($i=0, $count = sizeof($filterCategories); $i < $count; $i++) {
 			$filterCategory =& $filterCategories[$i];
 			echo '<br /> &nbsp; &nbsp; &nbsp; '
@@ -76,33 +76,33 @@ if($filter) {
 				.getFilterUrl($filterArray, $filterCategory->getId()).'">['._('Remove Filter').']'
 				.'</a>';
 		}
-	
+
 		echo '</p><hr />';
 	}
-	
+
 	$category->setFilter($filterArray);
 }
 
 // We display the trove
 
 ?>
-<table width="100%" border="0" cellspacing="0" cellpadding="0">
-	<tr valign="top">
-		<td width="50%">
+<table class="fullwidth">
+	<tr class="top">
+		<td class="halfwidth">
 		<?php
 			// here we print list of root level categories, and use open folder for current
 			$rootCategories = TroveCategoryFactory::getRootCategories();
 			echo _('Browse By').':';
 			for($i = 0, $count = sizeof($rootCategories); $i < $count; $i++) {
 				$rootCategory =& $rootCategories[$i];
-				
+
 				// print open folder if current, otherwise closed
 				// also make anchor if not current
 
 				echo '<br />';
 				if (($rootCategory->getId() == $category->getRootParentId())
 					|| ($rootCategory->getId() == $category->getId())) {
-					
+
 					echo html_image('ic/ofolder15.png','15','13',array());
 					echo '&nbsp; <strong>'.$rootCategory->getLocalizedLabel().'</strong>';
 				} else {
@@ -114,7 +114,7 @@ if($filter) {
 			}
 		?>
 		</td>
-		<td width="50%">
+		<td class="halfwidth">
 		<?php
 			$currentIndent='';
 			$parentCategories =& $category->getParents();
@@ -136,20 +136,20 @@ if($filter) {
 				}
 				echo '<br />';
 			}
-			
+
 			$childrenCategories =& $category->getChildren();
-			
+
 			$currentIndent .= str_repeat(' &nbsp; ', sizeof($parentCategories) * 2);
-			
+
 			for($i = 0, $count = sizeof($childrenCategories); $i < $count; $i++) {
 				$childCategory =& $childrenCategories[$i];
-				
+
 				echo $currentIndent;
 				echo '<a href="?form_cat='.$childCategory->getId().@$discrim_url.'">';
 				echo html_image('ic/cfolder15.png', '15', '13', array());
 				echo '&nbsp; '.$childCategory->getLocalizedLabel().'</a>';
 				echo ' <em>('
-					.sprintf(_('%1$s projects'), $childCategory->getSubProjectsCount())
+					.sprintf(_('%s projects'), $childCategory->getSubProjectsCount())
 					.')</em><br />';
 			}
 		?>
@@ -199,10 +199,10 @@ $html_limit .= '</span>';
 
 print $html_limit."<hr />\n";
 
-?><table border="0" cellpadding="0" width="100%"><?php
+?><table class="fullwidth"><?php
 while($project = db_fetch_array($projectsResult)) {
 	?>
-		<tr valign="top">
+		<tr class="top">
 			<td colspan="2"><?php
 	echo $count.'. ' ;
 	echo util_make_link_g ($project['unix_group_name'],
@@ -215,12 +215,12 @@ while($project = db_fetch_array($projectsResult)) {
 			<br />&nbsp;
 			</td>
 		</tr>
-		<tr valign="top">
+		<tr class="top">
 			<td><?php
 				// list all trove categories
 				//print trove_getcatlisting($row_grp['group_id'],1,0);
 			?></td>
-			<td align="right">
+			<td class="align-right">
 				Activity Percentile: <strong><?php echo number_format($project['percentile'],2) ?></strong>
 				<br />Activity Ranking: <strong><?php echo number_format($project['ranking'],2) ?></strong>
 				<br />Register Date: <strong><?php echo date($sys_datefmt, $project['register_time']) ?></strong>
@@ -239,5 +239,3 @@ if ($querytotalcount > $TROVE_BROWSELIMIT) {
 }
 
 $HTML->footer(array());
-
-?>
